(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[   1041853,      20050]
NotebookOptionsPosition[   1018708,      19282]
NotebookOutlinePosition[   1019240,      19302]
CellTagsIndexPosition[   1019197,      19299]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Chapter 9 Basic elastostatics (p. 139)\
\>", "Title",
 CellChangeTimes->{
  3.4175782754452877`*^9, {3.501833180366854*^9, 3.5018331880152917`*^9}, {
   3.5872838544732122`*^9, 3.587283857464639*^9}}],

Cell[BoxData[
 RowBox[{"<<", "Lautrup`"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4110371734305925`*^9, 3.411037179186592*^9}, 
   3.4791895782650003`*^9, 3.479190676333*^9, {3.479200154432*^9, 
   3.479200163918*^9}, {3.4846278439807262`*^9, 3.4846278475309296`*^9}, {
   3.5054095051518087`*^9, 3.5054095120562034`*^9}, {3.505410919608711*^9, 
   3.505410928023192*^9}, {3.5054109694335604`*^9, 3.5054109722087193`*^9}, 
   3.5759597070987153`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 9.1 Equations of elastostatics (p. 139)\
\>", "Title",
 CellChangeTimes->{{3.501833777560012*^9, 3.501833792246852*^9}, {
  3.587283859361807*^9, 3.5872838733925943`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Example 9.1 Deformation of the legs of a chair (p. 141)\
\>", "Section",
 CellChangeTimes->{{3.501833815224166*^9, 3.501833823078615*^9}, {
  3.5872838901537313`*^9, 3.5872838979527073`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(11\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575542381781667*^9, 3.5756891453182716`*^9, 3.5757928364963923`*^9, 
   3.5758707765130653`*^9, {3.575870853250655*^9, 3.5758708818122807`*^9}, 
   3.5758710302439184`*^9, 3.5758710738443546`*^9, 3.5758711121961727`*^9, {
   3.5758711469835787`*^9, 3.575871156485753*^9}, 3.575871197027822*^9, {
   3.575871236923832*^9, 3.5758712637051945`*^9}, 3.5759538385938272`*^9, 
   3.575959728701434*^9, 3.5764883014180756`*^9, 3.586581323430375*^9, 
   3.5872839439514685`*^9, 3.5872866221397295`*^9, 3.587286709147688*^9, 
   3.5873503630587025`*^9}]
}, Open  ]],

Cell["Parameters", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["g", "0"], "=", "AccelerationDueToGravity"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"70", " ", "Kilogram"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"30", " ", 
    SuperscriptBox["Centimeter", "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"50", " ", "Centimeter"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{
    SuperscriptBox["10", "9"], "Pascal"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5018339003310337`*^9, 3.5018339005460463`*^9}, {
  3.5872839247380733`*^9, 3.587283925210129*^9}}],

Cell["Stress", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "=", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"M", " ", 
      SubscriptBox["g", "0"]}], "A"], "//", 
    RowBox[{"ToUnit", "[", "Bar", "]"}]}], "//", "N"}]}]], "Input",
 CellChangeTimes->{{3.501833861867834*^9, 3.501833862275857*^9}}],

Cell[BoxData[
 TemplateBox[{"2.2882183333333335`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"bars\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: bars"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Bars\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542382018693*^9, 3.575870777158103*^9, 3.5758711567857695`*^9, 
   3.5758711973198614`*^9, {3.5758712372169275`*^9, 3.575871263836265*^9}, 
   3.5759538387138453`*^9, 3.5764883015391297`*^9, 3.5865813235503473`*^9, 
   3.587283944069471*^9, 3.587286622318741*^9, 3.587286709363714*^9, 
   3.5873503632536907`*^9}]
}, Open  ]],

Cell["Deformation", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "=", 
  RowBox[{
   FractionBox["P", "EE"], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.5872839292666283`*^9, 3.587283929604686*^9}}],

Cell[BoxData["0.00022882183333333337`"], "Output",
 CellChangeTimes->{
  3.5755423821447096`*^9, 3.5758707772441287`*^9, 3.5758711568617945`*^9, 
   3.575871197390909*^9, {3.5758712372958784`*^9, 3.575871263900219*^9}, 
   3.5759538387778716`*^9, 3.5764883016101336`*^9, 3.586581323616355*^9, 
   3.5872839441334944`*^9, 3.587286622403805*^9, 3.587286709464689*^9, 
   3.587350363337742*^9}]
}, Open  ]],

Cell["Displacement", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "=", 
  RowBox[{
   RowBox[{"uu", " ", "L"}], "//", 
   RowBox[{"ToUnit", "[", "Millimeter", "]"}]}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"0.11441091666666668`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"mm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: millimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Millimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542382193715*^9, 3.575870777377133*^9, 3.575871156990834*^9, 
   3.5758711975188837`*^9, {3.5758712374249353`*^9, 3.5758712639192214`*^9}, 
   3.5759538388238974`*^9, 3.5764883016301355`*^9, 3.586581323641362*^9, 
   3.5872839441534863`*^9, 3.5872866224408007`*^9, 3.5872867095097313`*^9, 
   3.587350363373707*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 9.2 Gravitational settling of a tall building (p. 141)\
\>", "Section",
 CellChangeTimes->{{3.5018339883520684`*^9, 3.501834001774836*^9}, {
  3.5872839763055487`*^9, 3.5872839795289516`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(8\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.575542382475748*^9, 3.57587077756817*^9, 3.5758711571478567`*^9, 
   3.575871197667945*^9, {3.5758712375749164`*^9, 3.575871264059239*^9}, 
   3.575953839008879*^9, 3.5764883017881165`*^9, 3.5865813238034177`*^9, 
   3.587283983482435*^9, 3.587286622631782*^9, 3.5872867097147264`*^9, 
   3.587350363543764*^9}]
}, Open  ]],

Cell["Parameters", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["g", "0"], "=", "AccelerationDueToGravity"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"63", "*", "63", " ", 
    SuperscriptBox["Meter", "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"413.0", " ", "Meter"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{"100", " ", 
    RowBox[{"Kilogram", "/", 
     SuperscriptBox["Meter", "3"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"2", " ", 
    SuperscriptBox["10", "11"], "Pascal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", "0.01"}], ";"}]}], "Input"],

Cell["Mass of building", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"M", "=", 
  RowBox[{
   RowBox[{"A", " ", "L", " ", "\[Rho]"}], "//", "ToSI"}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"1.639197`*^8"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"kg\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilograms"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilograms\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755423828427935`*^9, 3.5758707777522726`*^9, 3.575871157327865*^9, 
   3.575871197844036*^9, {3.5758712377519493`*^9, 3.5758712641922555`*^9}, 
   3.5759538391388955`*^9, 3.576488301927134*^9, 3.5865813239374423`*^9, 
   3.5872839836484537`*^9, 3.587286622779808*^9, 3.587286709871789*^9, 
   3.5873503636917844`*^9}]
}, Open  ]],

Cell["Stress", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"M", " ", 
     SubscriptBox["g", "0"]}], 
    RowBox[{"f", " ", "A"}]], "//", 
   RowBox[{"ToUnit", "[", "Pascal", "]"}]}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"4.05014645`*^7"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"Pa\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: pascals"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Pascals\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542383042816*^9, 3.575870777830223*^9, 3.57587115740889*^9, 
   3.5758711979809446`*^9, {3.575871237904955*^9, 3.575871264284269*^9}, 
   3.575953839237908*^9, 3.5764883020341487`*^9, 3.586581324043451*^9, 
   3.587283983744468*^9, 3.587286622892813*^9, 3.5872867099947596`*^9, 
   3.587350363804802*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "//", 
  RowBox[{"ToUnit", "[", "Bar", "]"}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"405.01464500000003`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"bars\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: bars"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Bars\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542383078822*^9, 3.5758707778592453`*^9, 3.5758711574318933`*^9, 
   3.575871198004984*^9, {3.575871237928975*^9, 3.57587126430527*^9}, 
   3.5759538392549314`*^9, 3.576488302051153*^9, 3.5865813240654526`*^9, 
   3.587283983765459*^9, 3.5872866229308553`*^9, 3.587286710039773*^9, 
   3.5873503638368006`*^9}]
}, Open  ]],

Cell["Deformation scale", "Text",
 CellChangeTimes->{{3.587284287384573*^9, 3.5872842912401114`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DD", "=", 
  RowBox[{
   FractionBox[
    RowBox[{"f", "  ", "EE"}], 
    RowBox[{"\[Rho]", " ", 
     SubscriptBox["g", "0"]}]], "//", 
   RowBox[{"ToUnit", "[", "Kilometer", "]"}]}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"2039.4324259558566`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"km\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542383395859*^9, 3.575870778151258*^9, 3.575871157726887*^9, 
   3.5758711983059826`*^9, {3.575871238223998*^9, 3.5758712644592896`*^9}, 
   3.5759538394079294`*^9, 3.5764883022141733`*^9, 3.586581324223476*^9, 
   3.5872839839214954`*^9, 3.5872866230988665`*^9, 3.587286710215778*^9, 
   3.587350364006783*^9}]
}, Open  ]],

Cell["Strain range", "Text",
 CellChangeTimes->{{3.5872843010963345`*^9, 3.58728430583191*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["L", "DD"], "//", "ToSI"}]], "Input"],

Cell[BoxData["0.00020250732249999998`"], "Output",
 CellChangeTimes->{
  3.5755423834908695`*^9, 3.5758707782622395`*^9, 3.5758711579059277`*^9, 
   3.575871198419037*^9, {3.575871238336012*^9, 3.575871264563302*^9}, 
   3.5759538394949846`*^9, 3.5764883022631793`*^9, 3.5865813242704887`*^9, 
   3.5872839839695487`*^9, 3.587286623166891*^9, 3.587286710373845*^9, 
   3.5873503640688295`*^9}]
}, Open  ]],

Cell["\<\
Vertical displacement of bulding\
\>", "Text",
 CellChangeTimes->{{3.5872843566243486`*^9, 3.587284361695939*^9}, {
  3.5872852703839836`*^9, 3.5872852717191668`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   SuperscriptBox["L", "2"], "DD"], "//", 
  RowBox[{"ToUnit", "[", "Centimeter", "]"}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"8.36355241925`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"cm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: centimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Centimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755423836898937`*^9, 3.575870778565277*^9, 3.575871158229988*^9, 
   3.575871198727039*^9, {3.5758712386450477`*^9, 3.5758712646263103`*^9}, 
   3.5759538395539894`*^9, 3.576488302376191*^9, 3.5865813243714952`*^9, 
   3.587283984031461*^9, 3.5872866232949123`*^9, 3.5872867104668245`*^9, 
   3.5873503641898484`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Figure 9.1 Saint-Venant\[CloseCurlyQuote]s principle (p. 142)\
\>", "Section",
 CellChangeTimes->{{3.501834248726961*^9, 3.5018342517111316`*^9}, {
  3.587285348550826*^9, 3.5872853647109656`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.411362505760398*^9, 3.4113625084573984`*^9}, 
   3.501833221711219*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(9\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.575542383967928*^9, 3.5758707787593436`*^9, 3.575871158381012*^9, {
   3.5758712387940664`*^9, 3.575871264773329*^9}, 3.575953839706967*^9, 
   3.576488302537211*^9, 3.586581324535491*^9, {3.5872866081059885`*^9, 
   3.5872866234908905`*^9}, 3.5872867106728725`*^9, 3.5872867861763344`*^9, 
   3.587286884687688*^9, 3.5872869371942787`*^9, 3.587286977160318*^9, 
   3.587287013820902*^9, 3.587349504796937*^9, 3.5873500509184685`*^9, 
   3.5873503643638687`*^9}]
}, Open  ]],

Cell["Comsol  image", "Text",
 CellChangeTimes->{{3.503382245307773*^9, 3.5033822532582283`*^9}, 
   3.5872865159014206`*^9, {3.5873498899733143`*^9, 3.587349891116436*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"image", "=", 
  RowBox[{
  "Import", "[", "\"\<data/elastostatics.saintvenantprincipleimage.jpg\>\"", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.411366449520133*^9, 3.411366458150133*^9}, {
   3.4113681681011333`*^9, 3.4113681901871333`*^9}, {3.412527021929*^9, 
   3.412527024943*^9}, {3.4791416935880003`*^9, 3.47914169552*^9}, 
   3.5018332217172194`*^9, {3.501833359483099*^9, 3.5018333756100216`*^9}, {
   3.5033799395338907`*^9, 3.5033799476693563`*^9}, {3.503382383070653*^9, 
   3.503382395653373*^9}, {3.503382900764263*^9, 3.5033829409255605`*^9}, {
   3.505372630886287*^9, 3.5053726438540287`*^9}, {3.5872862621195335`*^9, 
   3.5872862631267242`*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs3XlcFHeaP3DwABE8EjUxUU4F5VDwxBMUGpBLDhGvaDxBMIiIV06NSbwA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    "], {{0, 382}, {1616, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSizeRaw->{1616, 382},
  PlotRange->{{0, 1616}, {0, 382}}]], "Output",
 CellChangeTimes->{
  3.575542384923044*^9, 3.575870779447388*^9, 3.5758711586590023`*^9, {
   3.57587123913811*^9, 3.575871265051364*^9}, 3.575953841375177*^9, 
   3.576488303831382*^9, 3.586581324647528*^9, 3.5872857407430687`*^9, 
   3.587286263978773*^9, {3.587286608261977*^9, 3.5872866235719366`*^9}, 
   3.5872867107699027`*^9, 3.5872867862583847`*^9, 3.5872868848517065`*^9, 
   3.587286937329324*^9, 3.587286977310361*^9, 3.5872870139569197`*^9, 
   3.5873495057450137`*^9, 3.587350051077503*^9, 3.587350364445837*^9}]
}, Open  ]],

Cell["Construct image data", "Text",
 CellChangeTimes->{{3.5872865481814823`*^9, 3.58728655751766*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageDimensions", "[", "image", "]"}]], "Input",
 CellChangeTimes->{{3.587286696215064*^9, 3.5872867035259833`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1616", ",", "382"}], "}"}]], "Output",
 CellChangeTimes->{{3.5872867046211348`*^9, 3.587286710854858*^9}, 
   3.5872867863253703`*^9, 3.587286884935717*^9, 3.5872869374053154`*^9, 
   3.5872869773953304`*^9, 3.5872870140289307`*^9, 3.587349505898032*^9, 
   3.587350051147552*^9, 3.5873503645228844`*^9}]
}, Open  ]],

Cell["Coordinates of image rectangle", "Text",
 CellChangeTimes->{{3.5873493385740595`*^9, 3.5873494093089743`*^9}, 
   3.5873503351081743`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"zmin", ",", "rmin"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"zmax", ",", "rmax"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"1499", ",", "327"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"zsize", "=", 
   RowBox[{"zmax", "-", "zmin"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rsize", "=", 
   RowBox[{"rmax", "-", "rmin"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.411373411406133*^9, 3.4113734762451334`*^9}, {
   3.4113784076879997`*^9, 3.411378479131*^9}, 3.41137856476*^9, {
   3.411378881038*^9, 3.411378901821*^9}, {3.411379390233*^9, 
   3.4113794076879997`*^9}, {3.4113869609476075`*^9, 
   3.4113869937406073`*^9}, {3.4113873264726076`*^9, 
   3.4113873267496076`*^9}, {3.4113873592686076`*^9, 
   3.4113873785006075`*^9}, {3.411387426371608*^9, 3.4113874301156073`*^9}, {
   3.4113875113606076`*^9, 3.4113875116246076`*^9}, {3.411905931930397*^9, 
   3.4119059384243965`*^9}, {3.411905968616397*^9, 3.411905978892397*^9}, {
   3.41196100368804*^9, 3.4119610373260393`*^9}, {3.4120707878450003`*^9, 
   3.412070804708*^9}, {3.412144583785*^9, 3.412144599288*^9}, {
   3.412145012457*^9, 3.4121450516400003`*^9}, {3.412149630665*^9, 
   3.412149660568*^9}, {3.412527226407*^9, 3.412527260094*^9}, {
   3.4125275332349997`*^9, 3.4125275659709997`*^9}, 3.412527894955*^9, 
   3.412528040773*^9, {3.419573953399*^9, 3.4195739790629997`*^9}, {
   3.479142066356*^9, 3.479142095043*^9}, {3.503379271215665*^9, 
   3.503379286726552*^9}, {3.503379406511403*^9, 3.503379409718587*^9}, {
   3.5033795122464514`*^9, 3.503379515478636*^9}, {3.503379558519098*^9, 
   3.5033795607662263`*^9}, {3.503379623319804*^9, 3.5033796337504005`*^9}, {
   3.503380090183507*^9, 3.503380099016012*^9}, {3.5033801423024883`*^9, 
   3.5033801542141695`*^9}, {3.503382521160551*^9, 3.503382521502571*^9}, {
   3.5033825534313965`*^9, 3.503382554022431*^9}, {3.5033826099436293`*^9, 
   3.5033826290067196`*^9}, {3.5033829772236366`*^9, 
   3.5033829863901606`*^9}, {3.503383092768245*^9, 3.5033831042779036`*^9}, {
   3.587286833278231*^9, 3.5872868436055827`*^9}, {3.587287008550268*^9, 
   3.587287009030327*^9}}],

Cell[CellGroupData[{

Cell["\<\
Construct image with coordinate axes and ticks\
\>", "Subsection",
 CellChangeTimes->{{3.5873494340780525`*^9, 3.587349442197109*^9}, {
  3.5873496244129486`*^9, 3.587349633717189*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zticks", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"#", " ", 
         RowBox[{"zsize", "/", "4"}]}], "//", "N"}], ",", "#"}], "}"}], "&"}],
     ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "2", ",", "3", ",", "4"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.503382649836911*^9, 3.5033826964765787`*^9}, {
  3.5033827464614377`*^9, 3.503382821493729*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"374.5`", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"749.`", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1123.5`", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1498.`", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755423854711094`*^9, 3.5758707795624027`*^9, 3.575871158777027*^9, {
   3.5758712392561245`*^9, 3.5758712650754285`*^9}, 3.575953841532198*^9, 
   3.576488304221471*^9, 3.5865813246735315`*^9, {3.5872866084250245`*^9, 
   3.587286623751963*^9}, 3.5872867110248957`*^9, 3.5872867864884005`*^9, 
   3.5872868851197405`*^9, 3.587286937568365*^9, 3.5872869775443506`*^9, 
   3.58728701419199*^9, 3.587349506090056*^9, 3.587350051319518*^9, 
   3.5873503645678525`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rticks", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"rmax", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.503383132068493*^9, 3.503383174029893*^9}, {
  3.5873494952627544`*^9, 3.587349536933929*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"image", ",", 
    RowBox[{"Axes", "\[Rule]", "True"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<z\>\"", ",", "\"\<r\>\""}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"zticks", ",", "rticks"}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", 
     RowBox[{"1", "/", "3.7"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<elastostatics-saintvenantprinciple\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5033828399927874`*^9, 3.5033828415198746`*^9}, {
  3.503383124585065*^9, 3.5033831250310907`*^9}, {3.503383179001178*^9, 
  3.5033832085778694`*^9}, {3.503383244345915*^9, 3.5033832449929523`*^9}, {
  3.503383335308118*^9, 3.50338335684935*^9}, {3.5033834208260093`*^9, 
  3.50338350737696*^9}, {3.505372659063899*^9, 3.5053726729116907`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.5755423867892675`*^9, 3.57587077987644*^9, 3.575871158996086*^9, {
   3.575871239410161*^9, 3.5758712652314243`*^9}, 3.575953841885273*^9, 
   3.5764883043894444`*^9, 3.586581324818548*^9, {3.587286608585083*^9, 
   3.5872866239309435`*^9}, 3.5872867112009015`*^9, 3.587286786664379*^9, 
   3.587286885303788*^9, 3.5872869377393475`*^9, 3.587286977712407*^9, 
   3.58728701436497*^9, {3.5873495062730813`*^9, 3.5873495338795834`*^9}, 
   3.587350051495559*^9, 3.5873503647399426`*^9}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzs3ed3U+e2P/p9xx3j/h/35R2/8xtnnP9gnw2WgvbBQEIICaEEjG3JTTI9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   "], {{0, 0}, {1616, 382}}, {0, 255},
   ColorFunction->RGBColor],
  AspectRatio->0.27027027027027023`,
  Axes->True,
  AxesLabel->{
    FormBox["\"z\"", TraditionalForm], 
    FormBox["\"r\"", TraditionalForm]},
  ImageSize->Large,
  PlotRange->{{0, 1616}, {0, 382}},
  Ticks->{{{0., 
      FormBox["0", TraditionalForm]}, {374.5, 
      FormBox["1", TraditionalForm]}, {749., 
      FormBox["2", TraditionalForm]}, {1123.5, 
      FormBox["3", TraditionalForm]}, {1498., 
      FormBox["4", TraditionalForm]}}, {{0., 
      FormBox["0", TraditionalForm]}, {327, 
      FormBox["1", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.57554238682327*^9, 3.575870779890443*^9, 3.575871159008046*^9, {
   3.575871239422146*^9, 3.5758712652433863`*^9}, 3.5759538419042454`*^9, 
   3.576488304398445*^9, 3.5865813248275623`*^9, {3.587286608649026*^9, 
   3.5872866239949846`*^9}, 3.5872867112319183`*^9, 3.5872867866973977`*^9, 
   3.5872868853328323`*^9, 3.5872869377694035`*^9, 3.587286977775424*^9, 
   3.5872870143949723`*^9, {3.5873495063381014`*^9, 3.587349533941554*^9}, 
   3.587350051526557*^9, 3.5873503648129034`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 9.2 Application: Standing up to gravity (p. 142)\
\>", "Title",
 CellChangeTimes->{{3.4110306750625925`*^9, 3.4110306890525923`*^9}, {
  3.501834554369443*^9, 3.5018345747746096`*^9}, {3.587349660166437*^9, 
  3.5873496687575083`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Figure 9.2 Settling of block (p. 144)\
\>", "Section",
 CellChangeTimes->{{3.4111932007372103`*^9, 3.4111932053982105`*^9}, {
  3.411387756362608*^9, 3.411387761850608*^9}, {3.501834766799593*^9, 
  3.5018347685026903`*^9}, {3.5018349053195157`*^9, 3.5018349081426773`*^9}, {
  3.503397777139143*^9, 3.5033977915379667`*^9}, {3.587349673326091*^9, 
  3.587349682405198*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4110306922375927`*^9, 3.411030694943592*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(10\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575542441807868*^9, 3.5758712911466403`*^9, 3.586581325015544*^9, 
   3.5873504819575977`*^9, {3.587350861828291*^9, 3.587350887708584*^9}, 
   3.587350992524746*^9, 3.5873529395255938`*^9}]
}, Open  ]],

Cell["Comsol image", "Text",
 CellChangeTimes->{{3.503387268939109*^9, 3.5033872827388983`*^9}, {
  3.5033873559800873`*^9, 3.5033873633385077`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"raw", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<data/elastostatics.settlingimage.jpg\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4110326737885923`*^9, 3.4110327253925924`*^9}, {
   3.4113068942451897`*^9, 3.41130692007719*^9}, 3.41130706636419*^9, {
   3.4124999588570004`*^9, 3.412499963255*^9}, {3.4125000226359997`*^9, 
   3.412500046826*^9}, {3.4125000783450003`*^9, 3.4125000834960003`*^9}, 
   3.412500153597*^9, {3.4125027437209997`*^9, 3.41250274956*^9}, {
   3.412524232717*^9, 3.412524236947*^9}, {3.4125266848120003`*^9, 
   3.412526703002*^9}, {3.479200259168*^9, 3.479200259756*^9}, {
   3.492948328252752*^9, 3.4929483296588326`*^9}, {3.501834607931506*^9, 
   3.501834613905848*^9}, {3.503383748102728*^9, 3.503383753047011*^9}, {
   3.5033839812400627`*^9, 3.503384050726037*^9}, {3.5033849143514338`*^9, 
   3.5033849449511843`*^9}, {3.503385344079013*^9, 3.503385349207306*^9}, {
   3.503385723934739*^9, 3.5033857246217785`*^9}, 3.5033857794389143`*^9, 
   3.5033862499428253`*^9, 3.5033864823751197`*^9, {3.503387438311796*^9, 
   3.503387438861828*^9}, {3.503387853734557*^9, 3.5033878847583313`*^9}, {
   3.5033879529272304`*^9, 3.503387953711275*^9}, {3.503388168975588*^9, 
   3.50338817478292*^9}, {3.5033898773763027`*^9, 3.5033898893339863`*^9}, {
   3.5033908750313654`*^9, 3.50339094470235*^9}, {3.503390976308158*^9, 
   3.503390980038371*^9}, {3.5033915548952513`*^9, 3.503391579414654*^9}, {
   3.505371969310447*^9, 3.505371977541918*^9}, {3.505372012477916*^9, 
   3.5053720415575795`*^9}, 3.5053722156065345`*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvXm3Hsdxp+lZ/piPMfNRZj5CzyfoPmfmdLs9091222q7vUyb2izJEiVK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    "], {{0, 450}, {288, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSizeRaw->{288, 450},
  PlotRange->{{0, 288}, {0, 450}}]], "Output",
 CellChangeTimes->{
  3.575542442080902*^9, 3.5758712913126965`*^9, 3.586581325154591*^9, 
   3.587350482094631*^9, {3.587350861940344*^9, 3.587350887806589*^9}, 
   3.587350992632758*^9, 3.587352939643609*^9}]
}, Open  ]],

Cell["Image size", "Text",
 CellChangeTimes->{{3.5033917558747463`*^9, 3.5033917623641176`*^9}, {
   3.5033954798847475`*^9, 3.5033954834269505`*^9}, 3.5033955641995707`*^9, {
   3.5873510942595367`*^9, 3.587351096290766*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"xsize", ",", "zsize"}], "}"}], "=", 
  RowBox[{"ImageDimensions", "[", "raw", "]"}]}]], "Input",
 CellChangeTimes->{{3.5033875457199397`*^9, 3.503387552621334*^9}, {
   3.5033879590855827`*^9, 3.503387984181018*^9}, {3.503388178470131*^9, 
   3.503388186741604*^9}, 3.50339105292554*^9, {3.503391633781763*^9, 
   3.503391642260248*^9}, {3.5033917818382316`*^9, 3.503391800549302*^9}, {
   3.5033918373354063`*^9, 3.5033918394375257`*^9}, {3.503391871207343*^9, 
   3.5033918798698387`*^9}, {3.503391924568395*^9, 3.503391954598113*^9}, {
   3.503392079501257*^9, 3.503392080463312*^9}, {3.5033922061274996`*^9, 
   3.503392216053067*^9}, {3.503392269303113*^9, 3.50339227118122*^9}, {
   3.5033923179818974`*^9, 3.503392318429923*^9}, {3.5033925974238806`*^9, 
   3.5033925978469048`*^9}, {3.5033929235345325`*^9, 3.503392926534704*^9}, {
   3.5033929604626455`*^9, 3.503393028541539*^9}, {3.5033930937992716`*^9, 
   3.503393122517914*^9}, {3.503393266422145*^9, 3.503393266998178*^9}, 
   3.503394950711481*^9, 3.503395333854395*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"288", ",", "450"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755424421199045`*^9, 3.5758712913416767`*^9, 3.586581325688659*^9, 
   3.5873504821196322`*^9, {3.5873508619703674`*^9, 3.587350887834587*^9}, 
   3.587350992656763*^9, 3.5873529396735992`*^9}]
}, Open  ]],

Cell["Measured axis origin", "Text",
 CellChangeTimes->{{3.5033955670517335`*^9, 3.5033955738601227`*^9}, {
  3.5873504134439898`*^9, 3.587350415140246*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x0", ",", "z0"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"17", ",", "19"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5033954059855213`*^9, 3.5033954089606915`*^9}, {
  3.503395465206908*^9, 3.5033954765915594`*^9}, {3.5033955165828466`*^9, 
  3.5033955206380787`*^9}, {3.5033961444307575`*^9, 3.5033961450857954`*^9}, {
  3.5873504475733304`*^9, 3.5873504480203753`*^9}}],

Cell["\<\
Measured axes length (must come up identical)\
\>", "Text",
 CellChangeTimes->{{3.5033899758189335`*^9, 3.50338998241131*^9}, {
  3.5033957685852604`*^9, 3.5033957746676083`*^9}, {3.587350543860366*^9, 
  3.5873505855796337`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"x1", ",", "z1"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"230", "-", "x0"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"445", "-", "z0"}], ")"}], "/", "2"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5033956281002254`*^9, 3.503395650790523*^9}, {
  3.5033956995573125`*^9, 3.5033957512382684`*^9}, {3.503396312559374*^9, 
  3.5033963129103937`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"213", ",", "213"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755424421679106`*^9, 3.5758712913667088`*^9, 3.5865813259286947`*^9, {
   3.5873504554252944`*^9, 3.5873504821426544`*^9}, {3.5873508619953117`*^9, 
   3.5873508878555603`*^9}, 3.587350992680747*^9, 3.587352939700594*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make shear-free outline", "Subsection",
 CellChangeTimes->{{3.503393371252141*^9, 3.5033933766504498`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"thickness", "=", "0.003"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dashing", "=", "0.02"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DD", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{"1", "/", "3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ur", "=", 
   RowBox[{
    FractionBox["\[Nu]", "DD"], 
    RowBox[{"(", 
     RowBox[{"h", "-", "z"}], ")"}], "r"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"uz", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["h", "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"h", "-", "z"}], ")"}], "2"], "-", 
       RowBox[{"\[Nu]", " ", 
        SuperscriptBox["r", "2"]}]}], 
      RowBox[{"2", "DD"}]]}], "-", 
    RowBox[{
     FractionBox["\[Nu]", 
      RowBox[{"4", "DD"}]], 
     SuperscriptBox["a", "2"]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"figb", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "+", "ur"}], ")"}], "x1"}]}], ",", 
         RowBox[{"z0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "+", "uz"}], ")"}], "z1"}]}]}], "}"}], "/.", 
       RowBox[{"z", "\[Rule]", "h"}]}], "//", "Evaluate"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "a"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Gray", ",", 
        RowBox[{"Thickness", "[", "thickness", "]"}], ",", 
        RowBox[{"Dashing", "[", "dashing", "]"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"figc", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "+", "ur"}], ")"}], "x1"}]}], ",", 
         RowBox[{"z0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "+", "uz"}], ")"}], "z1"}]}]}], "}"}], "/.", 
       RowBox[{"r", "\[Rule]", "a"}]}], "//", "Evaluate"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", "h"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Gray", ",", 
        RowBox[{"Thickness", "[", "thickness", "]"}], ",", 
        RowBox[{"Dashing", "[", "dashing", "]"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figd", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "+", "ur"}], ")"}], "x1"}]}], ",", 
         RowBox[{"z0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "+", "uz"}], ")"}], "z1"}]}]}], "}"}], "/.", 
       RowBox[{"z", "\[Rule]", "0"}]}], "//", "Evaluate"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "a"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Gray", ",", 
        RowBox[{"Thickness", "[", "thickness", "]"}], ",", 
        RowBox[{"Dashing", "[", "dashing", "]"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fige", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "+", "ur"}], ")"}], "x1"}]}], ",", 
         RowBox[{"z0", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "+", "uz"}], ")"}], "z1"}]}]}], "}"}], "/.", 
       RowBox[{"r", "\[Rule]", "a"}]}], "//", "Evaluate"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", "h"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Gray", ",", 
        RowBox[{"Thickness", "[", "thickness", "]"}], ",", 
        RowBox[{"Dashing", "[", "dashing", "]"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4110351496745925`*^9, 3.411035159066592*^9}, 
   3.4110352806405926`*^9, {3.4110353714235926`*^9, 3.4110353840035925`*^9}, {
   3.4110354255495925`*^9, 3.4110354398605924`*^9}, {3.4110355256405926`*^9, 
   3.411035571191592*^9}, {3.4110356326565924`*^9, 3.4110356558865924`*^9}, {
   3.4110357552765923`*^9, 3.411035787474592*^9}, {3.4110359693505926`*^9, 
   3.4110359694665923`*^9}, {3.4110360114965925`*^9, 
   3.4110360116695924`*^9}, {3.4110361204475927`*^9, 
   3.4110363630265923`*^9}, {3.4110364050385923`*^9, 
   3.4110364056705923`*^9}, {3.411036673087592*^9, 3.4110366914615927`*^9}, {
   3.4110367217025924`*^9, 3.411036734040592*^9}, {3.4110367683615923`*^9, 
   3.4110367943465924`*^9}, {3.411036869731592*^9, 3.4110368750065928`*^9}, {
   3.4110369439775925`*^9, 3.4110369529425926`*^9}, {3.4110369858865924`*^9, 
   3.4110371476195927`*^9}, {3.4110373423105927`*^9, 
   3.4110373754505925`*^9}, {3.4110374667155924`*^9, 
   3.4110375278695927`*^9}, {3.4110375864975924`*^9, 
   3.4110376701055927`*^9}, {3.411037703009592*^9, 3.4110377456405926`*^9}, {
   3.4110379003425922`*^9, 3.411038098500592*^9}, {3.4110382874115925`*^9, 
   3.4110383167955923`*^9}, {3.4110954923459983`*^9, 
   3.4110955134689984`*^9}, {3.411095555551998*^9, 3.4110955774369984`*^9}, {
   3.41130694244119*^9, 3.41130698779919*^9}, {3.4113070246201897`*^9, 
   3.41130703914819*^9}, {3.4113073595461903`*^9, 3.41130735997519*^9}, {
   3.41130811205519*^9, 3.41130838792519*^9}, 3.41130842319219*^9, {
   3.41130880806319*^9, 3.4113088134001904`*^9}, {3.41130888295019*^9, 
   3.4113089380461903`*^9}, {3.4113798980150003`*^9, 3.411379968166*^9}, {
   3.411380381131*^9, 3.411380385219*^9}, {3.411380418722*^9, 
   3.411380449977*^9}, {3.4113804847209997`*^9, 3.4113805142539997`*^9}, 
   3.411380569929*^9, {3.412503160131*^9, 3.412503188252*^9}, {
   3.4125032429040003`*^9, 3.41250331629*^9}, {3.41250335269*^9, 
   3.4125034188059998`*^9}, {3.412524346321*^9, 3.4125243464560003`*^9}, {
   3.412524467462*^9, 3.41252447315*^9}, {3.4132615546994267`*^9, 
   3.4132615630474267`*^9}, {3.4132618645104265`*^9, 
   3.4132618893984265`*^9}, {3.4132700981573668`*^9, 
   3.4132701011803665`*^9}, {3.503390531252702*^9, 3.5033906731018157`*^9}, {
   3.5033933808956923`*^9, 3.503393386781029*^9}, {3.5033934809624157`*^9, 
   3.503393510127084*^9}, {3.503393569430476*^9, 3.5033935741087437`*^9}, {
   3.503394088620172*^9, 3.5033940968376417`*^9}, {3.503394256286762*^9, 
   3.5033942564077687`*^9}, {3.503394316604212*^9, 3.5033943166962175`*^9}, {
   3.503394723865506*^9, 3.5033947423005605`*^9}, {3.5033947990158043`*^9, 
   3.503394813053607*^9}, {3.5033948437983656`*^9, 3.5033948888339415`*^9}, {
   3.5033950965918245`*^9, 3.503395115020879*^9}, {3.503395148101771*^9, 
   3.5033951485647974`*^9}, {3.503395198509654*^9, 3.503395207201151*^9}, {
   3.5033957850462017`*^9, 3.5033957939637117`*^9}}],

Cell["Final plot", "Text",
 CellChangeTimes->{{3.5033934059621263`*^9, 3.50339341441961*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"right", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"raw", ",", "figb", ",", "figc", ",", "figd", ",", "fige"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4110351496745925`*^9, 3.411035159066592*^9}, 
   3.4110352806405926`*^9, {3.4110353714235926`*^9, 3.4110353840035925`*^9}, {
   3.4110354255495925`*^9, 3.4110354398605924`*^9}, {3.4110355256405926`*^9, 
   3.411035571191592*^9}, {3.4110356326565924`*^9, 3.4110356558865924`*^9}, {
   3.4110357552765923`*^9, 3.411035787474592*^9}, {3.4110359693505926`*^9, 
   3.4110359694665923`*^9}, {3.4110360114965925`*^9, 
   3.4110360116695924`*^9}, {3.4110361204475927`*^9, 
   3.4110363630265923`*^9}, {3.4110364050385923`*^9, 
   3.4110364056705923`*^9}, {3.411036673087592*^9, 3.4110366914615927`*^9}, {
   3.4110367217025924`*^9, 3.411036734040592*^9}, {3.4110367683615923`*^9, 
   3.4110367943465924`*^9}, {3.411036869731592*^9, 3.4110368750065928`*^9}, {
   3.4110369439775925`*^9, 3.4110369529425926`*^9}, {3.4110369858865924`*^9, 
   3.4110371476195927`*^9}, {3.4110373423105927`*^9, 
   3.4110373754505925`*^9}, {3.4110374667155924`*^9, 
   3.4110375278695927`*^9}, {3.4110375864975924`*^9, 
   3.4110376701055927`*^9}, {3.411037703009592*^9, 3.4110377456405926`*^9}, {
   3.4110379003425922`*^9, 3.411038098500592*^9}, {3.4110382874115925`*^9, 
   3.4110383167955923`*^9}, {3.4110954923459983`*^9, 
   3.4110955134689984`*^9}, {3.411095555551998*^9, 3.4110955774369984`*^9}, {
   3.41130694244119*^9, 3.41130698779919*^9}, {3.4113070246201897`*^9, 
   3.41130703914819*^9}, {3.4113073595461903`*^9, 3.41130735997519*^9}, {
   3.41130811205519*^9, 3.41130838792519*^9}, 3.41130842319219*^9, {
   3.41130880806319*^9, 3.4113088134001904`*^9}, {3.41130888295019*^9, 
   3.4113089380461903`*^9}, {3.4113798980150003`*^9, 3.411379968166*^9}, {
   3.4113805908120003`*^9, 3.4113806327609997`*^9}, 3.4124793807064247`*^9, 
   3.412503181304*^9, {3.412503427218*^9, 3.4125034308570004`*^9}, {
   3.412524483084*^9, 3.41252448513*^9}, 3.412526592976*^9, {
   3.4132615773444266`*^9, 3.4132615816044264`*^9}, {3.4132706795123663`*^9, 
   3.413270679679366*^9}, {3.417578538705288*^9, 3.4175785405292873`*^9}, {
   3.419574262231*^9, 3.41957426231*^9}, 3.4309106132376003`*^9, {
   3.479202970304*^9, 3.4792029799*^9}, {3.4792030389779997`*^9, 
   3.4792030404*^9}, {3.479203102337*^9, 3.47920314504*^9}, 
   3.479203215026*^9, {3.479203274354*^9, 3.479203274752*^9}, {
   3.479203391234*^9, 3.479203391361*^9}, {3.479203481362*^9, 
   3.479203481521*^9}, {3.47920355109*^9, 3.479203551264*^9}, 
   3.479209227973*^9, {3.4846269637603807`*^9, 3.484627078694955*^9}, 
   3.484627120032319*^9, 3.4929192069759536`*^9, {3.49294907004618*^9, 
   3.492949071235248*^9}, {3.4929491448514585`*^9, 3.492949148107645*^9}, {
   3.501485461982169*^9, 3.501485480484227*^9}, {3.5033904736164055`*^9, 
   3.503390473999428*^9}, {3.5033906971101885`*^9, 3.503390785285232*^9}, {
   3.5033934601612263`*^9, 3.503393468880725*^9}, 3.503393581256152*^9, {
   3.5033936211044316`*^9, 3.5033937584992905`*^9}, {3.503393918399436*^9, 
   3.503393918591447*^9}, 3.503394044121627*^9, {3.5033942237339*^9, 
   3.503394227895138*^9}, {3.503394349359085*^9, 3.503394379045783*^9}, {
   3.503394419935122*^9, 3.5033944203031435`*^9}, {3.5033946542405233`*^9, 
   3.503394688024456*^9}, {3.5033947520881205`*^9, 3.5033947681990414`*^9}, {
   3.503394897567441*^9, 3.5033948987835107`*^9}}],

Cell[BoxData[
 GraphicsBox[{RasterBox[CompressedData["
1:eJzsnQm0bVdVph9FCiGCFKWCWoL0lCJ2iB2lUqgg2NBYiCHSFliJdIoRlFZQ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    "], {{0, 0}, {288, 450}}, {0, 255},
    ColorFunction->RGBColor], {{}, {}, 
    {GrayLevel[0.5], Thickness[0.003], Dashing[0.02], LineBox[CompressedData["
1:eJwl1gk0lekfB3A0ShFhUElZsoRM915rdH2vLUaZLJWGmy1b3mHUfaNIiJiJ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      "]]}}, {{}, {}, 
    {GrayLevel[0.5], Thickness[0.003], Dashing[0.02], LineBox[CompressedData["
1:eJwd1H1QjAkcB/Di4gyLIuMqnUQdKqZOKy2+uJPV29pSe7vVbLtta7tnn+cp
+zi9sHHcIRe2obCpI6y6dBcZvXi5LFckelVbWa5TpjRF26bjdMtv5jff+fzx
m99/XxcJxZdNsLKyCrbsx/w0OTSsPybNRnO5UN6UTcPgO62nPJ2Nwu1l9Rcs
dvDnODHH2AjvTcgNtniwaHLyYCkbuvqWVadP0KjxCjINj7DByy1ifI/TcCzP
eO2fthL5qyL7CQ2NzGf/TKo56Acwl1vbD9PYkTKufazzx9Fzt07eSadRe04X
6roEEBiyFSkMjYz9PJ5cuh4PLtn3KBJoeHhEaIdPf4MQb3OIIobG5/fM/ZKZ
Adh0J1e/IoxG/MY6UZeMiy0snZtdAI38XTJEjAVi0lDkCnd/y79va9JeHA6B
d0c9b8pyGqterw5KVvNAqnWCd640xJxqbX3bFrh6cJUVc2n4nhyVVc0Pw97E
I16lLBqaaa7KbfJwDFErO8utaUgbB5MKH21FyQDPc94Ahcujzb0bF0XilNKc
0tNMYe6uq2E/5QrQ4dzr4nKDwtMhfkXfbCFYz2V/j1ygkDOroEW6U4Ro+8LU
vkwK6q+u/Vg/HoU8YZpX8k4Kh9q39FxMioGV3ewKdzGFcM2B/bAR48q/5jMB
mygMxVelpT8W4zuTPNfam8J07gvf5qOxcBafUXV8QeHKVKExNE6Cpk6JLHQi
BYnuWF+GhxTGQ0klXw+Q8GD5nVINSzG5KKDRr4XEhvTVXy6uj4NLZ+H09psk
bK+7VH7QyiBUN7nmXCAxVWfudkuPx8uwAE1NJokZ23huyyRyxPtxHbJ2kggS
QFTG3obPjs1M3SUmkT/N4eqKBQpoxmQj1ptJ3Hx20/BsXAFV1qTaUR8SNnH8
hrsdCdiRRzAsJxJZDXlRmx5+D0WV2P+GDYlipqMz4g8CKYEOhsMDSnRODOAe
LFIitT9WY25VYu7064tM2SSaqkznGm4rcWbkFYR7KXCtgjPrdEoMiTgc/Toa
JeE+mliNEny7A/fcK2n4OBrJOSlK/KxNa/NGIlizWgs4EiUEvWWhW/WJMDiK
TO8DlZhh1KvfIAnVJ847dfko8cF2n3tGbRK0C3bHRM6z/HcTdKs2b8dD469j
6ydb7qWDFQvub4fjjAxlyCABwePFvfMiVBCGTng33EagJlCd7WBQwWnjnKVH
La4rlQwldKpg5CwReVisCjwurXyqgmwJvzLuCYEy25c5Ud0qUDZnU1taCLx5
vWFt/isV9lWue3+tkYDIuiXFY1yFYvc9/yXXEegTRRULFjKgnI97zrE4c3QR
7zc3Bt72l6JLHxBo1a9hWS1mcH1Cw42++wQiTNGtFz0ZVHfN3y2qJWB7kV/w
1pfBk6zbHzj3CPwgsl+Wx2Vw6lCzV/tdAgm2jTtMgQyi9ryMYSy2Hutq44Yw
eE7OvFWsJzA/urvfxGfQzxWrne8QcEwuCA6KYlAMVUlFNQHfKoP8bAyDRPYB
Y4TF5uVi7VsxA/PC39ce+ZNAfIkg/LyMQbmjnlpqsX35gyfv5AxS7dry/rpN
QGH6heEnMFgz5dUjqcWS2DzPSwSDT/1l8af+ohj8D6+KMzY=
      "]]}}, {{}, {}, 
    {GrayLevel[0.5], Thickness[0.003], Dashing[0.02], LineBox[CompressedData["
1:eJwl1nk41lkbB3CZyhLZEpop+xB+eBZ+tofvYwlZyiOhImtI+NUUMkgojDVt
KJrUeKOkVKYaI15eoWa80igVMpSlp4VBTbb39M65rnPd1+c6f93n3Nd9H/Wg
GEGoqIiISCnZX+I/i4X/BzUKnbXubakKLHTMin7zxWWhpQXLdFjQfr+C+eIo
ZaFPpgULCs/WzH2x1QML9RXuLByvN2pcQrwiOWssN5CFilMb60WJnxk/vS57
gAWX8MgPXxFXDn2bcDyThVRW4Y5lxPGnDtiuPsuC62SDiBixo3OLZHENC5VV
Ey/EiVfPyXd/3cxC0Ta9CUniV1cDz5T1sKAsGsGTJr4ZeC1YfZwFg/PVTTLE
aasW9S/Os/CI/pQkTyy47zb1rRwbkq1O+xSJPxi8STcwY4PdThIkvjdg7lbj
woaGtf85VeK8wkxF9k42LlS1fqdJbPBJu4I+yob/7soWfeLZqv3Rd4vZOP2r
Jt+YuMOv2ZRXzUaQ+MVpLnF4c8B928dsXEuvW25DbBZbk/+fETY4dU7B9sTL
1y94O82y4TTw8qMz8cW8M6NuGhzoKmu2exEP+vZI+DIctGmRCye+JqX96Hka
B33y13XjiA/d+67E/zQHRz7FJyUTr9WW0w9p4CCnak1nLrHvBxfXGCku4ip/
kq8h1r1QsmpSlQu1Laff/0z80WvsxX4OF9tn8pY2EZ/85WhUwjYuMtULerqJ
u4425R25xEWjPHlg4h/NZb3F67mYOzj783J1CjFCf9XsTi46nmrkyhFLC+Zq
Cma4WJeUNqBD7LyW7jpjb4LygBwtb+KmG1cUal+a4JsvBUJcV+6+8HTaBOo6
DYc6iS8f+zC6KGmK86On5QaIT8RwG9xMTLF6qvvzAnGYfn34WJYpfjeIHuJr
UJC68OBXNQ6NNG196cfESwqjLjk60XA6VpMwQjyTInM82o9Gpp6U3izxgL9n
eH0GjeRXbu6amhRq1zyX93lBwyLpryuxxD6F42H5R8wwxbn/7/VaFFwP5wjq
SsxwMO53Nz4xnzHk9dWYIWG0eo0vsZ77Pnn9Z2aYEEwfzCKel/hc32pojmvO
Fe5viS8clpBfeGKO6IaCzU3aFN4xuvV79Cwx0ZJRV6JDQVYu+r8G1pbgFKft
vE3Mun5jWOhhiYRjI/we4v0T1tJRBy2h/G6kVl6XwtxeL/+oNkvkeXc45BFL
fJcqEr3LCpFvFI0K1lPQOvDCPqach/7VbTL39ClsUNTwNarjoTGy7dUQcfit
sKj37TxUDBtPixuQ+56ePBkzwUOarUWjJzE7VmIkBtaIvWooJiRGnGkW028N
V8cyHx1DCtVWba/NpIGbiUUS7cYU1us88x1ZDRQESBlNEV+UEz48qQa0pFRn
q7IonHktc2OSA9CxceOxxFkF3oeubANgomety6YQMvxaSe0S8PKrFdYnORS+
yVnmLGbHR9DQnXNFphSKYpXqb7nysVHwR1UHsULgeqOQrXxkza99O0csaeqm
2BTBh5wErRREU/g0cGIwoYAPh6mMJUZmFB5ztBLe9fFh9fVPht3mFLKf217+
I94WUZcfjtvzKKiEJBttTbNFo9Gp66nEl4R3bvTk2qKs1/VOI3HLvHH9k3Jb
zJYezuZZU1hQVf2t96EtLMbELS1sKDAhs+/61OzQmpXXasOnsOXtDfbrNjuo
/XUg/3sHCusWte7OKDugZ9et0VvuFGwD2N3NGg4Iuy99c4E4vMlGWGDgAIdX
kz87bqJwPW3bOn04YNwnOOIZsb14QerOMAd0q/btE/WgECk3u7HtlgO0DLhq
fp4Ubmt2PS8WbECLNTNs5UPBwylp3irHEZMuagoVQRQsVvOyxbgbUVZZrmeT
SPpTcvOWPZ2uSFFSOrS7mMLfUo2CGd4muFU22VjeJv1QptAt9cNmaKveLD3R
R+rBYHHFWX0Bfkr6M0prqSHaTm4aTQ3wxJMDKzPCKUPcbeoeu1yzBR9MEkNl
/A2RKHL8SNioF/LlG2uU8w1RtOTohlBLb2QqHpYxazOE+OYd2saZPmgUrjHd
vNQIztejynIbfPH77rPnJ2yMMPS41oqS2Y5TjKpJZroR3FdwDux03oEq2ZYg
8zYjrFo68qi71A8ZlSLCdkljUBuT3RWF/lB5dvVgO9sY2R66tVNyAdjrPWQ/
5kvOd17uXLwbgA2Zt+rdjhqDnnGxeOwTiGGz0y9KrhvjDaefk/9XIIT9JVoP
+ozxUCCJyDNBmN466Vctw4LirGexrFkwrN40Sa0ECznp9LIng8FQUS5NTIhl
ofqmlEh6Zgj+ZXMpSFjNgkn0ouNnzVCoPdg0GzPEwhvxnPJjD0MR67qwMkaV
DQnKdONkxC4oJe4Jc/Jlo+tjV4r50jDoWXpsu32cjdYLYh3nL4chX2Jtg+wf
ZA71bgvodgxH0/i9lF4FDqrfO0p8OxEOredv7YZ9OfgxX7DIz4/AQqDobZ1S
Dqx63NPt9XZjp5CRffqSg2ULw1+HP9oNqa7eftqAC7qmSMQrJhLrI6m50P1c
nOK//hiksgepvN+OlrZwcS5BO9m7cQ+upEwLQhRNIMtL9VDcEYV4u7bvc4JM
cPVlPD21NBp+bWfmqNsmuCmdu/tseTTGw5o9/5YwRchgoYE+LwZbrrYODG83
Bf8Ue8nz4Rj8ORc8XldnCrvxOLkqMFB1E69zkqZRIsmOELNl0Lucbdu5ksaE
nrAxxI5Biygz4SVL41xkAKO6gYFRk+6dYAUas0KnzhMuDLx8ct+mqNCofa+S
e2grg/73GuNN2jQ0pn8R99rD4G3zIba/NY14xdiA2igGXc0s9TEbGv81Mb4t
E8NgZNkn9n4+mQOxF8M69jKo2Nx07wd7Gs8+5rTaxDHYL+KYfGcjjWOf/dL1
Uhm4t6/LX+tNY3SN8ouMNAaOwlU1VT40rC0fcV6lM9jroTpJb6Mh/H7D0LkM
Btv/ZAYFZO44zRvaKuYySFwnFvpDMMln7VjxvjwGIp7nSpVDaczwLkx05jOo
a3f5u2IXjYvJSud/KGRwM2lQpSWC5FvW9WnkOIP5ux39gkgagnvZmx1OMoi3
aGsd3EOjcsDhUvkpBppzvV1MNP3Pv62I+ScyNP4HVHsOhw==
      "]]}}, {{}, {}, 
    {GrayLevel[0.5], Thickness[0.003], Dashing[0.02], LineBox[CompressedData["
1:eJwd1H1QjAkcB/Di4gyLIuMqnUQdKqZOKy2+uJPV29pSe7vVbLtta7tnn+cp
+zi9sHHcIRe2obCpI6y6dBcZvXi5LFckelVbWa5TpjRF26bjdMtv5jff+fzx
m99/XxcJxZdNsLKyCrbsx/w0OTSsPybNRnO5UN6UTcPgO62nPJ2Nwu1l9Rcs
dvDnODHH2AjvTcgNtniwaHLyYCkbuvqWVadP0KjxCjINj7DByy1ifI/TcCzP
eO2fthL5qyL7CQ2NzGf/TKo56Acwl1vbD9PYkTKufazzx9Fzt07eSadRe04X
6roEEBiyFSkMjYz9PJ5cuh4PLtn3KBJoeHhEaIdPf4MQb3OIIobG5/fM/ZKZ
Adh0J1e/IoxG/MY6UZeMiy0snZtdAI38XTJEjAVi0lDkCnd/y79va9JeHA6B
d0c9b8pyGqterw5KVvNAqnWCd640xJxqbX3bFrh6cJUVc2n4nhyVVc0Pw97E
I16lLBqaaa7KbfJwDFErO8utaUgbB5MKH21FyQDPc94Ahcujzb0bF0XilNKc
0tNMYe6uq2E/5QrQ4dzr4nKDwtMhfkXfbCFYz2V/j1ygkDOroEW6U4Ro+8LU
vkwK6q+u/Vg/HoU8YZpX8k4Kh9q39FxMioGV3ewKdzGFcM2B/bAR48q/5jMB
mygMxVelpT8W4zuTPNfam8J07gvf5qOxcBafUXV8QeHKVKExNE6Cpk6JLHQi
BYnuWF+GhxTGQ0klXw+Q8GD5nVINSzG5KKDRr4XEhvTVXy6uj4NLZ+H09psk
bK+7VH7QyiBUN7nmXCAxVWfudkuPx8uwAE1NJokZ23huyyRyxPtxHbJ2kggS
QFTG3obPjs1M3SUmkT/N4eqKBQpoxmQj1ptJ3Hx20/BsXAFV1qTaUR8SNnH8
hrsdCdiRRzAsJxJZDXlRmx5+D0WV2P+GDYlipqMz4g8CKYEOhsMDSnRODOAe
LFIitT9WY25VYu7064tM2SSaqkznGm4rcWbkFYR7KXCtgjPrdEoMiTgc/Toa
JeE+mliNEny7A/fcK2n4OBrJOSlK/KxNa/NGIlizWgs4EiUEvWWhW/WJMDiK
TO8DlZhh1KvfIAnVJ847dfko8cF2n3tGbRK0C3bHRM6z/HcTdKs2b8dD469j
6ydb7qWDFQvub4fjjAxlyCABwePFvfMiVBCGTng33EagJlCd7WBQwWnjnKVH
La4rlQwldKpg5CwReVisCjwurXyqgmwJvzLuCYEy25c5Ud0qUDZnU1taCLx5
vWFt/isV9lWue3+tkYDIuiXFY1yFYvc9/yXXEegTRRULFjKgnI97zrE4c3QR
7zc3Bt72l6JLHxBo1a9hWS1mcH1Cw42++wQiTNGtFz0ZVHfN3y2qJWB7kV/w
1pfBk6zbHzj3CPwgsl+Wx2Vw6lCzV/tdAgm2jTtMgQyi9ryMYSy2Hutq44Yw
eE7OvFWsJzA/urvfxGfQzxWrne8QcEwuCA6KYlAMVUlFNQHfKoP8bAyDRPYB
Y4TF5uVi7VsxA/PC39ce+ZNAfIkg/LyMQbmjnlpqsX35gyfv5AxS7dry/rpN
QGH6heEnMFgz5dUjqcWS2DzPSwSDT/1l8af+ohj8D6+KMzY=
      "]]}}},
  ImageSize->{288, 450},
  PlotRange->{{0, 288}, {0, 450}}]], "Output",
 CellChangeTimes->{
  3.575542442259922*^9, 3.5758712917187123`*^9, 3.5865813262527266`*^9, 
   3.5873504822946343`*^9, {3.5873508620483274`*^9, 3.587350887908597*^9}, 
   3.5873509927297864`*^9, 3.587352939755582*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flip and join", "Subsection",
 CellChangeTimes->{{3.503393817555668*^9, 3.5033938194677773`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"right", "=", 
  RowBox[{"ImageCrop", "[", 
   RowBox[{"right", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xsize", "-", "x0", "-", "1"}], ",", "zsize"}], "}"}], ",", 
    "Left"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5033959540468683`*^9, 3.5033959584871225`*^9}, {
   3.503396005895834*^9, 3.5033960093250303`*^9}, {3.503396043663994*^9, 
   3.503396061727027*^9}, 3.503396098399125*^9, 3.503396197086769*^9, {
   3.5033964085678654`*^9, 3.503396462535952*^9}, {3.587350822732436*^9, 
   3.5873508451322513`*^9}, {3.587350880108613*^9, 3.5873508802056*^9}, {
   3.587350989676439*^9, 3.587350989772399*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvemyHceR51mzfJhP8w7zKDOP0PME3WbTX8esZ6zLuq3bihJ3UeIqihL3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    "], {{0, 450}, {270, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSizeRaw->{270, 450},
  PlotRange->{{0, 270}, {0, 450}}]], "Output",
 CellChangeTimes->{
  3.5755424424939528`*^9, 3.575871291882733*^9, 3.586581326971834*^9, 
   3.5873504824226913`*^9, {3.5873508235015097`*^9, 3.5873508880196037`*^9}, 
   3.587350992840782*^9, 3.5873529398905983`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"left", "=", 
  RowBox[{"ImageReflect", "[", 
   RowBox[{"right", ",", 
    RowBox[{"Left", "\[Rule]", "Right"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5033868940616665`*^9, 3.5033869088765144`*^9}, 
   3.5033882054306726`*^9, {3.5033945901658587`*^9, 3.503394597112256*^9}, {
   3.5033958265265746`*^9, 3.503395903848997*^9}, {3.503395944798339*^9, 
   3.5033959867107363`*^9}, 3.5033962007989817`*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvemyJcW153l7+NCf+h36UbofofoJqsy6v7ZZddu9Vteq7CJSIOlqYJAQ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    "], {{0, 450}, {270, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSizeRaw->{270, 450},
  PlotRange->{{0, 270}, {0, 450}}]], "Output",
 CellChangeTimes->{
  3.57554244255696*^9, 3.5758712919327683`*^9, 3.5865813271228456`*^9, 
   3.5873504824536858`*^9, {3.5873508265508776`*^9, 3.587350888043626*^9}, 
   3.587350992864745*^9, 3.5873529399286027`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"image", "=", 
  RowBox[{"ImageAssemble", "[", 
   RowBox[{"{", 
    RowBox[{"left", ",", "right"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.50338437824377*^9, 3.50338438278803*^9}, {
   3.5033844256134796`*^9, 3.5033844739732456`*^9}, {3.503384516989706*^9, 
   3.503384554373844*^9}, {3.5033846248378744`*^9, 3.50338462545391*^9}, {
   3.5033846754697704`*^9, 3.5033846790539756`*^9}, {3.5033847616146975`*^9, 
   3.503384827782482*^9}, {3.503384870315915*^9, 3.503384904244856*^9}, {
   3.503385747318077*^9, 3.5033857481091223`*^9}, {3.5033858359021435`*^9, 
   3.50338584161347*^9}, {3.50338701440655*^9, 3.5033870180697594`*^9}, 
   3.5033882082218323`*^9, {3.5033908185431347`*^9, 3.5033908312308598`*^9}, 
   3.503394599870414*^9, 3.503396131286006*^9, 3.503396212030624*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvdmSXMeVrlk9XPRD9E0/SvcjnH6Cc8y6b9vsdJu1nTuKVGmosiqV1KWW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    "], {{0, 450}, {540, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSizeRaw->{540, 450},
  PlotRange->{{0, 540}, {0, 450}}]], "Output",
 CellChangeTimes->{
  3.575542442663972*^9, 3.5758712919837484`*^9, 3.5865813287630014`*^9, 
   3.5873504825217156`*^9, {3.587350831099475*^9, 3.5873508880916457`*^9}, 
   3.587350992914751*^9, 3.5873529399946513`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make tick marks", "Subsection",
 CellChangeTimes->{{3.5873511267716165`*^9, 3.587351129411894*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xticks", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xsize", "-", "x0", " ", "-", "1", "+", 
       RowBox[{"x", "*", "x1"}]}], ",", "x"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.503386387058668*^9, 3.5033864687743416`*^9}, {
   3.503386502696282*^9, 3.5033865028882933`*^9}, {3.5033865622856903`*^9, 
   3.503386572662284*^9}, {3.503386666518652*^9, 3.503386680709464*^9}, {
   3.5033895157816205`*^9, 3.5033895880627546`*^9}, {3.5033896968949795`*^9, 
   3.5033897386473675`*^9}, 3.5033899915038304`*^9, {3.5033900563845415`*^9, 
   3.503390082431031*^9}, 3.5033901161489596`*^9, {3.5033902640964217`*^9, 
   3.5033902729909306`*^9}, {3.5033965448876624`*^9, 
   3.5033965455677013`*^9}, {3.5873510624605083`*^9, 3.587351062868576*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"57.`", ",", 
     RowBox[{"-", "1.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"163.5`", ",", 
     RowBox[{"-", "0.5`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"270.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"376.5`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"483.`", ",", "1.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575542442704977*^9, 3.5758712920097513`*^9, 3.586581328920038*^9, 
   3.5873504825426674`*^9, {3.58735086226435*^9, 3.5873508881096334`*^9}, 
   3.5873509929357953`*^9, 3.587351064121738*^9, 3.5873529400286713`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zticks", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z0", "+", 
       RowBox[{"z", "*", "z1"}]}], ",", "z"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "2", ",", "0.5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5033867142933846`*^9, 3.5033867506304626`*^9}, {
   3.5033896249668655`*^9, 3.503389659725854*^9}, {3.503389997481172*^9, 
   3.5033899978471932`*^9}, {3.5033938699916673`*^9, 3.503393888693737*^9}, 
   3.503396887392253*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"19.`", ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"125.5`", ",", "0.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"232.`", ",", "1.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"338.5`", ",", "1.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"445.`", ",", "2.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575542442744982*^9, 3.5758712920317535`*^9, 3.5865813289520674`*^9, 
   3.58735048256067*^9, {3.587350862278352*^9, 3.587350888124611*^9}, 
   3.5873509929517574`*^9, 3.587352940050644*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show image", "Subsection",
 CellChangeTimes->{{3.5873511460750327`*^9, 3.587351147323227*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"image", ",", 
    RowBox[{"Axes", "\[Rule]", "True"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "z"}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xsize", "-", "x0", "-", "1"}], ",", "z0"}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"xticks", ",", "zticks"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"z0", ",", 
         RowBox[{"z0", "+", "zsize"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", 
     RowBox[{"zsize", "/", 
      RowBox[{"(", 
       RowBox[{"2", "xsize"}], ")"}]}]}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<elastostatics-settling\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5033881488704376`*^9, 3.5033881570309043`*^9}, {
  3.5033894616795263`*^9, 3.5033894905351763`*^9}, {3.50338967470271*^9, 
  3.5033896751597366`*^9}, {3.503390309597024*^9, 3.5033903114791317`*^9}, {
  3.503393900448409*^9, 3.5033939484801564`*^9}, {3.5033943362493353`*^9, 
  3.503394343776766*^9}, {3.5033944347849717`*^9, 3.503394562945302*^9}, {
  3.503395225994226*^9, 3.503395227009284*^9}, {3.503396509690649*^9, 
  3.5033965119137764`*^9}, {3.5033966068032036`*^9, 3.5033966368059196`*^9}, {
  3.5033966821375127`*^9, 3.503396796761069*^9}, {3.503396860347706*^9, 
  3.5033970437381954`*^9}, {3.5873507671103983`*^9, 3.587350801616786*^9}, {
  3.5873509161111097`*^9, 3.5873509484852147`*^9}, {3.5873510469255733`*^9, 
  3.5873510470445557`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.575542442968008*^9, 3.575871292171784*^9, 3.5865813297421727`*^9, 
   3.587350482714704*^9, {3.587350768230546*^9, 3.58735080206979*^9}, {
   3.5873508624104247`*^9, 3.5873509488852243`*^9}, 3.5873509930908003`*^9, {
   3.5873510486557517`*^9, 3.5873510681342373`*^9}, 3.587352940187678*^9}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzsvXvYbWVd9/uYZlmau13pW1mmvlbu1DwkZbu0kk4UuLGstnhuq2WaaG6j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   "], {{0, 0}, {540, 450}}, {0, 255},
   ColorFunction->RGBColor],
  AspectRatio->NCache[
    Rational[25, 32], 0.78125],
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox["z", TraditionalForm]},
  AxesOrigin->{270, 19},
  ImageSize->{540, 450},
  PlotRange->{All, {19, 469}},
  Ticks->{{{57., 
      FormBox[
       RowBox[{"-", "1.`"}], TraditionalForm]}, {163.5, 
      FormBox[
       RowBox[{"-", "0.5`"}], TraditionalForm]}, {270., 
      FormBox["0.`", TraditionalForm]}, {376.5, 
      FormBox["0.5`", TraditionalForm]}, {483., 
      FormBox["1.`", TraditionalForm]}}, {{19., 
      FormBox["0.`", TraditionalForm]}, {125.5, 
      FormBox["0.5`", TraditionalForm]}, {232., 
      FormBox["1.`", TraditionalForm]}, {338.5, 
      FormBox["1.5`", TraditionalForm]}, {445., 
      FormBox["2.`", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.5755424430200152`*^9, 3.5758712921908226`*^9, 3.586581329757128*^9, 
   3.587350482727691*^9, {3.587350768270585*^9, 3.587350802110793*^9}, {
   3.58735086242737*^9, 3.587350948922227*^9}, 3.5873509931077757`*^9, {
   3.587351048693755*^9, 3.587351068172201*^9}, 3.5873529402216606`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Figure 9.3 Vertical pressure (p. 145)\
\>", "Section",
 CellChangeTimes->{{3.4111911611322103`*^9, 3.41119116373621*^9}, {
  3.4125796678005323`*^9, 3.4125796896365323`*^9}, {3.5018348911517057`*^9, 
  3.501834896943037*^9}, {3.587351187275195*^9, 3.5873511948271427`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4111911671362104`*^9, 3.41119116968621*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(27\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.5755424434160604`*^9, 3.5758712924438033`*^9, 3.586581330565285*^9, 
   3.587351256018797*^9, {3.5873529274750824`*^9, 3.5873529403916616`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Read data for stress on the bottom line of the block\
\>", "Subsection",
 CellChangeTimes->{{3.587351214522612*^9, 3.5873512159068117`*^9}, {
  3.5873516621628275`*^9, 3.5873516775617948`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{
    "\"\<data/elastostatics.settlingpressure.data\>\"", ",", "Word", ",", 
     RowBox[{"RecordLists", "\[Rule]", "True"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.41119119310721*^9, 3.41119122262121*^9}, {
   3.41119137019621*^9, 3.4111913705492105`*^9}, {3.41119152367521*^9, 
   3.4111915523272104`*^9}, {3.4111917409052105`*^9, 3.41119174474121*^9}, 
   3.41119322202821*^9, {3.4111937078392105`*^9, 3.4111937295662103`*^9}, {
   3.5014855014524264`*^9, 3.5014855172513304`*^9}, {3.503397297359701*^9, 
   3.503397310645461*^9}, {3.5053718799263344`*^9, 3.5053718862296953`*^9}, {
   3.505372166213709*^9, 3.50537219296624*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Select, clean and plot data at z=0", "Subsection",
 CellChangeTimes->{{3.4111932325132103`*^9, 3.4111932377072105`*^9}, {
  3.4111939958462105`*^9, 3.41119399919421*^9}, {3.41119537498421*^9, 
  3.4111953757302103`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"table", "=", 
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{"data", ",", "1"}], "]"}], "//", "ToExpression"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "remove", " ", "header", " ", "and", " ", "convert", " ", "rest", " ", 
    "to", " ", "numbers"}], " ", "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.41119161509721*^9, 3.41119168819621*^9}, {
   3.41119177267221*^9, 3.4111918112872105`*^9}, {3.4111922214052105`*^9, 
   3.4111922311432104`*^9}, {3.41119292376421*^9, 3.4111929274332104`*^9}, 
   3.41119361431021*^9, {3.4111936566172104`*^9, 3.4111936679332104`*^9}, {
   3.4111937724922104`*^9, 3.41119378100321*^9}, {3.4111938547662106`*^9, 
   3.41119389185721*^9}, {3.41119393315621*^9, 3.41119395328521*^9}, {
   3.41119406975521*^9, 3.41119408558121*^9}, {3.41119411943021*^9, 
   3.4111941392962103`*^9}, 3.41119437121921*^9, {3.41119455266721*^9, 
   3.41119456383121*^9}, {3.41119521063421*^9, 3.41119521300221*^9}, {
   3.41119535550921*^9, 3.41119535896021*^9}, {3.41252651552*^9, 
   3.412526548627*^9}, {3.5873514314118557`*^9, 3.587351446563761*^9}, {
   3.5873530883362637`*^9, 3.587353089159342*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"table", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"radial", " ", "coordinates"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Reverse", "[", "r", "]"}]}], ",", "r"}], "]"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"combine", " ", "with", " ", "mirror", " ", "values"}], " ", 
   "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.41119544629321*^9, 3.41119547570321*^9}, {
  3.4125265689449997`*^9, 3.412526569144*^9}, {3.4125657954966817`*^9, 
  3.412565800462682*^9}, {3.4125658544786816`*^9, 3.4125659897556815`*^9}, {
  3.5873512517802896`*^9, 3.587351268044317*^9}, {3.5873514256680946`*^9, 
  3.5873514288595157`*^9}, {3.5873514735241575`*^9, 3.5873514747393074`*^9}, {
  3.5873515370991383`*^9, 3.5873515782762794`*^9}, {3.587351740355649*^9, 
  3.587351750442912*^9}, {3.5873530402482276`*^9, 3.587353040976318*^9}, {
  3.5873531016399517`*^9, 3.5873531026640377`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]zz", "=", 
   RowBox[{"table", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "3"}], "]"}], "]"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"vertical", " ", "stress"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]zz", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Reverse", "[", "\[Sigma]zz", "]"}], ",", "\[Sigma]zz"}], 
    "]"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"combine", " ", "with", " ", "mirror", " ", "values"}], " ", 
   "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.41119548588721*^9, 3.41119550397921*^9}, {
  3.4125265804*^9, 3.412526580598*^9}, {3.4125657249616814`*^9, 
  3.4125657487146816`*^9}, {3.4125659508836813`*^9, 3.4125659530346813`*^9}, {
  3.4125659932546816`*^9, 3.4125660411996813`*^9}, {3.5873516310279183`*^9, 
  3.5873516426033382`*^9}, {3.5873516989874697`*^9, 3.587351726378889*^9}, {
  3.58735175722773*^9, 3.58735177100349*^9}, {3.587353032809266*^9, 
  3.5873530335604086`*^9}, {3.5873531049753833`*^9, 3.5873531068636065`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]0", "=", 
   RowBox[{"-", "2"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   Cell["\[Sigma]0 = -\[Rho]0 g0 h with \[Rho]0=g0=1;  "], "undeformed", " ", 
    "vertical", " ", "bottom", " ", "stress"}], " ", "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.587351945123375*^9, 3.5873520125347824`*^9}, {
  3.5873526732402105`*^9, 3.587352698984349*^9}, {3.587352765304739*^9, 
  3.5873528558730907`*^9}, {3.587352907328534*^9, 3.5873529085677214`*^9}, {
  3.587352989137825*^9, 3.58735301339287*^9}, {3.5873530615119143`*^9, 
  3.587353068831833*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]pz", "=", 
   RowBox[{"Thread", "[", 
    RowBox[{"List", "[", 
     RowBox[{"r", ",", 
      RowBox[{
       RowBox[{"-", "\[Sigma]zz"}], "+", "\[Sigma]0"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.41119400588021*^9, 3.41119403341021*^9}, {
   3.41119565527421*^9, 3.41119566364221*^9}, {3.412526631836*^9, 
   3.412526631961*^9}, {3.412565766488682*^9, 3.4125657824856815`*^9}, {
   3.4125658157936816`*^9, 3.412565819205682*^9}, {3.484627155437344*^9, 
   3.484627161506691*^9}, 3.587351395388291*^9, {3.587351804275677*^9, 
   3.5873518250032883`*^9}, {3.587352920760211*^9, 3.5873529308644924`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figa", "=", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"\[CapitalDelta]pz", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", Cell[TextData[Cell[BoxData[
         FormBox[
          RowBox[{"\[CapitalDelta]", "\[NegativeThinSpace]", 
           SubscriptBox["p", "z"]}], TraditionalForm]]]]]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], "//", 
   "\[IndentingNewLine]", 
   RowBox[{"Figure", "[", 
    RowBox[{"\"\<elastostatics-settlingpressure\>\"", ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"0.85", "Large"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4111919120232105`*^9, 3.4111919284382105`*^9}, {
   3.41119208704721*^9, 3.4111920972212105`*^9}, {3.41119213188321*^9, 
   3.41119220413921*^9}, {3.4111922419072104`*^9, 3.41119224639721*^9}, {
   3.41119289042321*^9, 3.41119289657821*^9}, {3.41119294068621*^9, 
   3.41119294557121*^9}, 3.4111929792892103`*^9, {3.4111930366882105`*^9, 
   3.4111931173652105`*^9}, {3.41119326138021*^9, 3.41119329130421*^9}, {
   3.4111940183982105`*^9, 3.41119403009521*^9}, {3.4111988160582104`*^9, 
   3.4111988209242105`*^9}, {3.4111988745592103`*^9, 
   3.4111988756432104`*^9}, {3.4125660563406816`*^9, 
   3.4125660624856815`*^9}, {3.412566149920682*^9, 3.4125661947686815`*^9}, {
   3.4125797205675325`*^9, 3.4125797509235325`*^9}, {3.413270692731366*^9, 
   3.4132706945193663`*^9}, 3.413278387455*^9, {3.4175785933942876`*^9, 
   3.4175785960502872`*^9}, 3.4309106138306*^9, {3.484627146119811*^9, 
   3.4846271964706907`*^9}, {3.4846272274064603`*^9, 
   3.4846272344738646`*^9}, {3.4846272743311443`*^9, 3.4846272744691525`*^9}, 
   3.4929192122922573`*^9, {3.5014855261268377`*^9, 3.5014856544061747`*^9}, {
   3.501901575735202*^9, 3.501901584820721*^9}, {3.501901650828497*^9, 
   3.501901713708093*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.575542443816111*^9, 3.5758712929428663`*^9, 3.5865813313773713`*^9, 
   3.587351256441847*^9, {3.5873529277531304`*^9, 3.5873529406267385`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJw9k21Ik2EUhp9KMESykRAV5nKZ1o+S/FH0wS2yhIREpQX9SEz7IPshWDBE
whWVi5CsCFKQtpKklWyYs2yb50ULP0qQiJjham5q5ccqKVIqLN05HXh5eeDh
POfc93VvKCkvPL5UKbXn37fwf5hUZjGbv1D+6cy8364+OrFYEcq/kb5jZnM3
ee27TppM0+TKcM6Oal4K/CzabjRO0dfY9JA/xk2ZizVJxdv8QyOJLdT8oXZ9
SsoE2RIzhpJm7PRnbUmyTveZVNmW6bNVdaQW6xMpW3ulSsjGsrHGYCQyTupo
S/zg42s4rK8YCQTGSHVsijtX04iBVws1Slph/Jx9ogmG5fYBjydM6qb+YHuF
A8aiF7cdjhCpM9W5/ZedaKhfqBGydFf27I9vhSl0q9pqDZLmfz5vSG7j996T
+nF3lW/ezf2HKRjjjXS2PYE79cI9h+MdaRVxww3owIqc7xetVj9ZOlRubdMz
RPV5S/rpSMHOsAd5tG6v0fiG1KlUZ/lKH6L7vyaLvsBwaEknovsOUtYVXc2j
qU60Zo12eTwvKXj1V+WBesKx872XzOYeUqXZG9ekaIjq2U223vu946Ua+j9u
nQoEfGQpiE3Ladaw70hfscnkpsHdXU1PezTe9wG57lR568Iavunn0nS662SZ
XJ1QN/v/DDnzfch97gfpx+9B3uN5IPPwvJB5eR/IPrwvZF/WA6IH6wXRi/WE
6Ml6Q/RmPyB+sF8Qv9hPiJ/sN8Rv5gHCA/MC4YV5gvDEvEF4Yx4hPDKvEF6Z
ZwjPzDuEd84DJA+cF0heOE+QPHHeIHnjPELyyHmF5PUvuWDojw==
     "]]}, {}},
  AspectRatio->NCache[
    Rational[1, 3], 0.3333333333333333],
  Axes->True,
  AxesLabel->{
    FormBox["x", TraditionalForm], 
    FormBox[
     InterpretationBox[
      Cell[
       BoxData[
        FormBox[
         Cell[
          BoxData[
           FormBox[
            RowBox[{"\[CapitalDelta]", "\[NegativeThinSpace]", 
              SubscriptBox["p", "z"]}], TraditionalForm]]], 
         TraditionalForm]]], 
      TextCell[
       RawBoxes[
        Cell[
         BoxData[
          FormBox[
           RowBox[{"\[CapitalDelta]", "\[NegativeThinSpace]", 
             SubscriptBox["p", "z"]}], TraditionalForm]]]]]], 
     TraditionalForm]},
  AxesOrigin->{0., 0.},
  Method->{},
  PlotRange->{{-0.98333335, 0.98333335}, {-0.20071367090607817`, 
   0.1325855325411247}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.039333334, 0.039333334}, {0.006665984068944058, 
   0.006665984068944058}}]], "Output",
 CellChangeTimes->{
  3.575542443849114*^9, 3.575871292944866*^9, 3.586581331382337*^9, 
   3.5873512564448605`*^9, {3.5873529277560787`*^9, 3.587352940628706*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check that total force  vanishes", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{"Interpolation", "[", "\[CapitalDelta]pz", "]"}]}]], "Input",
 CellChangeTimes->{{3.41119356950921*^9, 3.4111936294942102`*^9}, {
  3.41119567342021*^9, 3.4111956748222103`*^9}, {3.413278267599*^9, 
  3.413278290449*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.98333335`"}], ",", "0.98333335`"}], "}"}], "}"}], 
    ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{
  3.575542443929123*^9, 3.5758712930238934`*^9, 3.586581331688409*^9, 
   3.5873512564858637`*^9, {3.5873529277930794`*^9, 3.587352940726713*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"force", "=", 
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{"2", "\[Pi]", " ", "x", " ", 
     RowBox[{"f", "[", "x", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.41119356950921*^9, 3.4111936294942102`*^9}, {
  3.41119567342021*^9, 3.4111956748222103`*^9}, {3.413278267599*^9, 
  3.413278313139*^9}}],

Cell[BoxData["0.0005488678329136527`"], "Output",
 CellChangeTimes->{
  3.57554244441518*^9, 3.5758712933739257`*^9, 3.586581332078432*^9, 
   3.587351256919945*^9, {3.587352927868112*^9, 3.587352940810715*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 9.3  Bending a beam (p. 146)\
\>", "Title",
 CellChangeTimes->{{3.5018349830079594`*^9, 3.501834991646454*^9}, {
  3.587353329733574*^9, 3.5873533373825903`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Margin figure: Pipe moment (p. 149)\
\>", "Section",
 CellChangeTimes->{{3.412154017175*^9, 3.412154018293*^9}, {3.412155366469*^9,
   3.412155375157*^9}, {3.58735327698297*^9, 3.587353295206286*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.412154023108*^9, 3.412154025815*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(8\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.5755424762279973`*^9, 3.575871299763722*^9, 
  3.5764883133095675`*^9, 3.58658133227347*^9, 3.5873531208433423`*^9, 
  3.5873537318620863`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"1", "-", 
     SuperscriptBox["x", "4"]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["a", "b"], ",", "\"\<Pipe/Solid\>\""}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<elastostatics-pipemoment\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.412154057999*^9, 3.412154169561*^9}, {3.412154223705*^9,
    3.412154270731*^9}, {3.412154418539*^9, 3.41215441913*^9}, {
   3.4175786140012875`*^9, 3.4175786162892876`*^9}, 3.4309106145416*^9, {
   3.4846276732629623`*^9, 3.484627757464778*^9}, {3.484627817451209*^9, 
   3.48462782131343*^9}, {3.4846279921121993`*^9, 3.484627998737578*^9}, 
   3.492919216501498*^9, {3.501485798249402*^9, 3.501485801542591*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5755424765360374`*^9, 3.57587129995275*^9, 
  3.576488313492592*^9, 3.586581332447504*^9, 3.587353121010355*^9, 
  3.587353732050074*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwd2Gc8Vu8bAHAkCRVRZIRSIStlhktkZDSMIhJCmWUkoewZ4Uc22XvvTeIh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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     FractionBox["a", "b"], TraditionalForm], 
    FormBox["\"Pipe/Solid\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.575542476552038*^9, 3.5758712999617653`*^9, 
  3.576488313499595*^9, 3.586581332449464*^9, 3.587353121018351*^9, 
  3.587353732053069*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 9.3 [Flexural rigidity of a water pipe] (p. 149)\
\>", "Section",
 CellChangeTimes->{{3.412155381552*^9, 3.412155385877*^9}, {
  3.5018350588552976`*^9, 3.501835061063424*^9}, {3.501835097238493*^9, 
  3.5018351087431507`*^9}, {3.58735330860697*^9, 3.587353311670309*^9}, {
  3.587353374854266*^9, 3.5873533791978426`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.412155388626*^9, 3.412155426792*^9}, {3.412155578042*^9,
    3.412155579448*^9}, {3.4121557323929996`*^9, 3.412155771513*^9}, {
   3.50183518460249*^9, 3.501835221913624*^9}, {3.5018353289617467`*^9, 
   3.501835341689475*^9}, {3.5018355680274205`*^9, 3.5018355707705774`*^9}, {
   3.501836087210116*^9, 3.501836095040564*^9}, {3.5019018074834566`*^9, 
   3.5019018078254766`*^9}, {3.5755425019860897`*^9, 3.5755425025451565`*^9}, 
   3.5873533871657963`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(11\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{{3.587353732219135*^9, 3.587353764815223*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.587353397471096*^9, 3.587353398782355*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["g", "0"], "=", "AccelerationDueToGravity"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"1.27", "Centimeter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"inner", " ", "pipe", " ", "radius"}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"1.68", "Centimeter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"outer", " ", "pipe", " ", "radius"}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"200.", " ", "Gigapascal"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Youngs", " ", "modulus"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"75.", " ", "Kilogram"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mass", " ", "of", " ", "pipe"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"1.", "Meter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"length", " ", "of", " ", "pipe"}], " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.412155388626*^9, 3.412155426792*^9}, {3.412155578042*^9,
   3.412155579448*^9}, {3.4121557323929996`*^9, 3.412155771513*^9}, {
  3.50183518460249*^9, 3.501835221913624*^9}, {3.5018353289617467`*^9, 
  3.501835341689475*^9}, {3.5018355680274205`*^9, 3.5018355707705774`*^9}, {
  3.501836087210116*^9, 3.501836095040564*^9}, {3.5019018074834566`*^9, 
  3.5019018078254766`*^9}, {3.5755425019860897`*^9, 3.5755425025451565`*^9}, {
  3.5873533871657963`*^9, 3.587353428656012*^9}, {3.5873536105758176`*^9, 
  3.5873536501588163`*^9}, {3.5873537591755295`*^9, 3.587353761374802*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.587353780742237*^9, 3.5873537825664105`*^9}}],

Cell["\<\
Ratio of area moment of pipe to solid rod\
\>", "Text",
 CellChangeTimes->{{3.58735349227001*^9, 3.587353494734326*^9}, {
  3.5873535499662657`*^9, 3.5873535554939613`*^9}, {3.5873536703583207`*^9, 
  3.587353678229351*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox[
   RowBox[{"(", 
    FractionBox["a", "b"], ")"}], "4"]}]], "Input",
 CellChangeTimes->{{3.412155910715*^9, 3.412155936984*^9}}],

Cell[BoxData["0.6734288941123265`"], "Output",
 CellChangeTimes->{
  3.57554247691708*^9, {3.575542511305208*^9, 3.5755425271871133`*^9}, 
   3.5755426003778954`*^9, 3.575871300166773*^9, 3.576488313715661*^9, 
   3.586581332999572*^9, 3.587353121232421*^9, {3.5873537322901363`*^9, 
   3.587353764910234*^9}}]
}, Open  ]],

Cell["Area moment of pipe", "Text",
 CellChangeTimes->{{3.5873535880060043`*^9, 3.5873535938617935`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"II", "=", 
  RowBox[{
   RowBox[{
    FractionBox["\[Pi]", "4"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "4"], "-", 
      SuperscriptBox["a", "4"]}], ")"}]}], "//", 
   RowBox[{"ToUnit", "[", "Centimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.412155535082*^9, 3.412155572153*^9}, {
  3.57554251782699*^9, 3.575542518194035*^9}}],

Cell[BoxData[
 TemplateBox[{"4.21326479544415`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{
            SuperscriptBox["\"cm\"", "4"]}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: centimeters to the fourth"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       SuperscriptBox["\"Centimeters\"", "4"]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755424770160933`*^9, {3.575542511386218*^9, 3.575542527260123*^9}, 
   3.5755426004499035`*^9, 3.5758713002137785`*^9, 3.576488313765628*^9, 
   3.5865813330495996`*^9, 3.5873531212803984`*^9, {3.5873537323271446`*^9, 
   3.587353764948223*^9}}]
}, Open  ]],

Cell["Flexural rigidity", "Text",
 CellChangeTimes->{{3.5873535997985168`*^9, 3.587353607173462*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EI", "=", 
  RowBox[{
   RowBox[{"EE", "*", "II"}], "//", 
   RowBox[{"ToUnit", "[", 
    RowBox[{"Newton", " ", 
     SuperscriptBox["Meter", "2"]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.412155716137*^9, 3.412155726696*^9}, {3.412155777111*^9,
   3.4121558120559998`*^9}, {3.575542583424861*^9, 3.575542583755901*^9}}],

Cell[BoxData[
 TemplateBox[{"8426.5295908883`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{
            SuperscriptBox["\"m\"", "2"], "\[InvisibleSpace]", "\"N\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: meter squared newtons"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       RowBox[{
         SuperscriptBox["\"Meters\"", "2"], " ", "\"Newtons\""}]}], 
     "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542477295127*^9, {3.575542511658251*^9, 3.5755425275311546`*^9}, {
   3.575542584992049*^9, 3.575542600643927*^9}, 3.575871300329793*^9, 
   3.576488313888641*^9, 3.586581333176589*^9, 3.5873531213954315`*^9, {
   3.5873537324251623`*^9, 3.5873537650542555`*^9}}]
}, Open  ]],

Cell["Bending moment", "Text",
 CellChangeTimes->{{3.5873536986699114`*^9, 3.5873537008622065`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["M", "b"], "=", 
  RowBox[{
   RowBox[{"L", " ", "M", " ", 
    SubscriptBox["g", "0"]}], "//", 
   RowBox[{"ToUnit", "[", 
    RowBox[{"Newton", " ", "Meter"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.501836073144312*^9, 3.501836083289892*^9}, {
  3.587353727558529*^9, 3.587353743947604*^9}, {3.5873538592390833`*^9, 
  3.5873538817948813`*^9}, {3.5873540360142717`*^9, 3.5873540416129637`*^9}}],

Cell[BoxData[
 TemplateBox[{"735.49875`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"m\"", "\[ThinSpace]", "\"N\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: meter newtons"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       RowBox[{"\"Meters\"", " ", "\"Newtons\""}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.587353728016562*^9, 3.5873537651402626`*^9}, {
   3.587353863321594*^9, 3.5873538823909492`*^9}, 3.5873540422330155`*^9}]
}, Open  ]],

Cell["Radius of curvature", "Text",
 CellChangeTimes->{{3.587353719613536*^9, 3.587353722573949*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", "=", 
  RowBox[{
   FractionBox["EI", 
    RowBox[{"L", " ", "M", " ", 
     SubscriptBox["g", "0"]}]], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.501836104005077*^9, 3.50183613186767*^9}, {
  3.575542614353572*^9, 3.575542615052656*^9}}],

Cell[BoxData[
 TemplateBox[{"11.456891790622759`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Meters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542477847192*^9, {3.575542512015293*^9, 3.5755425278921986`*^9}, {
   3.5755426011289854`*^9, 3.575542616441823*^9}, 3.5758713005918922`*^9, 
   3.5764883141576743`*^9, 3.5865813337056227`*^9, 3.587353121645462*^9, {
   3.5873537327141933`*^9, 3.587353765314288*^9}}]
}, Open  ]],

Cell["Bending angle", "Text",
 CellChangeTimes->{{3.587353819230073*^9, 3.587353821061304*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Phi]", "=", 
  RowBox[{
   FractionBox["L", "R"], "/", "Degree"}]}]], "Input",
 CellChangeTimes->{{3.501836414731849*^9, 3.5018364208662004`*^9}, {
   3.5018365210669312`*^9, 3.5018365223140025`*^9}, 3.5018365630513325`*^9, {
   3.5873537979273634`*^9, 3.587353800340642*^9}}],

Cell[BoxData["5.000988100453021`"], "Output",
 CellChangeTimes->{
  3.5755424778881984`*^9, {3.575542512061297*^9, 3.575542527944205*^9}, 
   3.575542601218996*^9, 3.5758713006408324`*^9, 3.5764883141996803`*^9, 
   3.586581334298772*^9, 3.587353121689469*^9, {3.5873537327561994`*^9, 
   3.587353765359293*^9}, 3.587353800756739*^9}]
}, Open  ]],

Cell["Terminal deflection", "Text",
 CellChangeTimes->{{3.587353833551853*^9, 3.5873538437011127`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"y", "=", 
  RowBox[{
   RowBox[{"R", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ")"}]}], "//", 
   RowBox[{"ToUnit", "[", "Centimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.501836542065132*^9, 3.5018365529137526`*^9}, {
  3.5755426969124775`*^9, 3.57554270226612*^9}}],

Cell[BoxData[
 TemplateBox[{"4.361415421343632`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"cm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: centimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Centimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542477989209*^9, {3.5755425121433086`*^9, 3.5755425280562177`*^9}, 
   3.575542601370014*^9, 3.5755427026301622`*^9, 3.5758713006868844`*^9, 
   3.576488314241683*^9, 3.586581334486741*^9, 3.587353121728443*^9, {
   3.587353732797161*^9, 3.587353765400296*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 9.5 [Paper-clips] (p. 150)\
\>", "Section",
 CellChangeTimes->{{3.501902109957758*^9, 3.5019021238445516`*^9}, {
  3.5873539795812025`*^9, 3.587353988413354*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4122266632655864`*^9, 3.4122266658295865`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(11\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.575542478283244*^9, 3.5755427178679924`*^9, 
  3.5755429196832066`*^9, 3.5758713008478584`*^9, 3.5764883144087057`*^9, 
  3.586581335069849*^9, 3.5873531218934894`*^9, 3.587353732964223*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Small", "Subsection",
 CellChangeTimes->{{3.501902197925789*^9, 3.5019021998288975`*^9}}],

Cell["Parameters", "Text",
 CellChangeTimes->{{3.587354013101458*^9, 3.587354014429614*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"0.25", "Millimeter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"radius", " ", "of", " ", "clips", " ", "thread"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"220", " ", "Gigapascal"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Young", "'"}], "s", " ", "modulus"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", 
   RowBox[{"220", " ", "Megapascal"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"yield", " ", "stress"}], " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4122266679325867`*^9, 3.4122267119105864`*^9}, 
   3.4122267579425864`*^9, {3.4122268973185863`*^9, 3.412226897813586*^9}, {
   3.4122272924865866`*^9, 3.4122272931735864`*^9}, {3.412227819190586*^9, 
   3.4122278194775867`*^9}, {3.4122291751745863`*^9, 
   3.4122291755095863`*^9}, {3.4122292233505864`*^9, 
   3.4122292246455865`*^9}, {3.413278460105*^9, 3.4132784804709997`*^9}, {
   3.5019022242002916`*^9, 3.50190222889756*^9}, {3.5755429007369347`*^9, 
   3.575542905071453*^9}, {3.587354053518487*^9, 3.5873540697025237`*^9}, {
   3.5873541039498215`*^9, 3.5873541189506817`*^9}, {3.5873541808624783`*^9, 
   3.587354185783045*^9}}],

Cell["Bending radius", "Text",
 CellChangeTimes->{{3.5873541922139025`*^9, 3.5873541941972046`*^9}, 
   3.5873542489249945`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", "=", 
  RowBox[{
   RowBox[{"a", 
    FractionBox["EE", "\[Sigma]"]}], "//", 
   RowBox[{"ToUnit", "[", "Centimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4122267149415865`*^9, 3.4122267734935865`*^9}}],

Cell[BoxData[
 TemplateBox[{"25.`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"cm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: centimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Centimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755424785262733`*^9, 3.5755427180880194`*^9, 
  3.5755429199002333`*^9, 3.5758713010008793`*^9, 3.5764883145497646`*^9, 
  3.586581335175807*^9, 3.5873531220175056`*^9, 3.5873537330912*^9}]
}, Open  ]],

Cell["Yield moment", "Text",
 CellChangeTimes->{{3.58735423186086*^9, 3.5873542454685745`*^9}, {
  3.587354337613145*^9, 3.5873543395563846`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["M", "b"], "=", 
  RowBox[{
   RowBox[{
    FractionBox["\[Pi]", "4"], 
    SuperscriptBox["a", "3"], "\[Sigma]"}], "//", 
   RowBox[{"ToUnit", "[", 
    RowBox[{"Newton", " ", "Millimeter"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4122268167365866`*^9, 3.4122268458785863`*^9}, {
  3.412227397702586*^9, 3.412227399926586*^9}, {3.501902287411907*^9, 
  3.5019022878589325`*^9}}],

Cell[BoxData[
 TemplateBox[{"2.6998061866787286`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"mm\"", "\[ThinSpace]", "\"N\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: millimeter newtons"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       RowBox[{"\"Millimeters\"", " ", "\"Newtons\""}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755424787833033`*^9, 3.5755427182980423`*^9, 
  3.575542920111257*^9, 3.5758713011358953`*^9, 3.576488314691742*^9, 
  3.5865813353268714`*^9, 3.587353122150526*^9, 3.5873537332042356`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large", "Subsection",
 CellChangeTimes->{{3.501902197925789*^9, 3.5019022107485223`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"1.0", "Millimeter"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"220", " ", "Gigapascal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", 
   RowBox[{"220", " ", "Megapascal"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4122266679325867`*^9, 3.4122267119105864`*^9}, 
   3.4122267579425864`*^9, {3.4122268973185863`*^9, 3.412226897813586*^9}, {
   3.4122272924865866`*^9, 3.4122272931735864`*^9}, {3.412227819190586*^9, 
   3.4122278194775867`*^9}, {3.4122291751745863`*^9, 
   3.4122291755095863`*^9}, {3.4122292233505864`*^9, 
   3.4122292246455865`*^9}, {3.413278460105*^9, 3.4132784804709997`*^9}, {
   3.5755429097600164`*^9, 3.5755429147486134`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", "=", 
  RowBox[{
   RowBox[{"a", 
    FractionBox["EE", "\[Sigma]"]}], "//", 
   RowBox[{"ToUnit", "[", "Centimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4122267149415865`*^9, 3.4122267734935865`*^9}}],

Cell[BoxData[
 TemplateBox[{"100.`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"cm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: centimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Centimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755424794203806`*^9, 3.575542718446062*^9, 
  3.575542920256276*^9, 3.5758713012119045`*^9, 3.57648831478078*^9, 
  3.5865813358789387`*^9, 3.5873531222245345`*^9, 3.587353733281247*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["M", "b"], "=", 
  RowBox[{
   RowBox[{
    FractionBox["\[Pi]", "4"], 
    SuperscriptBox["a", "3"], "\[Sigma]"}], "//", 
   RowBox[{"ToUnit", "[", 
    RowBox[{"Newton", " ", "Millimeter"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4122268167365866`*^9, 3.4122268458785863`*^9}, {
  3.412227397702586*^9, 3.412227399926586*^9}, {3.501902291915165*^9, 
  3.501902292338189*^9}}],

Cell[BoxData[
 TemplateBox[{"172.78759594743863`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"mm\"", "\[ThinSpace]", "\"N\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: millimeter newtons"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       RowBox[{"\"Millimeters\"", " ", "\"Newtons\""}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755424806515293`*^9, 3.5755427186520863`*^9, 
  3.5755429204643*^9, 3.5758713013289185`*^9, 3.5764883148968077`*^9, 
  3.586581336384963*^9, 3.587353122337511*^9, 3.587353733402278*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 9.4 Application: Twisting a shaft (p. 150)\
\>", "Title",
 CellChangeTimes->{{3.5019032420545096`*^9, 3.501903254052196*^9}, {
  3.587355786491189*^9, 3.587355790993758*^9}}],

Cell[CellGroupData[{

Cell["Example 9.6 Car engine (p.152)", "Section",
 CellChangeTimes->{{3.5019032932604384`*^9, 3.501903298516739*^9}, {
  3.5873558019862113`*^9, 3.5873558102421975`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(17\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.5755428883934517`*^9, 3.5755429343009615`*^9, 
  3.57554332793019*^9, 3.5758713062945423`*^9, 3.576488322203697*^9, 
  3.5865813374160886`*^9, 3.587356064798107*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"T", "=", 
   RowBox[{"100.", " ", "Newton", " ", "Meter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"typical", " ", "torque", " ", "from", " ", "car", " ", "engine"}],
    " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"2.", " ", "Centimeter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"drive", " ", "shaft", " ", "radius"}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"205.", " ", "Gigapascal"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Young", "'"}], "s", " ", "modulus"}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Nu]", "=", "0.29"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Poisson", "'"}], "s", " ", "ratio"}], " ", "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[CapitalOmega]", "=", 
   RowBox[{"3000.", " ", "RPM"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"rotations", " ", "per", " ", "minute"}], " ", "*)"}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.501903335967881*^9, {3.501903372296959*^9, 3.50190343228039*^9}, {
   3.5755429263970127`*^9, 3.5755429269440784`*^9}, {3.5873558435473256`*^9, 
   3.587355887842948*^9}, {3.58735601190751*^9, 3.5873560550749445`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5873562771788316`*^9, 3.5873562781849356`*^9}}],

Cell["Power", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "=", 
  RowBox[{
   RowBox[{"\[CapitalOmega]", " ", "T"}], "//", 
   RowBox[{"ToUnit", "[", "Kilowatt", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5019033446793795`*^9, 3.501903345631434*^9}, {
  3.5019034209597425`*^9, 3.5019034229198546`*^9}, {3.587355913026101*^9, 
  3.587355932842593*^9}, {3.5873559657147236`*^9, 3.587355970578329*^9}}],

Cell[BoxData[
 TemplateBox[{"31.41592653589793`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"kW\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilowatts"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Kilowatts\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575542888736493*^9, 3.5755429346099987`*^9, 3.5755433282212243`*^9, 
   3.575871306500571*^9, 3.5764883223947115`*^9, 3.5865813381112227`*^9, {
   3.5873559199249697`*^9, 3.5873559711263876`*^9}, 3.587356064973133*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "/", "Horsepower"}]], "Input",
 CellChangeTimes->{{3.5755429496648045`*^9, 3.5755429576627645`*^9}, {
  3.5755433106091127`*^9, 3.5755433142865543`*^9}, {3.575543352719165*^9, 
  3.5755433598700223`*^9}}],

Cell[BoxData["42.12944419457949`"], "Output",
 CellChangeTimes->{
  3.575542888771497*^9, {3.575542934649005*^9, 3.5755429629894037`*^9}, {
   3.5755433282612295`*^9, 3.575543360301073*^9}, 3.575871306568577*^9, 
   3.576488322463758*^9, 3.5865813382023106`*^9, 3.5873560650391903`*^9}]
}, Open  ]],

Cell["Shear modulus", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]", "=", 
  FractionBox["EE", 
   RowBox[{"2", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Nu]"}], ")"}]}]]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"79.45736434108527`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"GPa\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: gigapascals"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Gigapascals\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755428888075013`*^9, 3.5755429346900067`*^9, 
  3.575543328297233*^9, 3.5758713065906076`*^9, 3.5764883224827547`*^9, 
  3.5865813382253227`*^9, 3.5873560650591726`*^9}]
}, Open  ]],

Cell["Torsional rigidity", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CC", "=", 
  RowBox[{
   RowBox[{
    FractionBox["\[Pi]", "2"], "\[Mu]", " ", 
    SuperscriptBox["a", "4"]}], "//", 
   RowBox[{"ToUnit", "[", 
    RowBox[{"Newton", " ", 
     SuperscriptBox["Meter", "2"]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5755434280652046`*^9, 3.5755434302084627`*^9}}],

Cell[BoxData[
 TemplateBox[{"19969.813767004885`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{
            SuperscriptBox["\"m\"", "2"], "\[InvisibleSpace]", "\"N\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: meter squared newtons"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       RowBox[{
         SuperscriptBox["\"Meters\"", "2"], " ", "\"Newtons\""}]}], 
     "]"}]& )]], "Output",
 CellChangeTimes->{3.5755428890405293`*^9, 3.575542934914036*^9, 
  3.575543328530262*^9, 3.575543430952551*^9, 3.5758713067035933`*^9, 
  3.5764883225927362`*^9, 3.586581338978348*^9, 3.58735606516719*^9}]
}, Open  ]],

Cell["Torsion angle", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]", "=", 
  RowBox[{
   FractionBox["T", "CC"], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.501903356905079*^9, 3.501903357464111*^9}, {
  3.5873561113069887`*^9, 3.5873561417687845`*^9}}],

Cell[BoxData[
 TemplateBox[{"0.005007557965574268`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"per \"", "\[InvisibleSpace]", "\"meter\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: reciprocal meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["1", "\"Meters\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755428891085377`*^9, 3.5755429349540405`*^9, 3.5755433285962696`*^9, 
   3.5755434652616687`*^9, 3.5758713067996054`*^9, 3.5764883226917486`*^9, 
   3.5865813391073017`*^9, 3.5873560652652044`*^9, {3.5873561164536295`*^9, 
   3.587356142174875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]", " ", "/", "Degree"}]], "Input"],

Cell[BoxData[
 TemplateBox[{"0.28691193709452234`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{"\"per \"", "\[InvisibleSpace]", "\"meter\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: reciprocal meters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["1", "\"Meters\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5755428891465435`*^9, 3.5755429349920444`*^9, 
  3.5755433287442875`*^9, 3.5755434740437207`*^9, 3.575871306818611*^9, 
  3.576488322709751*^9, 3.5865813391263742`*^9, 3.5873560652881866`*^9}]
}, Open  ]],

Cell["Maximal shear stress", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Sigma]", "=", 
  RowBox[{
   RowBox[{"\[Mu]", " ", "\[Tau]", " ", "a"}], "//", 
   RowBox[{"ToUnit", "[", "Bar", "]"}]}]}]], "Input"],

Cell[BoxData[
 TemplateBox[{"79.57747154594767`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"bars\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: bars"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Bars\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575542889314562*^9, 3.5755429351500635`*^9, 
  3.5755433289063063`*^9, 3.5755434929819937`*^9, 3.5758713069126205`*^9, 
  3.5764883228067636`*^9, 3.5865813392193565`*^9, 3.5873560653811817`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 9.5 Application: Radial deformation of spherical body (p. 153)\
\>", "Title",
 CellChangeTimes->{{3.413353656989581*^9, 3.413353659020581*^9}, {
  3.501903783629486*^9, 3.5019038109080467`*^9}, {3.587356349569869*^9, 
  3.587356353145339*^9}, {3.587356649320531*^9, 3.5873566749287276`*^9}}],

Cell[CellGroupData[{

Cell["Analytic calculations", "Section",
 CellChangeTimes->{{3.587356885608199*^9, 3.5873569105523834`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.587356684342943*^9, 3.5873566887295065`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(26\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.587357447316712*^9, 3.587357477338519*^9, 
  3.5873575090705*^9, 3.587357644808546*^9, 3.5873608089518566`*^9, 
  3.5873608537094374`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Uniform radial displacement (p. 153)\
\>", "Subsection",
 CellChangeTimes->{{3.413353720828581*^9, 3.4133537234035807`*^9}, {
  3.501903850533313*^9, 3.5019038555325985`*^9}, {3.5019095063248053`*^9, 
  3.501909510548047*^9}, {3.5873567484579544`*^9, 3.5873567526245103`*^9}}],

Cell["Set up coordinate system", "Text",
 CellChangeTimes->{{3.587356596993044*^9, 3.5873566004244328`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Spherical", "[", 
    RowBox[{"r", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4133536953445807`*^9, 3.4133537030705805`*^9}}],

Cell["\<\
Assumption about the displacement\
\>", "Text",
 CellChangeTimes->{{3.5019038938377895`*^9, 3.5019038955798893`*^9}, {
  3.5873566040569267`*^9, 3.5873566071522408`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "r"], "[", "r", "]"}], ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equilibrium equation (p. 153)", "Subsection",
 CellChangeTimes->{{3.413353720828581*^9, 3.4133537234035807`*^9}, {
  3.501903850533313*^9, 3.5019038555325985`*^9}, {3.5873567557529693`*^9, 
  3.5873567599764404`*^9}}],

Cell["Volume force", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"Laplacian", "[", "u", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}], 
        RowBox[{"Grad", "[", 
         RowBox[{"Div", "[", "u", "]"}], "]"}]}]}], ")"}]}], "//", "Expand"}],
    "//", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{"\[Mu]", ",", "\[Lambda]"}], "}"}]}], "]"}], 
    "&"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{
          SubscriptBox["u", "r"], "[", "r", "]"}]}], 
        SuperscriptBox["r", "2"]], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["u", "r"], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "r"], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["u", "r"], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SubscriptBox["u", "r"], "[", "r", "]"}]}], 
        SuperscriptBox["r", "2"]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["u", "r"], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "r"], "-", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], ",", "0", 
   ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755435184450493`*^9, 3.5756887021566515`*^9, 3.5757928641739025`*^9, 
   3.5757941670715113`*^9, 3.575794225667852*^9, 3.5757942558026667`*^9, 
   3.5758706605674596`*^9, 3.575870708505478*^9, 3.5758713123643436`*^9, 
   3.575953861086652*^9, {3.5759541238476877`*^9, 3.575954148918836*^9}, {
   3.575959738313635*^9, 3.575959767301315*^9}, {3.5759606210225053`*^9, 
   3.575960648457944*^9}, 3.5764883278724017`*^9, 3.586581339628396*^9, {
   3.5873574475867834`*^9, 3.5873574774804926`*^9}, 3.5873575092125196`*^9, 
   3.5873576449485216`*^9, 3.587360809112877*^9, 3.587360853883498*^9}]
}, Open  ]],

Cell["Radial component", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "r"], "=", 
  RowBox[{"f", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4133534946065807`*^9, 3.4133534972785807`*^9}, {
  3.413353548000581*^9, 3.413353580815581*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Mu]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{
        SubscriptBox["u", "r"], "[", "r", "]"}]}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], "r"], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["u", "r"], "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"\[Lambda]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SubscriptBox["u", "r"], "[", "r", "]"}]}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], "r"], "-", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["u", "r"], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5755435184850535`*^9, 3.575688702179654*^9, 3.5757928642328787`*^9, 
   3.5757941670835104`*^9, 3.575794225692916*^9, 3.5757942558296537`*^9, 
   3.5758706605885296`*^9, 3.575870708526519*^9, 3.5758713123873186`*^9, 
   3.575953861110696*^9, {3.575954123867648*^9, 3.575954148945815*^9}, {
   3.5759597383326373`*^9, 3.575959767368323*^9}, {3.575960621047476*^9, 
   3.5759606484849396`*^9}, 3.5764883278965*^9, 3.5865813396463833`*^9, {
   3.5873574476087418`*^9, 3.587357477503503*^9}, 3.5873575092364798`*^9, 
   3.587357644973569*^9, 3.587360809141878*^9, 3.5873608539265046`*^9}]
}, Open  ]],

Cell["Check special form", "Text",
 CellChangeTimes->{{3.4133535392925806`*^9, 3.4133535404765806`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["f", "r"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Lambda]", "+", 
      RowBox[{"2", "\[Mu]"}]}], ")"}], 
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox["r", "2"]], 
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{
           SubscriptBox["u", "r"], "[", "r", "]"}]}], ")"}]}]}], ")"}]}]}]}], 
  "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.413353747329581*^9, 3.4133537511205807`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.5755435185240583`*^9, 3.575688702201662*^9, 3.575792864253917*^9, 
   3.575794167092511*^9, 3.575794225715898*^9, 3.5757942559166565`*^9, 
   3.5758706606094666`*^9, 3.575870708546526*^9, 3.575871312409334*^9, 
   3.575953861139701*^9, {3.575954123887707*^9, 3.575954148970841*^9}, {
   3.5759597383526397`*^9, 3.5759597673923635`*^9}, {3.5759606210824804`*^9, 
   3.5759606485079393`*^9}, 3.5764883279184203`*^9, 3.5865813396644335`*^9, {
   3.5873574476307845`*^9, 3.5873574775334997`*^9}, 3.587357509260537*^9, 
   3.5873576449985275`*^9, 3.58736080916586*^9, 3.587360853960498*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strains and stresses (p. 154)", "Subsection",
 CellChangeTimes->{{3.5873569601845956`*^9, 3.587356976152543*^9}}],

Cell["Strain", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], "+", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}]}], "//", 
   "Expand"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["u", "r"], "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], ",", "0", ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       SubscriptBox["u", "r"], "[", "r", "]"}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       SubscriptBox["u", "r"], "[", "r", "]"}], "r"]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.575543518717081*^9, 3.5756887023126454`*^9, 3.5757928643188844`*^9, 
   3.5757941671375074`*^9, 3.575794225763879*^9, 3.5757942559676733`*^9, {
   3.5758706606595116`*^9, 3.5758707085975337`*^9}, 3.5758713124633446`*^9, 
   3.575953861201666*^9, {3.5759541239336834`*^9, 3.575954149020815*^9}, 
   3.5759597383986864`*^9, {3.575960621138503*^9, 3.57596064855793*^9}, 
   3.5764883279734526`*^9, 3.58658133971138*^9, {3.5873574476817513`*^9, 
   3.5873574775855474`*^9}, 3.5873575093115487`*^9, 3.587357645055602*^9, 
   3.587360809219884*^9, 3.5873608540235305`*^9}]
}, Open  ]],

Cell["Stress", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Sigma]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"2", "\[Mu]", " ", "uu"}], "+", 
     RowBox[{"\[Lambda]", "  ", "UnitTensor", " ", 
      RowBox[{"Tr", "[", "uu", "]"}]}]}], "//", "Expand"}], "//", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{"#", ",", "A"}], "]"}], "&"}]}]}]], "Input",
 CellChangeTimes->{{3.5757942121271534`*^9, 3.5757942154886026`*^9}, {
  3.57595413683832*^9, 3.5759541377614403`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "\[Lambda]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5755435187590857`*^9, 3.57568870233365*^9, 3.5757928643289165`*^9, 
   3.575794167156499*^9, 3.5757942257868524`*^9, 3.5757942559936757`*^9, {
   3.575870660679475*^9, 3.5758707086075077`*^9}, 3.5758713124833193`*^9, 
   3.575953861231717*^9, {3.575954123953703*^9, 3.575954149046847*^9}, 
   3.57595973841469*^9, {3.575960621166527*^9, 3.575960648578933*^9}, 
   3.5764883279934235`*^9, 3.5865813397304325`*^9, {3.5873574477037535`*^9, 
   3.587357477608575*^9}, 3.5873575093364944`*^9, 3.587357645081538*^9, 
   3.58736080924485*^9, 3.5873608540575457`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Spherical shell under external pressure (p. 154)\
\>", "Subsection",
 CellChangeTimes->{{3.501904281467961*^9, 3.5019042924275875`*^9}, {
  3.587356995832044*^9, 3.5873570023918653`*^9}}],

Cell["General solution without external force", "Text",
 CellChangeTimes->{{3.5019042992599783`*^9, 3.5019043211642313`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["u", "r"], "[", "r_", "]"}], "=", 
   RowBox[{
    RowBox[{"A", " ", "r"}], "+", 
    FractionBox["B", 
     SuperscriptBox["r", "2"]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4133537695045805`*^9, 3.4133537698065805`*^9}, {
  3.413354698801581*^9, 3.413354724158581*^9}}],

Cell["Check solution", "Text",
 CellChangeTimes->{{3.5019043597524385`*^9, 3.5019043694909954`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "r"], "//", "Expand"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.575543518808092*^9, 3.5756887023596883`*^9, 3.5757928643880243`*^9, 
   3.5757941671765223`*^9, 3.5757942258148713`*^9, 3.5757942560236764`*^9, {
   3.575870660701521*^9, 3.575870708630518*^9}, 3.5758713125063257`*^9, 
   3.575953861264674*^9, {3.5759541239766617`*^9, 3.5759541490768533`*^9}, 
   3.5759597384356904`*^9, {3.575960621206524*^9, 3.5759606486019354`*^9}, 
   3.5764883280174727`*^9, 3.5865813397594223`*^9, {3.5873574477297573`*^9, 
   3.5873574776355186`*^9}, 3.587357509363541*^9, 3.587357645111554*^9, 
   3.587360809272858*^9, 3.5873608540944824`*^9}]
}, Open  ]],

Cell["Strains", "Text",
 CellChangeTimes->{{3.501904398396649*^9, 3.5019043995247135`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.5019044040339713`*^9, 3.5019044433822217`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "-", 
      FractionBox[
       RowBox[{"2", " ", "B"}], 
       SuperscriptBox["r", "3"]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"A", "+", 
      FractionBox["B", 
       SuperscriptBox["r", "3"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"A", "+", 
      FractionBox["B", 
       SuperscriptBox["r", "3"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755435188490973`*^9, 3.5756887023816924`*^9, 3.575792864407898*^9, 
   3.5757941671855235`*^9, 3.5757942258358455`*^9, 3.5757942560496435`*^9, {
   3.575870660720521*^9, 3.575870708648547*^9}, 3.575871312526325*^9, 
   3.5759538612937346`*^9, {3.5759541239956903`*^9, 3.5759541491018596`*^9}, 
   3.5759597384526925`*^9, {3.575960621232546*^9, 3.5759606486209383`*^9}, 
   3.576488328037473*^9, 3.5865813397794247`*^9, {3.587357447750778*^9, 
   3.5873574776575146`*^9}, 3.5873575093865623`*^9, 3.5873576451365447`*^9, 
   3.587360809296876*^9, 3.5873608541315513`*^9}]
}, Open  ]],

Cell["Stresses", "Text",
 CellChangeTimes->{{3.501904476285104*^9, 3.5019044787322435`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", "//", "Expand"}], "//", 
  RowBox[{"DoCollect", "[", 
   RowBox[{"{", 
    RowBox[{"A", ",", "B"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5019044812683887`*^9, 3.501904528007062*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"4", " ", "B", " ", "\[Mu]"}], 
        SuperscriptBox["r", "3"]]}], "+", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "B", " ", "\[Mu]"}], 
       SuperscriptBox["r", "3"]], "+", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "B", " ", "\[Mu]"}], 
       SuperscriptBox["r", "3"]], "+", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755435188931046`*^9, 3.5756887024036922`*^9, 3.575792864431926*^9, 
   3.575794167202531*^9, 3.575794225855889*^9, 3.575794256074685*^9, {
   3.57587066073952*^9, 3.5758707086675396`*^9}, 3.575871312545376*^9, 
   3.57595386132472*^9, {3.5759541240157113`*^9, 3.5759541491238194`*^9}, 
   3.5759597384676924`*^9, {3.5759606212665586`*^9, 3.57596064864098*^9}, 
   3.576488328056445*^9, 3.586581339800389*^9, {3.5873574477728043`*^9, 
   3.5873574776805573`*^9}, 3.5873575094115257`*^9, 3.587357645162548*^9, 
   3.58736080932086*^9, 3.5873608541664915`*^9}]
}, Open  ]],

Cell["Apply boundary conditions", "Text",
 CellChangeTimes->{{3.587357100912212*^9, 3.587357103671589*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "/.", 
          RowBox[{"r", "\[Rule]", "a"}]}], ")"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "/.", 
          RowBox[{"r", "\[Rule]", "b"}]}], ")"}], "\[Equal]", 
        RowBox[{"-", "P"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "B"}], "}"}]}], "]"}], "//", "First"}]}]], "Input",
 CellChangeTimes->{{3.4133538076485806`*^9, 3.4133538116795807`*^9}, 
   3.4133543556655807`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["b", "3"], " ", "P"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        SuperscriptBox["b", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Lambda]"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]]}], ",", 
   RowBox[{"B", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", "P"}], 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        SuperscriptBox["b", "3"]}], ")"}], " ", "\[Mu]"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.575543518936109*^9, 3.5756887024267073`*^9, 3.5757928644609437`*^9, 
   3.575794167223526*^9, 3.575794225877903*^9, 3.575794256101698*^9, {
   3.575870660763485*^9, 3.5758707086885147`*^9}, 3.57587131256633*^9, 
   3.575953861361729*^9, {3.5759541240366693`*^9, 3.575954149149822*^9}, 
   3.575959738486699*^9, {3.5759606212965484`*^9, 3.575960648662943*^9}, 
   3.5764883280814276`*^9, 3.5865813398274345`*^9, {3.5873574477957687`*^9, 
   3.587357477703535*^9}, 3.5873575094365396`*^9, 3.587357645189554*^9, 
   3.587360809347906*^9, 3.587360854207503*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solution in terms of Young\[CloseCurlyQuote]s modulus and Poisson\
\[CloseCurlyQuote]s ratio\
\>", "Subsection",
 CellChangeTimes->{{3.501904665796943*^9, 3.501904687980212*^9}}],

Cell["Standard transformation (8.11)", "Text",
 CellChangeTimes->{{3.5873571123677273`*^9, 3.5873571476162257`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lame", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "\[Rule]", 
      FractionBox[
       RowBox[{"EE", " ", "\[Nu]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", "\[Nu]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}]]}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", 
      FractionBox["EE", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}]]}]}], " ", "}"}]}], 
  ";"}]], "Input"],

Cell["Conversion helper function", "Text",
 CellChangeTimes->{{3.5873571679036536`*^9, 3.5873571732723355`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"do", "[", "e_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"e", "/.", "sol"}], "/.", "lame"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.413354832867581*^9, 3.4133548673105807`*^9}, {
  3.4133550003035808`*^9, 3.413355000446581*^9}}],

Cell["\<\
Convert all relevant quantities\
\>", "Text",
 CellChangeTimes->{{3.5873571795041313`*^9, 3.5873571846237755`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["u", "r"], "[", "r", "]"}], "//", "do"}], "//", 
  RowBox[{"DoCollect", "[", 
   RowBox[{"{", "P", "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.413353943775581*^9, 3.413353981151581*^9}, {
  3.413354875199581*^9, 3.413354876878581*^9}, {3.413355003967581*^9, 
  3.4133550043985806`*^9}, {3.5019047372400293`*^9, 3.501904791585138*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["b", "3"], " ", "P", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["r", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}]}], 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "3"], "-", 
     SuperscriptBox["b", "3"]}], ")"}], " ", "EE", " ", 
   SuperscriptBox["r", "2"]}]]], "Output",
 CellChangeTimes->{
  3.575543519006117*^9, 3.5756887024687023`*^9, 3.575792864510948*^9, 
   3.5757941672605095`*^9, 3.575794225922905*^9, 3.5757942561476917`*^9, {
   3.57587066080951*^9, 3.5758707087155476`*^9}, 3.5758713126063347`*^9, 
   3.5759538614287252`*^9, {3.5759541240856757`*^9, 3.5759541491918693`*^9}, 
   3.575959738522665*^9, {3.575960621349556*^9, 3.5759606487019615`*^9}, 
   3.5764883281344347`*^9, 3.586581339869439*^9, {3.587357447834812*^9, 
   3.5873574777435865`*^9}, 3.587357509478511*^9, 3.5873576452335987`*^9, 
   3.5873608093889294`*^9, 3.5873608542595034`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]d", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "r"], "[", "b", "]"}], "-", 
    RowBox[{
     SubscriptBox["u", "r"], "[", "a", "]"}]}], "//", "do"}]}]], "Input",
 CellChangeTimes->{{3.4133539550705805`*^9, 3.413353985888581*^9}, 
   3.413354890816581*^9, {3.4133550067515807`*^9, 3.413355007150581*^9}, {
   3.5019048188506975`*^9, 3.5019048295533094`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"b", " ", "P", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "+", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     RowBox[{"a", " ", "b"}], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", "EE"}]]], "Output",
 CellChangeTimes->{
  3.575543519071127*^9, 3.5756887025006742`*^9, 3.5757928645449567`*^9, 
   3.5757941672885337`*^9, 3.5757942259549036`*^9, 3.575794256182666*^9, {
   3.575870660840495*^9, 3.5758707087345123`*^9}, 3.575871312635377*^9, 
   3.5759538614837055`*^9, {3.575954124123722*^9, 3.575954149223837*^9}, 
   3.5759597385476685`*^9, {3.575960621392562*^9, 3.575960648732953*^9}, 
   3.576488328170479*^9, 3.5865813399054008`*^9, {3.5873574478658295`*^9, 
   3.5873574777745857`*^9}, 3.5873575095105786`*^9, 3.5873576452665606`*^9, 
   3.5873608094229164`*^9, 3.5873608543015313`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "//", "do"}]], "Input",
 CellChangeTimes->{
  3.413353929150581*^9, {3.413354637647581*^9, 3.413354645920581*^9}, 
   3.413354893775581*^9, {3.413355009838581*^9, 3.4133550102055807`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["b", "3"], " ", "P", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "3"], "-", 
          SuperscriptBox["b", "3"]}], ")"}], " ", "EE", " ", 
        SuperscriptBox["r", "3"]}]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "3"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "3"], "-", 
         SuperscriptBox["b", "3"]}], ")"}], " ", "EE", " ", 
       SuperscriptBox["r", "3"]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "3"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "3"], "-", 
         SuperscriptBox["b", "3"]}], ")"}], " ", "EE", " ", 
       SuperscriptBox["r", "3"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575543519128132*^9, 3.5756887025356865`*^9, 3.5757928645819187`*^9, 
   3.575794167320541*^9, 3.5757942259879074`*^9, 3.5757942562217045`*^9, {
   3.575870660876498*^9, 3.5758707087575116`*^9}, 3.5758713126683426`*^9, 
   3.57595386153971*^9, {3.5759541241657133`*^9, 3.5759541492578363`*^9}, 
   3.5759597385787153`*^9, {3.575960621433525*^9, 3.5759606487639704`*^9}, 
   3.5764883282074437`*^9, 3.5865813399414444`*^9, {3.5873574479007864`*^9, 
   3.5873574778085732`*^9}, 3.5873575095455503`*^9, 3.587357645303607*^9, 
   3.587360809461922*^9, 3.5873608543475585`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Sigma]", "//", "do"}]], "Input",
 CellChangeTimes->{
  3.413354115664581*^9, 3.4133548965445805`*^9, {3.4133550134555807`*^9, 
   3.413355013821581*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "3"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "3"], "-", 
         SuperscriptBox["r", "3"]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], "+", 
         SuperscriptBox["b", "3"]}], ")"}], " ", 
       SuperscriptBox["r", "3"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "3"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "3"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["r", "3"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "3"], "-", 
         SuperscriptBox["b", "3"]}], ")"}], " ", 
       SuperscriptBox["r", "3"]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["b", "3"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "3"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["r", "3"]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "3"], "-", 
         SuperscriptBox["b", "3"]}], ")"}], " ", 
       SuperscriptBox["r", "3"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.57554351919514*^9, 3.5756887025796814`*^9, 3.5757928646259394`*^9, 
   3.5757941673575068`*^9, 3.575794226027912*^9, 3.5757942562667093`*^9, {
   3.575870660917508*^9, 3.5758707087855577`*^9}, 3.57587131270735*^9, 
   3.5759538616127653`*^9, {3.5759541242226925`*^9, 3.5759541492988415`*^9}, 
   3.5759597386137114`*^9, {3.5759606214795303`*^9, 3.5759606488029613`*^9}, 
   3.576488328252449*^9, 3.586581339979458*^9, {3.587357447940826*^9, 
   3.587357477848583*^9}, 3.587357509587574*^9, 3.5873576453476114`*^9, 
   3.587360809503924*^9, 3.5873608544045534`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Thin shell approximation (p. 155)\
\>", "Subsection",
 CellChangeTimes->{{3.4131834859684076`*^9, 3.4131834884224076`*^9}, {
  3.501909312214703*^9, 3.5019093142688203`*^9}, {3.5873577828959007`*^9, 
  3.5873577855993314`*^9}}],

Cell["\<\
Helper function for first order calculations\
\>", "Text",
 CellChangeTimes->{{3.587357279143664*^9, 3.5873573060479903`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dothin", "[", "n_", "]"}], "[", "e_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"do", "[", "e", "]"}], "//", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{"#", ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", "0", ",", "n"}], "}"}]}], "]"}], "&"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.413354932223581*^9, 3.413354971760581*^9}, {
  3.413355036640581*^9, 3.413355037470581*^9}, {3.4133550677905807`*^9, 
  3.413355086366581*^9}, {3.5873607339404383`*^9, 3.5873607438766823`*^9}}],

Cell[TextData[{
 "Expansion into powers of ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.5873573370799084`*^9, 3.5873573481442523`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"a", "+", "d"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"a", "  ", "+", 
    RowBox[{"s", " ", "d"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4131834913054075`*^9, 3.4131834943384075`*^9}, {
  3.4131836246514077`*^9, 3.4131836280324078`*^9}, {3.4131842191574078`*^9, 
  3.4131842231184072`*^9}, {3.413189552341012*^9, 3.4131896295730124`*^9}}],

Cell[TextData[{
 "Convert quantities (only retain leading orders in ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " *)"
}], "Text",
 CellChangeTimes->{{3.58735735580827*^9, 3.5873573637352457`*^9}, {
  3.587357404768402*^9, 3.587357415439737*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    SubscriptBox["u", "r"], "[", "r", "]"}], " ", "//", 
   RowBox[{"dothin", "[", 
    RowBox[{"-", "1"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.413355091460581*^9, 3.413355112862581*^9}, {
   3.501907888327261*^9, 3.5019078885992765`*^9}, {3.501907967055764*^9, 
   3.5019080173986435`*^9}, 3.5019080491914625`*^9, {3.587357436800421*^9, 
   3.587357459408264*^9}, {3.5873607574683905`*^9, 3.5873607619639716`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["a", "2"], " ", "P", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], 
    RowBox[{"2", " ", "EE", " ", "d"}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "d", "]"}], "0"],
    SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
    Editable->False]}],
  SeriesData[$CellContext`d, 0, {
   Rational[1, 
      2] $CellContext`a^2 $CellContext`EE^(-1) $CellContext`P (-1 + \
$CellContext`\[Nu])}, -1, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.575543519365161*^9, 3.5756887027326937`*^9, 3.575792864791944*^9, 
   3.575794167416555*^9, 3.5757942261089234`*^9, 3.5757942563557315`*^9, 
   3.57587066104652*^9, 3.575870708859583*^9, 3.575871312786358*^9, 
   3.575953861822784*^9, {3.5759541243527093`*^9, 3.5759541493618493`*^9}, 
   3.575959738691682*^9, {3.5759606215756083`*^9, 3.575960648881971*^9}, 
   3.5764883283364596`*^9, 3.586581340806575*^9, {3.5873574407379227`*^9, 
   3.5873574779116006`*^9}, 3.587357509648555*^9, 3.5873576454126234`*^9, 
   3.5873607712121167`*^9, 3.5873608095669312`*^9, 3.587360854474555*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]d", "//", 
  RowBox[{"dothin", "[", "0", "]"}]}]], "Input",
 CellChangeTimes->{{3.413355182538581*^9, 3.413355186861581*^9}, {
  3.5873608296114473`*^9, 3.5873608318437276`*^9}, {3.5873608620685034`*^9, 
  3.587360862563586*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"a", " ", "P", " ", "\[Nu]"}], "EE"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "d", "]"}], "1"],
    SeriesData[$CellContext`d, 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[$CellContext`d, 
   0, {$CellContext`a $CellContext`EE^(-1) $CellContext`P $CellContext`\[Nu]},
    0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.575543519549182*^9, 3.5756887027726994`*^9, 3.575792864824957*^9, 
   3.575794167443514*^9, 3.5757942261399*^9, 3.575794256390729*^9, 
   3.575870661077523*^9, 3.575870708897529*^9, 3.5758713128043623`*^9, 
   3.5759538618747916`*^9, {3.5759541243937435`*^9, 3.575954149392858*^9}, 
   3.5759597387176847`*^9, {3.5759606216156015`*^9, 3.5759606489109745`*^9}, 
   3.5764883283715057`*^9, 3.586581340871563*^9, {3.587357440761917*^9, 
   3.587357477941595*^9}, 3.587357509679576*^9, 3.587357645444623*^9, {
   3.5873608095908937`*^9, 3.5873608630416517`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "  ", "//", 
  RowBox[{"dothin", "[", 
   RowBox[{"-", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.413355145666581*^9, 3.413355148862581*^9}, {
  3.5019079223912096`*^9, 3.5019079226422243`*^9}, {3.5019080541987486`*^9, 
  3.5019080569749074`*^9}, {3.5873574641568203`*^9, 3.5873574681603613`*^9}, {
  3.587360871195657*^9, 3.5873608751641784`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{
       FractionBox[
        RowBox[{"a", " ", "P", " ", "\[Nu]"}], 
        RowBox[{"EE", " ", "d"}]], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "d", "]"}], "0"],
        SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
        Editable->False]}],
      SeriesData[$CellContext`d, 
       0, {$CellContext`a $CellContext`EE^(-1) $CellContext`P $CellContext`\
\[Nu]}, -1, 0, 1],
      Editable->False], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     InterpretationBox[
      RowBox[{
       FractionBox[
        RowBox[{"a", " ", "P", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], 
        RowBox[{"2", " ", "EE", " ", "d"}]], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "d", "]"}], "0"],
        SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
        Editable->False]}],
      SeriesData[$CellContext`d, 0, {
       Rational[
         1, 2] $CellContext`a $CellContext`EE^(-1) $CellContext`P (-1 + \
$CellContext`\[Nu])}, -1, 0, 1],
      Editable->False], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     InterpretationBox[
      RowBox[{
       FractionBox[
        RowBox[{"a", " ", "P", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], 
        RowBox[{"2", " ", "EE", " ", "d"}]], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "d", "]"}], "0"],
        SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
        Editable->False]}],
      SeriesData[$CellContext`d, 0, {
       Rational[
         1, 2] $CellContext`a $CellContext`EE^(-1) $CellContext`P (-1 + \
$CellContext`\[Nu])}, -1, 0, 1],
      Editable->False]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755435196411924`*^9, 3.575688702833747*^9, 3.575792864885001*^9, 
   3.5757941674985404`*^9, 3.5757942261969366`*^9, 3.57579425644972*^9, 
   3.575870661191538*^9, 3.5758707090005426`*^9, 3.5758713128593664`*^9, 
   3.575953862049776*^9, {3.5759541245407324`*^9, 3.575954149448863*^9}, 
   3.5759597387726927`*^9, {3.575960621679555*^9, 3.575960648964981*^9}, 
   3.576488328439473*^9, 3.5865813409705734`*^9, {3.587357440784917*^9, 
   3.5873574779945984`*^9}, 3.5873575097335863`*^9, 3.5873576455026484`*^9, 
   3.5873608096159368`*^9, {3.587360854553578*^9, 3.5873608756292267`*^9}}]
}, Open  ]],

Cell["\<\
Stress tensor diagonal values treated separately\
\>", "Text",
 CellChangeTimes->{{3.5873577124320517`*^9, 3.587357745919228*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}], "//", 
  RowBox[{"dothin", "[", "0", "]"}]}]], "Input",
 CellChangeTimes->{{3.587357634807292*^9, 3.5873576583362017`*^9}, {
  3.587360884559308*^9, 3.587360891388214*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"P", " ", "s"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "d", "]"}], "1"],
    SeriesData[$CellContext`d, 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[$CellContext`d, 0, {-$CellContext`P $CellContext`s}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.5873576405969744`*^9, 3.5873576589033103`*^9}, 
   3.5873608096439033`*^9, 3.587360854588627*^9, {3.5873608879997835`*^9, 
   3.5873608917102647`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "//", 
  RowBox[{"dothin", "[", 
   RowBox[{"-", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5873576651881075`*^9, 3.5873576770646076`*^9}, {
  3.587360894396591*^9, 3.5873608980760574`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"a", " ", "P"}], 
     RowBox[{"2", " ", "d"}]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "d", "]"}], "0"],
    SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
    Editable->False]}],
  SeriesData[$CellContext`d, 0, {
   Rational[-1, 2] $CellContext`a $CellContext`P}, -1, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.587357674394354*^9, 3.587357678470767*^9}, 
   3.587360809668908*^9, 3.5873608546246176`*^9, 3.5873608985531063`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", "[", 
   RowBox[{"[", 
    RowBox[{"3", ",", "3"}], "]"}], "]"}], " ", "//", 
  RowBox[{"dothin", "[", 
   RowBox[{"-", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5873576868318195`*^9, 3.587357691208354*^9}, {
  3.5873609017884707`*^9, 3.587360910172573*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"a", " ", "P"}], 
     RowBox[{"2", " ", "d"}]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "d", "]"}], "0"],
    SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
    Editable->False]}],
  SeriesData[$CellContext`d, 0, {
   Rational[-1, 2] $CellContext`a $CellContext`P}, -1, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.5873576916224113`*^9, 3.587360809697939*^9, 
  3.5873608546606183`*^9, 3.5873609105545716`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 9.7 The bathysphere (p. 156)\
\>", "Section",
 CellChangeTimes->{{3.413192357543012*^9, 3.413192359150012*^9}, {
  3.5019072106685014`*^9, 3.501907216444832*^9}, {3.5873578013681903`*^9, 
  3.587357804247565*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.413192361414012*^9, 3.4131923639600124`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(25\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575543520008236*^9, 3.575543785109044*^9, 3.575543884098922*^9, 
   3.5756887030667753`*^9, 3.575792865101983*^9, 3.57579416770455*^9, 
   3.5757942264039583`*^9, 3.575794256669718*^9, 3.575870661514578*^9, 
   3.5758707092666144`*^9, 3.57587131305243*^9, 3.5759538623728127`*^9, {
   3.575954124845821*^9, 3.5759541496939383`*^9}, 3.5759597389757175`*^9, {
   3.575960621981594*^9, 3.575960649277046*^9}, 3.5764883286895475`*^9, 
   3.5865813440949893`*^9, {3.5873574483148317`*^9, 3.587357478222601*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Parameters", "Subsection"]], "Subsection",
 CellChangeTimes->{{3.413193114947012*^9, 3.4131931153640122`*^9}, {
  3.5873578300788093`*^9, 3.587357831406969*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "4.75", " ", "Foot"}], "//", "ToSI"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"inner", " ", "radius", " ", "of", " ", "sphere"}], " ", "*)"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"d", "=", 
   RowBox[{
    RowBox[{"1.", " ", "Inch"}], "//", "ToSI"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"thickness", " ", "of", " ", "sphere", " ", "wall"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"200", " ", "Giga", " ", "Pascal"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Young", "'"}], "s", " ", "modulus", " ", "for", " ", "steel", 
    " ", 
    RowBox[{"(", "guess", ")"}]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{"1", "/", "3"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Poisson", "'"}], "s", " ", "radius", " ", 
    RowBox[{"(", "guess", ")"}]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P", "=", 
   RowBox[{"100", " ", "Bar"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"pressure", " ", "at", " ", "100", " ", "meter", " ", "depth"}], 
   " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.413192366829012*^9, 3.4131924155310125`*^9}, {
  3.4131924573490124`*^9, 3.4131924772320123`*^9}, {3.413192977996012*^9, 
  3.4131929830000124`*^9}, {3.413193076667012*^9, 3.413193087550012*^9}, {
  3.413193151649012*^9, 3.413193160477012*^9}, {3.4131933226590123`*^9, 
  3.413193325544012*^9}, {3.413193863768012*^9, 3.413193875601012*^9}, {
  3.413197628202012*^9, 3.4131976336000123`*^9}, {3.587357872135173*^9, 
  3.5873578987604465`*^9}, {3.5873579900329094`*^9, 3.587358096735289*^9}, {
  3.5873581352240953`*^9, 3.5873581448323326`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5873578624868917`*^9, 3.5873578639030724`*^9}}],

Cell["\<\
Thin shell approximation is valid\
\>", "Text",
 CellChangeTimes->{{3.587357915607552*^9, 3.587357924414642*^9}, {
  3.5873581531993732`*^9, 3.587358153510415*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "/", "a"}]], "Input",
 CellChangeTimes->{{3.413192366829012*^9, 3.4131924155310125`*^9}, {
  3.4131924573490124`*^9, 3.4131924772320123`*^9}, {3.413192977996012*^9, 
  3.4131929830000124`*^9}, {3.413193076667012*^9, 3.413193087550012*^9}, {
  3.413193151649012*^9, 3.413193160477012*^9}, {3.4131933226590123`*^9, 
  3.413193325544012*^9}, {3.413193863768012*^9, 3.413193875601012*^9}}],

Cell[BoxData["0.03508771929824561`"], "Output",
 CellChangeTimes->{
  3.5755435200762444`*^9, 3.5755437853690753`*^9, 3.5755438842179356`*^9, 
   3.57568870317775*^9, 3.5757928652210026`*^9, 3.575794167755595*^9, 
   3.575794226515973*^9, 3.575794256726757*^9, 3.5758706618066144`*^9, 
   3.5758707096056185`*^9, 3.5758713131034403`*^9, 3.57595386244584*^9, {
   3.575954124894777*^9, 3.5759541497489405`*^9}, 3.5759597390257235`*^9, {
   3.575960622036601*^9, 3.575960649328027*^9}, 3.576488328750512*^9, 
   3.5865813442879505`*^9, {3.5873574484239025`*^9, 3.5873574782816367`*^9}}]
}, Open  ]],

Cell["Radial displacement", "Text",
 CellChangeTimes->{{3.413193109572012*^9, 3.413193111624012*^9}, {
  3.587358214662092*^9, 3.587358216622336*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "r"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Nu]"}], ")"}]}], 
    FractionBox[
     SuperscriptBox["a", "2"], 
     RowBox[{"2", "d"}]], 
    FractionBox["P", "EE"]}], "//", 
   RowBox[{"ToUnit", "[", "Millimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.413193119062012*^9, 3.413193182167012*^9}}],

Cell[BoxData[
 TemplateBox[{RowBox[{"-", "0.34385249999999995`"}]},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"mm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: millimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Millimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755435202612667`*^9, 3.575543785537097*^9, 3.575543884441963*^9, 
   3.575688703296809*^9, 3.5757928653570623`*^9, 3.5757941678595734`*^9, 
   3.57579422662795*^9, 3.575794256844781*^9, 3.5758706619516344`*^9, 
   3.575870709740636*^9, 3.5758713132104287`*^9, 3.57595386256888*^9, {
   3.575954125006832*^9, 3.575954149855914*^9}, 3.5759597391357374`*^9, {
   3.5759606221596575`*^9, 3.575960649441041*^9}, 3.576488328918536*^9, 
   3.5865813453741903`*^9, {3.587357448535902*^9, 3.5873574783946495`*^9}}]
}, Open  ]],

Cell["Thickness change", "Text",
 CellChangeTimes->{{3.4131933872030125`*^9, 3.413193389086012*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]d", "=", 
  RowBox[{
   RowBox[{"\[Nu]", " ", "a", " ", 
    FractionBox["P", "EE"]}], "//", 
   RowBox[{"ToUnit", "[", "Micrometer", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.413193391183012*^9, 3.413193393499012*^9}, {
  3.413193432070012*^9, 3.4131934560900126`*^9}, {3.501908254113183*^9, 
  3.5019082555772667`*^9}}],

Cell[BoxData[
 TemplateBox[{"12.065000000000001`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"\[Micro]m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: micrometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Micrometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575543520403284*^9, 3.575543785676114*^9, 3.575543884586981*^9, 
   3.5756887033788023`*^9, 3.5757928654450665`*^9, 3.575794167932598*^9, 
   3.575794226703969*^9, 3.5757942569857693`*^9, 3.5758706620546474`*^9, 
   3.575870709833647*^9, 3.575871313351428*^9, 3.57595386266089*^9, {
   3.575954125080801*^9, 3.575954149981927*^9}, 3.575959739209814*^9, {
   3.5759606222436666`*^9, 3.5759606495170503`*^9}, 3.576488329028555*^9, 
   3.5865813455851135`*^9, {3.5873574486199136`*^9, 3.5873574785256653`*^9}}]
}, Open  ]],

Cell["Radial strain", "Text",
 CellChangeTimes->{{3.4131935131590123`*^9, 3.4131935139360123`*^9}, {
  3.587358203614745*^9, 3.587358212158795*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "rr"], "=", 
  RowBox[{
   RowBox[{"\[Nu]", " ", 
    FractionBox["a", "d"], 
    FractionBox["P", "EE"]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.4131935169200125`*^9, 3.413193550855012*^9}}],

Cell[BoxData["0.000475`"], "Output",
 CellChangeTimes->{
  3.5755435206513133`*^9, 3.575543785817131*^9, 3.5755438847740026`*^9, 
   3.575688703475833*^9, 3.5757928655500393`*^9, 3.575794168073635*^9, 
   3.575794226799999*^9, 3.5757942570828085`*^9, 3.575870662180662*^9, 
   3.575870709951662*^9, 3.575871313436439*^9, 3.5759538627679024`*^9, {
   3.57595412517383*^9, 3.575954150077941*^9}, 3.575959739354827*^9, {
   3.5759606223466387`*^9, 3.575960649611062*^9}, 3.5764883291365604`*^9, 
   3.5865813461212244`*^9, {3.587357448721901*^9, 3.5873574786266365`*^9}}]
}, Open  ]],

Cell["\<\
Tangential strain (compression)\
\>", "Text",
 CellChangeTimes->{{3.587358225510502*^9, 3.5873582537429657`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "tt"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Nu]"}], ")"}], 
    FractionBox["a", "d"], 
    FractionBox["P", "EE"]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.4131935974490123`*^9, 3.4131936273490124`*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.000475`"}]], "Output",
 CellChangeTimes->{
  3.575543520786329*^9, 3.5755437859591465`*^9, 3.575543885054038*^9, 
   3.5756887035788007`*^9, 3.5757928656580544`*^9, 3.5757941681726475`*^9, 
   3.57579422689402*^9, 3.575794257301837*^9, 3.5758706623037186`*^9, 
   3.575870710076709*^9, 3.5758713135204935`*^9, 3.5759538628748765`*^9, {
   3.575954125271824*^9, 3.5759541501789618`*^9}, 3.575959739448804*^9, {
   3.575960622452696*^9, 3.5759606497051325`*^9}, 3.5764883292415977`*^9, 
   3.58658134650323*^9, {3.5873574488249383`*^9, 3.587357478726678*^9}}]
}, Open  ]],

Cell["Tangential stress", "Text",
 CellChangeTimes->{{3.4131936779200125`*^9, 3.4131936855640125`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Sigma]", "tt"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], 
    FractionBox["a", "d"], "P"}], "//", 
   RowBox[{"ToUnit", "[", "Bar", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4131936897810125`*^9, 3.413193735102012*^9}, {
  3.413193940737012*^9, 3.413193975992012*^9}, {3.413194144318012*^9, 
  3.413194153237012*^9}}],

Cell[BoxData[
 TemplateBox[{RowBox[{"-", "1425.`"}]},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"bars\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: bars"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Bars\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.575543521082367*^9, 3.5755437860811625`*^9, 3.57554388516705*^9, 
   3.5756887036318493`*^9, 3.575792865721064*^9, 3.5757941682156625`*^9, 
   3.575794226944025*^9, 3.5757942573658466`*^9, 3.5758706623576884`*^9, 
   3.5758707101206827`*^9, 3.575871313556492*^9, 3.5759538629299264`*^9, {
   3.57595412531987*^9, 3.575954150226958*^9}, 3.575959739491811*^9, {
   3.5759606225136733`*^9, 3.5759606497560806`*^9}, 3.5764883292946115`*^9, 
   3.5865813467533193`*^9, {3.5873574488839617`*^9, 3.587357478785698*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 9.8 The bathyscaphe (p. 156)\
\>", "Section",
 CellChangeTimes->{{3.413192357543012*^9, 3.413192359150012*^9}, {
  3.413196663584012*^9, 3.413196664388012*^9}, {3.5019084146693664`*^9, 
  3.5019084230368447`*^9}, {3.5873582769189157`*^9, 3.5873582818384933`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.413192361414012*^9, 3.4131923639600124`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(11\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.5755435218784637`*^9, 3.575544021906456*^9, 3.5756887037928705`*^9, 
   3.575792865897083*^9, 3.5757941683686867`*^9, 3.575794227097046*^9, 
   3.5757942578059006`*^9, 3.575870662564715*^9, 3.5758707103767643`*^9, 
   3.575871313719475*^9, 3.5759538631079483`*^9, {3.575954125470861*^9, 
   3.57595415038299*^9}, 3.5759597396468596`*^9, {3.5759606226837244`*^9, 
   3.575960649910143*^9}, 3.576488329471603*^9, 3.5865813470773783`*^9, {
   3.5873574490659285`*^9, 3.5873574789657106`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.413193114947012*^9, 3.4131931153640122`*^9}, {
  3.587358293974051*^9, 3.587358297310614*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{
    FractionBox["1", "2"], "200", " ", "Centimeter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"inner", " ", "radius", " ", "of", " ", "sphere"}], " ", "*)"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"d", "=", 
   RowBox[{
    RowBox[{"5.", " ", "Inch"}], "//", "ToSI"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"thickness", " ", "of", " ", "sphere", " ", "wall"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EE", "=", 
   RowBox[{"200", " ", "Gigapascal"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Young", "'"}], "s", " ", "modulus", " ", "for", " ", "steel", 
    " ", 
    RowBox[{"(", "guess", ")"}]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{"1.", "/", "3"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Poisson", "'"}], "s", " ", "ratio", " ", 
    RowBox[{"(", "guess", ")"}]}], " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P", "=", 
   RowBox[{"1100", " ", "Bar"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "pressure", " ", "at", " ", "bottom", " ", "of", " ", "the", " ", "sea"}], 
   " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"a", "+", "d"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"outer", " ", "radius", " ", "of", " ", "sphere"}], " ", "*)"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.413192366829012*^9, 3.4131924155310125`*^9}, {
   3.4131924573490124`*^9, 3.4131924772320123`*^9}, {3.413192977996012*^9, 
   3.4131929830000124`*^9}, {3.413193076667012*^9, 3.413193087550012*^9}, {
   3.413193151649012*^9, 3.413193160477012*^9}, {3.4131933226590123`*^9, 
   3.413193325544012*^9}, {3.413193863768012*^9, 3.413193875601012*^9}, {
   3.4131966763640122`*^9, 3.413196679062012*^9}, {3.413196814221012*^9, 
   3.413196814336012*^9}, {3.4131976454460125`*^9, 3.4131976602780123`*^9}, 
   3.413197751178012*^9, {3.4131977954060125`*^9, 3.413197799881012*^9}, {
   3.413197894902012*^9, 3.4131978978240123`*^9}, 3.4131980432760124`*^9, {
   3.413198284925012*^9, 3.413198288596012*^9}, {3.5755440145295734`*^9, 
   3.5755440150246325`*^9}, {3.5873583007608967`*^9, 3.587358411767888*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5873584176706285`*^9, 3.5873584185186615`*^9}}],

Cell["\<\
Parameter for thin wall approximation\
\>", "Text",
 CellChangeTimes->{{3.5873584266137266`*^9, 3.587358433950596*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "/", "a"}], "//", "ToSI"}]], "Input",
 CellChangeTimes->{{3.413192366829012*^9, 3.4131924155310125`*^9}, {
  3.4131924573490124`*^9, 3.4131924772320123`*^9}, {3.413192977996012*^9, 
  3.4131929830000124`*^9}, {3.413193076667012*^9, 3.413193087550012*^9}, {
  3.413193151649012*^9, 3.413193160477012*^9}, {3.4131933226590123`*^9, 
  3.413193325544012*^9}, {3.413193863768012*^9, 3.413193875601012*^9}, {
  3.413197758384012*^9, 3.4131977594410124`*^9}}],

Cell[BoxData["0.127`"], "Output",
 CellChangeTimes->{
  3.575543522395523*^9, 3.575544022157486*^9, 3.5756887038808813`*^9, 
   3.5757928659931035`*^9, 3.5757941684576535`*^9, 3.5757942271830587`*^9, 
   3.5757942594690685`*^9, 3.5758706628967915`*^9, 3.5758707126470547`*^9, 
   3.5758713138104863`*^9, 3.575953863249977*^9, {3.57595412555586*^9, 
   3.5759541504709883`*^9}, 3.575959739730812*^9, {3.575960622778735*^9, 
   3.575960649996152*^9}, 3.5764883295696135`*^9, 3.5865813475003576`*^9, {
   3.58735744915698*^9, 3.587357479063736*^9}}]
}, Open  ]],

Cell["Radial displacement", "Text",
 CellChangeTimes->{{3.413193109572012*^9, 3.413193111624012*^9}, {
  3.587358476846038*^9, 3.5873584783823185`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "r"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[Nu]"}], ")"}]}], 
    FractionBox[
     SuperscriptBox["a", "2"], 
     RowBox[{"2", "d"}]], 
    FractionBox["P", "EE"]}], "//", 
   RowBox[{"ToUnit", "[", "Millimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.413193119062012*^9, 3.413193182167012*^9}}],

Cell[BoxData[
 TemplateBox[{RowBox[{"-", "1.4435695538057745`"}]},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"mm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: millimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Millimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755435226145487`*^9, 3.575544022473527*^9, 3.5756887040499043`*^9, 
   3.575792866162159*^9, 3.5757941686266804`*^9, 3.57579422734708*^9, 
   3.575794260537204*^9, 3.5758706631727877`*^9, 3.5758707162184515`*^9, 
   3.5758713139635053`*^9, 3.5759538634309874`*^9, {3.5759541257808886`*^9, 
   3.5759541506420517`*^9}, 3.575959739882831*^9, {3.5759606230207577`*^9, 
   3.5759606502171774`*^9}, 3.57648833426321*^9, 3.5865813484565153`*^9, {
   3.587357449336963*^9, 3.5873574792377567`*^9}}]
}, Open  ]],

Cell["Thickness change", "Text",
 CellChangeTimes->{{3.4131933872030125`*^9, 3.413193389086012*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]d", "=", 
  RowBox[{
   RowBox[{"\[Nu]", " ", "a", " ", 
    FractionBox["P", "EE"]}], "//", 
   RowBox[{"ToUnit", "[", "Millimeter", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.413193391183012*^9, 3.413193393499012*^9}, {
  3.413193432070012*^9, 3.4131934560900126`*^9}}],

Cell[BoxData[
 TemplateBox[{"0.18333333333333335`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"mm\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: millimeters"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Millimeters\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755435227485647`*^9, 3.575544022609541*^9, 3.5756887041268854`*^9, 
   3.5757928662901893`*^9, 3.575794168700675*^9, 3.5757942274200683`*^9, 
   3.5757942622234693`*^9, 3.575870663271806*^9, 3.575870716828602*^9, 
   3.5758713140295134`*^9, 3.5759538635210013`*^9, {3.5759541258509073`*^9, 
   3.57595415072202*^9}, 3.5759597399529*^9, {3.5759606230997763`*^9, 
   3.5759606502911477`*^9}, 3.5764883345212383`*^9, 3.5865813486004963`*^9, {
   3.587357449418002*^9, 3.5873574793157444`*^9}}]
}, Open  ]],

Cell["Radial strain", "Text",
 CellChangeTimes->{{3.4131935131590123`*^9, 3.4131935139360123`*^9}, {
  3.587358499429844*^9, 3.5873585044775095`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "rr"], "=", 
  RowBox[{
   RowBox[{"\[Nu]", " ", 
    FractionBox["a", "d"], 
    FractionBox["P", "EE"]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.4131935169200125`*^9, 3.413193550855012*^9}}],

Cell[BoxData["0.0014435695538057745`"], "Output",
 CellChangeTimes->{
  3.575543522880581*^9, 3.5755440227995634`*^9, 3.5756887042729006`*^9, 
   3.575792866396187*^9, 3.5757941688017406`*^9, 3.575794227573099*^9, 
   3.5757942625094957`*^9, 3.5758706633998594`*^9, 3.575870717044656*^9, 
   3.575871314123525*^9, 3.5759538636370125`*^9, {3.575954125946909*^9, 
   3.5759541508220325`*^9}, 3.5759597400508957`*^9, {3.575960623211769*^9, 
   3.57596065039016*^9}, 3.576488335929416*^9, 3.586581349465644*^9, {
   3.5873574495740323`*^9, 3.5873574794187694`*^9}}]
}, Open  ]],

Cell["Tangential strain", "Text",
 CellChangeTimes->{{3.587358510390283*^9, 3.5873585126455417`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "tt"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], 
    RowBox[{"(", 
     RowBox[{"1", "-", "\[Nu]"}], ")"}], 
    FractionBox["a", "d"], 
    FractionBox["P", "EE"]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{{3.4131935974490123`*^9, 3.4131936273490124`*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.0014435695538057747`"}]], "Output",
 CellChangeTimes->{
  3.5755435230135965`*^9, 3.5755440229915876`*^9, 3.5756887043789415`*^9, 
   3.5757928664981747`*^9, 3.5757941688967223`*^9, 3.5757942276771173`*^9, 
   3.575794262629508*^9, 3.575870663583888*^9, 3.5758707174196*^9, 
   3.5758713142115364`*^9, 3.5759538637430296`*^9, {3.575954126044921*^9, 
   3.575954150921088*^9}, 3.5759597402239122`*^9, {3.575960623318802*^9, 
   3.575960650487212*^9}, 3.57648833664451*^9, 3.586581349648678*^9, {
   3.587357449682045*^9, 3.5873574795717964`*^9}}]
}, Open  ]],

Cell["Tangential stress", "Text",
 CellChangeTimes->{{3.4131936779200125`*^9, 3.4131936855640125`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Sigma]", "tt"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], 
    FractionBox["a", "d"], "P"}], "//", 
   RowBox[{"ToUnit", "[", "Bar", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4131936897810125`*^9, 3.413193735102012*^9}, {
  3.413193940737012*^9, 3.413193975992012*^9}, {3.413194144318012*^9, 
  3.413194153237012*^9}}],

Cell[BoxData[
 TemplateBox[{RowBox[{"-", "4330.708661417323`"}]},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"bars\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: bars"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Bars\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755435232766285`*^9, 3.575544023213616*^9, 3.5756887044319215`*^9, 
   3.5757928665522017`*^9, 3.5757941689417434`*^9, 3.575794227728138*^9, 
   3.575794262685512*^9, 3.5758706636378465`*^9, 3.5758707181367364`*^9, 
   3.5758713142505417`*^9, 3.5759538637999926`*^9, {3.5759541260929966`*^9, 
   3.57595415103506*^9}, 3.575959743060299*^9, {3.57596062337681*^9, 
   3.5759606506562204`*^9}, 3.5764883367365384`*^9, 3.586581350096714*^9, {
   3.5873574497390494`*^9, 3.5873574796268053`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 9.6 Application: Radial deformation of a cylindrical body (p. 156)\
\>", "Title",
 CellChangeTimes->{{3.5019092689812303`*^9, 3.5019092868362513`*^9}, {
  3.587358538430756*^9, 3.587358548446088*^9}}],

Cell[CellGroupData[{

Cell["Analytic calculations (p. 157)", "Section",
 CellChangeTimes->{{3.5019093494618335`*^9, 3.501909354773137*^9}, {
  3.5873585711178513`*^9, 3.5873585743262777`*^9}, {3.5873586659177647`*^9, 
  3.5873586705583253`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(23\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575544093884095*^9, 3.575792996702543*^9, 3.5757931030438843`*^9, 
   3.5757931407826524`*^9, 3.5757939985513487`*^9, 3.5757940772211947`*^9, 
   3.5757942695203323`*^9, 3.575871334665105*^9, {3.575954177651415*^9, 
   3.575954207123102*^9}, 3.575954242824585*^9, 3.576488350756301*^9, 
   3.5865813506568165`*^9, 3.587358792849678*^9, {3.587359192019822*^9, 
   3.587359218864185*^9}, 3.587360452310072*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Cylindrical", "[", 
    RowBox[{"r", ",", "\[Phi]", ",", "z"}], "]"}], "]"}], ";"}]], "Input"],

Cell["Radial assumption", "Text",
 CellChangeTimes->{{3.5019093611175003`*^9, 3.5019093626605883`*^9}, {
  3.5873585888702145`*^9, 3.5873585921905236`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "r"], "[", "r", "]"}], ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Equilibrium equation (p. 157)", "Subsection",
 CellChangeTimes->{{3.5019093922462807`*^9, 3.5019093975565844`*^9}, {
  3.5873586791183825`*^9, 3.5873586827578683`*^9}}],

Cell["Volume force", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"Laplacian", "[", "u", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}], 
        RowBox[{"Grad", "[", 
         RowBox[{"Div", "[", "u", "]"}], "]"}]}]}], ")"}]}], "//", "Expand"}],
    "//", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{"\[Mu]", ",", "\[Lambda]"}], "}"}]}], "]"}], 
    "&"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SubscriptBox["u", "r"], "[", "r", "]"}]}], 
        SuperscriptBox["r", "2"]], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox[
           SubscriptBox["u", "r"], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "r"], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["u", "r"], "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"\[Lambda]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}], 
        SuperscriptBox["r", "2"]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox[
          SubscriptBox["u", "r"], "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], "r"], "-", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], ",", "0", 
   ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.575544094055114*^9, 3.5757929967855716`*^9, 3.575793103166936*^9, 
   3.5757931409046483`*^9, 3.57579399891739*^9, 3.5757940773262405`*^9, 
   3.5757942696483784`*^9, 3.575871334777157*^9, {3.5759541777584147`*^9, 
   3.575954207226117*^9}, 3.575954242940628*^9, 3.5764883508743*^9, 
   3.5865813508967867`*^9, 3.587358792961673*^9, {3.5873591921218367`*^9, 
   3.587359218962208*^9}, 3.587360452444092*^9}]
}, Open  ]],

Cell["Radial component", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "r"], "=", 
  RowBox[{"f", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4133534946065807`*^9, 3.4133534972785807`*^9}, {
  3.413353548000581*^9, 3.413353580815581*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Mu]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SubscriptBox["u", "r"], "[", "r", "]"}]}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], "r"], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["u", "r"], "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"\[Lambda]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["u", "r"], "[", "r", "]"}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        SubscriptBox["u", "r"], "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "r"], "-", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["u", "r"], "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5755440940941195`*^9, 3.5757929968095226`*^9, 3.5757931031898804`*^9, 
   3.5757931409296513`*^9, 3.575793999230398*^9, 3.575794077353208*^9, 
   3.5757942696734247`*^9, 3.5758713347991533`*^9, {3.5759541777834654`*^9, 
   3.575954207256119*^9}, 3.5759542429706035`*^9, 3.5764883508972993`*^9, 
   3.58658135094479*^9, 3.5873587929857326`*^9, {3.5873591921477976`*^9, 
   3.587359218992217*^9}, 3.5873604524800715`*^9}]
}, Open  ]],

Cell["Check special form", "Text",
 CellChangeTimes->{{3.4133535392925806`*^9, 3.4133535404765806`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["f", "r"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Lambda]", "+", 
      RowBox[{"2", "\[Mu]"}]}], ")"}], 
    RowBox[{
     SubscriptBox["\[PartialD]", "r"], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "r"], 
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], 
        RowBox[{"(", 
         RowBox[{"r", " ", 
          RowBox[{
           SubscriptBox["u", "r"], "[", "r", "]"}]}], ")"}]}]}], ")"}]}]}]}], 
  "//", "Expand"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.575544094135123*^9, 3.5757929968305635`*^9, 3.575793103214941*^9, 
   3.5757931409556828`*^9, 3.575793999255476*^9, 3.575794077377243*^9, 
   3.5757942696963587`*^9, 3.575871334820233*^9, {3.575954177810421*^9, 
   3.5759542072771215`*^9}, 3.575954242996607*^9, 3.576488350919304*^9, 
   3.5865813510238004`*^9, 3.5873587930097013`*^9, {3.5873591921808014`*^9, 
   3.5873592190162106`*^9}, 3.587360452504116*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Strain and stress tensors (p. 158)\
\>", "Subsection",
 CellChangeTimes->{{3.587358689197673*^9, 3.587358727261492*^9}}],

Cell["Strain", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], "+", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}]}], "//", 
   "Expand"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       SubscriptBox["u", "r"], "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], ",", "0", ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       SubscriptBox["u", "r"], "[", "r", "]"}], "r"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575544094307144*^9, 3.575792996866534*^9, {3.5757930950138936`*^9, 
   3.575793103249928*^9}, 3.5757931409896455`*^9, 3.575793999463481*^9, 
   3.575794077415221*^9, 3.5757942697274003`*^9, 3.5758713348551283`*^9, {
   3.5759541778424263`*^9, 3.575954207310171*^9}, 3.575954243034664*^9, 
   3.5764883509623127`*^9, 3.586581351835925*^9, 3.587358793046726*^9, {
   3.5873591922178507`*^9, 3.587359219053176*^9}, 3.587360452541101*^9}]
}, Open  ]],

Cell["Stress", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Sigma]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"2", "\[Mu]", " ", "uu"}], "+", 
     RowBox[{"\[Lambda]", "  ", 
      RowBox[{"Tr", "[", "uu", "]"}], "UnitTensor"}]}], " ", "//", "Expand"}],
    "//", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{"#", ",", "A"}], "]"}], "&"}]}]}]], "Input",
 CellChangeTimes->{{3.5757939761114883`*^9, 3.5757939783537965`*^9}, {
  3.5757944337969584`*^9, 3.5757944355991845`*^9}, {3.5759541880857115`*^9, 
  3.5759541892909145`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"\[Lambda]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Lambda]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Lambda]", " ", 
        RowBox[{
         SubscriptBox["u", "r"], "[", "r", "]"}]}], "r"], "+", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "r"], "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.57554409434715*^9, 3.575792996875554*^9, 3.575793103259925*^9, 
   3.575793141014737*^9, 3.5757939994874635`*^9, 3.5757940774342437`*^9, 
   3.575794269749361*^9, 3.575871334876129*^9, {3.575954177864428*^9, 
   3.5759542073211718`*^9}, 3.5759542430606146`*^9, 3.5764883509843664`*^9, 
   3.5865813521739464`*^9, 3.5873587930777273`*^9, {3.587359192242852*^9, 
   3.587359219077179*^9}, 3.5873604525651073`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Clamped pipe under internal pressure (p. 158)\
\>", "Subsection",
 CellChangeTimes->{{3.501909670893218*^9, 3.5019096768435583`*^9}, {
  3.587358747453967*^9, 3.5873587503573904`*^9}}],

Cell["General solution without body forces", "Text",
 CellChangeTimes->{{3.5019096846930075`*^9, 3.5019096904283357`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["u", "r"], "[", "r_", "]"}], "=", 
   RowBox[{
    RowBox[{"A", " ", "r"}], "+", 
    FractionBox["B", "r"]}]}], ";"}]], "Input"],

Cell["\<\
Check the vanishing of the radial body force\
\>", "Text",
 CellChangeTimes->{{3.587358837693325*^9, 3.5873588643657827`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["f", "r"], "//", "Expand"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.5755440943951564`*^9, 3.5757929968995843`*^9, 3.5757931032859335`*^9, 
   3.575793191315994*^9, 3.5757939996334476`*^9, 3.5757940774632587`*^9, 
   3.5757942697724037`*^9, 3.5758713348991346`*^9, {3.575954177890476*^9, 
   3.575954207336129*^9}, 3.575954243090618*^9, 3.5764883510103188`*^9, 
   3.5865813523759665`*^9, 3.587358793108697*^9, {3.5873591861400857`*^9, 
   3.5873592191052265`*^9}, 3.5873604525961094`*^9}]
}, Open  ]],

Cell["Strain tensor", "Text",
 CellChangeTimes->{{3.5873588032940073`*^9, 3.5873588081416144`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.4133553819025807`*^9, 3.4133553842055807`*^9}, {
  3.501909807983059*^9, 3.501909820007747*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "-", 
      FractionBox["B", 
       SuperscriptBox["r", "2"]]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"A", "+", 
      FractionBox["B", 
       SuperscriptBox["r", "2"]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575544094474163*^9, 3.5757929969385777`*^9, 3.5757931033309126`*^9, 
   3.575793191366087*^9, 3.5757939997924614`*^9, 3.57579407750626*^9, 
   3.5757942698124084`*^9, 3.5758713349371395`*^9, {3.5759541779354773`*^9, 
   3.5759542073781757`*^9}, 3.5759542431406245`*^9, 3.576488351058322*^9, 
   3.586581352448986*^9, 3.58735879313373*^9, {3.5873591861630664`*^9, 
   3.587359219127225*^9}, 3.5873604526201124`*^9}]
}, Open  ]],

Cell["Stress tensor", "Text",
 CellChangeTimes->{{3.5873588116780796`*^9, 3.587358813477311*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", "//", "Expand"}], "//", 
  RowBox[{"DoCollect", "[", 
   RowBox[{"{", 
    RowBox[{"A", ",", "B"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.413355393503581*^9, 3.4133553939815807`*^9}, {
  3.5019098253430524`*^9, 3.5019098428060513`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "B", " ", "\[Mu]"}], 
        SuperscriptBox["r", "2"]]}], "+", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "B", " ", "\[Mu]"}], 
       SuperscriptBox["r", "2"]], "+", 
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Lambda]"}], "+", 
         RowBox[{"2", " ", "\[Mu]"}]}], ")"}]}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"2", " ", "A", " ", "\[Lambda]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755440945141687`*^9, 3.57579299696154*^9, 3.5757931033519287`*^9, 
   3.575793191393985*^9, 3.575794000017537*^9, 3.5757940775152407`*^9, 
   3.5757942698323736`*^9, 3.575871334957142*^9, {3.5759541779574804`*^9, 
   3.5759542073991404`*^9}, 3.5759542431656275`*^9, 3.576488351084325*^9, 
   3.586581352472004*^9, 3.5873587931607184`*^9, {3.587359186188093*^9, 
   3.5873592191502323`*^9}, 3.5873604526441164`*^9}]
}, Open  ]],

Cell["\<\
Boundary conditions for radial stresses\
\>", "Text",
 CellChangeTimes->{{3.587358918222477*^9, 3.5873589418614383`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "/.", 
          RowBox[{"r", "\[Rule]", "a"}]}], ")"}], "\[Equal]", 
        RowBox[{"-", "P"}]}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Sigma]", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "/.", 
          RowBox[{"r", "\[Rule]", "b"}]}], ")"}], "\[Equal]", "0"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "B"}], "}"}]}], "]"}], "//", "First"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "2"], " ", "P"}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]]}], ",", 
   RowBox[{"B", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "P"}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}], ")"}], " ", "\[Mu]"}]]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.575544094557174*^9, 3.5757929969885473`*^9, 3.575793103376918*^9, 
   3.5757931914169817`*^9, 3.575794000339572*^9, 3.5757940775272665`*^9, 
   3.5757942698564253`*^9, 3.575871334984145*^9, {3.575954177985443*^9, 
   3.5759542074211407`*^9}, 3.5759542431946473`*^9, 3.5764883511203294`*^9, 
   3.5865813526170387`*^9, 3.5873587931897388`*^9, {3.5873591863410854`*^9, 
   3.5873592191751947`*^9}, 3.5873604526701193`*^9}]
}, Open  ]],

Cell["\<\
Conversion from Lame coefficients\
\>", "Text",
 CellChangeTimes->{{3.501909776397253*^9, 3.501909779692441*^9}, {
  3.587358954541993*^9, 3.587358994084961*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lame", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "\[Rule]", 
      FractionBox[
       RowBox[{"EE", " ", "\[Nu]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", "\[Nu]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}]]}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", 
      FractionBox["EE", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}]]}]}], " ", "}"}]}], 
  ";"}]], "Input"],

Cell["Convenience function", "Text",
 CellChangeTimes->{{3.587358999205595*^9, 3.587359009932993*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"do", "[", "e_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"e", "/.", "sol"}], "/.", "lame"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.413355307425581*^9, 3.413355370558581*^9}}],

Cell["Radial displacement", "Text",
 CellChangeTimes->{{3.5873590193411427`*^9, 3.587359022069602*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["u", "r"], "[", "r", "]"}], "//", "do"}]], "Input",
 CellChangeTimes->{{3.413355329967581*^9, 3.413355334062581*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], " ", "P", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Nu]"}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}], " ", "EE", " ", "r"}]]}]], "Output",
 CellChangeTimes->{
  3.5755440946221833`*^9, 3.5757929970335913`*^9, 3.5757931034139504`*^9, 
   3.575793191455017*^9, 3.575794000466547*^9, 3.575794077554267*^9, 
   3.5757942698934255`*^9, 3.575871335026203*^9, {3.5759541780364895`*^9, 
   3.5759542074621444`*^9}, 3.5759542432356367`*^9, 3.5764883511693354`*^9, 
   3.58658135275506*^9, 3.5873587932377205`*^9, {3.587359186392118*^9, 
   3.587359219214196*^9}, 3.587360452711126*^9}]
}, Open  ]],

Cell["Change in thickness", "Text",
 CellChangeTimes->{{3.5873590364132805`*^9, 3.5873591022215595`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]d", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "r"], "[", "b", "]"}], "-", 
    RowBox[{
     SubscriptBox["u", "r"], "[", "a", "]"}]}], "//", "do"}]}]], "Input",
 CellChangeTimes->{{3.4133539550705805`*^9, 3.413353985888581*^9}, 
   3.413354890816581*^9, {3.4133550067515807`*^9, 3.413355007150581*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"a", " ", "P", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "\[Nu]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}], " ", "EE"}]]}]], "Output",
 CellChangeTimes->{
  3.575544094668189*^9, 3.575792997064555*^9, 3.5757931034409227`*^9, 
   3.5757931914810233`*^9, 3.5757940005275917`*^9, 3.575794077569229*^9, 
   3.575794269919429*^9, 3.575871335054178*^9, {3.5759541780714965`*^9, 
   3.575954207489149*^9}, 3.5759542432666473`*^9, 3.576488351211341*^9, 
   3.586581353496146*^9, 3.587358793270753*^9, {3.5873591864591303`*^9, 
   3.5873592192432013`*^9}, 3.5873604527420893`*^9}]
}, Open  ]],

Cell["Strain tensor", "Text",
 CellChangeTimes->{{3.5873591114136925`*^9, 3.5873591133009305`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "//", "do"}]], "Input",
 CellChangeTimes->{{3.4133553819025807`*^9, 3.4133553842055807`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "\[Nu]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}], ")"}], " ", "EE", " ", 
       SuperscriptBox["r", "2"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "2"], " ", "P", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"]}], ")"}], " ", "EE", " ", 
        SuperscriptBox["r", "2"]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575544094725195*^9, 3.5757929971006002`*^9, 3.5757931034769526`*^9, 
   3.575793191522972*^9, 3.575794000709619*^9, 3.5757940775922728`*^9, 
   3.5757942699533887`*^9, 3.575871335090158*^9, {3.575954178116516*^9, 
   3.575954207523202*^9}, 3.5759542433046975`*^9, 3.5764883512543893`*^9, 
   3.5865813535931606`*^9, 3.587358793312769*^9, {3.5873591865031247`*^9, 
   3.5873592192802362`*^9}, 3.587360452779131*^9}]
}, Open  ]],

Cell["Stress tensor", "Text",
 CellChangeTimes->{{3.5873591211969223`*^9, 3.5873591232371798`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Sigma]", "//", "do"}]], "Input",
 CellChangeTimes->{{3.413355393503581*^9, 3.4133553939815807`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["r", "2"]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}], ")"}], " ", 
       SuperscriptBox["r", "2"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "2"], " ", "P", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["r", "2"]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"]}], ")"}], " ", 
        SuperscriptBox["r", "2"]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", "P", " ", "\[Nu]"}], 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755440947942038`*^9, 3.5757929971445627`*^9, 3.5757931035199375`*^9, 
   3.5757931915660205`*^9, 3.5757940010046597`*^9, 3.575794077624235*^9, 
   3.5757942699944315`*^9, 3.575871335136162*^9, {3.57595417817451*^9, 
   3.5759542075641575`*^9}, 3.5759542433486547`*^9, 3.576488351302399*^9, 
   3.586581354761323*^9, 3.5873587933577642`*^9, {3.587359186546118*^9, 
   3.5873592193232355`*^9}, 3.5873604528241425`*^9}]
}, Open  ]],

Cell["Radial pressure", "Text",
 CellChangeTimes->{{3.5019101205729384`*^9, 3.5019101226370564`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["p", "r"], "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Sigma]", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "//", "do"}]}]], "Input",
 CellChangeTimes->{{3.5019101261012545`*^9, 3.501910155496936*^9}, {
  3.501910206079829*^9, 3.501910209360017*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], " ", "P", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["r", "2"]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}], " ", 
    SuperscriptBox["r", "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.575544094847209*^9, 3.575792997175596*^9, 3.575793103548964*^9, 
   3.5757931915940228`*^9, 3.575794001273671*^9, 3.575794077639262*^9, 
   3.575794270021394*^9, 3.5758713351671658`*^9, {3.5759541782084866`*^9, 
   3.5759542075911756`*^9}, 3.5759542433856573`*^9, 3.576488351338357*^9, 
   3.586581354977293*^9, 3.58735879339277*^9, {3.5873591866281133`*^9, 
   3.58735921935525*^9}, 3.587360452853117*^9}]
}, Open  ]],

Cell["Average pressure", "Text",
 CellChangeTimes->{{3.501910248373248*^9, 3.5019102515484295`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "3"]}], 
    RowBox[{"Tr", "[", "\[Sigma]", "]"}]}], "//", "do"}]}]], "Input",
 CellChangeTimes->{{3.501910255376649*^9, 3.501910279632036*^9}, {
  3.501910313640981*^9, 3.5019103456248107`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox["a", "2"], " ", "P", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[Nu]"}], ")"}]}], 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "-", 
     SuperscriptBox["b", "2"]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.575544094900215*^9, 3.575792997208611*^9, 3.5757931035789723`*^9, 
   3.5757931916239853`*^9, 3.5757940015406847`*^9, 3.575794077657239*^9, 
   3.5757942700493984`*^9, 3.575871335199172*^9, {3.5759541782484765`*^9, 
   3.5759542076201644`*^9}, 3.575954243420692*^9, 3.5764883513753614`*^9, 
   3.5865813550893497`*^9, 3.587358793428733*^9, {3.5873591866691484`*^9, 
   3.587359219385236*^9}, 3.5873604528851457`*^9}]
}, Open  ]],

Cell["Tangential stress at inner surface", "Text",
 CellChangeTimes->{{3.501910390437374*^9, 3.5019103981088123`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Sigma]", "\[Phi]\[Phi]"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}], "/.", 
    RowBox[{"r", "\[Rule]", "a"}]}], "//", "do"}]}]], "Input",
 CellChangeTimes->{{3.5019104016250134`*^9, 3.5019104330788126`*^9}, {
  3.587359167598715*^9, 3.5873592102701297`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}], ")"}], " ", "P"}], 
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["a", "2"]}], "+", 
   SuperscriptBox["b", "2"]}]]], "Output",
 CellChangeTimes->{
  3.5755440950712366`*^9, 3.5757929972336164`*^9, 3.5757931036009717`*^9, 
   3.5757931916460285`*^9, 3.57579400185876*^9, 3.5757940776662636`*^9, 
   3.5757942700714564`*^9, 3.575871335223175*^9, {3.5759541782734814`*^9, 
   3.5759542076422644`*^9}, 3.5759542434496636`*^9, 3.5764883514043703`*^9, 
   3.5865813561124783`*^9, 3.587358793457777*^9, {3.587359172031288*^9, 
   3.5873592194142513`*^9}, 3.587360452916151*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 9.9 One-inch water pipe (p. 160)\
\>", "Section",
 CellChangeTimes->{{3.58736060295599*^9, 3.587360612915331*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.412761605988*^9, 3.412761613401*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(24\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575544095392274*^9, 3.5757929974176006`*^9, 3.575793103781955*^9, 
   3.575793191825052*^9, 3.575794002104796*^9, 3.575794077814311*^9, 
   3.5757942702464237`*^9, 3.5758713354082255`*^9, {3.5759541784565086`*^9, 
   3.575954207828191*^9}, 3.575954243639744*^9, 3.576488351608397*^9, 
   3.5865813572726*^9, 3.587358793662803*^9, 3.5873591927529316`*^9, 
   3.58736045308617*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection",
 CellChangeTimes->{{3.5873594509573107`*^9, 3.587359454180811*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"0.5", "*", "0.957", "Inch"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"inner", " ", "radius", " ", "of", " ", "pipe"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"0.5", "*", "1.315", "Inch"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"outer", " ", "radius", " ", "of", " ", "pipe"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]", "=", 
   RowBox[{"2000", "Bar"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"yield", " ", "strength", " ", "of", " ", "iron"}], " ", "*)"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4127616155039997`*^9, 3.412761654826*^9}, {
  3.4133447141265807`*^9, 3.413344737822581*^9}, {3.4133450217575808`*^9, 
  3.413345029566581*^9}, {3.413347278862581*^9, 3.413347309472581*^9}, {
  3.4133503252475805`*^9, 3.4133503294855804`*^9}, {3.413350541518581*^9, 
  3.4133505544945807`*^9}, {3.5019107721522064`*^9, 3.5019108153596783`*^9}, {
  3.501910874889083*^9, 3.5019108778152504`*^9}, {3.587359559069912*^9, 
  3.5873595936532497`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.5873595067813377`*^9, 3.587359507764497*^9}}],

Cell["Blowup pressure", "Text",
 CellChangeTimes->{{3.587359625484275*^9, 3.5873596289727216`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "=", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["a", "2"]}], 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["a", "2"]}]], "\[Sigma]"}], "//", 
   RowBox[{"ToUnit", "[", "Bar", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.412761660546*^9, 3.41276168065*^9}, {
  3.413344743854581*^9, 3.4133447524625807`*^9}}],

Cell[BoxData[
 TemplateBox[{"615.0119051489676`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"bars\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: bars"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Bars\""}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5755440956883116`*^9, 3.575792997643668*^9, 3.5757931039220133`*^9, 
   3.5757931919590387`*^9, 3.575794002258772*^9, 3.575794077965319*^9, 
   3.5757942703894544`*^9, 3.575871335560216*^9, {3.575954178603563*^9, 
   3.5759542079652076`*^9}, 3.5759542437907352`*^9, 3.5764883520004396`*^9, 
   3.5865813584497623`*^9, 3.587358793821823*^9, 3.5873591928999343`*^9, 
   3.5873604531861825`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Unclamped pipe, analytic calculations (p. 160)\
\>", "Section",
 CellChangeTimes->{{3.501911321997656*^9, 3.501911324492799*^9}, {
  3.587359728477182*^9, 3.587359735916134*^9}, {3.5873597664129477`*^9, 
  3.587359770428414*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5019113869283695`*^9, 3.501911388982487*^9}, {
  3.5019114217263603`*^9, 3.5019114255105762`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(4\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.575544096447401*^9, 3.575544207562732*^9, 3.5757929979907184`*^9, 
   3.5757931043300333`*^9, 3.575793433506421*^9, 3.575794002594817*^9, 
   3.575794078355394*^9, 3.57579427078651*^9, 3.5757943631411505`*^9, 
   3.5757944744521055`*^9, 3.575871335982312*^9, {3.5759541790056133`*^9, 
   3.575954208366258*^9}, 3.575954244198801*^9, 3.57648835239349*^9, 
   3.5865813592788754`*^9, 3.5873597810907893`*^9, 3.5873603113033667`*^9, 
   3.5873604533672075`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uniform radial displacement", "Subsection",
 CellChangeTimes->{{3.587359824125193*^9, 3.587359829107812*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Cylindrical", "[", 
    RowBox[{"r", ",", "\[Phi]", ",", "z"}], "]"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "r"], "[", "r", "]"}], ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results", "Subsection",
 CellChangeTimes->{{3.587359936036276*^9, 3.5873599370443797`*^9}}],

Cell["Displacements", "Text",
 CellChangeTimes->{{3.587359944828355*^9, 3.5873599505321217`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Q", "=", 
   RowBox[{"2", "\[Nu]", " ", 
    FractionBox[
     SuperscriptBox["a", "2"], 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["a", "2"]}]], "P"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5019114863000536`*^9, 3.5019115016819334`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "r"], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "\[Nu]"}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}], ")"}], " ", "EE", " ", "r"}]]}], "+", 
    RowBox[{"\[Nu]", " ", "r", " ", 
     FractionBox["Q", "EE"]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.501911431732932*^9, 3.5019114589064865`*^9}, {
   3.5019115136386175`*^9, 3.501911528966494*^9}, 3.5019115614053493`*^9, 
   3.501911631088335*^9, 3.501911731023051*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], " ", "P", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["r", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}], " ", "EE", " ", "r"}]]}]], "Output",
 CellChangeTimes->{
  3.5755440986436653`*^9, 3.5755442077387533`*^9, 3.575792998044717*^9, 
   3.575793104375081*^9, 3.575793433616479*^9, 3.575794002763876*^9, 
   3.575794078399373*^9, 3.57579427083354*^9, 3.5757943632561345`*^9, 
   3.5757944745591216`*^9, 3.5758713360372753`*^9, {3.5759541790535774`*^9, 
   3.5759542084082637`*^9}, 3.575954244248765*^9, 3.5764883524465384`*^9, 
   3.5865813598249054`*^9, 3.587359781201804*^9, 3.5873603113873367`*^9, 
   3.5873604534892488`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "z"], "=", 
  RowBox[{
   RowBox[{"-", "z"}], " ", 
   FractionBox["Q", "EE"]}]}]], "Input",
 CellChangeTimes->{{3.501911643916069*^9, 3.501911703393471*^9}, 
   3.5019117344982495`*^9, 3.5019117964087906`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"], " ", "P", " ", "z", " ", "\[Nu]"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"]}], ")"}], " ", "EE"}]]}]], "Output",
 CellChangeTimes->{
  3.5755440995557733`*^9, 3.575544207781759*^9, 3.57579299807472*^9, 
   3.5757931043980703`*^9, 3.5757934336394043`*^9, 3.575794002787881*^9, 
   3.5757940784223776`*^9, 3.5757942708585033`*^9, 3.5757943632781353`*^9, 
   3.575794474585139*^9, 3.5758713360603237`*^9, {3.575954179076623*^9, 
   3.5759542084352665`*^9}, 3.5759542442748065`*^9, 3.5764883524735003`*^9, 
   3.586581359863948*^9, 3.587359781228829*^9, 3.5873603114113617`*^9, 
   3.587360453516183*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["u", "r"], ",", "0", ",", 
     SubscriptBox["u", "z"]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5019117122599773`*^9, 3.501911744008794*^9}}],

Cell["Strain tensor", "Text",
 CellChangeTimes->{{3.5873599946916*^9, 3.5873599959077735`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], "+", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], ")"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.5019119839975204`*^9, 3.5019119855866113`*^9}, {
  3.501912093945809*^9, 3.501912107798601*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}], ")"}], " ", "EE", " ", 
       SuperscriptBox["r", "2"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "2"], " ", "P", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Nu]"}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "\[Nu]"}], ")"}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"]}], ")"}], " ", "EE", " ", 
        SuperscriptBox["r", "2"]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "P", " ", "\[Nu]"}], 
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", "EE"}], "-", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", "EE"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575544103201213*^9, 3.575544207986784*^9, 3.5757929981366887`*^9, 
   3.5757931044580784`*^9, 3.5757934336964474`*^9, 3.57579400294588*^9, 
   3.5757940784804296`*^9, 3.5757942709115553`*^9, 3.5757943633401527`*^9, 
   3.5757944746451015`*^9, 3.5758713361383176`*^9, {3.5759541791345882`*^9, 
   3.5759542084922743`*^9}, 3.5759542443428326`*^9, 3.5764883525435085`*^9, 
   3.586581360137941*^9, 3.5873597812868137`*^9, 3.587360311469396*^9, 
   3.5873604535762324`*^9}]
}, Open  ]],

Cell["Convert Lame coefficients", "Text",
 CellChangeTimes->{{3.5873599602043004`*^9, 3.587359969060408*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lame", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "\[Rule]", 
      FractionBox[
       RowBox[{"EE", " ", "\[Nu]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", "\[Nu]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}]]}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", 
      FractionBox["EE", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{"1", "+", "\[Nu]"}], ")"}]}]]}]}], " ", "}"}]}], 
  ";"}]], "Input"],

Cell["Stress tensor", "Text",
 CellChangeTimes->{{3.5873600008843985`*^9, 3.5873600019235516`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Sigma]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"2", "\[Mu]", " ", "uu"}], "+", 
     RowBox[{"\[Lambda]", "  ", "UnitTensor", " ", 
      RowBox[{"Tr", "[", "uu", "]"}]}]}], "/.", "lame"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.5019121188882356`*^9, 3.5019121218634057`*^9}, {
  3.501912156009359*^9, 3.501912171376238*^9}, {3.575794350511567*^9, 
  3.575794352518789*^9}, {3.5759542373579593`*^9, 3.5759542383100863`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", "P", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["r", "2"]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"]}], ")"}], " ", 
       SuperscriptBox["r", "2"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "2"], " ", "P", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["r", "2"]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"]}], ")"}], " ", 
        SuperscriptBox["r", "2"]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5755441038222857`*^9, 3.5755442080447903`*^9, 3.575792998164693*^9, 
   3.575793104498101*^9, 3.575793433728424*^9, 3.5757940030318727`*^9, 
   3.57579407850835*^9, 3.5757942709515133`*^9, 3.5757943633741508`*^9, 
   3.5757944746811323`*^9, 3.5758713361793203`*^9, {3.575954179196597*^9, 
   3.575954208547283*^9}, 3.575954244389784*^9, 3.5764883530026517`*^9, 
   3.586581360215009*^9, 3.58735978132578*^9, 3.5873603115083833`*^9, 
   3.587360453613231*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Thin wall approximation", "Subsection",
 CellChangeTimes->{{3.5019122137736626`*^9, 3.5019122178528957`*^9}}],

Cell["Helper function", "Text",
 CellChangeTimes->{{3.5873599834281564`*^9, 3.5873599858835077`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dothin", "[", "n_", "]"}], "[", "e_", "]"}], ":=", 
  RowBox[{
   RowBox[{"e", "//", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{"#", ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", "0", ",", "n"}], "}"}]}], "]"}], "&"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.413354932223581*^9, 3.413354971760581*^9}, {
   3.413355036640581*^9, 3.413355037470581*^9}, {3.4133550677905807`*^9, 
   3.413355086366581*^9}, {3.413355819135581*^9, 3.413355830079581*^9}, 
   3.5019123482493544`*^9, {3.587360281148593*^9, 3.587360282012703*^9}, {
   3.587360333389101*^9, 3.5873603381006985`*^9}, {3.5873604086606054`*^9, 
   3.587360435564969*^9}}],

Cell[TextData[{
 "Introduce the thickness ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.5873600154042044`*^9, 3.5873600212279873`*^9}, {
  3.587360083675826*^9, 3.5873600876152377`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"a", "+", "d"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"a", "  ", "+", 
    RowBox[{"s", " ", "d"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4131834913054075`*^9, 3.4131834943384075`*^9}, {
  3.4131836246514077`*^9, 3.4131836280324078`*^9}, {3.4131842191574078`*^9, 
  3.4131842231184072`*^9}, {3.413189552341012*^9, 3.4131896295730124`*^9}}],

Cell["Displacement to leading order", "Text",
 CellChangeTimes->{{3.5873600750446596`*^9, 3.5873601012600856`*^9}, {
  3.5873601758913536`*^9, 3.5873601797479753`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "//", 
  RowBox[{"dothin", "[", 
   RowBox[{"-", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.413355091460581*^9, 3.413355112862581*^9}, {
   3.501912318071628*^9, 3.501912320047741*^9}, {3.5873600314612494`*^9, 
   3.5873600317172337`*^9}, 3.587360148812982*^9, 3.587360299788924*^9, {
   3.5873604625003676`*^9, 3.5873604675079956`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], " ", "P"}], 
      RowBox[{"EE", " ", "d"}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "d", "]"}], "0"],
      SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
      Editable->False]}],
    SeriesData[$CellContext`d, 
     0, {$CellContext`a^2 $CellContext`EE^(-1) $CellContext`P}, -1, 0, 1],
    Editable->False], ",", "0", ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"a", " ", "P", " ", "z", " ", "\[Nu]"}], 
       RowBox[{"EE", " ", "d"}]]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "d", "]"}], "0"],
      SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
      Editable->False]}],
    SeriesData[$CellContext`d, 
     0, {-$CellContext`a $CellContext`EE^(-1) $CellContext`P $CellContext`z \
$CellContext`\[Nu]}, -1, 0, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575544105251457*^9, 3.575792998231701*^9, 3.5757931045350695`*^9, 
   3.5757940031069202`*^9, 3.575794078569393*^9, 3.575794270993574*^9, 
   3.5758713362273417`*^9, {3.5759541792376003`*^9, 3.5759542085893126`*^9}, 
   3.5759542444337873`*^9, 3.5764883533286505`*^9, 3.5865813668808126`*^9, {
   3.5873600333804283`*^9, 3.5873600367478504`*^9}, 3.587360149171008*^9, {
   3.587360289521612*^9, 3.58736031157239*^9}, 3.587360343328388*^9, {
   3.587360453675203*^9, 3.587360468355088*^9}}]
}, Open  ]],

Cell["Strain tensor", "Text",
 CellChangeTimes->{{3.5873601691165276`*^9, 3.5873601719479446`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uu", " ", "//", 
  RowBox[{"dothin", "[", 
   RowBox[{"-", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.413355145666581*^9, 3.413355148862581*^9}, {
   3.587360160268418*^9, 3.5873601605324326`*^9}, 3.5873603842685432`*^9, {
   3.5873604817407417`*^9, 3.58736048469215*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"a", " ", "P", " ", "\[Nu]"}], 
         RowBox[{"EE", " ", "d"}]]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "d", "]"}], "0"],
        SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
        Editable->False]}],
      SeriesData[$CellContext`d, 
       0, {-$CellContext`a $CellContext`EE^(-1) $CellContext`P $CellContext`\
\[Nu]}, -1, 0, 1],
      Editable->False], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     InterpretationBox[
      RowBox[{
       FractionBox[
        RowBox[{"a", " ", "P"}], 
        RowBox[{"EE", " ", "d"}]], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "d", "]"}], "0"],
        SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
        Editable->False]}],
      SeriesData[$CellContext`d, 
       0, {$CellContext`a $CellContext`EE^(-1) $CellContext`P}, -1, 0, 1],
      Editable->False], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"a", " ", "P", " ", "\[Nu]"}], 
         RowBox[{"EE", " ", "d"}]]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "d", "]"}], "0"],
        SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
        Editable->False]}],
      SeriesData[$CellContext`d, 
       0, {-$CellContext`a $CellContext`EE^(-1) $CellContext`P $CellContext`\
\[Nu]}, -1, 0, 1],
      Editable->False]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.575544105349471*^9, 3.5757929982717476`*^9, 3.575793104570058*^9, 
   3.575794003632986*^9, 3.575794078608395*^9, 3.5757942710295486`*^9, 
   3.575871336264366*^9, {3.5759541792736053`*^9, 3.57595420862029*^9}, 
   3.575954244476818*^9, 3.5764883533706264`*^9, 3.586581366928834*^9, 
   3.5873600367828903`*^9, 3.587360161598528*^9, {3.5873602895816307`*^9, 
   3.5873603116363926`*^9}, 3.587360343354388*^9, 3.5873603845865726`*^9, 
   3.5873604537032366`*^9, 3.587360485165181*^9}]
}, Open  ]],

Cell["Stress tensor", "Text",
 CellChangeTimes->{{3.5873601907722244`*^9, 3.5873601933235483`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", " ", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}], "//", 
  RowBox[{"dothin", "[", "0", "]"}]}]], "Input",
 CellChangeTimes->{{3.4133552120945807`*^9, 3.4133552151335807`*^9}, {
  3.587360198932271*^9, 3.587360216956525*^9}, {3.5873605235410223`*^9, 
  3.58736052862864*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"P", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "s"}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "d", "]"}], "1"],
    SeriesData[$CellContext`d, 0, {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[$CellContext`d, 0, {$CellContext`P (-1 + $CellContext`s)}, 0, 1, 
   1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.5755441064926076`*^9, 3.5757929982977514`*^9, 3.5757931045980988`*^9, 
   3.5757940041540527`*^9, 3.5757940786204033`*^9, 3.5757942710575657`*^9, 
   3.5758713362883496`*^9, {3.5759541793286552`*^9, 3.575954208707301*^9}, 
   3.575954244501796*^9, 3.576488353396635*^9, 3.586581367000803*^9, 
   3.587360036810859*^9, {3.58736020024238*^9, 3.5873602172865725`*^9}, {
   3.587360289614683*^9, 3.5873603116734047`*^9}, 3.5873603433793545`*^9, 
   3.5873604537622595`*^9, 3.587360529081717*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "2"}], "]"}], "]"}], " ", "//", 
  RowBox[{"dothin", "[", 
   RowBox[{"-", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.587360221077038*^9, 3.587360230821263*^9}, {
  3.587360534348387*^9, 3.5873605384679112`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"a", " ", "P"}], "d"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "d", "]"}], "0"],
    SeriesData[$CellContext`d, 0, {}, -1, 0, 1],
    Editable->False]}],
  SeriesData[$CellContext`d, 0, {$CellContext`a $CellContext`P}, -1, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.587360231208268*^9, {3.5873602896466513`*^9, 3.5873603117023897`*^9}, 
   3.5873603434053655`*^9, 3.587360453789276*^9, 3.587360539056925*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{851, 941},
WindowMargins->{{44, Automatic}, {43, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1485, 35, 210, 5, 65, "Title"],
Cell[1698, 42, 470, 8, 41, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2205, 55, 189, 4, 65, "Title"],
Cell[CellGroupData[{
Cell[2419, 63, 201, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[2645, 71, 59, 1, 41, "Input"],
Cell[2707, 74, 765, 15, 21, "Message"]
}, Open  ]],
Cell[3487, 92, 26, 0, 30, "Text"],
Cell[3516, 94, 689, 20, 122, "Input"],
Cell[4208, 116, 22, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[4255, 120, 276, 8, 56, "Input"],
Cell[4534, 130, 747, 16, 41, "Output"]
}, Open  ]],
Cell[5296, 149, 27, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[5348, 153, 168, 4, 56, "Input"],
Cell[5519, 159, 391, 6, 41, "Output"]
}, Open  ]],
Cell[5925, 168, 28, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[5978, 172, 141, 4, 41, "Input"],
Cell[6122, 178, 762, 16, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6933, 200, 210, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[7168, 208, 59, 1, 41, "Input"],
Cell[7230, 211, 531, 12, 21, "Message"]
}, Open  ]],
Cell[7776, 226, 26, 0, 30, "Text"],
Cell[7805, 228, 716, 22, 145, "Input"],
Cell[8524, 252, 32, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[8581, 256, 115, 3, 41, "Input"],
Cell[8699, 261, 750, 16, 41, "Output"]
}, Open  ]],
Cell[9464, 280, 22, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[9511, 284, 209, 7, 57, "Input"],
Cell[9723, 293, 737, 16, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10497, 314, 85, 2, 41, "Input"],
Cell[10585, 318, 744, 16, 41, "Output"]
}, Open  ]],
Cell[11344, 337, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[11470, 342, 220, 7, 58, "Input"],
Cell[11693, 351, 755, 16, 41, "Output"]
}, Open  ]],
Cell[12463, 370, 95, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[12583, 375, 75, 2, 56, "Input"],
Cell[12661, 379, 393, 6, 41, "Output"]
}, Open  ]],
Cell[13069, 388, 177, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[13271, 396, 139, 4, 59, "Input"],
Cell[13413, 402, 756, 16, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14218, 424, 207, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[14450, 432, 153, 3, 41, "Input"],
Cell[14606, 437, 682, 14, 21, "Message"]
}, Open  ]],
Cell[15303, 454, 173, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[15501, 460, 690, 12, 41, "Input"],
Cell[16194, 474, 68182, 1121, 172, "Output"]
}, Open  ]],
Cell[84391, 1598, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[84519, 1603, 140, 2, 41, "Input"],
Cell[84662, 1607, 344, 6, 41, "Output"]
}, Open  ]],
Cell[85021, 1616, 144, 2, 30, "Text"],
Cell[85168, 1620, 2293, 44, 102, "Input"],
Cell[CellGroupData[{
Cell[87486, 1668, 195, 4, 36, "Subsection"],
Cell[CellGroupData[{
Cell[87706, 1676, 482, 15, 41, "Input"],
Cell[88191, 1693, 860, 20, 41, "Output"]
}, Open  ]],
Cell[89066, 1716, 348, 10, 41, "Input"],
Cell[CellGroupData[{
Cell[89439, 1730, 1037, 22, 82, "Input"],
Cell[90479, 1754, 675, 12, 21, "Message"],
Cell[91157, 1768, 68484, 1130, 209, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[159714, 2906, 253, 5, 65, "Title"],
Cell[CellGroupData[{
Cell[159992, 2915, 384, 7, 75, "Section"],
Cell[CellGroupData[{
Cell[160401, 2926, 127, 2, 41, "Input"],
Cell[160531, 2930, 411, 10, 21, "Message"]
}, Open  ]],
Cell[160957, 2943, 149, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[161131, 2949, 1636, 24, 41, "Input"],
Cell[162770, 2975, 83328, 1371, 475, "Output"]
}, Open  ]],
Cell[246113, 4349, 226, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[246364, 4356, 1088, 17, 41, "Input"],
Cell[247455, 4375, 296, 6, 41, "Output"]
}, Open  ]],
Cell[247766, 4384, 157, 2, 30, "Text"],
Cell[247926, 4388, 446, 10, 41, "Input"],
Cell[248375, 4400, 240, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[248640, 4409, 426, 12, 41, "Input"],
Cell[249069, 4423, 324, 6, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[249430, 4434, 113, 1, 36, "Subsection"],
Cell[249546, 4437, 7420, 180, 377, "Input"],
Cell[256969, 4619, 93, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[257087, 4624, 3431, 51, 41, "Input"],
Cell[260521, 4677, 93653, 1540, 475, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[354223, 6223, 103, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[354351, 6228, 646, 13, 41, "Input"],
Cell[355000, 6243, 83425, 1372, 475, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[438462, 7620, 431, 8, 41, "Input"],
Cell[438896, 7630, 83359, 1371, 475, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[522292, 9006, 814, 13, 41, "Input"],
Cell[523109, 9021, 161302, 2649, 475, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[684460, 11676, 105, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[684590, 11681, 924, 18, 41, "Input"],
Cell[685517, 11701, 663, 18, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[686217, 11724, 539, 13, 41, "Input"],
Cell[686759, 11739, 595, 16, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[687403, 11761, 100, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[687528, 11766, 1767, 39, 102, "Input"],
Cell[689298, 11807, 482, 9, 21, "Message"],
Cell[689783, 11818, 163101, 2684, 475, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[852945, 14509, 283, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[853253, 14518, 126, 2, 41, "Input"],
Cell[853382, 14522, 365, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[853784, 14536, 203, 4, 36, "Subsection"],
Cell[853990, 14542, 732, 13, 41, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[854759, 14560, 226, 3, 36, "Subsection"],
Cell[854988, 14565, 1165, 21, 41, "Input"],
Cell[856156, 14588, 1108, 25, 62, "Input"],
Cell[857267, 14615, 1064, 24, 62, "Input"],
Cell[858334, 14641, 591, 12, 41, "Input"],
Cell[858928, 14655, 674, 14, 41, "Input"],
Cell[CellGroupData[{
Cell[859627, 14673, 2013, 37, 86, "Input"],
Cell[861643, 14712, 335, 7, 21, "Message"],
Cell[861981, 14721, 2026, 51, 165, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[864056, 14778, 54, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[864135, 14782, 265, 5, 41, "Input"],
Cell[864403, 14789, 440, 13, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[864880, 14807, 410, 10, 41, "Input"],
Cell[865293, 14819, 211, 3, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[865577, 14830, 180, 4, 65, "Title"],
Cell[CellGroupData[{
Cell[865782, 14838, 210, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[866017, 14846, 119, 2, 41, "Input"],
Cell[866139, 14850, 360, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[866536, 14864, 1010, 22, 76, "Input"],
Cell[867549, 14888, 325, 7, 21, "Message"],
Cell[867877, 14897, 6554, 117, 257, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[874480, 15020, 341, 6, 75, "Section"],
Cell[CellGroupData[{
Cell[874846, 15030, 541, 8, 41, "Input"],
Cell[875390, 15040, 262, 7, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[875689, 15052, 98, 1, 36, "Subsection"],
Cell[875790, 15055, 1623, 39, 142, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[877450, 15099, 97, 1, 36, "Subsection"],
Cell[877550, 15102, 234, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[877809, 15111, 180, 5, 55, "Input"],
Cell[877992, 15118, 310, 5, 41, "Output"]
}, Open  ]],
Cell[878317, 15126, 105, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[878447, 15131, 378, 11, 54, "Input"],
Cell[878828, 15144, 793, 19, 41, "Output"]
}, Open  ]],
Cell[879636, 15166, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[879762, 15171, 349, 8, 43, "Input"],
Cell[880114, 15181, 878, 21, 41, "Output"]
}, Open  ]],
Cell[881007, 15205, 100, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[881132, 15210, 439, 10, 41, "Input"],
Cell[881574, 15222, 641, 15, 41, "Output"]
}, Open  ]],
Cell[882230, 15240, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[882356, 15245, 273, 7, 58, "Input"],
Cell[882632, 15254, 702, 15, 41, "Output"]
}, Open  ]],
Cell[883349, 15272, 95, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[883469, 15277, 302, 6, 56, "Input"],
Cell[883774, 15285, 334, 5, 41, "Output"]
}, Open  ]],
Cell[884123, 15293, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[884251, 15298, 343, 9, 41, "Input"],
Cell[884597, 15309, 706, 15, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[885364, 15331, 180, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[885569, 15339, 129, 2, 41, "Input"],
Cell[885701, 15343, 408, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[886146, 15357, 95, 1, 36, "Subsection"],
Cell[886244, 15360, 92, 1, 30, "Text"],
Cell[886339, 15363, 1268, 28, 82, "Input"],
Cell[887610, 15393, 128, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[887763, 15399, 236, 6, 56, "Input"],
Cell[888002, 15407, 615, 13, 41, "Output"]
}, Open  ]],
Cell[888632, 15423, 146, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[888803, 15429, 422, 11, 54, "Input"],
Cell[889228, 15442, 729, 16, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[890006, 15464, 95, 1, 36, "Subsection"],
Cell[890104, 15467, 772, 16, 82, "Input"],
Cell[CellGroupData[{
Cell[890901, 15487, 236, 6, 56, "Input"],
Cell[891140, 15495, 613, 13, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[891790, 15513, 420, 11, 54, "Input"],
Cell[892213, 15526, 725, 16, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[893011, 15550, 192, 4, 65, "Title"],
Cell[CellGroupData[{
Cell[893228, 15558, 170, 2, 75, "Section"],
Cell[CellGroupData[{
Cell[893423, 15564, 59, 1, 41, "Input"],
Cell[893485, 15567, 383, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[893905, 15581, 32, 0, 36, "Subsection"],
Cell[893940, 15583, 1205, 32, 122, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[895182, 15620, 99, 1, 36, "Subsection"],
Cell[895284, 15623, 21, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[895330, 15627, 370, 7, 41, "Input"],
Cell[895703, 15636, 656, 14, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[896396, 15655, 232, 4, 41, "Input"],
Cell[896631, 15661, 286, 4, 41, "Output"]
}, Open  ]],
Cell[896932, 15668, 29, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[896986, 15672, 149, 5, 58, "Input"],
Cell[897138, 15679, 610, 13, 41, "Output"]
}, Open  ]],
Cell[897763, 15695, 34, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[897822, 15699, 325, 9, 54, "Input"],
Cell[898150, 15710, 797, 19, 41, "Output"]
}, Open  ]],
Cell[898962, 15732, 29, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[899016, 15736, 223, 5, 56, "Input"],
Cell[899242, 15743, 787, 18, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[900066, 15766, 64, 1, 41, "Input"],
Cell[900133, 15769, 725, 16, 41, "Output"]
}, Open  ]],
Cell[900873, 15788, 36, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[900934, 15792, 159, 4, 41, "Input"],
Cell[901096, 15798, 621, 13, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[901790, 15819, 309, 5, 104, "Title"],
Cell[CellGroupData[{
Cell[902124, 15828, 108, 1, 75, "Section"],
Cell[CellGroupData[{
Cell[902257, 15833, 127, 2, 41, "Input"],
Cell[902387, 15837, 356, 9, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[902780, 15851, 286, 5, 36, "Subsection"],
Cell[903069, 15858, 108, 1, 30, "Text"],
Cell[903180, 15861, 242, 6, 41, "Input"],
Cell[903425, 15869, 180, 4, 30, "Text"],
Cell[903608, 15875, 186, 7, 41, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[903831, 15887, 223, 3, 36, "Subsection"],
Cell[904057, 15892, 28, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[904110, 15896, 575, 20, 41, "Input"],
Cell[904688, 15918, 1920, 50, 56, "Output"]
}, Open  ]],
Cell[906623, 15971, 32, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[906680, 15975, 242, 6, 41, "Input"],
Cell[906925, 15983, 1779, 47, 56, "Output"]
}, Open  ]],
Cell[908719, 16033, 104, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[908848, 16038, 654, 22, 57, "Input"],
Cell[909505, 16062, 638, 9, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[910192, 16077, 119, 1, 36, "Subsection"],
Cell[910314, 16080, 22, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[910361, 16084, 287, 10, 56, "Input"],
Cell[910651, 16096, 1149, 29, 56, "Output"]
}, Open  ]],
Cell[911815, 16128, 22, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[911862, 16132, 460, 12, 41, "Input"],
Cell[912325, 16146, 2304, 63, 92, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[914678, 16215, 197, 4, 36, "Subsection"],
Cell[914878, 16221, 125, 1, 30, "Text"],
Cell[915006, 16224, 339, 10, 57, "Input"],
Cell[915348, 16236, 100, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[915473, 16241, 77, 2, 41, "Input"],
Cell[915553, 16245, 623, 9, 41, "Output"]
}, Open  ]],
Cell[916191, 16257, 91, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[916307, 16262, 126, 2, 41, "Input"],
Cell[916436, 16266, 1123, 27, 57, "Output"]
}, Open  ]],
Cell[917574, 16296, 92, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[917691, 16301, 239, 6, 41, "Input"],
Cell[917933, 16309, 1707, 46, 57, "Output"]
}, Open  ]],
Cell[919655, 16358, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[919787, 16363, 845, 25, 41, "Input"],
Cell[920635, 16390, 1331, 35, 66, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[922015, 16431, 188, 4, 36, "Subsection"],
Cell[922206, 16437, 116, 1, 30, "Text"],
Cell[922325, 16440, 548, 19, 58, "Input"],
Cell[922876, 16461, 112, 1, 30, "Text"],
Cell[922991, 16464, 286, 7, 41, "Input"],
Cell[923280, 16473, 125, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[923430, 16480, 402, 9, 41, "Input"],
Cell[923835, 16491, 1184, 29, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[925056, 16525, 412, 10, 41, "Input"],
Cell[925471, 16537, 1290, 32, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[926798, 16574, 217, 4, 41, "Input"],
Cell[927018, 16580, 2838, 79, 120, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[929893, 16664, 179, 4, 41, "Input"],
Cell[930075, 16670, 2109, 59, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[932233, 16735, 237, 5, 36, "Subsection"],
Cell[932473, 16742, 136, 3, 30, "Text"],
Cell[932612, 16747, 571, 15, 41, "Input"],
Cell[933186, 16764, 209, 6, 30, "Text"],
Cell[933398, 16772, 440, 10, 62, "Input"],
Cell[933841, 16784, 288, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[934154, 16796, 474, 10, 41, "Input"],
Cell[934631, 16808, 1202, 28, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[935870, 16841, 261, 5, 41, "Input"],
Cell[936134, 16848, 1008, 22, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[937179, 16875, 382, 7, 41, "Input"],
Cell[937564, 16884, 2554, 67, 57, "Output"]
}, Open  ]],
Cell[940133, 16954, 140, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[940298, 16961, 284, 7, 41, "Input"],
Cell[940585, 16970, 534, 14, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[941156, 16989, 312, 8, 41, "Input"],
Cell[941471, 16999, 571, 16, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[942079, 17020, 310, 8, 41, "Input"],
Cell[942392, 17030, 548, 16, 57, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[943001, 17053, 231, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[943257, 17062, 127, 2, 41, "Input"],
Cell[943387, 17066, 727, 14, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[944151, 17085, 185, 2, 36, "Subsection"],
Cell[944339, 17089, 1792, 44, 138, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[946168, 17138, 99, 1, 36, "Subsection"],
Cell[946270, 17141, 174, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[946469, 17149, 413, 6, 41, "Input"],
Cell[946885, 17157, 584, 8, 41, "Output"]
}, Open  ]],
Cell[947484, 17168, 150, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[947659, 17174, 400, 13, 60, "Input"],
Cell[948062, 17189, 965, 18, 41, "Output"]
}, Open  ]],
Cell[949042, 17210, 100, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[949167, 17215, 354, 8, 56, "Input"],
Cell[949524, 17225, 957, 18, 41, "Output"]
}, Open  ]],
Cell[950496, 17246, 148, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[950669, 17252, 247, 7, 56, "Input"],
Cell[950919, 17261, 568, 8, 41, "Output"]
}, Open  ]],
Cell[951502, 17272, 123, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[951650, 17279, 344, 11, 56, "Input"],
Cell[951997, 17292, 588, 9, 41, "Output"]
}, Open  ]],
Cell[952600, 17304, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[952728, 17309, 396, 11, 56, "Input"],
Cell[953127, 17322, 945, 18, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[954133, 17347, 281, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[954439, 17356, 127, 2, 41, "Input"],
Cell[954569, 17360, 710, 14, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[955316, 17379, 149, 2, 36, "Subsection"],
Cell[955468, 17383, 2227, 53, 158, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[957732, 17441, 99, 1, 36, "Subsection"],
Cell[957834, 17444, 129, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[957988, 17451, 491, 8, 41, "Input"],
Cell[958482, 17461, 546, 8, 41, "Output"]
}, Open  ]],
Cell[959043, 17472, 152, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[959220, 17478, 400, 13, 60, "Input"],
Cell[959623, 17493, 950, 18, 41, "Output"]
}, Open  ]],
Cell[960588, 17514, 100, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[960713, 17519, 303, 7, 56, "Input"],
Cell[961019, 17528, 935, 18, 41, "Output"]
}, Open  ]],
Cell[961969, 17549, 150, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[962144, 17555, 247, 7, 56, "Input"],
Cell[962394, 17564, 561, 8, 41, "Output"]
}, Open  ]],
Cell[962970, 17575, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[963096, 17580, 344, 11, 56, "Input"],
Cell[963443, 17593, 576, 9, 41, "Output"]
}, Open  ]],
Cell[964034, 17605, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[964162, 17610, 396, 11, 56, "Input"],
Cell[964561, 17623, 937, 18, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[965571, 17649, 218, 4, 104, "Title"],
Cell[CellGroupData[{
Cell[965814, 17657, 223, 3, 75, "Section"],
Cell[CellGroupData[{
Cell[966062, 17664, 59, 1, 41, "Input"],
Cell[966124, 17667, 629, 13, 21, "Message"]
}, Open  ]],
Cell[966768, 17683, 164, 4, 41, "Input"],
Cell[966935, 17689, 156, 2, 30, "Text"],
Cell[967094, 17693, 186, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[967305, 17704, 174, 2, 36, "Subsection"],
Cell[967482, 17708, 28, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[967535, 17712, 575, 20, 41, "Input"],
Cell[968113, 17734, 1673, 46, 56, "Output"]
}, Open  ]],
Cell[969801, 17783, 32, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[969858, 17787, 242, 6, 41, "Input"],
Cell[970103, 17795, 1554, 43, 56, "Output"]
}, Open  ]],
Cell[971672, 17841, 104, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[971801, 17846, 524, 19, 56, "Input"],
Cell[972328, 17867, 465, 7, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[972842, 17880, 130, 3, 36, "Subsection"],
Cell[972975, 17885, 22, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[973022, 17889, 287, 10, 56, "Input"],
Cell[973312, 17901, 931, 23, 56, "Output"]
}, Open  ]],
Cell[974258, 17927, 22, 0, 30, "Text"],
Cell[CellGroupData[{
Cell[974305, 17931, 520, 14, 41, "Input"],
Cell[974828, 17947, 1986, 57, 92, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[976863, 18010, 194, 4, 36, "Subsection"],
Cell[977060, 18016, 122, 1, 30, "Text"],
Cell[977185, 18019, 193, 7, 56, "Input"],
Cell[977381, 18028, 136, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[977542, 18035, 77, 2, 41, "Input"],
Cell[977622, 18039, 473, 7, 41, "Output"]
}, Open  ]],
Cell[978110, 18049, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[978234, 18054, 175, 3, 41, "Input"],
Cell[978412, 18059, 859, 21, 57, "Output"]
}, Open  ]],
Cell[979286, 18083, 97, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[979408, 18088, 292, 7, 41, "Input"],
Cell[979703, 18097, 1330, 36, 57, "Output"]
}, Open  ]],
Cell[981048, 18136, 131, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[981204, 18143, 753, 24, 41, "Input"],
Cell[981960, 18169, 1200, 33, 66, "Output"]
}, Open  ]],
Cell[983175, 18205, 172, 4, 30, "Text"],
Cell[983350, 18211, 548, 19, 58, "Input"],
Cell[983901, 18232, 102, 1, 30, "Text"],
Cell[984006, 18235, 243, 6, 41, "Input"],
Cell[984252, 18243, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[984380, 18248, 168, 4, 41, "Input"],
Cell[984551, 18254, 997, 26, 68, "Output"]
}, Open  ]],
Cell[985563, 18283, 105, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[985693, 18288, 358, 9, 41, "Input"],
Cell[986054, 18299, 872, 22, 58, "Output"]
}, Open  ]],
Cell[986941, 18324, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[987065, 18329, 122, 2, 41, "Input"],
Cell[987190, 18333, 1961, 55, 68, "Output"]
}, Open  ]],
Cell[989166, 18391, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[989290, 18396, 126, 2, 41, "Input"],
Cell[989419, 18400, 1720, 49, 68, "Output"]
}, Open  ]],
Cell[991154, 18452, 101, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[991280, 18457, 322, 9, 41, "Input"],
Cell[991605, 18468, 821, 21, 68, "Output"]
}, Open  ]],
Cell[992441, 18492, 100, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[992566, 18497, 292, 8, 56, "Input"],
Cell[992861, 18507, 736, 17, 66, "Output"]
}, Open  ]],
Cell[993612, 18527, 118, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[993755, 18532, 381, 10, 41, "Input"],
Cell[994139, 18544, 711, 17, 62, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[994911, 18568, 132, 3, 75, "Section"],
Cell[CellGroupData[{
Cell[995068, 18575, 119, 2, 41, "Input"],
Cell[995190, 18579, 600, 13, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[995827, 18597, 100, 1, 36, "Subsection"],
Cell[995930, 18600, 1098, 25, 82, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[997065, 18630, 97, 1, 36, "Subsection"],
Cell[997165, 18633, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[997289, 18638, 432, 13, 60, "Input"],
Cell[997724, 18653, 822, 17, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[998607, 18677, 239, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[998871, 18686, 180, 3, 41, "Input"],
Cell[999054, 18691, 678, 14, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[999769, 18710, 115, 1, 36, "Subsection"],
Cell[999887, 18713, 164, 4, 41, "Input"],
Cell[1000054, 18719, 186, 7, 41, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1000277, 18731, 97, 1, 36, "Subsection"],
Cell[1000377, 18734, 97, 1, 30, "Text"],
Cell[1000477, 18737, 307, 9, 60, "Input"],
Cell[CellGroupData[{
Cell[1000809, 18750, 970, 28, 66, "Input"],
Cell[1001782, 18780, 1090, 29, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1002909, 18814, 254, 7, 56, "Input"],
Cell[1003166, 18823, 793, 18, 66, "Output"]
}, Open  ]],
Cell[1003974, 18844, 244, 7, 41, "Input"],
Cell[1004221, 18853, 95, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[1004341, 18858, 408, 12, 56, "Input"],
Cell[1004752, 18872, 2310, 66, 120, "Output"]
}, Open  ]],
Cell[1007077, 18941, 109, 1, 30, "Text"],
Cell[1007189, 18944, 548, 19, 58, "Input"],
Cell[1007740, 18965, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[1007864, 18970, 486, 11, 41, "Input"],
Cell[1008353, 18983, 1545, 43, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1009947, 19032, 115, 1, 36, "Subsection"],
Cell[1010065, 19035, 101, 1, 30, "Text"],
Cell[1010169, 19038, 716, 17, 41, "Input"],
Cell[1010888, 19057, 259, 7, 30, "Text"],
Cell[1011150, 19066, 440, 10, 62, "Input"],
Cell[1011593, 19078, 168, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[1011786, 19084, 375, 7, 41, "Input"],
Cell[1012164, 19093, 1539, 39, 60, "Output"]
}, Open  ]],
Cell[1013718, 19135, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[1013842, 19140, 301, 6, 41, "Input"],
Cell[1014146, 19148, 2209, 59, 57, "Output"]
}, Open  ]],
Cell[1016370, 19210, 99, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[1016494, 19215, 341, 8, 41, "Input"],
Cell[1016838, 19225, 939, 22, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1017814, 19252, 308, 8, 41, "Input"],
Cell[1018125, 19262, 531, 14, 56, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature owTjbY7yUjKZ4DK7YYDbx1P0 *)
