(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[   1407780,      31138]
NotebookOptionsPosition[   1385313,      30386]
NotebookOutlinePosition[   1385784,      30404]
CellTagsIndexPosition[   1385741,      30401]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Chapter 31 Turbulence (p. 565)", "Title",
 CellChangeTimes->{
  3.4830769358442893`*^9, {3.5030243723866*^9, 3.5030243771996*^9}, {
   3.5884149281777935`*^9, 3.5884149353447027`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "Lautrup`"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.390215869765786*^9, {3.4827532189596*^9, 3.4827532300636*^9}, 
   3.483076193225814*^9, {3.483151035634323*^9, 3.4831510413096476`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 31.1 Scaling in fully developed turbulence (p. 565)\
\>", "Title",
 CellChangeTimes->{{3.5030243865906*^9, 3.5030244089276*^9}, {
  3.588414941097455*^9, 3.588414957040518*^9}}],

Cell[CellGroupData[{

Cell["\<\
Example 31.1 Concrete water pipe (p. 566)\
\>", "Section",
 CellChangeTimes->{{3.5030244244656*^9, 3.5030244339996*^9}, {
  3.588414971049226*^9, 3.588414973849559*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{3.5030244748326*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(30\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{
  3.575627583839383*^9, {3.5756276198769083`*^9, 3.5756276452991*^9}, 
   3.5866610497836466`*^9, 3.5884149043007326`*^9}]
}, Open  ]],

Cell["Parameters", "Text",
 CellChangeTimes->{3.5030244748326*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"0.5", " ", "Meter"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"pipe", " ", "radius"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Q", "=", 
   RowBox[{"10.", " ", 
    RowBox[{
     SuperscriptBox["Meter", "3"], "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"discharge", " ", "rate"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], 
    RowBox[{
     SuperscriptBox["Meter", "2"], "/", "Second"}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"viscosity", " ", "of", " ", "water"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "=", 
   RowBox[{"1000", " ", 
    RowBox[{"Kilogram", "/", 
     SuperscriptBox["Meter", "3"]}]}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"density", " ", "of", " ", "water"}], " ", "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["C", "f"], "=", "0.005"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "friction", " ", "coefficient", " ", "for", " ", "rough", " ", "pipe"}], 
   " ", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.5030244748346*^9, {3.58841499928283*^9, 3.588415057379212*^9}}],

Cell["Maximal eddy size", "Text",
 CellChangeTimes->{3.5030244748356*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"2", " ", "a"}]}], ";"}]], "Input",
 CellChangeTimes->{3.5030244748356*^9}],

Cell["Average velocity", "Text",
 CellChangeTimes->{3.5030244748366003`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", "=", 
  RowBox[{
   FractionBox["Q", 
    RowBox[{"\[Pi]", " ", 
     SuperscriptBox["a", "2"]}]], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{3.5030244748375998`*^9}],

Cell[BoxData[
 TemplateBox[{"12.732395447351628`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
            "\"s\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters per second"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5756275840274067`*^9, {3.575627620098936*^9, 3.5756276455171275`*^9}, 
   3.5866610499647007`*^9, 3.5884149044927764`*^9}]
}, Open  ]],

Cell["Reynolds number", "Text",
 CellChangeTimes->{3.5030244748375998`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rey", "=", " ", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "a", " ", "U"}], "\[Nu]"], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{3.5030244748386*^9}],

Cell[BoxData["1.2732395447351629`*^7"], "Output",
 CellChangeTimes->{
  3.5756275841374846`*^9, {3.5756276202059493`*^9, 3.5756276456231394`*^9}, 
   3.586661050063713*^9, 3.588414904595807*^9}]
}, Open  ]],

Cell["Specific rate of dissipation", "Text",
 CellChangeTimes->{3.5030244748386*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Epsilon]", "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["C", "f"], " ", 
    FractionBox[
     SuperscriptBox["U", "3"], "a"]}], "//", 
   RowBox[{"ToUnit", "[", 
    RowBox[{"Watt", "/", "Kilogram"}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.5030244748406*^9}],

Cell[BoxData[
 TemplateBox[{"20.64098203724768`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"W\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
            "\"kg\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: watts per kilogram"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Watts\"", "\"Kilograms\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5756275842764406`*^9, {3.575627620322973*^9, 3.5756276457402186`*^9}, 
   3.586661050197764*^9, 3.5884149047337823`*^9}]
}, Open  ]],

Cell["Dissipation per unit of pipe length", "Text",
 CellChangeTimes->{3.5030244748406*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "\[Pi]", " ", 
   SuperscriptBox["a", "2"], "\[Epsilon]"}], "//", 
  RowBox[{"ToUnit", "[", "Kilowatt", "]"}]}]], "Input",
 CellChangeTimes->{
  3.5030244748416*^9, {3.5756276124599776`*^9, 3.575627613132062*^9}}],

Cell[BoxData[
 TemplateBox[{"16.21138938277405`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"kW\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]",
             "\"m\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: kilowatts per meter"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Kilowatts\"", "\"Meters\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.5756275844464593`*^9, 3.575627645895175*^9}, 
   3.5866610503737617`*^9, 3.588414904904849*^9}]
}, Open  ]],

Cell["Ratio of turbulent and laminar friction factors", "Text",
 CellChangeTimes->{
  3.5030244748416*^9, {3.5030248768185997`*^9, 3.5030248977916*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["C", "f"], 
  FractionBox["Rey", "16"]}]], "Input",
 CellChangeTimes->{3.5030244748426*^9, 3.5030248747956*^9}],

Cell[BoxData["3978.873577297384`"], "Output",
 CellChangeTimes->{
  3.575627584466461*^9, {3.575627620517023*^9, 3.5756276459192142`*^9}, 
   3.5866610503937654`*^9, 3.588414904924843*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Figure 31.1 Data extracted from Grant et al (1962) (p. 568)\
\>", "Section",
 CellChangeTimes->{{3.5030250568346*^9, 3.5030250595206003`*^9}, {
  3.588415163217615*^9, 3.5884151729208736`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(9\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.575627584643484*^9, 3.586661050555784*^9, 
  3.588414905085862*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Get", "[", "\"\<data/turbulence.grant.m\>\"", " ", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4827532774126*^9, 3.4827532872636003`*^9}, {
   3.4827535643375998`*^9, 3.4827535907646*^9}, {3.4827536345126*^9, 
   3.4827536424186*^9}, {3.4827537952486*^9, 3.4827538176966*^9}, {
   3.4828120744630003`*^9, 3.482812083054*^9}, {3.5053634171222897`*^9, 
   3.5053634192504115`*^9}, 3.5053699379792614`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"table", "=", 
   SuperscriptBox["10", "data"]}], ";"}]], "Input",
 CellChangeTimes->{{3.482812086175*^9, 3.482812153067*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig1a", "=", 
  RowBox[{"ListLogLogPlot", "[", 
   RowBox[{"table", ",", 
    RowBox[{"PlotMarkers", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<\[Diamond]\>\"", ",", "Tiny"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]]}], ",", 
       RowBox[{"2", " ", 
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]]}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482812111041*^9, 3.4828121294370003`*^9}, {
   3.4828121788929996`*^9, 3.4828122407530003`*^9}, 3.482812494017*^9, {
   3.48281259573*^9, 3.482812684973*^9}, {3.501505674311248*^9, 
   3.5015056985106325`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJzt1fs31GkcwPFxmZgMZoYZuZsRE9awjKTwfdKpXNuKVCTEKHtosrVbMUrJ
Nt1tNQkrXaQolz2FKfQ8CiuDaCiFlcgkMW4VY5vZds9p9ofdP8EPz/mc1/l8
zvPrm76Nu56jisPhar+8v2ekUdBijdpurMWJHGLkqIcuHhhRkbNfK40bK90x
rTGo9Nf7pHMND7iZFMRO7sqPMx9Q+us+ICZrIDiOjM64Nu+gmHVgsvp1Prc7
SErnMwnFKhgJBS8dN3PxacPkbdLRTZY6SpcENR8qbtBC7om2hSVvGzFNmrvf
5uz5yIHPDzfZnwOLKnsvMJdroiWxbmYn3SqwcM9qm+RBPOL6uXoK23MxocJu
knlPHWkvS2z6HFgKV9c3ZPc3qiBOmEj9xfUqmCsq00fHcEh01BDjpwmh7dhZ
rwnpZ/j4HzfAl7I49q34Wchixe4LuNQEybzVB38gfIIgG0YsjRPDqArBJu+8
Cbi06eqOYd4z6JLwapV5ynu4rdVeW5HZBUP9Xhdumh6AYSpkamnhH/BCNutQ
S3gntDNMPF3a8wrmn7T/JbqoCV55vcbo/k9vYB3Hlbmc+RvUbTCofR7eB3de
9hIXHv0VmiaBSxTFIDw5sKV7/4k67JFqS3dffx88trre+kVLO1Ys2Ds1RR2G
uT6RDs7SPqzWoLr+QN4IvFNI9nOSDWNT76Kj+kqlsLCx2Dni4Bi2deFaSUbI
GEzwaX97sX8Kyxnztqk1G4dvn4rPHK/7iA0mRwe52E7CzIy08ru2s9hC37AL
kaOT8NF0m926ADk2qyiwhsIPcPi7Dce4QhxgaaUczHf5AH+8VsNb7KsKkFVF
B99/Bmq1b6840qUGFOMlBmUkGbwxDj5ZmOLB/eCsHrewP6EHQ/Itt3geAKXF
vs+/UcA7twY7I9I1QTpREp/BlEMPxfomJmM+yGombOzeqYBvZjiBflFaIOah
s3xq/Ms9f/1uQ3UiIN5Jjs9KwqEtqRyZ+0ptQNtzObj3oQp686xtRO25Dtid
L7hHH1JFYiLnCoupq/QDNXd9GzYJtHUeN4nWVUeH7SdOET+TwIHtwqsxjupo
f0OlhG5FBme1qv0JZfOQ0dCT++l+ZDA9j8mqPamGVm+8qTFWRwauYvNdY2vV
kedEQiR+lAy6M4vwBcF4xD61rNKIRgGk66lb08XqSp/HU8VOe/FobF3laT0N
PfBeEj/4e4EGyi5b5RikqwfcTkx/yHPQQNKgMyL59X/tNfU8psBdH4zmrorj
8ecjwTkL1SDxF68IsWEYEpQWPBI8rT5HQENOsTnyWKryPj1BJg7MoAFv3if8
smQtNEBawZXbG4C8u+dfB/Zpo3s81ZQ4viHw7ez3FrwnKh1YvpitHkFCRBM/
YwNzI+DLbj0hDdX5j8Mrz5XXlBkB//SqFh+RLroT0r0uzt8YpCzUPRT1koQ0
ZAtHaP3G4HZ0wm1qDgmFZMbza/abgCCK5d6tT8ioeEm5ZRzJFKSsT7tKOktG
XZyBz0c8zEARCpNyiRTEwttnOrSbgRITX6fGJD00TO/d/hBnAV6yFrs/+ZmC
zieklhn4W4DiUTHJtJaCPGuYavEZFoAgOlLYJdRDZyN2XTJg0UHPoM7DVA4V
Pa232zyjywDdwouXnxXpIx6tNX9NKAO4CnyWCq5SkXXMnqlr+QygOSMT8Xfp
K03YINHp76Wi1rIFXjPjDOV/ifjqM2s8LJV7yw2RPdf4lmB+aphjegYNNefh
7WbEliD61JHh2RULUEUIx9lRxQpwKmXEgtkFaGvmx9g0ljVAdB0troEJWum5
IrTKYxGomcwYqgk3RtJTkpvkY4uAKZ9OcHE2R4cOd0py+m2BScgtydEkM9RB
p6d6J9oBK8DqCXhngQ4k1LXm1NkB94jeiXyRBaLsfWxt62kPPKpELirLGOgG
r5lXXs4CQZOu3Y77GEhmTFsQGeAAvud2sAcaLNEqfuqtj2JHMNeHuT7M9WGu
D3N9mOvD//XhL4z/2AM=
    "], {
     {GrayLevel[0], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 99], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 100], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 101], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 102], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 103], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 104], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 105], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 106], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 107], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 108], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 109], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 110], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 111], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 112], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 113], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 114], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 115], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 116], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 117], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 118], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 119], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 120], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 121], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 122], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 123], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 124], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 125], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 126], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 127], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 128], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 129], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 130], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 131], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 132], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 133], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 134], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 135], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 136], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 137], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 138], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 139], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 140], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 141], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 142], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 143], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 144], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 145], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 146], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 147], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 148], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 149], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 150], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 151], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 152], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 153], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 154], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 155], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 156], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 157], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 158], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 159], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 160], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 161], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 162], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 163], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 164], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 165], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 166], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 167], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 168], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 169], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 170], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 171], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 172], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 173], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 174], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 175], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 176], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 177], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 178], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 179], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 180], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 181], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 182], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 183], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 184], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 185], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 186], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 187], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 188], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 189], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 190], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 191], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 192], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 193], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 194], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 195], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 196]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->
   NCache[{-Log[50000], -
     Log[500]}, {-10.819778284410283`, -6.214608098422191}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-4.422848629194137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.7722610630529876`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.3813947543659757`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.101092789211817, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.882403588246988, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.703062659591171, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.551046452292545, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.419118909249997, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939546, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.8329091229351039, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.2237754316221159`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.5040773967762742`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.7227665977411037`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9021075263969205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0541237336955462`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.186051276738094, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {-4.422848629194137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.7722610630529876`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.3813947543659757`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.101092789211817, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.882403588246988, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.703062659591171, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.551046452292545, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.419118909249997, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939546, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.8329091229351039, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.2237754316221159`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.5040773967762742`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.7227665977411037`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9021075263969205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0541237336955462`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.186051276738094, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->
   NCache[{{-Log[50000], 0.6884729428052196}, {-Log[500], 
      16.827982635128386`}}, {{-10.819778284410283`, 
    0.6884729428052196}, {-6.214608098422191, 16.827982635128386`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-4.422848629194137, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.7722610630529876`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.3813947543659757`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.101092789211817, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.882403588246988, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.703062659591171, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.551046452292545, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.419118909249997, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.1823215567939546, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.8329091229351039, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.2237754316221159`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.5040773967762742`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.7227665977411037`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9021075263969205`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0541237336955462`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.186051276738094, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.787491742782046, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.438079308923196, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.8289456176102075`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.1092475827643655`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.327936783729195, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.507277712385012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.659293919683638, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.7912214627261855`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.392661928770137, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.043249494911286`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.4341158035983, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.714417768752456`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.933106969717286`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.112447898373103`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.26446410567173, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.396391648714276`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.997832114758229`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.648419680899378`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.03928598958639, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.319587954740548`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.538277155705378`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.717618084361195`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.86963429165982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.00156183470237, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.5756275848725123`*^9, 3.586661050777811*^9, 
  3.588414905303907*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig1b", "=", 
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    SuperscriptBox["k", 
     RowBox[{
      RowBox[{"-", "5"}], "/", "3"}]], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "4.5"}]], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4828122509049997`*^9, 3.482812274301*^9}, {
  3.482812335758*^9, 3.482812385663*^9}, {3.4828124227679996`*^9, 
  3.4828124320629997`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAAF44T7Ce5JMC9SxCa9kQxQJq84WOH
tyTA1cfmfZtDMUAc66/b5rUkwOxDvWFAQjFAIkhMy6WyJMAcPGopij8xQC4C
haojrCTAeyzEuB06MUBEdvZoH58kwDgNeNdELzFAcl7Z5RaFJMC0zt8Ukxkx
QM4un98FUSTAq1Gvjy/uMECJxnd+IeAjwBzQY+kbkDBAyAMwS7h2I8AmA6g+
RDgwQLUBl29gDyPALVimZEvEL0Cm9ko/Rp8iwBSbJxR1CS9AG5HePKc2IsAs
R8i6FlsuQJQiv+VFxSHAS+STKR+eLUC8dE7m9VUhwDltLdWZ5CxAZ2y9FCHu
IMBWX+Z3jDcsQBZbee6JfSDAeULK4uV7K0BJ7xT2bRQgwM6OzUS3zCpAVoi+
qsZaH8Dyxp7j+iAqQCIg7b8sex7AHPCaSqVmKUD1AtswiaodwHaCtqjHuChA
0dNi+GDIHMDYBf3OUPwnQAkmSG9b6hvAB3URMkxDJ0BJw+xBTBsbwGdNRYy/
liZAkU4ra7g6GsDOFqSumdslQOAkKfAaaRnAZUkiyOssJUA46cDL+IUYwANt
y6mkbyRA7C62VvmmF8BvfELIz7UjQKe/aj3w1hbAC/XY3XIII0BrPrl6YvUV
wK5emrt8TCJANgjHE8siFcCCMXuQ/pwhQF5TMlxWVBTAI/ApovLwIECOjDf7
XHQTwMufA3xNNiBAxRD89VmjEsBHcfmZQBAfQAWDWkfSwBHACIVBzLOWHUCi
dhZIbeIQwGNwJXgLJBxARrWRpP4SEMAfLkgSU8oaQOTDTa8WZA7A6M3APGhT
GUBKs/bMHMAMwBNAeFVt9RdAaqVaSWgkC8DYicvnVp4WQJtz8nKqZQnAq7V0
Cg4qFUDa1whU2cQHwOCzXBu1zhNAKhhT4v4ABsAjlJq8KVYSQIjuGygRWwTA
xkYXTI72EECgx5/MaL0CwAqiX6quOw9AyXxXHrf8AMCkejzd208MQP+PG0/k
s/6///eW7OiVCUCO3u+7Ryj7v3Y5nRyRoQZAkTI65jWt978jKts/ArsDQLCy
gX/9bfS/kr+WP1MGAUDx6jBzsujwvzwy/L9+Lvw/nZ66q4E+67/YLsa5FrT2
Pz9y/+uzzOS/34n/mUBV8T9KbCfCgZ3bvz3aIHdBA+c/DkmJ0AIizb+KZ3JY
AkfYP4qVX8x6rcy/9VH6VObl1z8H4jXI8jjMv1s8glHKhNc/AHviv+JPy78s
EZJKksLWP/KsO6/Cfcm/yrqxPCI+1T/VEO6NgtnFvwUO8SBCNdI/ObGllgQi
vb8Ead/SA0fIPzJKUo70OLy/1D3vy8uExz8q4/6F5E+7v6IS/8STwsY/HBVY
dcR9ub8+vB63Iz7FPwB5ClSE2bW/gQ9em0M1wj+Pgd4iCCKtv/5ruccGR7g/
gLM3EuhPq7+OFdm5lsK2P3LlkAHIfam/Nb/4qyY+tT9WSUPgh9mlv3ASOJBG
NbI/OiJQOw8inb/acW2xDEeoPx6GAhrPfZm/GMWslSw+pT8B6rT4jtmVv2QY
7HlMNaI/kWMzbB0ijb+DfdWEGEeYP1grmCmd2YW/MiRUTVg1kj8/5vnNOSJ9
v1KVpSswR4g/m+uGkXIibb/8w0V5X0d4PzvwrYLGYYy+njyTF9Cmlz5KqEhc

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-10.361632918473205`, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {2.4849066497880004`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.1354942159291497`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.5263605246161616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.8066624897703196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.02535169073515, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.204692619390966, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.356708826689592, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.48863636973214, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.090076835776092, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.7406644019172415`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.131530710604252, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.411832675758411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.630521876723241, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.809862805379057, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.961879012677683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.093806555720231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.695247021764184`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.345834587905333`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.736700896592344`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.017002861746503`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.235692062711331`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.415032991367148`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.567049198665774`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.698976741708323`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {2.4849066497880004`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.1354942159291497`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.5263605246161616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.8066624897703196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.02535169073515, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.204692619390966, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.356708826689592, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.48863636973214, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.090076835776092, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.7406644019172415`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.131530710604252, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.411832675758411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.630521876723241, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.809862805379057, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.961879012677683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.093806555720231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.695247021764184`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.345834587905333`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.736700896592344`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.017002861746503`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.235692062711331`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.415032991367148`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.567049198665774`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.698976741708323`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-10.361632918473205`, 0}, {0., 17.269387845018844`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{0., 
      FormBox["1", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {2.4849066497880004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.1354942159291497`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.5263605246161616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.8066624897703196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.02535169073515, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.204692619390966, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.356708826689592, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.48863636973214, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.090076835776092, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.7406644019172415`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.131530710604252, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.411832675758411, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.630521876723241, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.809862805379057, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.961879012677683, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.093806555720231, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.695247021764184`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.345834587905333`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.736700896592344`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.017002861746503`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.235692062711331`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.415032991367148`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.567049198665774`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.698976741708323`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.575627585023532*^9, 3.586661050926829*^9, 
  3.5884149054559135`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"fig1a", ",", "fig1b", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"k", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<E\>\"", ",", "Italic"}], "]"}]}], "}"}]}]}], "]"}], "//",
   "\[IndentingNewLine]", 
  RowBox[{
  "Figure", "[", "\"\<turbulence-energyspectrum\>\"", "]"}]}]], "Input",
 CellChangeTimes->{
  3.390215886493786*^9, {3.4824724922922044`*^9, 3.4824725224999323`*^9}, 
   3.4827530708976*^9, {3.482811823007*^9, 3.482811826299*^9}, {
   3.482812501027*^9, 3.482812591731*^9}, 3.482813818209*^9, {
   3.5015054857584634`*^9, 3.501505491733805*^9}, {3.501505542574713*^9, 
   3.501505566782098*^9}, {3.501505612609719*^9, 3.5015056542601013`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.575627585181591*^9, 3.586661051100811*^9, 
  3.588414905616948*^9}],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJzt1fs31GkcwPFxmZgMZoYZuZsRE9awjKTwfdKpXNuKVCTEKHtosrVbMUrJ
Nt1tNQkrXaQolz2FKfQ8CiuDaCiFlcgkMW4VY5vZds9p9ofdP8EPz/mc1/l8
zvPrm76Nu56jisPhar+8v2ekUdBijdpurMWJHGLkqIcuHhhRkbNfK40bK90x
rTGo9Nf7pHMND7iZFMRO7sqPMx9Q+us+ICZrIDiOjM64Nu+gmHVgsvp1Prc7
SErnMwnFKhgJBS8dN3PxacPkbdLRTZY6SpcENR8qbtBC7om2hSVvGzFNmrvf
5uz5yIHPDzfZnwOLKnsvMJdroiWxbmYn3SqwcM9qm+RBPOL6uXoK23MxocJu
knlPHWkvS2z6HFgKV9c3ZPc3qiBOmEj9xfUqmCsq00fHcEh01BDjpwmh7dhZ
rwnpZ/j4HzfAl7I49q34Wchixe4LuNQEybzVB38gfIIgG0YsjRPDqArBJu+8
Cbi06eqOYd4z6JLwapV5ynu4rdVeW5HZBUP9Xhdumh6AYSpkamnhH/BCNutQ
S3gntDNMPF3a8wrmn7T/JbqoCV55vcbo/k9vYB3Hlbmc+RvUbTCofR7eB3de
9hIXHv0VmiaBSxTFIDw5sKV7/4k67JFqS3dffx88trre+kVLO1Ys2Ds1RR2G
uT6RDs7SPqzWoLr+QN4IvFNI9nOSDWNT76Kj+kqlsLCx2Dni4Bi2deFaSUbI
GEzwaX97sX8Kyxnztqk1G4dvn4rPHK/7iA0mRwe52E7CzIy08ru2s9hC37AL
kaOT8NF0m926ADk2qyiwhsIPcPi7Dce4QhxgaaUczHf5AH+8VsNb7KsKkFVF
B99/Bmq1b6840qUGFOMlBmUkGbwxDj5ZmOLB/eCsHrewP6EHQ/Itt3geAKXF
vs+/UcA7twY7I9I1QTpREp/BlEMPxfomJmM+yGombOzeqYBvZjiBflFaIOah
s3xq/Ms9f/1uQ3UiIN5Jjs9KwqEtqRyZ+0ptQNtzObj3oQp686xtRO25Dtid
L7hHH1JFYiLnCoupq/QDNXd9GzYJtHUeN4nWVUeH7SdOET+TwIHtwqsxjupo
f0OlhG5FBme1qv0JZfOQ0dCT++l+ZDA9j8mqPamGVm+8qTFWRwauYvNdY2vV
kedEQiR+lAy6M4vwBcF4xD61rNKIRgGk66lb08XqSp/HU8VOe/FobF3laT0N
PfBeEj/4e4EGyi5b5RikqwfcTkx/yHPQQNKgMyL59X/tNfU8psBdH4zmrorj
8ecjwTkL1SDxF68IsWEYEpQWPBI8rT5HQENOsTnyWKryPj1BJg7MoAFv3if8
smQtNEBawZXbG4C8u+dfB/Zpo3s81ZQ4viHw7ez3FrwnKh1YvpitHkFCRBM/
YwNzI+DLbj0hDdX5j8Mrz5XXlBkB//SqFh+RLroT0r0uzt8YpCzUPRT1koQ0
ZAtHaP3G4HZ0wm1qDgmFZMbza/abgCCK5d6tT8ioeEm5ZRzJFKSsT7tKOktG
XZyBz0c8zEARCpNyiRTEwttnOrSbgRITX6fGJD00TO/d/hBnAV6yFrs/+ZmC
zieklhn4W4DiUTHJtJaCPGuYavEZFoAgOlLYJdRDZyN2XTJg0UHPoM7DVA4V
Pa232zyjywDdwouXnxXpIx6tNX9NKAO4CnyWCq5SkXXMnqlr+QygOSMT8Xfp
K03YINHp76Wi1rIFXjPjDOV/ifjqM2s8LJV7yw2RPdf4lmB+aphjegYNNefh
7WbEliD61JHh2RULUEUIx9lRxQpwKmXEgtkFaGvmx9g0ljVAdB0troEJWum5
IrTKYxGomcwYqgk3RtJTkpvkY4uAKZ9OcHE2R4cOd0py+m2BScgtydEkM9RB
p6d6J9oBK8DqCXhngQ4k1LXm1NkB94jeiXyRBaLsfWxt62kPPKpELirLGOgG
r5lXXs4CQZOu3Y77GEhmTFsQGeAAvud2sAcaLNEqfuqtj2JHMNeHuT7M9WGu
D3N9mOvD//XhL4z/2AM=
     "], {
      {GrayLevel[0], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 99], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 100], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 101], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 102], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 103], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 104], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 105], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 106], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 107], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 108], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 109], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 110], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 111], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 112], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 113], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 114], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 115], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 116], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 117], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 118], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 119], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 120], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 121], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 122], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 123], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 124], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 125], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 126], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 127], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 128], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 129], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 130], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 131], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 132], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 133], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 134], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 135], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 136], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 137], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 138], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 139], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 140], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 141], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 142], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 143], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 144], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 145], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 146], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 147], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 148], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 149], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 150], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 151], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 152], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 153], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 154], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 155], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 156], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 157], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 158], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 159], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 160], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 161], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 162], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 163], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 164], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 165], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 166], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 167], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 168], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 169], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 170], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 171], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 172], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 173], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 174], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 175], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 176], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 177], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 178], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 179], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 180], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 181], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 182], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 183], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 184], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 185], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 186], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 187], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 188], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 189], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 190], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 191], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 192], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 193], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 194], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 195], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 196]}, {}}], {}}, {{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAAF44T7Ce5JMC9SxCa9kQxQJq84WOH
tyTA1cfmfZtDMUAc66/b5rUkwOxDvWFAQjFAIkhMy6WyJMAcPGopij8xQC4C
haojrCTAeyzEuB06MUBEdvZoH58kwDgNeNdELzFAcl7Z5RaFJMC0zt8Ukxkx
QM4un98FUSTAq1Gvjy/uMECJxnd+IeAjwBzQY+kbkDBAyAMwS7h2I8AmA6g+
RDgwQLUBl29gDyPALVimZEvEL0Cm9ko/Rp8iwBSbJxR1CS9AG5HePKc2IsAs
R8i6FlsuQJQiv+VFxSHAS+STKR+eLUC8dE7m9VUhwDltLdWZ5CxAZ2y9FCHu
IMBWX+Z3jDcsQBZbee6JfSDAeULK4uV7K0BJ7xT2bRQgwM6OzUS3zCpAVoi+
qsZaH8Dyxp7j+iAqQCIg7b8sex7AHPCaSqVmKUD1AtswiaodwHaCtqjHuChA
0dNi+GDIHMDYBf3OUPwnQAkmSG9b6hvAB3URMkxDJ0BJw+xBTBsbwGdNRYy/
liZAkU4ra7g6GsDOFqSumdslQOAkKfAaaRnAZUkiyOssJUA46cDL+IUYwANt
y6mkbyRA7C62VvmmF8BvfELIz7UjQKe/aj3w1hbAC/XY3XIII0BrPrl6YvUV
wK5emrt8TCJANgjHE8siFcCCMXuQ/pwhQF5TMlxWVBTAI/ApovLwIECOjDf7
XHQTwMufA3xNNiBAxRD89VmjEsBHcfmZQBAfQAWDWkfSwBHACIVBzLOWHUCi
dhZIbeIQwGNwJXgLJBxARrWRpP4SEMAfLkgSU8oaQOTDTa8WZA7A6M3APGhT
GUBKs/bMHMAMwBNAeFVt9RdAaqVaSWgkC8DYicvnVp4WQJtz8nKqZQnAq7V0
Cg4qFUDa1whU2cQHwOCzXBu1zhNAKhhT4v4ABsAjlJq8KVYSQIjuGygRWwTA
xkYXTI72EECgx5/MaL0CwAqiX6quOw9AyXxXHrf8AMCkejzd208MQP+PG0/k
s/6///eW7OiVCUCO3u+7Ryj7v3Y5nRyRoQZAkTI65jWt978jKts/ArsDQLCy
gX/9bfS/kr+WP1MGAUDx6jBzsujwvzwy/L9+Lvw/nZ66q4E+67/YLsa5FrT2
Pz9y/+uzzOS/34n/mUBV8T9KbCfCgZ3bvz3aIHdBA+c/DkmJ0AIizb+KZ3JY
AkfYP4qVX8x6rcy/9VH6VObl1z8H4jXI8jjMv1s8glHKhNc/AHviv+JPy78s
EZJKksLWP/KsO6/Cfcm/yrqxPCI+1T/VEO6NgtnFvwUO8SBCNdI/ObGllgQi
vb8Ead/SA0fIPzJKUo70OLy/1D3vy8uExz8q4/6F5E+7v6IS/8STwsY/HBVY
dcR9ub8+vB63Iz7FPwB5ClSE2bW/gQ9em0M1wj+Pgd4iCCKtv/5ruccGR7g/
gLM3EuhPq7+OFdm5lsK2P3LlkAHIfam/Nb/4qyY+tT9WSUPgh9mlv3ASOJBG
NbI/OiJQOw8inb/acW2xDEeoPx6GAhrPfZm/GMWslSw+pT8B6rT4jtmVv2QY
7HlMNaI/kWMzbB0ijb+DfdWEGEeYP1grmCmd2YW/MiRUTVg1kj8/5vnNOSJ9
v1KVpSswR4g/m+uGkXIibb/8w0V5X0d4PzvwrYLGYYy+njyTF9Cmlz5KqEhc

      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["k", TraditionalForm], 
    FormBox[
     StyleBox["\"E\"", Italic, StripOnInput -> False], TraditionalForm]},
  AxesOrigin->
   NCache[{-Log[50000], -
     Log[500]}, {-10.819778284410283`, -6.214608098422191}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-4.422848629194137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.7722610630529876`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.3813947543659757`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.101092789211817, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.882403588246988, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.703062659591171, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.551046452292545, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.419118909249997, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939546, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.8329091229351039, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.2237754316221159`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.5040773967762742`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.7227665977411037`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9021075263969205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0541237336955462`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.186051276738094, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {-4.422848629194137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.7722610630529876`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.3813947543659757`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.101092789211817, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.882403588246988, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.703062659591171, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.551046452292545, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.419118909249997, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.1823215567939546, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.8329091229351039, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.2237754316221159`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.5040773967762742`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.7227665977411037`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9021075263969205`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0541237336955462`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.186051276738094, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->
   NCache[{{-Log[50000], 0.6884729428052196}, {-Log[500], 
      16.827982635128386`}}, {{-10.819778284410283`, 
    0.6884729428052196}, {-6.214608098422191, 16.827982635128386`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-4.422848629194137, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.7722610630529876`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.3813947543659757`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.101092789211817, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.882403588246988, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.703062659591171, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.551046452292545, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.419118909249997, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.1823215567939546, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.8329091229351039, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.2237754316221159`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.5040773967762742`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.7227665977411037`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9021075263969205`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0541237336955462`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.186051276738094, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.787491742782046, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.438079308923196, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.8289456176102075`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.1092475827643655`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.327936783729195, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.507277712385012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.659293919683638, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.7912214627261855`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.392661928770137, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.043249494911286`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.4341158035983, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.714417768752456`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.933106969717286`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.112447898373103`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.26446410567173, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.396391648714276`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.997832114758229`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.648419680899378`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.03928598958639, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.319587954740548`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.538277155705378`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.717618084361195`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.86963429165982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.00156183470237, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.5756275853165674`*^9, 3.5866610512238264`*^9, 
  3.5884149057349386`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 31.2 and 31.3 Concrete water pipe, continued (p. 569 and 570)\
\>", "Section",
 CellChangeTimes->{{3.5030244244656*^9, 3.5030244339996*^9}, {
  3.5030259855206003`*^9, 3.5030259862076*^9}, {3.5030269961436*^9, 
  3.5030269974076*^9}, {3.58841519294541*^9, 3.5884152121288614`*^9}, {
  3.588415292769097*^9, 3.588415304040532*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5030271201076*^9, 3.5030271236176*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(5\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.5756275855565987`*^9, 3.5866610514478717`*^9, 
  3.5884149059579754`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   RowBox[{
    SuperscriptBox["10", 
     RowBox[{"-", "6"}]], 
    RowBox[{
     SuperscriptBox["Meter", "2"], "/", "Second"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", 
   RowBox[{"20.6", " ", 
    RowBox[{"Watt", "/", "Kilogram"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"1", "Meter"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5030271409676*^9, 3.5030272037816*^9}}],

Cell["Length scale", "Text",
 CellChangeTimes->{3.5030244748445997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Lambda]", "d"], "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "4"}]], 
    SuperscriptBox["\[Nu]", 
     RowBox[{"3", "/", "4"}]]}], "//", 
   RowBox[{"ToUnit", "[", "Micrometer", "]"}]}]}]], "Input",
 CellChangeTimes->{3.5030244748466*^9}],

Cell[BoxData[
 TemplateBox[{"14.843393298690698`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"\[Micro]m\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: micrometers"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Micrometers\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5756275858056297`*^9, 3.586661051657922*^9, 
  3.5884149061590023`*^9}]
}, Open  ]],

Cell["Time scale", "Text",
 CellChangeTimes->{3.5030244748466*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Tau]", "d"], "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}]], 
    SuperscriptBox["\[Nu]", 
     RowBox[{"1", "/", "2"}]]}], "//", 
   RowBox[{"ToUnit", "[", "Microsecond", "]"}]}]}]], "Input",
 CellChangeTimes->{3.5030244748476*^9}],

Cell[BoxData[
 TemplateBox[{"220.32632461961586`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"\[Micro]s\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: microseconds"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Microseconds\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.575627585926645*^9, 3.5866610518089485`*^9, 
  3.5884149063129787`*^9}]
}, Open  ]],

Cell["Velocity scale", "Text",
 CellChangeTimes->{3.5030244748486*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["u", "d"], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", " ", "\[Nu]"}], ")"}], 
     RowBox[{"1", "/", "4"}]], "//", 
    RowBox[{"ToUnit", "[", 
     RowBox[{"Centimeter", "/", "Second"}], "]"}]}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.5030244748486*^9, 3.5030259810476*^9, {3.5756276896766768`*^9, 
   3.5756277119804735`*^9}}],

Cell[BoxData[
 TemplateBox[{"6.737003998190952`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"cm\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]",
             "\"s\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: centimeters per second"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Centimeters\"", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.5756275860806646`*^9, {3.5756276956794367`*^9, 3.575627712779574*^9}, 
   3.5866610519509573`*^9, 3.5884149064530373`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Eddy viscosity", "Subsection",
 CellChangeTimes->{{3.5030273593936*^9, 3.5030273618386*^9}}],

Cell["Inertial range ratio", "Text",
 CellChangeTimes->{{3.5030264952816*^9, 3.5030264980636*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["L", 
   SubscriptBox["\[Lambda]", "d"]], "//", "ToSI"}]], "Input",
 CellChangeTimes->{{3.5030263189646*^9, 3.5030263434625998`*^9}}],

Cell[BoxData["67370.0399819095`"], "Output",
 CellChangeTimes->{3.575627586133671*^9, 3.5866610520069675`*^9, 
  3.5884149065030475`*^9}]
}, Open  ]],

Cell["Eddy viscosity", "Text",
 CellChangeTimes->{{3.5030265624316*^9, 3.5030265646236*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Nu]", "L"], "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Epsilon]", 
     RowBox[{"1", "/", "3"}]], 
    SuperscriptBox["L", 
     RowBox[{"4", "/", "3"}]]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{
  3.5030263380016003`*^9, {3.5030265665966*^9, 3.5030265969946003`*^9}}],

Cell[BoxData[
 TemplateBox[{"2.7412947864931967`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          RowBox[{
            SuperscriptBox["\"m\"", "2"], "\[NegativeMediumSpace]", "\"/\"", 
            "\[InvisibleSpace]", "\"s\""}]}], 
        "QuantityUnitTraditionalLabel"]}], ShowStringCharacters -> False], 
    "Unit: meters squared per second"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox[
        SuperscriptBox["\"Meters\"", "2"], "\"Seconds\""]}], 
     "]"}]& )]], "Output",
 CellChangeTimes->{3.575627586234684*^9, 3.586661052104968*^9, 
  3.588414906611058*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continued (p. 570)", "Subsection",
 CellChangeTimes->{
  3.5030244748506002`*^9, {3.5030269704646*^9, 3.5030269825285997`*^9}, {
   3.5884152626253467`*^9, 3.5884152737127333`*^9}, {3.588415428713388*^9, 
   3.588415431992792*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"12.7", 
    RowBox[{"Meter", "/", "Second"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["C", "f"], "=", "0.005"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5030271409676*^9, 3.5030272037816*^9}, {
  3.5030272759426003`*^9, 3.5030273191906*^9}, {3.5030274100106*^9, 
  3.5030274369026003`*^9}}],

Cell["Velocity", "Text",
 CellChangeTimes->{3.5030244748506002`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["u", "L"], "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[Epsilon]", " ", "L"}], ")"}], 
    RowBox[{"1", "/", "3"}]], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{3.5030244748515997`*^9}],

Cell[BoxData[
 TemplateBox[{"2.7412947864931967`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", 
          
          RowBox[{"\"m\"", "\[InvisibleSpace]", "\"/\"", "\[InvisibleSpace]", 
            "\"s\""}]}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: meters per second"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", 
       FractionBox["\"Meters\"", "\"Seconds\""]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5756275863717566`*^9, 3.586661052241995*^9, 
  3.588414906734041*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  SubscriptBox["u", "L"], "U"]], "Input",
 CellChangeTimes->{{3.5030257777216*^9, 3.5030257818476*^9}}],

Cell[BoxData["0.21584998318844067`"], "Output",
 CellChangeTimes->{3.5756275864367247`*^9, 3.5866610523370066`*^9, 
  3.5884149067950563`*^9}]
}, Open  ]],

Cell["Integral velocity to flow velocity", "Text",
 CellChangeTimes->{3.5030244748526*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 SuperscriptBox[
  SubscriptBox["C", "f"], 
  RowBox[{"1", "/", "3"}]]], "Input",
 CellChangeTimes->{3.5030244748526*^9}],

Cell[BoxData["0.17099759466766973`"], "Output",
 CellChangeTimes->{3.5756275864827185`*^9, 3.5866610523900127`*^9, 
  3.588414906814085*^9}]
}, Open  ]],

Cell["Reynolds number", "Text",
 CellChangeTimes->{3.5030244748536*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["Rey", "L"], "=", 
  FractionBox[
   RowBox[{
    SubscriptBox["u", "L"], "L"}], "\[Nu]"]}]], "Input",
 CellChangeTimes->{3.5030244748546*^9}],

Cell[BoxData["2.7412947864931966`*^6"], "Output",
 CellChangeTimes->{3.575627586594783*^9, 3.5866610525909977`*^9, 
  3.5884149069060974`*^9}]
}, Open  ]],

Cell["Grid points", "Text",
 CellChangeTimes->{3.5030244748546*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NN", "=", 
  SuperscriptBox[
   SubscriptBox["Rey", "L"], 
   RowBox[{"9", "/", "4"}]]}]], "Input",
 CellChangeTimes->{3.5030244748556004`*^9}],

Cell[BoxData["3.057739019530283`*^14"], "Output",
 CellChangeTimes->{3.575627586626773*^9, 3.5866610526690493`*^9, 
  3.588414906927098*^9}]
}, Open  ]],

Cell["Time scale", "Text",
 CellChangeTimes->{3.5030244748566*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Tau]", "L"], "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Tau]", "d"], 
    SqrtBox[
     SubscriptBox["Rey", "L"]]}], "//", "ToSI"}]}]], "Input",
 CellChangeTimes->{3.5030244748576*^9}],

Cell[BoxData[
 TemplateBox[{"0.3647911216725621`"},
  "QuantityUnit",
  DisplayFunction->(TooltipBox[
    StyleBox[
     RowBox[{#, "\[InvisibleSpace]", 
       StyleBox[
        RowBox[{" ", "\"s\""}], "QuantityUnitTraditionalLabel"]}], 
     ShowStringCharacters -> False], "Unit: seconds"]& ),
  InterpretationFunction->(RowBox[{"Quantity", "[", 
     RowBox[{#, ",", "\"Seconds\""}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5756275866587915`*^9, 3.586661053258083*^9, 
  3.5884149069521227`*^9}]
}, Open  ]],

Cell["Ratio of time scales", "Text",
 CellChangeTimes->{3.5030244748576*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 SqrtBox[
  SubscriptBox["Rey", "L"]]], "Input",
 CellChangeTimes->{3.5030244748585997`*^9}],

Cell[BoxData["1655.685594094844`"], "Output",
 CellChangeTimes->{3.5756275868697653`*^9, 3.5866610532971306`*^9, 
  3.5884149069711027`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 31.3 Universal inner layer near a smooth wall (p. 574)\
\>", "Title",
 CellChangeTimes->{{3.4830762651649284`*^9, 3.4830762814488597`*^9}, {
  3.4831576070691876`*^9, 3.483157610915407*^9}, {3.483238538070443*^9, 
  3.483238544598817*^9}, {3.483238625190426*^9, 3.4832386315447893`*^9}, {
  3.5030289994105997`*^9, 3.5030290088476*^9}, {3.5884154456815023`*^9, 
  3.5884154509931717`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Figure 31.2 The near-wall region (p. 575)\
\>", "Section",
 CellChangeTimes->{{3.5884156601927824`*^9, 3.5884156720572543`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5030303389826*^9, 3.5030303421776*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(23\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.5756277910354176`*^9, 3.586661057703681*^9, 
  3.588414907998248*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data from Princeton SuperPipe", "Subsection",
 CellChangeTimes->{{3.5884156935290155`*^9, 3.588415711425285*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<data/turbulence.princeton2004.m\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.4824844969850664`*^9, 3.482484554123335*^9}, {
  3.4824846011680255`*^9, 3.4824846077214003`*^9}, {3.4827537494276*^9, 
  3.4827537858076*^9}, {3.48307623267807*^9, 3.483076233290105*^9}, {
  3.4830762977317915`*^9, 3.4830762985758395`*^9}, {3.4830864839063754`*^9, 
  3.483086492837886*^9}, {3.5053703148958197`*^9, 3.50537032224724*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdata", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"profiles", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483241636189646*^9, 3.483241643735077*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"fdata", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "0.12"}], "&"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4830938661267138`*^9, 3.4830938738061533`*^9}, {
   3.483093905625973*^9, 3.483093969969653*^9}, {3.4830941339720335`*^9, 
   3.4830941340910406`*^9}, {3.483094165537839*^9, 3.4830941658578577`*^9}, {
   3.483095799109274*^9, 3.4830958204114923`*^9}, {3.4830958854502125`*^9, 
   3.4830958861382523`*^9}, {3.4831582068414927`*^9, 
   3.4831582070975075`*^9}, {3.4831583417292075`*^9, 3.483158348272582*^9}, 
   3.483158395566287*^9, {3.4831585038874826`*^9, 3.4831585039764876`*^9}, {
   3.4831593998707294`*^9, 3.4831594044739933`*^9}, 3.483159709598445*^9, {
   3.48316824915988*^9, 3.4831682789885864`*^9}, {3.4831700357920694`*^9, 
   3.483170039696293*^9}, {3.4832416135273495`*^9, 3.483241621035779*^9}, {
   3.4832437327285604`*^9, 3.483243742267106*^9}, {3.4832440545239663`*^9, 
   3.4832440668906736`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"data", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "17"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "Black", "}"}]}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\[SmallCircle]\>\"", ",", "Tiny"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4831635351952567`*^9, 3.483163535582279*^9}, {
  3.4831637888897676`*^9, 3.4831637894828014`*^9}, {3.4831638911246147`*^9, 
  3.483163892708706*^9}, {3.4831639641987944`*^9, 3.483163983491898*^9}, {
  3.48316405083775*^9, 3.4831640584441853`*^9}, {3.483164226687808*^9, 
  3.483164226827816*^9}, {3.4831647686718073`*^9, 3.483164800062603*^9}, {
  3.4831648385708055`*^9, 3.483164839462857*^9}, {3.483165131097537*^9, 
  3.48316518797379*^9}, {3.483165582251342*^9, 3.4831655918688917`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJztW2dYVme2RVOMjho1GINGo6iA1K/SBH1BEaMSKYoFlSaoKArSRRREUESU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    "], {
     {GrayLevel[0], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 31], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 32], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 33], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 34], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 35], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 36], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 62], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 63], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 64], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 65], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 66], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 67], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 68], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 69], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 70], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 71], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 72], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 95], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 96], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 97], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 98], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 99], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 100], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 101], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 102], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 103], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 104], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 105], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 106], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 107], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 108], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 128], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 129], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 130], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 131], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 132], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 133], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 134], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 135], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 136], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 137], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 138], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 139], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 140], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 141], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 142], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 143], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 144], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 161], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 162], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 163], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 164], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 165], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 166], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 167], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 168], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 169], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 170], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 171], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 172], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 173], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 174], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 175], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 176], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 177], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 178], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 179], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 180], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 195], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 196], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 197], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 198], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 199], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 200], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 201], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 202], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 203], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 204], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 205], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 206], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 207], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 208], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 209], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 210], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 211], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 212], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 213], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 214], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 215], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 216], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 228], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 229], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 230], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 231], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 232], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 233], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 234], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 235], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 236], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 237], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 238], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 239], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 240], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 241], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 242], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 243], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 244], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 245], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 246], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 247], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 248], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 249], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 250], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 251], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 252], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 261], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 262], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 263], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 264], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 265], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 266], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 267], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 268], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 269], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 270], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 271], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 272], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 273], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 274], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 275], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 276], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 277], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 278], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 279], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 280], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 281], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 282], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 283], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 284], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 285], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 286], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 287], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 288], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 295], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 296], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 297], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 298], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 299], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 300], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 301], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 302], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 303], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 304], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 305], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 306], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 307], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 308], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 309], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 310], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 311], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 312], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 313], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 314], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 315], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 316], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 317], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 318], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 319], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 320], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 321], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 322], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 323], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 324], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 329], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 330], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 331], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 332], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 333], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 334], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 335], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 336], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 337], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 338], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 339], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 340], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 341], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 342], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 343], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 344], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 345], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 346], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 347], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 348], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 349], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 350], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 351], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 352], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 353], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 354], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 355], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 356], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 357], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 358], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 359], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 360], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 363], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 364], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 365], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 366], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 367], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 368], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 369], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 370], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 371], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 372], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 373], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 374], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 375], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 376], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 377], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 378], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 379], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 380], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 381], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 382], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 383], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 384], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 385], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 386], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 387], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 388], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 389], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 390], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 391], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 392], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 393], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 394], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 395], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 396], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 397], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 398], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 399], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 400], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 401], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 402], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 403], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 404], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 405], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 406], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 407], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 408], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 409], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 410], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 411], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 412], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 413], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 414], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 415], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 416], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 417], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 418], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 419], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 420], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 421], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 422], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 423], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 424], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 425], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 426], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 427], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 428], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 429], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 430], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 431], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 432], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 433], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 434], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 435], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 436], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 437], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 438], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 439], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 440], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 441], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 442], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 443], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 444], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 445], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 446], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 447], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 448], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 449], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 450], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 451], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 452], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 453], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 454], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 455], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 456], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 457], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 458], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 459], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 460], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 461], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 462], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 463], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 464], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 465], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 466], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 467], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 468], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 469], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 470], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 471], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 472], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 473], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 474], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 475], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 476], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 477], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 478], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 479], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 480], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 481], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 482], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 483], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 484], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 485], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 486], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 487], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 488], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 489], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 490], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 491], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 492], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 493], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 494], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 495], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 496], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 497], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 498], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 499], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 500], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 501], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 502], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 503], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 504], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 505], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 506], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 507], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 508], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 509], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 510], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 511], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 512], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 513], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 514], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 515], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 516], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 517], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 518], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 519], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 520], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 521], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 522], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 523], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 524], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 525], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 526], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 527], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 528], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 529], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 530], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 531], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 532], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 533], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 534], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 535], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 536], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 537], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 538], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 539], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 540], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 541], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 542], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 543], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 544], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 545], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 546], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 547], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 548], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 549], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 550], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 551], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 552], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 553], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 554], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 555], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 556], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 557], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 558], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 559], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 560], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 561], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 562], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 563], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 564], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 565], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 566], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 567], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 568], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 569], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 570], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 571], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 572], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 573], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 574], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 575], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 576], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 577], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 578], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 579], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 580], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 581], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 582], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 583], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 584], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 585], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 586], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 587], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 588], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 589], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 590], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 591], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 592], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 593], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 594], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 595], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 596], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 597], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 598], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 599], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 600], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 601], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 602], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 603], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 604], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 605], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 606], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 607], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 608], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 609], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 610], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 611], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 612], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 613], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 614], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 615], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 616], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 617], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 618], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 619], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 620], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 621], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 622], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 623], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 624], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 625], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 626], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 627], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 628], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 629], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 630], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 631], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 632], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 633], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 634], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 635], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 636], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 637], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 638], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 639], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 640], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 641], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 642], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 643], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 644], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 645], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 646], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 647], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 648], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 649], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 650], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 651], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 652], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 653], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 654], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 655], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 656], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 657], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 658], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 659], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 660], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 661], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 662], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 663], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 664], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 665], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 666], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 667], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 668], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 669], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 670], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 671], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 672], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 673], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 674], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 675], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 676], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 677], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 678], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 679], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 680], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 681], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 682], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 683], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 706], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 707], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 708], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 709], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 710], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 711], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 712], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 713], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 714], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 715], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 716], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 717], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 718], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 719], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 720], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 721], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 722], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 723], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 724], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 725], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 726], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 727], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 728], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 729], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 730], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 731], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 732], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 733], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 734], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 735], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 736], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 737], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 738], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 739], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 740], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 741], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 742], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 743], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 744], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 745], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 746], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 747], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 748], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 749], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 750], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 751], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 752], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 753], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 754], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 755], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 756], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 757], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 758], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 759], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 760], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 761], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 762], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 763], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 764], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 765], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 766], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 767], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 768], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 769], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 770], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 771], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 772], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 773], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 774], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 775], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 776], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 777], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 778], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 779], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 780], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 781], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 782], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 783], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 784], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 785], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 786], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 787], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 788], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 789], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 790], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 791], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 792], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 793], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 794], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 795], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 796], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 797], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 798], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 799], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 800], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 801], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 802], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 803], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 804], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 805], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 806], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 807], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 808], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 809], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 810], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 811], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 812], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 813], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 814], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 815], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 816], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 817], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 818], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 819], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 820], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 821], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 822], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 823], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 824], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 825], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 826], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 827], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 828], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 829], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 830], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 831], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 832], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 833], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 834], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 835], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 836], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 837], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 838], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 839], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 840], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 841], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 842], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 843], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 844], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 845], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 846], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 847], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 848], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 849], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 850], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 851], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 852], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 853], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 854], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 855], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 856], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 857], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 858], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 859], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 860], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 861], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 862], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 863]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 100}, {0, 17}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5756277914284487`*^9, 3.5866610589218135`*^9, 
  3.5884149083682423`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"A", ",", "B"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"2.3742240073187184`", ",", "5.552129321995249`"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5030301700685997`*^9, 3.5030301832026*^9}, {
  3.5030302259926*^9, 3.5030302333185997`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"flo", "[", "s_", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", "\[Pi]"}], "+", 
     RowBox[{"6", " ", 
      SqrtBox["3"], " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "s", " ", "\[Gamma]"}]}], 
        SqrtBox["3"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", 
        RowBox[{"s", " ", "\[Gamma]"}]}], "]"}]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", 
        RowBox[{"s", " ", "\[Gamma]"}], "+", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         SuperscriptBox["\[Gamma]", "2"]}]}], "]"}]}]}], 
    RowBox[{"18", " ", "\[Gamma]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fhi", "[", "s_", "]"}], "=", 
   RowBox[{
    FractionBox["A", "4"], 
    RowBox[{"Log", "[", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Beta]", " "}], "A"], 
       SuperscriptBox["s", "4"]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "s_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"flo", "[", "s", "]"}], "+", 
     RowBox[{"fhi", "[", "s", "]"}]}], "//", "N"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4831527699455194`*^9, 3.4831528848560925`*^9}, {
   3.483153810065011*^9, 3.4831538126601596`*^9}, 3.4831542710383773`*^9, {
   3.4831601368408823`*^9, 3.4831601377619348`*^9}, {3.483160191503009*^9, 
   3.483160191894031*^9}, 3.4831620338243837`*^9, {3.4837057666310916`*^9, 
   3.4837057844981136`*^9}, {3.483706161017649*^9, 3.4837061633607836`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]", "=", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"2", "\[Pi]"}], 
     RowBox[{"3", 
      SqrtBox["3"]}]], "/", 
    RowBox[{"(", 
     RowBox[{"B", "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "A", " ", 
       RowBox[{"Log", "[", 
        FractionBox["A", "\[Beta]"], "]"}]}]}], ")"}]}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.483160362459787*^9, 3.48316055063455*^9}, {
   3.4831617233896275`*^9, 3.4831617287819357`*^9}, 3.483162119514284*^9, {
   3.4832439990837955`*^9, 3.483244014578682*^9}, {3.4837063996993012`*^9, 
   3.4837064072437325`*^9}}],

Cell[BoxData[
 FractionBox["1.2091995761561452`", 
  RowBox[{"5.552129321995249`", "\[VeryThinSpace]", "+", 
   RowBox[{"0.5935560018296796`", " ", 
    RowBox[{"Log", "[", 
     FractionBox["2.3742240073187184`", "\[Beta]"], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.5756277915594654`*^9, 3.586661059199829*^9, 
  3.5884149085452976`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Beta]", "=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "\[Beta]", "}"}], ",", 
    RowBox[{"\[Beta]", "/.", 
     RowBox[{"FindFit", "[", 
      RowBox[{"data", ",", 
       RowBox[{"f", "[", "s", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"\[Beta]", ",", 
          SuperscriptBox["10", 
           RowBox[{"-", "6"}]]}], "}"}], "}"}], ",", "s"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.483094763614047*^9, 3.483094768838346*^9}, {
   3.4830948338490644`*^9, 3.48309484076946*^9}, {3.4830949179628754`*^9, 
   3.4830949187899227`*^9}, {3.4830949501757183`*^9, 3.483094950613743*^9}, {
   3.4830952353630295`*^9, 3.483095240589329*^9}, {3.483095587565174*^9, 
   3.483095592087433*^9}, {3.483095760555069*^9, 3.483095770664647*^9}, {
   3.4831550016951685`*^9, 3.483155012812804*^9}, {3.4831578137030063`*^9, 
   3.4831578275717993`*^9}, {3.4831582935134497`*^9, 
   3.4831582965406227`*^9}, {3.4831583588051844`*^9, 
   3.4831583694737945`*^9}, {3.4831584095470867`*^9, 
   3.4831584325874043`*^9}, {3.483159818791691*^9, 3.483159891527851*^9}, {
   3.483159973802557*^9, 3.4831600672439013`*^9}, {3.4831601246831865`*^9, 
   3.483160166365571*^9}, {3.483160214727337*^9, 3.4831602455220985`*^9}, {
   3.4831606642550488`*^9, 3.4831606697383623`*^9}, {3.4831607257255645`*^9, 
   3.4831607644517794`*^9}, 3.483161735685331*^9, {3.4831617790578117`*^9, 
   3.483161799975008*^9}, {3.4837058081834683`*^9, 3.4837058085524893`*^9}, {
   3.483705919953861*^9, 3.4837059241230993`*^9}, 3.4837061864121017`*^9, {
   3.4837064435538096`*^9, 3.483706510894661*^9}}],

Cell[BoxData["0.00012769389976395042`"], "Output",
 CellChangeTimes->{3.5756277915904694`*^9, 3.5866610592638674`*^9, 
  3.588414908574308*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"f", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.483161520495023*^9, 3.483161553510911*^9, 3.4831615851487207`*^9, {
   3.483162239491147*^9, 3.483162243146356*^9}, {3.483163543345723*^9, 
   3.4831635440567636`*^9}, 3.483164067005675*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwd0Xs4lAkfxvGxJoeKpKzRisFgRsY8ItUUc0s05DjEg1crTDMOlShi1Q6R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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 100}, {0., 16.4442034143214}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.575627791637475*^9, 3.586661059570933*^9, 
  3.58841490860327*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"Log", "[", "s", "]"}]}], "+", "B"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.483164083848638*^9, 3.4831641298582697`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0nk41IkDBvCJIVk22SE0mDvGMd8pVBN5Q6ZSkgZfRYoIlRghpULrCEtR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 7.},
  Method->{},
  PlotRange->{{0, 100}, {7.1637254192925415`, 16.48583488690303}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5756277916534915`*^9, 3.586661059644914*^9, 
  3.588414908624273*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{"s", ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0", ",", "15"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.4831640715689354`*^9, {3.483164133629485*^9, 3.48316413895279*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxFxW0w03EcAPDFdR7uaIY2GsImsRmuJs80cVs3J0WnIw+z8mK4PJY7YdeZ
4lyZJFeO3U5FISexxG66SnflMPZvXdSp7hK23R5snFO98P29+NzHO684lW+F
w+G4//zftDT9htLYGrO3spN0LR4rid07znUmj4QJ4YqUXpU11gI7bRBbLCoJ
vDyeXGxQDcGJlNWvOpUCtqjC7mpVc/AU65F0VrICk5fHfuXR1mEXQXavDUsP
t4QkvkpOM8Of24PlOvwO3CitmbFy2xe3N7F15ab4oTUsOseOmTPth0vDu7On
hbZwgmarqmjFHq6LOpPrfsIBjui/P3x98gAsMOtq3zs4wZZA/BI9jQBH9T3t
amtzhnUETk66wgX+0ZSTXmJzEGZrKtk/mUR4jWdbOlxDghMpRCuRwg0mfPRr
HtS4w+SGgRQmkwy3B4bjnS97wB/c44/r73jCEWTFbcaiF+xoLSnLFR6GPeu8
ojL8vGE7auZI6jt0ULTbQGWWD1yyRJji4Hxhjb4pjd2OTmK87WDTKfCEPnJ7
8xO6iBaqnuVT4eiNfGWGnR98ikLiOkjQ/rW3rirCjsAB/PBJqhrNnyi4MXzF
H57sUubrXI/Chse7m4yXaB61z66DGwDrAsTMIS16VLr93dgQCF9I8I2L9KTB
hwpFY0FytKu94Dn3PB2WsqqrtBno0OpmljgTnawdXMBy0fWLRgtPgDZLak5W
1aHVkeL5nj50Qbn0Absfbep/wV8bRBN8sM2QEfRpWw/yazl6XNmTP7+A5jiO
0iswNJY0bSJ9QRtkfxoufkPTu4Of/V5Fj6vjK5rW0RyXs7EMLfqSqHy2zIg2
yOs7iGa0cOseT7aFxh97QsvaQXcWyoy7u+i/RQ8mnw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 15}, {0., 14.999999693877552`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5756277916725206`*^9, 3.5866610597149343`*^9, 
  3.588414908643319*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get Moser, Kim, Mansour data (1997)", "Subsection",
 CellChangeTimes->{{3.483164260726755*^9, 3.4831642716873817`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<data/turbulence.mkm.m\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.482485386967971*^9, 3.4824853944994016`*^9}, {
   3.4827536566406*^9, 3.4827536706876*^9}, {3.4827537086436*^9, 
   3.4827537185916*^9}, {3.4827538420486*^9, 3.4827538449756002`*^9}, {
   3.483075708478088*^9, 3.483075709206129*^9}, 3.4830761300442*^9, {
   3.483076565078082*^9, 3.483076578748864*^9}, {3.48307673129959*^9, 
   3.4830767348237915`*^9}, {3.4831715275663943`*^9, 
   3.4831715280054197`*^9}, {3.5053703919172254`*^9, 
   3.5053703968295064`*^9}, {3.505371470157897*^9, 3.5053714708299356`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Rey0s"], "Input",
 CellChangeTimes->{{3.4830766135628557`*^9, 3.4830766150829425`*^9}, 
   3.483153474131797*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"178.12`", ",", "392.24`", ",", "587.19`"}], "}"}]], "Output",
 CellChangeTimes->{3.5756277917025533`*^9, 3.5866610599119186`*^9, 
  3.5884149086753225`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"mkmdata", "=", 
   RowBox[{"profiles", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483164327758589*^9, 3.4831643282156153`*^9}, 
   3.505370561661934*^9, 3.575627818803887*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rey0", "=", 
  RowBox[{"mkmdata", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4831643312997913`*^9, 3.4831643318038206`*^9}}],

Cell[BoxData["587.19`"], "Output",
 CellChangeTimes->{3.5756277917555285`*^9, 3.5866610603760185`*^9, 
  3.5884149086983232`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogLinearPlot", "[", "mkmdata", "]"}]], "Input",
 CellChangeTimes->{{3.483153531062053*^9, 3.4831535392975245`*^9}, {
  3.4831643483847685`*^9, 3.4831643499348574`*^9}, {3.4831643995056925`*^9, 
  3.483164405198018*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwtVQs4VYkaFZJ0FOcc54ERklA4j31SM9echfoiTRrdjFeSQUbuSV41SuUK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      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-3.1186911809544386`, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-3.1186911809544386`, 6.375348447182542}, {0., 21.263}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.575627791817498*^9, 3.586661060468031*^9, 
  3.588414908760321*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 31.2", "Subsection",
 CellChangeTimes->{{3.5030297822256002`*^9, 3.5030297859035997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig5", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"mkmdata", ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "100"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "17"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\[Diamond]\>\"", ",", "Tiny"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.390215983268786*^9, 3.3902159860097857`*^9}, {
   3.482486302165317*^9, 3.482486308488679*^9}, {3.482813745183*^9, 
   3.482813748222*^9}, {3.482827997564*^9, 3.482827999834*^9}, 
   3.482828035901*^9, {3.4831631493751893`*^9, 3.4831631574436507`*^9}, {
   3.483164408306196*^9, 3.483164408449204*^9}, {3.4831644388299417`*^9, 
   3.483164442283139*^9}, {3.4831644775361557`*^9, 3.4831645754207544`*^9}, {
   3.483164645225747*^9, 3.4831646567394056`*^9}, {3.483165089443155*^9, 
   3.4831650947684593`*^9}, 3.4831654551030693`*^9, {3.483165516797598*^9, 
   3.483165518018668*^9}, 3.505370542544841*^9, {3.5053712786149416`*^9, 
   3.5053712796620016`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJztVXlQVVUYRzTcyJRIVAwBEUWW9+6794qGdH/iCmYoCPkUCREREYH3AJFV
nkYuZW7jqKBCoeJC5pjjmOZugEtqIDmkoGlimKWkqbhN57zvjH/0f/9xZxjm
3HfO932/7Vy32JSwWbY2NjbfsT/+/79PaMAL1Vi2XXsz7IGjedt27aSTZ/gb
ZZWapfO1Q8Xlldrhv41bOmbWa9/WbHVMz6nXbhzttkn+qknbmhrY5UpZk7Zn
7K/ZjntatLvr9tmbKlq0q635id+nt2pBF+Pr7iS2aqfidsVMDmuHsODNBZ5B
7dCv8I9JB7fYodG0/IvfzHao7hhYHFFij7dY1f3+9hj1WdKd5zt74FJd5D1d
QA9k2BZ1co5+B+ONnw79udARWc2eUqek3vBbVfpUanLCM96u9l3MsUmxdBjt
jNwZhgh9iBt+PM+ez13QPXvI7vev9IeDo1Z5rc4V/stGxNxe5Ymf3NmkIe7o
PmXY/ur5Xki9sLSmsbQ/HpRXjvdf5oO4gOuhK654YByHV6VDZDfffZvvD8CY
Aw9fXt4g0fm7nmDd1/aKk8HISA08OxAcnstoFfMYipY1gxC18uQ/g4b7w2Hx
8bNfjvZCLG84bhji+dPkhehDwfa2cwOw5T5rnDkYE1esT3YoC8RfuZoa/Www
drXUTIh9oMFKi8kbRRvZ4zWCeGz0prqzgujcSB+wU4eCK0aiiqEYUeoDt73m
hNUvRxHOxz6oncAmMI4hXGN9kZaw+s/cY2OxpGf9hSdrfXFrW/FpV30wOM0V
13xpvt0hSOGN3Pyorv4DsF/7To3zA2fv6LEJtN7qJ+qH4sVONvhNP4TY23ov
yZ9I87rowF2TGjEJ/HVPo472S2FgbK9PXqND7w6MaYdwbEjmDXWw0v4kHJP5
YDZ68HYlNycTr331GMgb10QQviF6WOWsjMSrywuaPSfpSbdjHwme9dT/yBQ8
DWcFP9HDGoLjRnSwbtSDy9ilairNfUAPmT+108DHrb+gh9X3t6Lw6CVr0KTH
QRcG7Ol0wvdK1GvLV1u+2vL1v+QrjL/o8TGscveUqH6vGHA71PhKsNK+MwZH
S/roGkZJcOQBGj4DF5+wgaZJ5KOaGcSDWaJ6c2Kx6bTrXvNSCfcYi4XtZ4oc
SeA0RJXMpDr7JcIXGEc5OiPWDXGk83WJdF84C9acPhL1+scjjxuns4H8dSZe
6CXWptk4weAckA203zkBdYxeaZyB+lclkF+iDJS79DmUs1QDzeWRSLkoNODx
IKZcXSLpv9EALy7k0rlY24sB/lrUNy4S95SEqMigupKO0a/X1vOBSXDWNXjY
nRD1HyURnsuif8U8mu93A+k5OxlWuz434BQbd6V7CjKsDWWqeyOF/OUqU//Q
VMqvQSa+vkkVeslUv7uJ/BEpUz2ziXw6WyacdSbClyWTP4aaSY9lYr3JTD4u
kgm/TZrImbhH4tMQFHP7kvthsf98GgbYWdaNPCcTHjkdORz4L2J/Ubq4j8Ta
NgP8+NVWmXRMzKA+nRTyb20GrHZ2UoRf5qOUwfPwVAhv+Xx8yC8qRSF8Dpng
14p9kEJ+zMukXIUq5I/mTGRygqaL3yMW0ByJCvU/uUDcswrxrc+CE7tuwhcr
pOfmLKq3UszXNZvyUKzQPZmdDU6Pd7lC+WnOxnam1t59CkwcwJQcyu8Rhfiq
zqF7tlqsh+aK74TYvyOX9jeIer3zCPcdheZenocfWNwSWhTy9/M80uuZQjwm
5dP87VXipzEfTP3yyq4q1Z+4kPq9rQr8C0mvPmJ/nwLs4J8ZN5XwhxeQfwaq
5J8VBXRv+6rk78oCwmtQRQ4s5AN/lfw6zEL131PpfZoF51hcHwaKeSosdG9D
JXxNFqGnSnr1WyS+H+rr/FnxsfW/xaLomA==
    "], {
     {GrayLevel[0], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 55], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 56], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 57], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 58], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 59], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 60], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 61], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 62], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 63], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 64], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 65], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 66], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 67], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 68], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 69], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 70], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 71], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 72], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 73], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 74], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 75], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 76], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 77], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 78], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 79], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 80], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 81], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 82], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 83], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 84], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 85], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 86], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 87], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 88], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 89], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 90], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 91], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 92], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 93], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 94], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 95], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 96], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 97], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 98], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 99], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 100], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 101], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 102], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 103], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 104], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 105], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 106], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 107], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 108], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 109], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 110], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 111], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 112], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 113], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 114], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 115], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 116], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 117], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 118], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 119], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 120], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 121], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 122], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 123], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 124], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 125], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 126], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 127], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 128], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 131], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 132], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 133], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 134], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 135], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 136], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 137], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 138], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 139], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 140], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 141], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 142], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 143], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 144], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 145], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 146], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 147], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 148], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 149], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 150], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 151], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 152], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 153], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 154], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 155], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 156], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 157], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 158], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 159], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 160], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 161], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 162], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 163], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 164], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 165], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 166], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 167], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 168], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 169], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 170], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 171], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 172], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 173], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 174], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 175], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 176], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 177], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 178], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 179], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 180], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 181], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 182], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 183], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 184], InsetBox[
       StyleBox["\<\"\[Diamond]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 185]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 100}, {0, 17}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.575627791900508*^9, 3.5866610623182507`*^9, 
  3.588414908845344*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"fig1", ",", "fig2", ",", "fig3", ",", "fig4", ",", "fig5", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"HoldForm", "[", 
        RowBox[{"y", "/", 
         SubscriptBox["\[Delta]", "0"]}], "]"}], ",", 
       RowBox[{"HoldForm", "[", 
        RowBox[{
         SubscriptBox["v", "x"], "\"\</\>\"", 
         SubscriptBox["u", "0"]}], "]"}]}], "}"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<turbulence-nearwall\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4831644264242325`*^9, 3.483164427572298*^9}, {
   3.4831646976487455`*^9, 3.4831647108855023`*^9}, {3.4831649901524754`*^9, 
   3.4831649908115134`*^9}, {3.4831654617934523`*^9, 
   3.4831654839497194`*^9}, {3.483171496913641*^9, 3.4831714999428144`*^9}, {
   3.483171610920162*^9, 3.4831716118422146`*^9}, {3.4831718343359404`*^9, 
   3.4831718355950127`*^9}, 3.4831741801751146`*^9, {3.5030305390316*^9, 
   3.5030306107166*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.575627792050596*^9, 3.5866610639944315`*^9, 
  3.5884149090003223`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, GraphicsComplexBox[CompressedData["
1:eJztW2dYVme2RVOMjho1GINGo6iA1K/SBH1BEaMSKYoFlSaoKArSRRREUESU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     "], {
      {GrayLevel[0], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 31], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 32], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 33], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 34], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 35], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 36], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 62], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 63], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 64], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 65], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 66], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 67], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 68], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 69], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 70], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 71], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 72], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 95], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 96], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 97], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 98], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 99], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 100], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 101], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 102], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 103], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 104], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 105], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 106], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 107], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 108], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 128], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 129], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 130], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 131], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 132], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 133], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 134], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 135], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 136], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 137], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 138], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 139], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 140], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 141], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 142], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 143], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 144], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 161], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 162], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 163], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 164], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 165], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 166], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 167], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 168], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 169], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 170], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 171], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 172], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 173], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 174], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 175], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 176], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 177], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 178], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 179], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 180], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 195], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 196], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 197], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 198], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 199], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 200], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 201], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 202], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 203], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 204], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 205], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 206], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 207], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 208], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 209], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 210], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 211], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 212], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 213], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 214], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 215], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 216], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 228], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 229], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 230], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 231], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 232], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 233], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 234], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 235], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 236], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 237], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 238], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 239], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 240], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 241], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 242], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 243], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 244], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 245], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 246], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 247], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 248], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 249], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 250], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 251], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 252], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 261], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 262], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 263], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 264], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 265], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 266], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 267], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 268], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 269], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 270], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 271], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 272], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 273], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 274], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 275], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 276], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 277], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 278], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 279], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 280], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 281], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 282], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 283], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 284], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 285], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 286], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 287], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 288], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 295], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 296], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 297], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 298], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 299], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 300], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 301], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 302], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 303], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 304], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 305], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 306], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 307], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 308], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 309], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 310], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 311], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 312], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 313], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 314], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 315], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 316], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 317], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 318], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 319], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 320], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 321], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 322], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 323], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 324], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 329], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 330], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 331], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 332], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 333], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 334], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 335], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 336], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 337], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 338], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 339], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 340], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 341], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 342], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 343], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 344], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 345], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 346], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 347], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 348], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 349], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 350], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 351], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 352], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 353], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 354], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 355], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 356], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 357], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 358], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 359], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 360], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 363], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 364], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 365], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 366], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 367], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 368], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 369], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 370], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 371], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 372], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 373], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 374], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 375], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 376], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 377], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 378], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 379], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 380], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 381], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 382], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 383], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 384], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 385], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 386], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 387], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 388], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 389], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 390], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 391], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 392], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 393], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 394], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 395], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 396], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 397], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 398], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 399], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 400], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 401], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 402], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 403], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 404], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 405], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 406], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 407], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 408], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 409], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 410], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 411], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 412], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 413], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 414], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 415], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 416], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 417], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 418], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 419], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 420], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 421], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 422], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 423], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 424], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 425], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 426], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 427], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 428], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 429], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 430], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 431], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 432], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 433], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 434], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 435], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 436], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 437], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 438], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 439], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 440], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 441], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 442], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 443], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 444], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 445], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 446], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 447], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 448], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 449], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 450], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 451], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 452], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 453], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 454], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 455], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 456], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 457], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 458], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 459], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 460], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 461], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 462], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 463], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 464], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 465], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 466], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 467], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 468], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 469], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 470], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 471], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 472], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 473], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 474], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 475], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 476], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 477], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 478], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 479], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 480], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 481], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 482], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 483], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 484], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 485], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 486], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 487], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 488], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 489], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 490], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 491], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 492], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 493], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 494], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 495], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 496], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 497], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 498], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 499], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 500], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 501], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 502], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 503], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 504], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 505], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 506], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 507], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 508], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 509], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 510], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 511], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 512], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 513], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 514], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 515], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 516], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 517], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 518], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 519], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 520], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 521], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 522], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 523], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 524], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 525], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 526], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 527], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 528], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 529], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 530], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 531], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 532], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 533], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 534], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 535], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 536], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 537], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 538], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 539], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 540], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 541], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 542], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 543], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 544], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 545], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 546], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 547], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 548], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 549], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 550], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 551], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 552], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 553], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 554], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 555], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 556], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 557], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 558], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 559], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 560], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 561], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 562], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 563], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 564], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 565], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 566], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 567], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 568], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 569], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 570], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 571], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 572], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 573], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 574], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 575], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 576], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 577], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 578], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 579], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 580], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 581], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 582], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 583], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 584], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 585], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 586], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 587], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 588], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 589], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 590], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 591], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 592], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 593], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 594], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 595], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 596], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 597], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 598], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 599], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 600], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 601], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 602], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 603], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 604], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 605], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 606], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 607], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 608], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 609], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 610], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 611], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 612], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 613], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 614], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 615], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 616], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 617], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 618], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 619], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 620], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 621], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 622], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 623], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 624], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 625], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 626], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 627], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 628], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 629], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 630], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 631], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 632], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 633], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 634], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 635], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 636], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 637], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 638], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 639], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 640], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 641], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 642], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 643], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 644], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 645], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 646], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 647], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 648], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 649], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 650], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 651], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 652], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 653], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 654], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 655], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 656], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 657], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 658], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 659], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 660], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 661], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 662], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 663], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 664], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 665], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 666], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 667], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 668], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 669], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 670], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 671], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 672], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 673], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 674], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 675], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 676], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 677], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 678], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 679], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 680], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 681], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 682], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 683], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 706], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 707], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 708], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 709], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 710], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 711], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 712], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 713], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 714], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 715], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 716], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 717], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 718], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 719], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 720], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 721], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 722], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 723], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 724], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 725], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 726], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 727], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 728], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 729], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 730], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 731], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 732], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 733], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 734], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 735], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 736], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 737], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 738], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 739], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 740], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 741], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 742], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 743], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 744], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 745], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 746], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 747], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 748], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 749], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 750], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 751], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 752], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 753], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 754], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 755], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 756], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 757], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 758], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 759], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 760], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 761], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 762], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 763], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 764], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 765], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 766], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 767], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 768], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 769], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 770], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 771], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 772], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 773], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 774], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 775], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 776], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 777], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 778], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 779], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 780], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 781], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 782], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 783], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 784], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 785], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 786], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 787], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 788], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 789], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 790], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 791], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 792], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 793], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 794], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 795], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 796], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 797], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 798], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 799], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 800], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 801], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 802], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 803], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 804], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 805], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 806], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 807], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 808], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 809], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 810], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 811], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 812], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 813], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 814], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 815], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 816], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 817], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 818], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 819], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 820], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 821], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 822], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 823], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 824], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 825], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 826], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 827], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 828], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 829], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 830], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 831], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 832], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 833], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 834], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 835], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 836], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 837], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 838], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 839], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 840], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 841], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 842], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 843], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 844], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 845], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 846], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 847], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 848], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 849], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 850], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 851], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 852], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 853], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 854], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 855], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 856], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 857], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 858], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 859], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 860], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 861], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 862], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 863]}, {}}], {}}, {{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwd0Xs4lAkfxvGxJoeKpKzRisFgRsY8ItUUc0s05DjEg1crTDMOlShi1Q6R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      "]]}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0nk41IkDBvCJIVk22SE0mDvGMd8pVBN5Q6ZSkgZfRYoIlRghpULrCEtR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      "]]}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxFxW0w03EcAPDFdR7uaIY2GsImsRmuJs80cVs3J0WnIw+z8mK4PJY7YdeZ
4lyZJFeO3U5FISexxG66SnflMPZvXdSp7hK23R5snFO98P29+NzHO684lW+F
w+G4//zftDT9htLYGrO3spN0LR4rid07znUmj4QJ4YqUXpU11gI7bRBbLCoJ
vDyeXGxQDcGJlNWvOpUCtqjC7mpVc/AU65F0VrICk5fHfuXR1mEXQXavDUsP
t4QkvkpOM8Of24PlOvwO3CitmbFy2xe3N7F15ab4oTUsOseOmTPth0vDu7On
hbZwgmarqmjFHq6LOpPrfsIBjui/P3x98gAsMOtq3zs4wZZA/BI9jQBH9T3t
amtzhnUETk66wgX+0ZSTXmJzEGZrKtk/mUR4jWdbOlxDghMpRCuRwg0mfPRr
HtS4w+SGgRQmkwy3B4bjnS97wB/c44/r73jCEWTFbcaiF+xoLSnLFR6GPeu8
ojL8vGE7auZI6jt0ULTbQGWWD1yyRJji4Hxhjb4pjd2OTmK87WDTKfCEPnJ7
8xO6iBaqnuVT4eiNfGWGnR98ikLiOkjQ/rW3rirCjsAB/PBJqhrNnyi4MXzF
H57sUubrXI/Chse7m4yXaB61z66DGwDrAsTMIS16VLr93dgQCF9I8I2L9KTB
hwpFY0FytKu94Dn3PB2WsqqrtBno0OpmljgTnawdXMBy0fWLRgtPgDZLak5W
1aHVkeL5nj50Qbn0Absfbep/wV8bRBN8sM2QEfRpWw/yazl6XNmTP7+A5jiO
0iswNJY0bSJ9QRtkfxoufkPTu4Of/V5Fj6vjK5rW0RyXs7EMLfqSqHy2zIg2
yOs7iGa0cOseT7aFxh97QsvaQXcWyoy7u+i/RQ8mnw==
      "]]}}, {{}, GraphicsComplexBox[CompressedData["
1:eJztVXlQVVUYRzTcyJRIVAwBEUWW9+6794qGdH/iCmYoCPkUCREREYH3AJFV
nkYuZW7jqKBCoeJC5pjjmOZugEtqIDmkoGlimKWkqbhN57zvjH/0f/9xZxjm
3HfO932/7Vy32JSwWbY2NjbfsT/+/79PaMAL1Vi2XXsz7IGjedt27aSTZ/gb
ZZWapfO1Q8Xlldrhv41bOmbWa9/WbHVMz6nXbhzttkn+qknbmhrY5UpZk7Zn
7K/ZjntatLvr9tmbKlq0q635id+nt2pBF+Pr7iS2aqfidsVMDmuHsODNBZ5B
7dCv8I9JB7fYodG0/IvfzHao7hhYHFFij7dY1f3+9hj1WdKd5zt74FJd5D1d
QA9k2BZ1co5+B+ONnw79udARWc2eUqek3vBbVfpUanLCM96u9l3MsUmxdBjt
jNwZhgh9iBt+PM+ez13QPXvI7vev9IeDo1Z5rc4V/stGxNxe5Ymf3NmkIe7o
PmXY/ur5Xki9sLSmsbQ/HpRXjvdf5oO4gOuhK654YByHV6VDZDfffZvvD8CY
Aw9fXt4g0fm7nmDd1/aKk8HISA08OxAcnstoFfMYipY1gxC18uQ/g4b7w2Hx
8bNfjvZCLG84bhji+dPkhehDwfa2cwOw5T5rnDkYE1esT3YoC8RfuZoa/Www
drXUTIh9oMFKi8kbRRvZ4zWCeGz0prqzgujcSB+wU4eCK0aiiqEYUeoDt73m
hNUvRxHOxz6oncAmMI4hXGN9kZaw+s/cY2OxpGf9hSdrfXFrW/FpV30wOM0V
13xpvt0hSOGN3Pyorv4DsF/7To3zA2fv6LEJtN7qJ+qH4sVONvhNP4TY23ov
yZ9I87rowF2TGjEJ/HVPo472S2FgbK9PXqND7w6MaYdwbEjmDXWw0v4kHJP5
YDZ68HYlNycTr331GMgb10QQviF6WOWsjMSrywuaPSfpSbdjHwme9dT/yBQ8
DWcFP9HDGoLjRnSwbtSDy9ilairNfUAPmT+108DHrb+gh9X3t6Lw6CVr0KTH
QRcG7Ol0wvdK1GvLV1u+2vL1v+QrjL/o8TGscveUqH6vGHA71PhKsNK+MwZH
S/roGkZJcOQBGj4DF5+wgaZJ5KOaGcSDWaJ6c2Kx6bTrXvNSCfcYi4XtZ4oc
SeA0RJXMpDr7JcIXGEc5OiPWDXGk83WJdF84C9acPhL1+scjjxuns4H8dSZe
6CXWptk4weAckA203zkBdYxeaZyB+lclkF+iDJS79DmUs1QDzeWRSLkoNODx
IKZcXSLpv9EALy7k0rlY24sB/lrUNy4S95SEqMigupKO0a/X1vOBSXDWNXjY
nRD1HyURnsuif8U8mu93A+k5OxlWuz434BQbd6V7CjKsDWWqeyOF/OUqU//Q
VMqvQSa+vkkVeslUv7uJ/BEpUz2ziXw6WyacdSbClyWTP4aaSY9lYr3JTD4u
kgm/TZrImbhH4tMQFHP7kvthsf98GgbYWdaNPCcTHjkdORz4L2J/Ubq4j8Ta
NgP8+NVWmXRMzKA+nRTyb20GrHZ2UoRf5qOUwfPwVAhv+Xx8yC8qRSF8Dpng
14p9kEJ+zMukXIUq5I/mTGRygqaL3yMW0ByJCvU/uUDcswrxrc+CE7tuwhcr
pOfmLKq3UszXNZvyUKzQPZmdDU6Pd7lC+WnOxnam1t59CkwcwJQcyu8Rhfiq
zqF7tlqsh+aK74TYvyOX9jeIer3zCPcdheZenocfWNwSWhTy9/M80uuZQjwm
5dP87VXipzEfTP3yyq4q1Z+4kPq9rQr8C0mvPmJ/nwLs4J8ZN5XwhxeQfwaq
5J8VBXRv+6rk78oCwmtQRQ4s5AN/lfw6zEL131PpfZoF51hcHwaKeSosdG9D
JXxNFqGnSnr1WyS+H+rr/FnxsfW/xaLomA==
     "], {
      {GrayLevel[0], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 55], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 56], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 57], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 58], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 59], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 60], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 61], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 62], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 63], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 64], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 65], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 66], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 67], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 68], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 69], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 70], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 71], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 72], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 73], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 74], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 75], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 76], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 77], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 78], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 79], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 80], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 81], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 82], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 83], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 84], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 85], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 86], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 87], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 88], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 89], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 90], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 91], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 92], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 93], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 94], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 95], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 96], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 97], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 98], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 99], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 100], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 101], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 102], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 103], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 104], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 105], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 106], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 107], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 108], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 109], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 110], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 111], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 112], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 113], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 114], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 115], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 116], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 117], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 118], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 119], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 120], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 121], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 122], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 123], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 124], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 125], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 126], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 127], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 128], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 131], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 132], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 133], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 134], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 135], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 136], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 137], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 138], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 139], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 140], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 141], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 142], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 143], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 144], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 145], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 146], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 147], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 148], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 149], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 150], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 151], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 152], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 153], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 154], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 155], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 156], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 157], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 158], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 159], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 160], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 161], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 162], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 163], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 164], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 165], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 166], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 167], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 168], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 169], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 170], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 171], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 172], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 173], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 174], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 175], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 176], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 177], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 178], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 179], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 180], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 181], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 182], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 183], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 184], InsetBox[
        StyleBox["\<\"\[Diamond]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 185]}, {}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     TagBox[
      FractionBox["y", 
       SubscriptBox["\[Delta]", "0"]], HoldForm], TraditionalForm], 
    FormBox[
     TagBox[
      RowBox[{
        SubscriptBox["v", "x"], " ", "\"/\"", " ", 
        SubscriptBox["u", "0"]}], HoldForm], TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->Large,
  Method->{},
  PlotRange->{{0, 100}, {0, 17}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5756277923725677`*^9, 3.586661064667556*^9, 
  3.588414909312382*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Figure 31.3 Logarithmic law of the wall (p. 576)\
\>", "Section",
 CellChangeTimes->{{3.5030291182876*^9, 3.5030291225116*^9}, {
  3.588415511136845*^9, 3.5884155377452507`*^9}}],

Cell[CellGroupData[{

Cell["Data from Princeton Superpipe", "Subsection",
 CellChangeTimes->{{3.483076224183584*^9, 3.483076227689785*^9}, 
   3.48316721955799*^9, {3.5030291138576*^9, 3.5030291146076*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(11\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.575627790041314*^9, 3.586661053755146*^9, 
  3.588414907132124*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<data/turbulence.princeton2004.m\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.4824844969850664`*^9, 3.482484554123335*^9}, {
  3.4824846011680255`*^9, 3.4824846077214003`*^9}, {3.4827537494276*^9, 
  3.4827537858076*^9}, {3.48307623267807*^9, 3.483076233290105*^9}, {
  3.4830762977317915`*^9, 3.4830762985758395`*^9}, {3.4830864839063754`*^9, 
  3.483086492837886*^9}, {3.5053699638417406`*^9, 3.5053699698720856`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Karmans"], "Input",
 CellChangeTimes->{{3.483076323521266*^9, 3.4830763243993163`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1824.7`", ",", "3327.5`", ",", "5108.5`", ",", "6617.3`", ",", "8536.4`", 
   ",", "10914.`", ",", "14849.`", ",", "19778.`", ",", "25279.`", ",", 
   "32870.`", ",", "42295.`", ",", "54530.`", ",", "76478.`", ",", "102200.`",
    ",", "127920.`", ",", "165700.`", ",", "216980.`", ",", "284260.`", ",", 
   "530030.`"}], "}"}]], "Output",
 CellChangeTimes->{3.575627790141343*^9, 3.58666105420324*^9, 
  3.588414907237141*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"profiles", "//", "Dimensions"}]], "Input",
 CellChangeTimes->{{3.4830874065771494`*^9, 3.483087410477372*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"19", ",", "57", ",", "4"}], "}"}]], "Output",
 CellChangeTimes->{3.5756277901833057`*^9, 3.5866610543022575`*^9, 
  3.5884149072551413`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["a"], "Input",
 CellChangeTimes->{3.4832420361075196`*^9}],

Cell[BoxData["0.06468`"], "Output",
 CellChangeTimes->{3.5756277902083187`*^9, 3.586661054454247*^9, 
  3.588414907273142*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Delta]", "0"], "=", 
  FractionBox["a", "Karmans"]}]], "Input",
 CellChangeTimes->{{3.4832423172375994`*^9, 3.4832423366227083`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.000035446922781827146`", ",", "0.00001943801652892562`", ",", 
   "0.000012661250856415779`", ",", "9.77437927855772`*^-6", ",", 
   "7.576964528372617`*^-6", ",", "5.926333150082463`*^-6", ",", 
   "4.355848878712371`*^-6", ",", "3.2703003337041157`*^-6", ",", 
   "2.5586455160409827`*^-6", ",", "1.9677517493154853`*^-6", ",", 
   "1.52925877763329`*^-6", ",", "1.1861360718870348`*^-6", ",", 
   "8.457334135306886`*^-7", ",", "6.328767123287672`*^-7", ",", 
   "5.056285178236398`*^-7", ",", "3.903439951719976`*^-7", ",", 
   "2.980919900451655`*^-7", ",", "2.2753816928164355`*^-7", ",", 
   "1.22030828443673`*^-7"}], "}"}]], "Output",
 CellChangeTimes->{3.5756277902304106`*^9, 3.5866610545142865`*^9, 
  3.588414907291147*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make fit to logarithmic law of the wall", "Subsection",
 CellChangeTimes->{{3.4830941370232086`*^9, 3.483094138228277*^9}, {
  3.4831593643206964`*^9, 3.4831593726121707`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdata", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"profiles", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483241636189646*^9, 3.483241643735077*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"logdata", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"fdata", ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ">", "300"}], "&&", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "0.12"}]}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483241705374603*^9, 3.4832417472439976`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figh", "=", 
  RowBox[{"ListLogLinearPlot", "[", 
   RowBox[{"logdata", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "Black", "}"}]}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", "\"\<\[SmallCircle]\>\"", "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"100", ",", 
         RowBox[{"4", " ", 
          SuperscriptBox["10", "5"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"15", ",", "35"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"HoldForm", "[", 
        RowBox[{"y", "/", 
         SubscriptBox["\[Delta]", "0"]}], "]"}], ",", 
       "\"\<\!\(\*SubscriptBox[\(v\), \(x\)]\)/\!\(\*SubscriptBox[\(u\), \
\(0\)]\)\>\""}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390216053281786*^9, 3.390216053957786*^9}, {
   3.482490165817305*^9, 3.48249016974753*^9}, {3.482827396251*^9, 
   3.482827405691*^9}, {3.4830939357686973`*^9, 3.4830939457412677`*^9}, {
   3.483097874022952*^9, 3.4830978786822186`*^9}, {3.4831611699789743`*^9, 
   3.4831611709880323`*^9}, 3.483161231550496*^9, 3.4831690702478437`*^9, {
   3.4832387883197565`*^9, 3.4832387890868006`*^9}, {3.4832388465890894`*^9, 
   3.4832389508440523`*^9}, {3.4832390134756346`*^9, 3.483239051456807*^9}, {
   3.483239176881981*^9, 3.4832392003923264`*^9}, {3.4832393048302994`*^9, 
   3.483239345033599*^9}, {3.4832407463137474`*^9, 3.483240765084821*^9}, {
   3.4832407978346944`*^9, 3.483240801309893*^9}, {3.483241308047877*^9, 
   3.4832413345123906`*^9}, {3.50150576997972*^9, 3.50150582417682*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztWflbTWvY7lSGk5CiPc+VqBPZa609pts8a5BKZEiijkyZkjJ0DJnJnClC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    "], {
     {GrayLevel[0], 
      TagBox[InsetBox["\[SmallCircle]", 434],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 435],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 436],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 437],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 438],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 439],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 440],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 441],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 442],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 443],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 444],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 445],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 446],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 447],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 448],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 449],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 450],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 451],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 452],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 453],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 454],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 455],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 456],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 457],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 458],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 459],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 460],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 461],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 462],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 463],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 464],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 465],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 466],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 467],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 468],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 469],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 470],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 471],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 472],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 473],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 474],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 475],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 476],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 477],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 478],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 479],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 480],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 481],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 482],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 483],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 484],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 485],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 486],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 487],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 488],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 489],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 490],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 491],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 492],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 493],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 494],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 495],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 496],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 497],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 498],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 499],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 500],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 501],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 502],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 503],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 504],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 505],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 506],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 507],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 508],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 509],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 510],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 511],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 512],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 513],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 514],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 515],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 516],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 517],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 518],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 519],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 520],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 521],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 522],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 523],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 524],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 525],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 526],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 527],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 528],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 529],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 530],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 531],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 532],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 533],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 534],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 535],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 536],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 537],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 538],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 539],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 540],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 541],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 542],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 543],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 544],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 545],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 546],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 547],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 548],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 549],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 550],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 551],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 552],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 553],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 554],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 555],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 556],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 557],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 558],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 559],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 560],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 561],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 562],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 563],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 564],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 565],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 566],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 567],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 568],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 569],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 570],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 571],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 572],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 573],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 574],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 575],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 576],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 577],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 578],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 579],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 580],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 581],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 582],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 583],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 584],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 585],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 586],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 587],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 588],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 589],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 590],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 591],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 592],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 593],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 594],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 595],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 596],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 597],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 598],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 599],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 600],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 601],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 602],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 603],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 604],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 605],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 606],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 607],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 608],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 609],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 610],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 611],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 612],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 613],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 614],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 615],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 616],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 617],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 618],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 619],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 620],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 621],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 622],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 623],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 624],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 625],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 626],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 627],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 628],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 629],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 630],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 631],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 632],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 633],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 634],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 635],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 636],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 637],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 638],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 639],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 640],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 641],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 642],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 643],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 644],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 645],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 646],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 647],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 648],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 649],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 650],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 651],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 652],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 653],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 654],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 655],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 656],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 657],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 658],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 659],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 660],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 661],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 662],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 663],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 664],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 665],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 666],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 667],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 668],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 669],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 670],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 671],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 672],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 673],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 674],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 675],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 676],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 677],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 678],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 679],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 680],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 681],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 682],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 683],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 684],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 685],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 686],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 687],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 688],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 689],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 690],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 691],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 692],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 693],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 694],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 695],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 696],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 697],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 698],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 699],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 700],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 701],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 702],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 703],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 704],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 705],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 706],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 707],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 708],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 709],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 710],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 711],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 712],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 713],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 714],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 715],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 716],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 717],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 718],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 719],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 720],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 721],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 722],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 723],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 724],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 725],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 726],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 727],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 728],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 729],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 730],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 731],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 732],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 733],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 734],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 735],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 736],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 737],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 738],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 739],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 740],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 741],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 742],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 743],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 744],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 745],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 746],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 747],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 748],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 749],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 750],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 751],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 752],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 753],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 754],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 755],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 756],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 757],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 758],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 759],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 760],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 761],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 762],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 763],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 764],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 765],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 766],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 767],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 768],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 769],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 770],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 771],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 772],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 773],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 774],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 775],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 776],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 777],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 778],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 779],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 780],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 781],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 782],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 783],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 784],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 785],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 786],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 787],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 788],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 789],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 790],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 791],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 792],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 793],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 794],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 795],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 796],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 797],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 798],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 799],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 800],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 801],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 802],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 803],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 804],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 805],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 806],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 807],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 808],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 809],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 810],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 811],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 812],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 813],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 814],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 815],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 816],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 817],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 818],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 819],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 820],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 821],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 822],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 823],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 824],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 825],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 826],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 827],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 828],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 829],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 830],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 831],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 832],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 833],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 834],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 835],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 836],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 837],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 838],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 839],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 840],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 841],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 842],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 843],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 844],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 845],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 846],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 847],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 848],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 849],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 850],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 851],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 852],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 853],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 854],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 855],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 856],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 857],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 858],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 859],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 860],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 861],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 862],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 863],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 864],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 865],
       "InsetString"], 
      TagBox[InsetBox["\[SmallCircle]", 866],
       "InsetString"]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     TagBox[
      FractionBox["y", 
       SubscriptBox["\[Delta]", "0"]], HoldForm], TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(v\\), \
\\(x\\)]\\)/\\!\\(\\*SubscriptBox[\\(u\\), \\(0\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{4.605170185988092, 15},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{4.605170185988092, 12.89921982609012}, {15, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.575627790345313*^9, 3.586661054822322*^9, 
  3.588414907424161*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"A", ",", "B"}], "}"}], "=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"A", ",", "B"}], "}"}], ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"A", ",", "B"}], "}"}], "/.", 
     RowBox[{"FindFit", "[", 
      RowBox[{"logdata", ",", 
       RowBox[{
        RowBox[{"A", " ", 
         RowBox[{"Log", "[", "s", "]"}]}], "+", "B"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"A", ",", "2.3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"B", ",", "5.6"}], "}"}]}], "}"}], ",", "s"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.483094763614047*^9, 3.483094768838346*^9}, {
   3.4830948338490644`*^9, 3.48309484076946*^9}, {3.4830949179628754`*^9, 
   3.4830949187899227`*^9}, {3.4830949501757183`*^9, 3.483094950613743*^9}, {
   3.4830952353630295`*^9, 3.483095240589329*^9}, {3.483095587565174*^9, 
   3.483095592087433*^9}, {3.483095760555069*^9, 3.483095770664647*^9}, {
   3.4831550016951685`*^9, 3.483155012812804*^9}, {3.4831578137030063`*^9, 
   3.4831578275717993`*^9}, {3.4831582935134497`*^9, 
   3.4831582965406227`*^9}, {3.4831583588051844`*^9, 
   3.4831583694737945`*^9}, {3.4831584095470867`*^9, 3.483158471406625*^9}, {
   3.483159119020666*^9, 3.483159135335599*^9}, 3.483159482443453*^9, 
   3.483161236306768*^9, {3.483161819282112*^9, 3.4831618365621004`*^9}, {
   3.483241264552389*^9, 3.4832412830394464`*^9}, {3.4832418109676423`*^9, 
   3.483241813063762*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.3742240073187166`", ",", "5.552129321995264`"}], "}"}]], "Output",
 CellChangeTimes->{3.5756277904803867`*^9, 3.5866610569145784`*^9, 
  3.588414907485168*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox["1", "A"]], "Input",
 CellChangeTimes->{{3.483158223473444*^9, 3.4831582300278187`*^9}, {
   3.483158318210862*^9, 3.483158318293867*^9}, 3.4831594892968445`*^9, {
   3.483161841773399*^9, 3.4831618419564095`*^9}}],

Cell[BoxData["0.42119024865279264`"], "Output",
 CellChangeTimes->{3.575627790527334*^9, 3.586661057015561*^9, 
  3.588414907503189*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final figure 31.3", "Subsection",
 CellChangeTimes->{{3.5030292559056*^9, 3.5030292582716*^9}, {
  3.588415597248775*^9, 3.588415608281248*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figc", "=", 
  RowBox[{"LogLinearPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"Log", "[", "s", "]"}]}], "+", "B"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "150", ",", 
      RowBox[{"2", " ", 
       SuperscriptBox["10", "5"]}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390216091446786*^9, 3.390216094879786*^9}, {
   3.4824902096848145`*^9, 3.482490214888112*^9}, {3.48309782835034*^9, 
   3.4830978287283616`*^9}, {3.483097958619791*^9, 3.483097962658022*^9}, 
   3.4831609306852875`*^9, {3.483161062472825*^9, 3.4831610730744314`*^9}, 
   3.4831618459836397`*^9, {3.483169091882081*^9, 3.483169091993088*^9}, {
   3.4831705372087493`*^9, 3.483170552837643*^9}, {3.4832388073908477`*^9, 
   3.48323880953697*^9}, {3.4832392168372664`*^9, 3.483239271030366*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVx30wlAkAx3FTjmTbXqzd9bZ2WbtP03p5dll219rfI5G8dTbubikRRa9m
ayWW5tBdolK6hJpeqExUI9fkqDNqmqHklu2SalylkXcblZKrc3985zsfXtKu
6JR5ZmZmEXP9/4vsePM3Cxk4ucVq2KAlUWHedECwiIE3PM4aYg+JEhPLMm0x
A5IX4iv7dST0bUarcRsGDGvjt3pkkojODFv8yZEBK/n14aIcEl975PY0Twb0
tJiR4IMkfiyz8/JWM5BUf2709hkSC5k9cQWVDHh88Z2oaSPB0byejfSzRfqp
NN0fbmK8nKi7cfOBLSIvW4jO6sX4PlcvU2qY6LhO5Ru6xNCqX1hNfGDifev+
OLmHBFTWl3H/X1m4tWp58r4CCVreXnG6yWeDb/x7zPRKgtGIBKfIFjbEGi77
d6U32r4zkvlRdngR/UQbXuoNtXnP0dcjdvCMORrpZPLG4XUV8/py7OHc3qC5
F+wD3Zmk4BmaA65JMyxvVvpgkXuzETUOGLyq8Pln2gdqulHnKnPEnZPbS/si
pAiVZid6PXGEf+E5LbNWirFYgrMh3QlxOu1kuYUv0H5iQmjGAct4/cJknC8C
844tdDzNgV5uMuY3+mKqOEJe5+6MHJvTPsN0P6j7yhs2P3SG8OMaduF2P5An
PnzlSrjQdpdV7m7zw5LXOdfis7nQcNdGSTgyhKg78662czGy17pgRbYMMTty
EzuW8cCmxEOfumRoml9fk63hYWD+9PhSoRx779QyUMPDesOfuk35clhzLYq6
TTyk0ydFh3rlmL5ICLJULhDFEilDUgUUNY+W3yh2waGyWeWJ4wrEqrt9Gx+7
oGCNfwhjUIE23tmtRhdXCCz3d3UE+WNZ+cPLt7e5IsXHvVhT6Y+G4qwIaYMr
Vq3f91Zi8kdd1TvWfTM+Oo+03VsVroR+U9soL5SPKTLfILqgRHXwloHSMj5a
+7Ah/JsSVd0pw8aXfIj+TXOkYgPw+dlAbDXhBl9bMvvn2gBctvAaLMxww4j0
i2bGUgXR86f5yhY3KB54bVu9QQUrY2iQBV0Any1ps53NKihDlDsS4gQY/Opc
ZrAGQpNLzv1SJYD5fGp1tRSoq679dPedAFNF/TJGCjBwWBD3SC5E/aPmeztL
gMwpV0FqnhCg9TtNNAFJ+iFbtkGIqr+KGq2HANdr9CUn2QQeh20dWcagQLd0
a+21I7CC1NOMc55JUGidHAjkMY+4l9pSMCxNfVztRMDjVf0uGxaFXF3rqQYX
AoUZn6ds7Ck89d/D6xIRUJ4/OMvgUih+2CumUQQufry0iCWisJdv6o8KJDD7
vNGjZ85JORa/la4kEN36IKrMnYLMUzJtH0zgW9H4MZYnhYHjxc3Lwwj8xJMy
2WIK0KiCQmII0MPvc+z8KKxoiPlwKJZAMtmj6p0zk7b9UucPBJqYQxvLZRTG
7pxaEKshkPqKVmWnoFDBm+xITiBwN2Od0D6AwoGsBbk1Gwmw4zevfjbndCPH
czSRwE4qM61CRSHkQNix3ckEHGmna+0pCuK+xMBbKQS07652PJszxzdzamYz
gfYnLWMVgRSsSo5UB6QScL7dRY9bSeH9YHVMXhqBjPP9ng5BFP4DHo32RA==

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->NCache[{
     Log[150], 17.448500277801564`}, {5.0106352940962555`, 
    17.448500277801564`}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {8.517193191416238, 
       FormBox["5000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
          
          TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
      10.819778284410283`, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
          
          TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
      11.512925464970229`, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
          
          TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
      13.122363377404328`, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
          
          TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
      5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->NCache[{{
      Log[150], 
      Log[200000]}, {17.448500277801564`, 34.53207968344479}}, {{
    5.0106352940962555`, 12.206072645530174`}, {17.448500277801564`, 
    34.53207968344479}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {8.517193191416238, 
      FormBox["5000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
         TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
          SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
     10.819778284410283`, 
      FormBox[
       TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
         TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
          SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
     11.512925464970229`, 
      FormBox[
       TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
         TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
          SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
     13.122363377404328`, 
      FormBox[
       TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
         TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
          SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
     5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.575627790599345*^9, 3.586661057097602*^9, 
  3.588414907574174*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"figh", ",", "figc"}], "]"}], "//", "\[IndentingNewLine]", 
  RowBox[{
  "Figure", "[", "\"\<turbulence-logarithmiclaw\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.483160936068595*^9, 3.4831609402468348`*^9}, {
   3.4831610316560626`*^9, 3.483161032081087*^9}, {3.483169095462286*^9, 
   3.483169095569292*^9}, {3.483238987064124*^9, 3.483239001182932*^9}, {
   3.483239062977466*^9, 3.4832390665356693`*^9}, {3.483239394333419*^9, 
   3.483239420127894*^9}, 3.4832432789836082`*^9, 3.4832436823466787`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5756277907383623`*^9, 3.586661057360609*^9, 
  3.588414907716172*^9}],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJztWflbTWvY7lSGk5CiPc+VqBPZa609pts8a5BKZEiijkyZkjJ0DJnJnClC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     "], {
      {GrayLevel[0], 
       TagBox[InsetBox["\[SmallCircle]", 434],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 435],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 436],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 437],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 438],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 439],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 440],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 441],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 442],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 443],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 444],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 445],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 446],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 447],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 448],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 449],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 450],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 451],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 452],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 453],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 454],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 455],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 456],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 457],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 458],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 459],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 460],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 461],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 462],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 463],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 464],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 465],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 466],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 467],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 468],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 469],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 470],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 471],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 472],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 473],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 474],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 475],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 476],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 477],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 478],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 479],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 480],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 481],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 482],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 483],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 484],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 485],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 486],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 487],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 488],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 489],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 490],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 491],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 492],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 493],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 494],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 495],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 496],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 497],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 498],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 499],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 500],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 501],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 502],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 503],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 504],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 505],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 506],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 507],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 508],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 509],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 510],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 511],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 512],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 513],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 514],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 515],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 516],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 517],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 518],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 519],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 520],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 521],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 522],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 523],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 524],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 525],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 526],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 527],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 528],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 529],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 530],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 531],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 532],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 533],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 534],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 535],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 536],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 537],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 538],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 539],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 540],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 541],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 542],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 543],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 544],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 545],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 546],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 547],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 548],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 549],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 550],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 551],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 552],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 553],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 554],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 555],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 556],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 557],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 558],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 559],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 560],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 561],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 562],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 563],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 564],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 565],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 566],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 567],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 568],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 569],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 570],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 571],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 572],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 573],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 574],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 575],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 576],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 577],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 578],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 579],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 580],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 581],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 582],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 583],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 584],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 585],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 586],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 587],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 588],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 589],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 590],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 591],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 592],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 593],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 594],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 595],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 596],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 597],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 598],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 599],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 600],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 601],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 602],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 603],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 604],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 605],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 606],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 607],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 608],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 609],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 610],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 611],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 612],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 613],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 614],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 615],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 616],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 617],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 618],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 619],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 620],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 621],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 622],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 623],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 624],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 625],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 626],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 627],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 628],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 629],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 630],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 631],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 632],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 633],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 634],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 635],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 636],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 637],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 638],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 639],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 640],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 641],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 642],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 643],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 644],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 645],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 646],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 647],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 648],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 649],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 650],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 651],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 652],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 653],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 654],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 655],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 656],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 657],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 658],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 659],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 660],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 661],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 662],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 663],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 664],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 665],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 666],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 667],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 668],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 669],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 670],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 671],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 672],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 673],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 674],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 675],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 676],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 677],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 678],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 679],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 680],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 681],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 682],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 683],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 684],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 685],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 686],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 687],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 688],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 689],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 690],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 691],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 692],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 693],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 694],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 695],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 696],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 697],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 698],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 699],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 700],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 701],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 702],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 703],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 704],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 705],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 706],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 707],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 708],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 709],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 710],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 711],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 712],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 713],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 714],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 715],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 716],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 717],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 718],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 719],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 720],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 721],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 722],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 723],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 724],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 725],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 726],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 727],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 728],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 729],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 730],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 731],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 732],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 733],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 734],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 735],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 736],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 737],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 738],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 739],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 740],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 741],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 742],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 743],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 744],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 745],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 746],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 747],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 748],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 749],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 750],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 751],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 752],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 753],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 754],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 755],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 756],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 757],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 758],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 759],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 760],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 761],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 762],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 763],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 764],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 765],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 766],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 767],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 768],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 769],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 770],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 771],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 772],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 773],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 774],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 775],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 776],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 777],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 778],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 779],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 780],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 781],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 782],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 783],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 784],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 785],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 786],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 787],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 788],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 789],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 790],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 791],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 792],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 793],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 794],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 795],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 796],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 797],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 798],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 799],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 800],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 801],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 802],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 803],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 804],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 805],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 806],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 807],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 808],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 809],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 810],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 811],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 812],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 813],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 814],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 815],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 816],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 817],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 818],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 819],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 820],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 821],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 822],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 823],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 824],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 825],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 826],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 827],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 828],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 829],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 830],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 831],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 832],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 833],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 834],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 835],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 836],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 837],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 838],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 839],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 840],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 841],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 842],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 843],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 844],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 845],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 846],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 847],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 848],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 849],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 850],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 851],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 852],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 853],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 854],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 855],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 856],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 857],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 858],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 859],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 860],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 861],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 862],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 863],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 864],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 865],
        "InsetString"], 
       TagBox[InsetBox["\[SmallCircle]", 866],
        "InsetString"]}, {}}], {}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVx30wlAkAx3FTjmTbXqzd9bZ2WbtP03p5dll219rfI5G8dTbubikRRa9m
ayWW5tBdolK6hJpeqExUI9fkqDNqmqHklu2SalylkXcblZKrc3985zsfXtKu
6JR5ZmZmEXP9/4vsePM3Cxk4ucVq2KAlUWHedECwiIE3PM4aYg+JEhPLMm0x
A5IX4iv7dST0bUarcRsGDGvjt3pkkojODFv8yZEBK/n14aIcEl975PY0Twb0
tJiR4IMkfiyz8/JWM5BUf2709hkSC5k9cQWVDHh88Z2oaSPB0byejfSzRfqp
NN0fbmK8nKi7cfOBLSIvW4jO6sX4PlcvU2qY6LhO5Ru6xNCqX1hNfGDifev+
OLmHBFTWl3H/X1m4tWp58r4CCVreXnG6yWeDb/x7zPRKgtGIBKfIFjbEGi77
d6U32r4zkvlRdngR/UQbXuoNtXnP0dcjdvCMORrpZPLG4XUV8/py7OHc3qC5
F+wD3Zmk4BmaA65JMyxvVvpgkXuzETUOGLyq8Pln2gdqulHnKnPEnZPbS/si
pAiVZid6PXGEf+E5LbNWirFYgrMh3QlxOu1kuYUv0H5iQmjGAct4/cJknC8C
844tdDzNgV5uMuY3+mKqOEJe5+6MHJvTPsN0P6j7yhs2P3SG8OMaduF2P5An
PnzlSrjQdpdV7m7zw5LXOdfis7nQcNdGSTgyhKg78662czGy17pgRbYMMTty
EzuW8cCmxEOfumRoml9fk63hYWD+9PhSoRx779QyUMPDesOfuk35clhzLYq6
TTyk0ydFh3rlmL5ICLJULhDFEilDUgUUNY+W3yh2waGyWeWJ4wrEqrt9Gx+7
oGCNfwhjUIE23tmtRhdXCCz3d3UE+WNZ+cPLt7e5IsXHvVhT6Y+G4qwIaYMr
Vq3f91Zi8kdd1TvWfTM+Oo+03VsVroR+U9soL5SPKTLfILqgRHXwloHSMj5a
+7Ah/JsSVd0pw8aXfIj+TXOkYgPw+dlAbDXhBl9bMvvn2gBctvAaLMxww4j0
i2bGUgXR86f5yhY3KB54bVu9QQUrY2iQBV0Any1ps53NKihDlDsS4gQY/Opc
ZrAGQpNLzv1SJYD5fGp1tRSoq679dPedAFNF/TJGCjBwWBD3SC5E/aPmeztL
gMwpV0FqnhCg9TtNNAFJ+iFbtkGIqr+KGq2HANdr9CUn2QQeh20dWcagQLd0
a+21I7CC1NOMc55JUGidHAjkMY+4l9pSMCxNfVztRMDjVf0uGxaFXF3rqQYX
AoUZn6ds7Ck89d/D6xIRUJ4/OMvgUih+2CumUQQufry0iCWisJdv6o8KJDD7
vNGjZ85JORa/la4kEN36IKrMnYLMUzJtH0zgW9H4MZYnhYHjxc3Lwwj8xJMy
2WIK0KiCQmII0MPvc+z8KKxoiPlwKJZAMtmj6p0zk7b9UucPBJqYQxvLZRTG
7pxaEKshkPqKVmWnoFDBm+xITiBwN2Od0D6AwoGsBbk1Gwmw4zevfjbndCPH
czSRwE4qM61CRSHkQNix3ckEHGmna+0pCuK+xMBbKQS07652PJszxzdzamYz
gfYnLWMVgRSsSo5UB6QScL7dRY9bSeH9YHVMXhqBjPP9ng5BFP4DHo32RA==

      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     TagBox[
      FractionBox["y", 
       SubscriptBox["\[Delta]", "0"]], HoldForm], TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(v\\), \
\\(x\\)]\\)/\\!\\(\\*SubscriptBox[\\(u\\), \\(0\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{4.605170185988092, 15},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{4.605170185988092, 12.89921982609012}, {15, 35}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.575627790816372*^9, 3.5866610573716393`*^9, 
  3.58841490779021*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Univeral inner law of the wall (p. 576)\
\>", "Section",
 CellChangeTimes->{{3.48317244152067*^9, 3.483172443053757*^9}, {
  3.4831726699137325`*^9, 3.4831726771441464`*^9}, {3.5030311454906*^9, 
  3.5030311501275997`*^9}, {3.5884158820420003`*^9, 3.588415887864694*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4831724457649126`*^9, 3.4831724488640895`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(36\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.575627792827677*^9, 3.5866610655096784`*^9, 
  3.588414909595437*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Delta]", "0"], "[", "x_", "]"}], "=", 
   FractionBox["\[Nu]", 
    RowBox[{
     SubscriptBox["u", "0"], "[", "x", "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["v", "x"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "0"], "[", "x", "]"}], 
    RowBox[{"f", "[", 
     FractionBox["y", 
      RowBox[{
       SubscriptBox["\[Delta]", "0"], "[", "x", "]"}]], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["v", "y"], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{
       SubscriptBox["u", "0"], "'"}], "[", "x", "]"}]}], "y", " ", 
    RowBox[{"f", "[", 
     FractionBox["y", 
      RowBox[{
       SubscriptBox["\[Delta]", "0"], "[", "x", "]"}]], "]"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.483172481636964*^9, 3.483172596030507*^9}, {
  3.483172658723093*^9, 3.4831726633173556`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "x"], 
    SubscriptBox["v", "x"]}], "+", 
   RowBox[{
    SubscriptBox["\[PartialD]", "y"], 
    SubscriptBox["v", "y"]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.4831725417134*^9, 3.4831725477707467`*^9}, {
  3.48317260569706*^9, 3.4831726250811687`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5756277928666296`*^9, 3.5866610657046843`*^9, 
  3.5884149096614046`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Interpolation between linear and logarithmic sublayers (p. 578)\
\>", "Section",
 CellChangeTimes->{{3.5030299361776*^9, 3.5030299444316*^9}, {
  3.588415968169912*^9, 3.58841597179333*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(7\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.575627793786745*^9, 3.58666106645578*^9, 
  3.588414909824467*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wall interpolation function", "Subsection"],

Cell[CellGroupData[{

Cell["Low part", "Subsubsection",
 CellChangeTimes->{{3.4831527432259912`*^9, 3.4831527472702227`*^9}, {
  3.483153142973856*^9, 3.4831531446629524`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lo", "[", "s_", "]"}], "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Gamma]", " "}], "3"], 
       SuperscriptBox["s", "3"]}]}]], ",", "s"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.483151815420924*^9, 3.4831518235573893`*^9}, 
   3.483151871738145*^9, {3.483151928351383*^9, 3.483151969471735*^9}, {
   3.483152280515526*^9, 3.4831523168046017`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    SqrtBox["3"], " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "s", " ", "\[Gamma]"}]}], 
      SqrtBox["3"]], "]"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "+", 
      RowBox[{"s", " ", "\[Gamma]"}]}], "]"}]}], "-", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", 
     RowBox[{"s", " ", "\[Gamma]"}], "+", 
     RowBox[{
      SuperscriptBox["s", "2"], " ", 
      SuperscriptBox["\[Gamma]", "2"]}]}], "]"}]}], 
  RowBox[{"6", " ", "\[Gamma]"}]]], "Output",
 CellChangeTimes->{3.5756277944498816`*^9, 3.586661067193833*^9, 
  3.5884149098694735`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"flo", "[", "s_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"lo", "[", "s", "]"}], "-", 
    RowBox[{"lo", "[", "0", "]"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.4831523280692463`*^9, 3.4831523430241013`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SqrtBox["3"], " ", "\[Pi]"}], "+", 
   RowBox[{"6", " ", 
    SqrtBox["3"], " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "s", " ", "\[Gamma]"}]}], 
      SqrtBox["3"]], "]"}]}], "+", 
   RowBox[{"6", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "+", 
      RowBox[{"s", " ", "\[Gamma]"}]}], "]"}]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", 
      RowBox[{"s", " ", "\[Gamma]"}], "+", 
      RowBox[{
       SuperscriptBox["s", "2"], " ", 
       SuperscriptBox["\[Gamma]", "2"]}]}], "]"}]}]}], 
  RowBox[{"18", " ", "\[Gamma]"}]]], "Output",
 CellChangeTimes->{3.5756277953749704`*^9, 3.5866610672648783`*^9, 
  3.5884149099054356`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"flo", "'"}], "[", "s", "]"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.483152663162412*^9, 3.483152676570179*^9}}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "+", 
   RowBox[{
    SuperscriptBox["s", "3"], " ", 
    SuperscriptBox["\[Gamma]", "3"]}]}]]], "Output",
 CellChangeTimes->{3.575627795545023*^9, 3.586661067308899*^9, 
  3.5884149099264793`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"flo", "[", "s", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4831529822806644`*^9, 3.48315299356231*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"s", "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Gamma]", "3"], " ", 
     SuperscriptBox["s", "4"]}], "4"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "s", "]"}], "5"],
    SeriesData[$CellContext`s, 0, {}, 1, 5, 1],
    Editable->False]}],
  SeriesData[$CellContext`s, 0, {
   1, 0, 0, Rational[-1, 4] $CellContext`\[Gamma]^3}, 1, 5, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.575627795697027*^9, 3.586661067383896*^9, 
  3.588414910006491*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"flo", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "\[Infinity]", ",", "2"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"\[Gamma]", ">", "0"}]}]}], "]"}], "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.4831531551455517`*^9, 3.483153160461856*^9}, {
  3.483153260033551*^9, 3.4831532816327868`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], 
    RowBox[{"3", " ", 
     SqrtBox["3"], " ", "\[Gamma]"}]], "-", 
   FractionBox["1", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Gamma]", "3"], " ", 
     SuperscriptBox["s", "2"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "s"], "]"}], "3"],
    SeriesData[$CellContext`s, 
     DirectedInfinity[1], {}, 0, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`s, 
   DirectedInfinity[1], {
   Rational[2, 3] 3^Rational[-1, 2] Pi/$CellContext`\[Gamma], 0, 
    Rational[-1, 2] $CellContext`\[Gamma]^(-3)}, 0, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.575627796185088*^9, 3.58666106790396*^9, 
  3.588414910265538*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["High part", "Subsubsection",
 CellChangeTimes->{{3.4831531329472823`*^9, 3.4831531351074057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hi", "[", "s_", "]"}], "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    FractionBox[
     RowBox[{"A", " ", "\[Beta]", " ", 
      SuperscriptBox["s", "3"]}], 
     RowBox[{"A", "+", 
      RowBox[{"\[Beta]", " ", 
       SuperscriptBox["s", "4"]}]}]], ",", "s"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.483151793102648*^9, 3.483151807551474*^9}, {
  3.483151916961732*^9, 3.4831519744790215`*^9}, {3.483705608273034*^9, 
  3.483705613223317*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "A", " ", 
  RowBox[{"Log", "[", 
   RowBox[{"A", "+", 
    RowBox[{
     SuperscriptBox["s", "4"], " ", "\[Beta]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.5756277962490735`*^9, 3.5866610679929333`*^9, 
  3.5884149102904844`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fhi", "[", "s_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"hi", "[", "s", "]"}], "-", 
    RowBox[{
     FractionBox["1", "4"], "A", " ", 
     RowBox[{"Log", "[", "A", "]"}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.483152365224371*^9, 3.4831524049186416`*^9}, {
  3.4837056436830597`*^9, 3.483705643994077*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "A", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Log", "[", "A", "]"}]}], "+", 
    RowBox[{"Log", "[", 
     RowBox[{"A", "+", 
      RowBox[{
       SuperscriptBox["s", "4"], " ", "\[Beta]"}]}], "]"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5756277962971206`*^9, 3.5866610681209493`*^9, 
  3.5884149103104873`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fhi", "'"}], "[", "s", "]"}]], "Input",
 CellChangeTimes->{{3.483152702510663*^9, 3.483152704798794*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"A", " ", 
   SuperscriptBox["s", "3"], " ", "\[Beta]"}], 
  RowBox[{"A", "+", 
   RowBox[{
    SuperscriptBox["s", "4"], " ", "\[Beta]"}]}]]], "Output",
 CellChangeTimes->{3.5756277963530903`*^9, 3.586661068152952*^9, 
  3.5884149103294897`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"fhi", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "\[Infinity]", ",", "2"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{
      RowBox[{"\[Beta]", ">", "0"}], "&&", 
      RowBox[{"A", ">", "0"}]}]}]}], "]"}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.4831530132004333`*^9, 3.4831530384488773`*^9}, {
  3.4831533105904427`*^9, 3.483153327336401*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "A"}], " ", 
       RowBox[{"Log", "[", "A", "]"}]}], "+", 
      RowBox[{"4", " ", "A", " ", 
       RowBox[{"Log", "[", "s", "]"}]}], "+", 
      RowBox[{"A", " ", 
       RowBox[{"Log", "[", "\[Beta]", "]"}]}]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "s"], "]"}], "3"],
    SeriesData[$CellContext`s, 
     DirectedInfinity[1], {}, 0, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`s, 
   DirectedInfinity[1], {
   Rational[1, 4] (-$CellContext`A Log[$CellContext`A] + 
     4 $CellContext`A Log[$CellContext`s] + $CellContext`A 
      Log[$CellContext`\[Beta]])}, 0, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.575627796433119*^9, 3.586661068200984*^9, 
  3.5884149103535247`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "s_", "]"}], "=", 
  RowBox[{
   RowBox[{"flo", "[", "s", "]"}], "+", 
   RowBox[{"fhi", "[", "s", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.483152571524171*^9, 3.48315258759409*^9}, 
   3.483174108231*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", "A", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Log", "[", "A", "]"}]}], "+", 
     RowBox[{"Log", "[", 
      RowBox[{"A", "+", 
       RowBox[{
        SuperscriptBox["s", "4"], " ", "\[Beta]"}]}], "]"}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     SqrtBox["3"], " ", "\[Pi]"}], "+", 
    RowBox[{"6", " ", 
     SqrtBox["3"], " ", 
     RowBox[{"ArcTan", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "s", " ", "\[Gamma]"}]}], 
       SqrtBox["3"]], "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", 
       RowBox[{"s", " ", "\[Gamma]"}]}], "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", 
       RowBox[{"s", " ", "\[Gamma]"}], "+", 
       RowBox[{
        SuperscriptBox["s", "2"], " ", 
        SuperscriptBox["\[Gamma]", "2"]}]}], "]"}]}]}], 
   RowBox[{"18", " ", "\[Gamma]"}]]}]], "Output",
 CellChangeTimes->{3.575627796579096*^9, 3.586661068235012*^9, 
  3.5884149103735127`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Figure 31.4 Make general fit with A and B given (p. 579)\
\>", "Section",
 CellChangeTimes->{{3.4830941370232086`*^9, 3.483094138228277*^9}, {
  3.4831593643206964`*^9, 3.4831593726121707`*^9}, {3.483159459552143*^9, 
  3.4831594611202335`*^9}, {3.4831638564686327`*^9, 3.4831638600408373`*^9}, {
  3.5884160126415653`*^9, 3.58841602856958*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5030299611956*^9, 3.5030299640836*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(21\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.575627797018189*^9, 3.586661068883122*^9, 
  3.588414910534555*^9, 3.5884160063257575`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get Princeton data", "Subsection",
 CellChangeTimes->{{3.588416035954539*^9, 3.5884160392089696`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<data/turbulence.princeton2004.m\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.4824844969850664`*^9, 3.482484554123335*^9}, {
  3.4824846011680255`*^9, 3.4824846077214003`*^9}, {3.4827537494276*^9, 
  3.4827537858076*^9}, {3.48307623267807*^9, 3.483076233290105*^9}, {
  3.4830762977317915`*^9, 3.4830762985758395`*^9}, {3.4830864839063754`*^9, 
  3.483086492837886*^9}, {3.505371352822186*^9, 3.5053713649018764`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fdata", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"profiles", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483241636189646*^9, 3.483241643735077*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"fdata", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "0.12"}], "&"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4830938661267138`*^9, 3.4830938738061533`*^9}, {
   3.483093905625973*^9, 3.483093969969653*^9}, {3.4830941339720335`*^9, 
   3.4830941340910406`*^9}, {3.483094165537839*^9, 3.4830941658578577`*^9}, {
   3.483095799109274*^9, 3.4830958204114923`*^9}, {3.4830958854502125`*^9, 
   3.4830958861382523`*^9}, {3.4831582068414927`*^9, 
   3.4831582070975075`*^9}, {3.4831583417292075`*^9, 3.483158348272582*^9}, 
   3.483158395566287*^9, {3.4831585038874826`*^9, 3.4831585039764876`*^9}, {
   3.4831593998707294`*^9, 3.4831594044739933`*^9}, 3.483159709598445*^9, {
   3.48316824915988*^9, 3.4831682789885864`*^9}, {3.4831700357920694`*^9, 
   3.483170039696293*^9}, {3.4832416135273495`*^9, 3.483241621035779*^9}, {
   3.4832437327285604`*^9, 3.483243742267106*^9}, {3.4832440545239663`*^9, 
   3.4832440668906736`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"A", ",", "B"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"2.3742240073187184`", ",", "5.552129321995249`"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5030301700685997`*^9, 3.5030301832026*^9}, {
  3.5030302259926*^9, 3.5030302333185997`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "data", "]"}]], "Input",
 CellChangeTimes->{3.482827609051*^9}],

Cell[BoxData["684"], "Output",
 CellChangeTimes->{3.5756277972762413`*^9, 3.5866610700482197`*^9, 
  3.5884149105795617`*^9, 3.5884160064317408`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogLinearPlot", "[", 
  RowBox[{"data", ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"PointSize", "[", "Tiny", "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.483243930347864*^9, 3.483243966960958*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {GrayLevel[0], PointSize[Tiny], PointBox[CompressedData["
1:eJxlWnk8lF3YFkJ2M2axzJixZ519YeRq076QUkqLlGhPKimSt0W7aJX2TUWb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      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{1.667631346011831, 0},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{1.667631346011831, 11.049555782360533`}, {0, 31.831}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.575627797481268*^9, 3.5866610701562443`*^9, 
  3.5884149106475716`*^9, 3.5884160065017443`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"\[Beta]", ",", "\[Gamma]"}], "]"}]], "Input",
 CellChangeTimes->{{3.483244031634657*^9, 3.4832440391560874`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"flo", "[", "s_", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", "\[Pi]"}], "+", 
     RowBox[{"6", " ", 
      SqrtBox["3"], " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "s", " ", "\[Gamma]"}]}], 
        SqrtBox["3"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", 
        RowBox[{"s", " ", "\[Gamma]"}]}], "]"}]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", 
        RowBox[{"s", " ", "\[Gamma]"}], "+", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         SuperscriptBox["\[Gamma]", "2"]}]}], "]"}]}]}], 
    RowBox[{"18", " ", "\[Gamma]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fhi", "[", "s_", "]"}], "=", 
   RowBox[{
    FractionBox["A", "4"], 
    RowBox[{"Log", "[", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Beta]", " "}], "A"], 
       SuperscriptBox["s", "4"]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "s_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"flo", "[", "s", "]"}], "+", 
     RowBox[{"fhi", "[", "s", "]"}]}], "//", "N"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4831527699455194`*^9, 3.4831528848560925`*^9}, {
   3.483153810065011*^9, 3.4831538126601596`*^9}, 3.4831542710383773`*^9, {
   3.4831601368408823`*^9, 3.4831601377619348`*^9}, {3.483160191503009*^9, 
   3.483160191894031*^9}, 3.4831620338243837`*^9, {3.4837057666310916`*^9, 
   3.4837057844981136`*^9}, {3.483706161017649*^9, 3.4837061633607836`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Gamma]", "=", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"2", "\[Pi]"}], 
     RowBox[{"3", 
      SqrtBox["3"]}]], "/", 
    RowBox[{"(", 
     RowBox[{"B", "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "A", " ", 
       RowBox[{"Log", "[", 
        FractionBox["A", "\[Beta]"], "]"}]}]}], ")"}]}], "//", 
   "N"}]}]], "Input",
 CellChangeTimes->{{3.483160362459787*^9, 3.48316055063455*^9}, {
   3.4831617233896275`*^9, 3.4831617287819357`*^9}, 3.483162119514284*^9, {
   3.4832439990837955`*^9, 3.483244014578682*^9}, {3.4837063996993012`*^9, 
   3.4837064072437325`*^9}}],

Cell[BoxData[
 FractionBox["1.2091995761561452`", 
  RowBox[{"5.552129321995249`", "\[VeryThinSpace]", "+", 
   RowBox[{"0.5935560018296796`", " ", 
    RowBox[{"Log", "[", 
     FractionBox["2.3742240073187184`", "\[Beta]"], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.5756277978442583`*^9, 3.5866610702022133`*^9, 
  3.58841491072854*^9, 3.5884160065497475`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Beta]", "=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "\[Beta]", "}"}], ",", 
    RowBox[{"\[Beta]", "/.", 
     RowBox[{"FindFit", "[", 
      RowBox[{"data", ",", 
       RowBox[{"f", "[", "s", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"\[Beta]", ",", 
          SuperscriptBox["10", 
           RowBox[{"-", "6"}]]}], "}"}], "}"}], ",", "s"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.483094763614047*^9, 3.483094768838346*^9}, {
   3.4830948338490644`*^9, 3.48309484076946*^9}, {3.4830949179628754`*^9, 
   3.4830949187899227`*^9}, {3.4830949501757183`*^9, 3.483094950613743*^9}, {
   3.4830952353630295`*^9, 3.483095240589329*^9}, {3.483095587565174*^9, 
   3.483095592087433*^9}, {3.483095760555069*^9, 3.483095770664647*^9}, {
   3.4831550016951685`*^9, 3.483155012812804*^9}, {3.4831578137030063`*^9, 
   3.4831578275717993`*^9}, {3.4831582935134497`*^9, 
   3.4831582965406227`*^9}, {3.4831583588051844`*^9, 
   3.4831583694737945`*^9}, {3.4831584095470867`*^9, 
   3.4831584325874043`*^9}, {3.483159818791691*^9, 3.483159891527851*^9}, {
   3.483159973802557*^9, 3.4831600672439013`*^9}, {3.4831601246831865`*^9, 
   3.483160166365571*^9}, {3.483160214727337*^9, 3.4831602455220985`*^9}, {
   3.4831606642550488`*^9, 3.4831606697383623`*^9}, {3.4831607257255645`*^9, 
   3.4831607644517794`*^9}, 3.483161735685331*^9, {3.4831617790578117`*^9, 
   3.483161799975008*^9}, {3.4837058081834683`*^9, 3.4837058085524893`*^9}, {
   3.483705919953861*^9, 3.4837059241230993`*^9}, 3.4837061864121017`*^9, {
   3.4837064435538096`*^9, 3.483706510894661*^9}}],

Cell[BoxData["0.00012769389976395042`"], "Output",
 CellChangeTimes->{3.5756277979052625`*^9, 3.5866610702282534`*^9, 
  3.5884149107555847`*^9, 3.5884160065817537`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["\[Gamma]"], "Input",
 CellChangeTimes->{{3.4831612758260283`*^9, 3.4831612934270353`*^9}, {
   3.4831617687952247`*^9, 3.4831617703753147`*^9}, 3.48316213236502*^9}],

Cell[BoxData["0.10619022229401615`"], "Output",
 CellChangeTimes->{3.575627798052335*^9, 3.5866610702452393`*^9, 
  3.5884149107755594`*^9, 3.588416006605774*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Alpha]", "=", 
  RowBox[{
   SuperscriptBox["\[Gamma]", "3"], "-", "\[Beta]"}]}]], "Input",
 CellChangeTimes->{{3.483095599148837*^9, 3.483095619952027*^9}, {
  3.483157840482538*^9, 3.4831578418366156`*^9}, {3.4831583151916895`*^9, 
  3.4831583153536987`*^9}, {3.483160823518158*^9, 3.4831608247022257`*^9}, {
  3.4831621357762146`*^9, 3.4831621376583223`*^9}, {3.48370607833292*^9, 
  3.4837060787259426`*^9}, {3.483706210745494*^9, 3.4837062117015486`*^9}}],

Cell[BoxData["0.001069745626883571`"], "Output",
 CellChangeTimes->{3.575627798114287*^9, 3.586661070262266*^9, 
  3.5884149107935905`*^9, 3.5884160066287966`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox["1", "A"]], "Input",
 CellChangeTimes->{{3.483158223473444*^9, 3.4831582300278187`*^9}, {
   3.483158318210862*^9, 3.483158318293867*^9}, 3.4831608311115923`*^9, {
   3.483162140780501*^9, 3.483162141475541*^9}}],

Cell[BoxData["0.4211902486527923`"], "Output",
 CellChangeTimes->{3.5756277981453342`*^9, 3.586661070278271*^9, 
  3.588414910811593*^9, 3.588416006651822*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fige", "=", 
  RowBox[{"LogLinearPlot", "[", 
   RowBox[{
    RowBox[{"f", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "1", ",", 
      SuperscriptBox["10", "6"]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390216380865786*^9, 3.390216404063786*^9}, {
  3.482490130631293*^9, 3.482490135595577*^9}, {3.483160875148111*^9, 
  3.4831608838546085`*^9}, {3.483162149259986*^9, 3.4831621531532087`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwVxXk8lAkfAHCGkZzjaByhYYjmMeSICL+feeR6Uyq0GraSiKJUq9JFNkTu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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->NCache[{{0, 
      Log[1000000]}, {0., 38.35324549225114}}, {{0, 13.815510557964274`}, {0.,
      38.35324549225114}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.5756277983743773`*^9, 3.5866610703682723`*^9, 
  3.588414910906577*^9, 3.588416006749811*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 31.4", "Subsection",
 CellChangeTimes->{{3.4831594269512787`*^9, 3.4831594281953497`*^9}, {
  3.5030302498426*^9, 3.5030302752166*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pdata", "=", 
   RowBox[{"fdata", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4830881470765033`*^9, 3.483088186749772*^9}, {
  3.483088299231206*^9, 3.483088302590398*^9}, {3.483088349215065*^9, 
  3.4830883742944994`*^9}, {3.4830884049992557`*^9, 3.483088406812359*^9}, {
  3.483094379186059*^9, 3.4830943847673783`*^9}, {3.4832401126745057`*^9, 
  3.483240145831402*^9}, {3.483241649228391*^9, 3.483241654709705*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figa", "=", 
  RowBox[{"ListLogLinearPlot", "[", 
   RowBox[{"pdata", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", 
       RowBox[{"PointSize", "[", "Tiny", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.483087616011128*^9, 3.483087640221513*^9}, {
   3.4830879264458838`*^9, 3.483087931926197*^9}, {3.4830880130868397`*^9, 
   3.4830880132458487`*^9}, {3.483088050174961*^9, 3.483088051006008*^9}, {
   3.4830881931341376`*^9, 3.4830882130942793`*^9}, {3.483088246838209*^9, 
   3.483088330718007*^9}, {3.4830883796058035`*^9, 3.4830884116066337`*^9}, {
   3.4830900953189363`*^9, 3.48309010202232*^9}, {3.483090135279222*^9, 
   3.4830901387194185`*^9}, {3.483168640317253*^9, 3.483168641206304*^9}, 
   3.48316874131903*^9, {3.4831687775651035`*^9, 3.4831687784131517`*^9}, {
   3.4831691975211234`*^9, 3.483169198386173*^9}, {3.483169312875721*^9, 
   3.4831693137527714`*^9}, {3.4831694836834908`*^9, 
   3.4831694846425457`*^9}, {3.4831699977608943`*^9, 
   3.4831699985469394`*^9}, {3.483170095741499*^9, 3.4831701389789715`*^9}, {
   3.483239819566741*^9, 3.4832398391858625`*^9}, {3.483239899072288*^9, 
   3.4832399171713233`*^9}, {3.4832401514387226`*^9, 
   3.4832401518917484`*^9}, {3.4832416618711147`*^9, 3.4832416644792633`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {GrayLevel[0], PointSize[Tiny], PointBox[CompressedData["
1:eJxlXHdczW/7T0Vp707jnM7qtNfZs96F7FEiIiORLbJHIUVkREjJjDLKiuyV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      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{1.667631346011831, 4.892},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{1.667631346011831, 13.274277271776858`}, {4.892, 37.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.575627798601389*^9, 3.586661070479286*^9, 
  3.5884149110116158`*^9, 3.5884160068487883`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figd", "=", 
  RowBox[{"LogLinearPlot", "[", 
   RowBox[{"s", ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "4"}]], ",", "20"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390216061503786*^9, 3.390216065323786*^9}, {
   3.390216129907786*^9, 3.390216143492786*^9}, {3.482490176812934*^9, 
   3.4824901839413424`*^9}, {3.4829806792209997`*^9, 3.482980679317*^9}, {
   3.482980762053*^9, 3.482980766465*^9}, {3.482980802005*^9, 
   3.48298080258*^9}, 3.483159324088395*^9, {3.4831695320682583`*^9, 
   3.483169532182265*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVl3c4118bx+299/ZFJLIlQvcnsyIjouy9QkiKBj8ZDatQKKnM7FkhPkch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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->
   NCache[{-Log[10000], 0.00010000002491035537`}, {-9.210340371976184, 
    0.00010000002491035537`}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->NCache[{{-Log[10000], 
      Log[20]}, {0.00010000002491035537`, 
     19.999995017930146`}}, {{-9.210340371976184, 2.995732273553991}, {
    0.00010000002491035537`, 19.999995017930146`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.5756277994645147`*^9, 3.5866610705792956`*^9, 
  3.5884149111036305`*^9, 3.588416006935807*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figb", "=", 
  RowBox[{"LogLinearPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"Log", "[", "s", "]"}]}], "+", "B"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "2", ",", 
      RowBox[{"2", " ", 
       SuperscriptBox["10", "5"]}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390216091446786*^9, 3.390216094879786*^9}, {
   3.4824902096848145`*^9, 3.482490214888112*^9}, {3.48309782835034*^9, 
   3.4830978287283616`*^9}, {3.483097958619791*^9, 3.483097962658022*^9}, 
   3.4831609306852875`*^9, {3.483161062472825*^9, 3.4831610730744314`*^9}, 
   3.4831618459836397`*^9, {3.483169091882081*^9, 3.483169091993088*^9}, {
   3.4831705372087493`*^9, 3.483170552837643*^9}, {3.4832388073908477`*^9, 
   3.48323880953697*^9}, {3.4832392168372664`*^9, 3.483239271030366*^9}, {
   3.483244745674498*^9, 3.4832447613343935`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0Gs0lAkAh/E5Sk1qNqIL5sIwM2+RWxiN4f2/TBdhVtotlyg0M26VNlu0
uSSVON1WpZw6xmqiErlMu1ttTnLUorS0rcIZWpmaJpSKEbXth+f8vj+2sdtD
ZUY0Gi34a//beIyd4e80SOpOxiUfb2Fip9fJbJfAQdI07LAZv5MJ+/5Zuaz4
QdLTuvr6zW4mDrh9yB8rHSRzSidoWj0Tq/9uPXNlvpa0qjpxymcuCw+s0uvN
p7RkwL2G27p1LHSpOl//2/qKvGSwNlvRy8LQzbyI3IQ3pCL6sdowzIb2bkKK
r/IdOV7a2NlWaoOsMu1zUcBHkntqy76+X23Bk1ibPdEYSPGRortZ97lQuTeY
BzdNkRsLdeGiETso2nu53Doa+i1nqrym8xDvaHFx9hUjJFf5S0Kd+RhJ4B1q
OjsdL1eZpY19J0DQwPMsH8UM3I+p2NwnJ3DqYFfshUg6qg5vOj9wbDFqZXui
Wp1MMOHad9RRtQTreWPqO+Oz4aF5a0FTO0A7p3Jc9YqB3cV2w0PdjghyZaxb
8/tcsJ+wM22Hl+Khb2fg0D+maOGIYrZbOkP0PYNV8tAMy4Q7k+05LjDNZ01U
189DPbvKqK7cBT0dAW3CKnN4MQx+7d6umCcKuswpsvj6qSKK0ewKUp2YkVk4
H+U74rlPI91wTbnri6RgAboupdTohtyQfznsSNIPCyH+pdeKnbYMkffXm87a
uggXSiOcNHPcUTTdoWTGBkv4xoiZjUXuWFCj70kSWyGkTP5Yx/FAwY6Wuas9
rLFFr/QsrfNAUkimNJfFROUHcme6jycof2mO0JKFMePhcE2HJyIvzpaFmrJx
48ygSYFMCI2gZN2Dj2xce+13OmxIiPA/pMKGEQ4qVlS31uV4ocQrsZC+1Qad
m7K7XRjLUdtSFivT2ODHybPq0ZPLcUeeVJkRaQtr5d3lEkIE43nsyRXttng/
LfTM9RoRJPeim/8M4qJ924jy+kpv/FaQf3rqDhe9Z0f3d/3lDSl9qe8LdzvE
rSJdESGG5mjU5rwaO+g/Fed5DImhsk/P6+bZozwl8kZQmg/kTVwHXZk95HqH
028Zvghg+qsqOTyc00nEPUpfxOyX8jiFPBhfarz1cjGJ1PdaTrApHzu2hWhz
bpO4lZps43CAD/oe210l9gD/qmL81hgf5p9vRynjgYLhkTUmqQIoD2yxiq8F
eJSsbOZLAVZuFTdhDPBL5h5l6ARYZDywNHUc2FykSTPXC6A7V1BUbgDOvQmX
ckYEONb2LPGbScCiWGrwHBegyyHdrIdGYdqo8Fs5nUCSTh2924RC/wWTT00E
geMKZ8NVFoXP7fdetCwhEPvlSWw/mwLzU+6jR44E3Isy2yxsKISt/aLqcSHw
tPlByU9cCo+mRkPeexHg8pNXBggoNKzvvWgXQEA9UFE44EKhZ1/xicWBBA7u
DZla6EZhonLDXudgAuEW4/LAZRQ8p3Ws9V5L4LP/KlGtB4Wq6ubJ0HACq8te
9GWJKLQ9268NiyRg5X1kTZ03BZ0x1REdRUDf4V4/KKbA33izPDGGwAmj3EPB
JAXJobSfU+IIxBU7vM0Ghdhaj4xdMgKebp0R9RSF7N53ir0KAvSWPU1aPwrn
6ddCcxIIPIvhOllLKPwHVVEanA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->NCache[{
     Log[2], 7.1978165565280765`}, {0.6931471805599453, 7.1978165565280765`}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->NCache[{{
      Log[2], 
      Log[200000]}, {7.1978165565280765`, 34.53207947424717}}, {{
    0.6931471805599453, 12.206072645530174`}, {7.1978165565280765`, 
    34.53207947424717}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.575627799585473*^9, 3.5866610706763144`*^9, 
  3.58841491119564*^9, 3.588416007021818*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s0", "=", 
  RowBox[{"s", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"s", "\[Equal]", 
      RowBox[{
       RowBox[{"A", " ", 
        RowBox[{"Log", "[", "s", "]"}]}], "+", "B"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "10"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.483161342941867*^9, 3.483162178610665*^9}],

Cell[BoxData["11.311587562172232`"], "Output",
 CellChangeTimes->{3.5756277996245174`*^9, 3.5866610707193146`*^9, 
  3.588414911225648*^9, 3.5884160070508223`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ticks", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Log", "[", 
        SuperscriptBox["10", "n"], "]"}], ",", 
       SuperscriptBox["\"\<10\>\"", "n"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "8"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.390216746659786*^9, 3.3902167631467857`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"figa", ",", "figb", ",", "figd", ",", "fige", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*FractionBox[\(y\), SubscriptBox[\(\[Delta]\), \(0\)]]\)\>\"",
        ",", "\"\<\!\(\*SubscriptBox[\(v\), \
\(x\)]\)/\!\(\*SubscriptBox[\(u\), \(0\)]\)\>\""}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"ticks", ",", "Automatic"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"Log", "[", 
          SuperscriptBox["10", "6"], "]"}]}], "}"}], ",", "All"}], "}"}]}], 
    ",", 
    RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<turbulence-lawofthewall\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390216104332786*^9, 3.3902161101527863`*^9}, {
   3.3902162098887863`*^9, 3.3902162243637857`*^9}, {3.3902167141977863`*^9, 
   3.3902167260727863`*^9}, {3.390216783519786*^9, 3.390216806681786*^9}, {
   3.4824892249394903`*^9, 3.482489228879716*^9}, {3.4828278111540003`*^9, 
   3.482827828705*^9}, {3.4828283794440002`*^9, 3.482828380833*^9}, {
   3.482980954809*^9, 3.482980967208*^9}, 3.483097554488676*^9, {
   3.483161416387068*^9, 3.4831614218783817`*^9}, {3.4831692141540747`*^9, 
   3.4831692867082243`*^9}, {3.483169534505398*^9, 3.483169535738468*^9}, {
   3.483170057337302*^9, 3.483170070486054*^9}, {3.4831704291125665`*^9, 
   3.483170521381844*^9}, {3.4831705738088427`*^9, 3.483170574007854*^9}, {
   3.4831718789634933`*^9, 3.4831718791805058`*^9}, 3.4831741882995796`*^9, {
   3.4832447487926764`*^9, 3.4832447520708637`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.575627799874549*^9, 3.5866610708623343`*^9, 
  3.5884149113726807`*^9, 3.5884160071978693`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, 
     {GrayLevel[0], PointSize[Tiny], PointBox[CompressedData["
1:eJxlXHdczW/7T0Vp707jnM7qtNfZs96F7FEiIiORLbJHIUVkREjJjDLKiuyV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       "]]}, {}}, {}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0Gs0lAkAh/E5Sk1qNqIL5sIwM2+RWxiN4f2/TBdhVtotlyg0M26VNlu0
uSSVON1WpZw6xmqiErlMu1ttTnLUorS0rcIZWpmaJpSKEbXth+f8vj+2sdtD
ZUY0Gi34a//beIyd4e80SOpOxiUfb2Fip9fJbJfAQdI07LAZv5MJ+/5Zuaz4
QdLTuvr6zW4mDrh9yB8rHSRzSidoWj0Tq/9uPXNlvpa0qjpxymcuCw+s0uvN
p7RkwL2G27p1LHSpOl//2/qKvGSwNlvRy8LQzbyI3IQ3pCL6sdowzIb2bkKK
r/IdOV7a2NlWaoOsMu1zUcBHkntqy76+X23Bk1ibPdEYSPGRortZ97lQuTeY
BzdNkRsLdeGiETso2nu53Doa+i1nqrym8xDvaHFx9hUjJFf5S0Kd+RhJ4B1q
OjsdL1eZpY19J0DQwPMsH8UM3I+p2NwnJ3DqYFfshUg6qg5vOj9wbDFqZXui
Wp1MMOHad9RRtQTreWPqO+Oz4aF5a0FTO0A7p3Jc9YqB3cV2w0PdjghyZaxb
8/tcsJ+wM22Hl+Khb2fg0D+maOGIYrZbOkP0PYNV8tAMy4Q7k+05LjDNZ01U
189DPbvKqK7cBT0dAW3CKnN4MQx+7d6umCcKuswpsvj6qSKK0ewKUp2YkVk4
H+U74rlPI91wTbnri6RgAboupdTohtyQfznsSNIPCyH+pdeKnbYMkffXm87a
uggXSiOcNHPcUTTdoWTGBkv4xoiZjUXuWFCj70kSWyGkTP5Yx/FAwY6Wuas9
rLFFr/QsrfNAUkimNJfFROUHcme6jycof2mO0JKFMePhcE2HJyIvzpaFmrJx
48ygSYFMCI2gZN2Dj2xce+13OmxIiPA/pMKGEQ4qVlS31uV4ocQrsZC+1Qad
m7K7XRjLUdtSFivT2ODHybPq0ZPLcUeeVJkRaQtr5d3lEkIE43nsyRXttng/
LfTM9RoRJPeim/8M4qJ924jy+kpv/FaQf3rqDhe9Z0f3d/3lDSl9qe8LdzvE
rSJdESGG5mjU5rwaO+g/Fed5DImhsk/P6+bZozwl8kZQmg/kTVwHXZk95HqH
028Zvghg+qsqOTyc00nEPUpfxOyX8jiFPBhfarz1cjGJ1PdaTrApHzu2hWhz
bpO4lZps43CAD/oe210l9gD/qmL81hgf5p9vRynjgYLhkTUmqQIoD2yxiq8F
eJSsbOZLAVZuFTdhDPBL5h5l6ARYZDywNHUc2FykSTPXC6A7V1BUbgDOvQmX
ckYEONb2LPGbScCiWGrwHBegyyHdrIdGYdqo8Fs5nUCSTh2924RC/wWTT00E
geMKZ8NVFoXP7fdetCwhEPvlSWw/mwLzU+6jR44E3Isy2yxsKISt/aLqcSHw
tPlByU9cCo+mRkPeexHg8pNXBggoNKzvvWgXQEA9UFE44EKhZ1/xicWBBA7u
DZla6EZhonLDXudgAuEW4/LAZRQ8p3Ws9V5L4LP/KlGtB4Wq6ubJ0HACq8te
9GWJKLQ9268NiyRg5X1kTZ03BZ0x1REdRUDf4V4/KKbA33izPDGGwAmj3EPB
JAXJobSfU+IIxBU7vM0Ghdhaj4xdMgKebp0R9RSF7N53ir0KAvSWPU1aPwrn
6ddCcxIIPIvhOllLKPwHVVEanA==
      "]]}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVl3c4118bx+299/ZFJLIlQvcnsyIjouy9QkiKBj8ZDatQKKnM7FkhPkch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      "]]}}, {{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwVxXk8lAkfAHCGkZzjaByhYYjmMeSICL+feeR6Uyq0GraSiKJUq9JFNkTu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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*FractionBox[\\(y\\), SubscriptBox[\\(\[Delta]\\), \
\\(0\\)]]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(v\\), \
\\(x\\)]\\)/\\!\\(\\*SubscriptBox[\\(u\\), \\(0\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  FrameTicks->{{Automatic, Automatic}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  ImageSize->Large,
  Method->{},
  PlotRange->NCache[{{0, 
      Log[1000000]}, All}, {{0, 13.815510557964274`}, All}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{0, 
      FormBox["1", TraditionalForm]}, {
      NCache[
       Log[10], 2.302585092994046], 
      FormBox["\"10\"", TraditionalForm]}, {
      NCache[
       Log[100], 4.605170185988092], 
      FormBox[
       SuperscriptBox["\"10\"", "2"], TraditionalForm]}, {
      NCache[
       Log[1000], 6.907755278982137], 
      FormBox[
       SuperscriptBox["\"10\"", "3"], TraditionalForm]}, {
      NCache[
       Log[10000], 9.210340371976184], 
      FormBox[
       SuperscriptBox["\"10\"", "4"], TraditionalForm]}, {
      NCache[
       Log[100000], 11.512925464970229`], 
      FormBox[
       SuperscriptBox["\"10\"", "5"], TraditionalForm]}, {
      NCache[
       Log[1000000], 13.815510557964274`], 
      FormBox[
       SuperscriptBox["\"10\"", "6"], TraditionalForm]}, {
      NCache[
       Log[10000000], 16.11809565095832], 
      FormBox[
       SuperscriptBox["\"10\"", "7"], TraditionalForm]}, {
      NCache[
       Log[100000000], 18.420680743952367`], 
      FormBox[
       SuperscriptBox["\"10\"", "8"], TraditionalForm]}}, 
    Automatic}]], "Output",
 CellChangeTimes->{3.5756277999305162`*^9, 3.586661070924333*^9, 
  3.5884149114186687`*^9, 3.5884160072508516`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 31.4 The outer layer (p. 579)\
\>", "Title",
 CellChangeTimes->{{3.5030309584656*^9, 3.5030309637595997`*^9}, {
  3.588416102994055*^9, 3.5884161056253357`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Figure 31.5 Prandtl's universal law of friction (p. 580)\
\>", "Section",
 CellChangeTimes->{{3.4832466338104935`*^9, 3.4832466502274323`*^9}, {
  3.58841612914536*^9, 3.588416139025629*^9}}],

Cell[CellGroupData[{

Cell["Solving the equation", "Subsection",
 CellChangeTimes->{{3.4832467423367004`*^9, 3.4832467452638683`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4832466531345987`*^9, 3.4832466563597827`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(34\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.5756278537903194`*^9, 3.5866610710893607`*^9, 
  3.588414911589693*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "=", "2.37"}], ";"}]], "Input",
 CellChangeTimes->{{3.483246790484454*^9, 3.483246806156351*^9}, {
  3.4842068788626003`*^9, 3.4842068899456*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalLambda]", "[", 
   RowBox[{
    RowBox[{"R_", "?", "NumericQ"}], ",", "DD_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "\[CapitalLambda]", "}"}], ",", 
    RowBox[{"\[CapitalLambda]", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A", " ", 
           RowBox[{"Log", "[", 
            FractionBox["R", "\[CapitalLambda]"], "]"}]}], "+", "DD"}], ")"}],
         "\[Equal]", "\[CapitalLambda]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[CapitalLambda]", ",", "1"}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.483411055665869*^9, 3.48341110935894*^9}, {
  3.4836710639700003`*^9, 3.4836710868389997`*^9}, {3.483671169974*^9, 
  3.48367137695*^9}, {3.4842068576476*^9, 3.4842069421006002`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalLambda]", "[", 
  RowBox[{"1000", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.483246834398966*^9, 3.4832468419824*^9}, {
  3.483248249555908*^9, 3.4832482498939276`*^9}, {3.483411115073267*^9, 
  3.4834111158413105`*^9}}],

Cell[BoxData["10.744144629485744`"], "Output",
 CellChangeTimes->{3.5756278538663225`*^9, 3.586661071164364*^9, 
  3.588414911618657*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 31.5", "Subsection",
 CellChangeTimes->{{3.5030309839526*^9, 3.5030309881126003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig1", "=", 
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    RowBox[{"\[CapitalLambda]", "[", 
     RowBox[{"R", ",", "0"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"R", ",", "100", ",", 
      SuperscriptBox["10", "8"]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30", ",", 
         SuperscriptBox["10", "8"]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "55"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4832472912530966`*^9, 3.483247319039686*^9}, {
   3.483247557702337*^9, 3.4832475943934355`*^9}, {3.483247706940873*^9, 
   3.483247755905673*^9}, {3.4832480451002145`*^9, 3.483248046897317*^9}, {
   3.4832480822703404`*^9, 3.4832480847354813`*^9}, {3.4832481345693316`*^9, 
   3.4832481633969803`*^9}, {3.4832482078215213`*^9, 3.483248207925527*^9}, {
   3.483248661202453*^9, 3.4832487413900394`*^9}, {3.4832488199005303`*^9, 
   3.4832488955728583`*^9}, {3.4832489304128513`*^9, 
   3.4832491513764896`*^9}, {3.4832496127608795`*^9, 
   3.4832496128358836`*^9}, {3.483671110164*^9, 3.483671121189*^9}, {
   3.483671398884*^9, 3.483671402224*^9}, 3.483671481491*^9, {
   3.483671511826*^9, 3.483671571666*^9}, {3.4842069553255997`*^9, 
   3.4842070662206*^9}, {3.4842071404936*^9, 3.4842071743016*^9}, {
   3.4842072748606*^9, 3.4842072751126003`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwVz3s01HkABfDxGvP4KU0oY72fUcN8lUF2f1eHNFrZVBPT8dzKYzDldbZJ
WaKj2pKkF7O7aksvWjXG0SpFs3FSqSwpm2pjpRDHhlrs7B/33PP5555zbePk
YVt0GQxGiDb/d5Og4kGNjIegt/sKNQPTtDHLqYi1jQff88wNSUPTdNSri6HR
GTyctZ5ymDM2TU+VqNqpXTwYapTtYZ+naY+pu4/jD/Hg3pIe0240Qyubhzst
a3goDQuuLicz9Hfhfr37PvIQ7ftZmr1zhnbP6xqJzZ2PCzOioCTOLF08VKpM
qTZBc/XhWBafATp4g9Peu6bwzzGIH1cysP3Tcb7FczMsihx/7WOugxNNcWVc
5kK0Lmn7/uoJHXCzBRMsS3Pcc5kYpTm6SAvJ641dzQevJTj1RY4uotIiPEUZ
Fig5Qjz8h3VxrFAYZ77vC2yK4/L01uqhSV1subHWEju8neWddXrw7Ry7VnHf
CnOLTH34JvrwEnfVJry0xocBWWqwTB/zB21PBxbYYKCg9eKO3/UhPP9UEmls
iyaRgcWhhQYQpz15ZFdpi97oUz2ZqQaw7y/Kc1puB5Fl24rXjQY487jtZw+N
HbZ4jZ+LYTNhdS+kYEBqD/+f9M4clTBB+4V2neu3x1rF5fakciak9UdHeLsd
QIq3GTzoY0L0suzLGzxHjNr0aS65GeJ6jv1UitIRV5xWVjJkhhC5jSjaPJ0Q
8YvSs6nKENLQ5UnCW06ofbMxOm7QELSluKhD7AzGOu+UEAcWrCdOKRx7nTH5
j+ZKfiwLZ8UpT7KTXBD1Sn6HnGTB8fyesVydRXDe48vkdrAQ/+umIE3pIviK
QkSRFBuhQhV7ro0rsqreci/QbAhvfnOEqXbFXxYR1owsNuqbUwr1V7hhHiM1
u7iSDb30r1W454ZoaXGDVRcbqwTyc64xi5H/7Ma/J9kceMbxmBbvFqNnZfPH
GhEHC09PudXnLkF6YMPq8gQOzkhjGyPnCDC6t9VEUsrBh4b9hTghQPudCdv1
tzja/5MLHi1xxztBgCNnmAMHXr9JQr07zH6jLV8s4GKvLpUscfGAuaNp19oA
Lp63FwwcT/MAXy6osZBzsed5Y1lPnQd2tcxXi49x4fLegkzqCvFOMhQ+28iF
jY/3rJlYiPcvamR+/VxMSZf93XFQCMHtV4lmXAoP89ZfTXwqRNmg7+VYQmGy
31OlY0WgyJ8OTJZQ6GLQGd7WBFt7C//kbqSg5gcvldsQVF7fnnhJ6/Q1Maoe
O4LR3XFRg+EUhmt/UNU5E4QZDDfEb6LQl9+nShESlDnw18TEUHhsd7y2O4DA
iGnVtiqJQo3f6UzjlQRnV+eM9Wt9WFK1LCiIgP/HdqMCGYWQ/c21KjHBsOk8
29vJFFpGR2qL1hAkD21u9JZTuHlrlTownMCnQ9PtmEFB+WxdVnYEwY/CT+Jm
rbPHo7yuSQnKvbqrYzIp+Lhkqm0iCXQLlJKyLAqqogr151gCyl9mZbyDQsmF
y1nkW4LZQZulVVqnNdd5JW4myH148KtgBQWPifvqzq3a/QMlwvydFObO684y
SiBwyHfn22Zr/7u+8QpIJJgzVThxQ+u2gJGPiiQCQ0VFq3QXhUtRn9Q1MoKE
Y4rDE1r/BzMt+YE=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{3.4011973816621555`, 0.6931471805599453},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {0.6931471805599453, 
       FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {2.995732273553991, 
       FormBox["20", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {5.298317366548036, 
       FormBox["200", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{3.4011973816621555`, 18.420680743952367`}, {0.6931471805599453,
    4.007333185232471}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{{{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {4.787491742782046, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.438079308923196, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.8289456176102075`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.1092475827643655`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.327936783729195, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.507277712385012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.659293919683638, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.7912214627261855`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.392661928770137, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.043249494911286`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.4341158035983, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.714417768752456`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.933106969717286`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.112447898373103`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.26446410567173, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.396391648714276`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.997832114758229`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.648419680899378`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.03928598958639, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.319587954740548`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.538277155705378`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.717618084361195`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.86963429165982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.00156183470237, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{0., 
      FormBox["1", TraditionalForm]}, {0.6931471805599453, 
      FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.5756278539793034`*^9, 3.586661071280391*^9, 
  3.5884149117357116`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"table", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"\[CapitalLambda]", "[", 
      RowBox[{"R", ",", "DD"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"DD", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "5"}], ",", "5", ",", "10", ",", "15", ",", "20"}], 
        "}"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483247122696456*^9, 3.4832472395121374`*^9}, {
  3.483247328096204*^9, 3.4832473372387266`*^9}, {3.48324741264704*^9, 
  3.4832474783547983`*^9}, {3.4832481088868628`*^9, 3.4832481213125734`*^9}, {
  3.4832481794118967`*^9, 3.483248180015931*^9}, {3.4832491941059337`*^9, 
  3.483249195984041*^9}, {3.483671414113*^9, 3.483671416545*^9}, {
  3.4842070724596*^9, 3.4842070906356*^9}, {3.4842072581406*^9, 
  3.4842072585386*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig2", "=", 
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    RowBox[{"table", "//", "Evaluate"}], ",", 
    RowBox[{"{", 
     RowBox[{"R", ",", 
      SuperscriptBox["10", "2"], ",", 
      SuperscriptBox["10", "8"]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Black"}], "}"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4828980817167997`*^9, 3.4828981656057997`*^9}, {
   3.4828982141538*^9, 3.4828982150137997`*^9}, {3.4828988784258003`*^9, 
   3.4828988853528*^9}, {3.48324681593391*^9, 3.483246816235927*^9}, {
   3.4832469428151674`*^9, 3.483246943931231*^9}, {3.4832470190765295`*^9, 
   3.4832470259169207`*^9}, {3.4832470597918577`*^9, 
   3.4832471124958725`*^9}, {3.4832471661929436`*^9, 3.483247167725031*^9}, {
   3.483247255235037*^9, 3.4832472863218145`*^9}, {3.4832473476523223`*^9, 
   3.4832473541216927`*^9}, {3.4832474267428465`*^9, 
   3.4832474294049983`*^9}, {3.4832475014411187`*^9, 3.483247539386289*^9}, {
   3.483247761594999*^9, 3.483247767610343*^9}, {3.483247992433202*^9, 
   3.483248019570754*^9}, {3.4832492568535223`*^9, 3.4832492607357445`*^9}, 
   3.483249509589978*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz2s0lAkAxvFxGzPeVDusDYsxrhFm3glZte+TQ4wabCLGSUata1YxbGul
KMKqoZJip1xSardOMjPSlsJ2OQebaCkpXTZ0nUwWo4u1H57zP7+Pj3Vs6trv
tWk0mnBu/7fdteavxmQWbkXO6GnvUFMLGfZSxlYWTI6MdCfvUVPRT84Eb5Sw
EHp067G+X9SU5qC8Z94OFjzXfIySVaopruZmb/x+Fubv84kyvaimZB1v+y0a
WYjIbPvYpFZT2yOWDxdNsvDkfUjE9rj3lFvegEqcawSv1pid4oAJquxNuSzl
nDE0FfFuN0wnKSowzL7g5peIu+L1Z8T5KWrbTIWZ+QMTRLbEFdIdNNSR9tgq
gr4IoU0H5Ib1MxSR7TrFsDCFjir9UePEBypNmDcsXm2GOmWgpHn1Jyo6LZLv
KTHHs4aLi8VFn6nDhbxY06KvUZyjcLGqnaXalWUW6xUWaK+ufpgrpuGbfnVT
TbcluK/++PX0Exo8BAOKhMdW2DgbO1YQqQWjl9a1fvlsPPt0+dXxv7XAa7gX
vmGhNYpLN5mt9NWGIK3vDueUNSqHuAKNUhs2I9I8e28OllrX0y5xdFDX21XN
vc6BocXzGrfdOrDsFOaPiWzw+e7H7uZRHVDLgwdOjthAgocz0yt1IWo5pGLl
2GLe7XNWnGpdeD6uWnGFZYfDx89k2Gp0cWmnjSZFZofRuJ+jgwR68HRWZXXx
7XG88HVggEwPomDvJN41e9xRxhsteqEHykIgvStwQHJnnZTNo8NqqjLLbtgB
9UKdS4PZdNQLUvqykxxx0XloLKaNDruG3epcrcUg9/6wfitTH/Hno/yvly+G
7YK9oawgfQTz5MwFbCfEF5TqCUv0wWsNOUBXOoHV2On4rlsfLR0phbo+zji4
jV8nZTKgk75Gjk5nrDbazy/2YSDANfWkU8wS2MxererKYYAfy6Kbv1qCsGz9
yGMKBhbVapxbcl1wIifE+7CKgTqR+OqG+a4IqtkVmmDLxLvLxYU44ooV7Ws4
euuZc/+nv7rj4gblC4/O0yVM2LJGjBNa3NDiRaQcvcJEgfa8LeGOXORPDaan
jzPxoCd/rCKNC76w57OHjQF2P7haNdTMheunVL+GEAM4vjYnp7V58G0zfTS6
ywBsr2WzJgIeqiVdcfSzBtCI3Efv7uPhxNGngm0DBridt+5C4j0e0gMzhKW6
BKZH+HItSxLj88sPDboQGKBRkmVWJLg+pe5lrgSUZoFLU9kkHl3PuOnvRiA9
KEY+xCExHMxslXMJvFWUyJsdSNwOKJ/cxyfwfM9zeQqPxKG+sIoVXgR6ORWK
+74k3Ht0G8p8CTQur81YuIrERounSav8CJSGn3X39yfh4v2v5Yc5C4s7FHIB
CdnSG6LN/gRujasU0iASYuN11h6BBFqvBSj9IkhQP9q97g8mIBsMzcyOJPGm
MqOjOIRA9kS0R5OIxI5cdsm33xHwcsxQsjeQSGyTjtevJSCX1ig/iEkEmxgb
SsIIHDz9eya5icSB6KxUh3ACaR3NHombSfx0XtgxOGfuVLeyP45ES7EvtTKC
wIIv7mcaJpAoOrYlfmLOb53+8fBNJPGy1yD3VCSBLl/VZFYSiaAt1iUiEYHf
omeUjckk6s5dKDSMIvAfmUMIyA==
     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz3tUkwUYBnAYGwy2L+HzhuCAMUDkun0kYuDhUUGcxm0gCROUq1wcyFQg
ROSqoCGYchMJwZOhmYVuIwwRXIodJXUYqKzEDAJLLh5iTENbf7znPb/zvH+8
DzcuQ5RI09PTC9TN//umW/PPbWkkcuq9uH4KGkyZDpXMPSSmpQ3ez9tpiHl+
MXjHPhL9zh5kfgcN2pOyB+yDJFppITOKThr42l7VruMkmhiJx+2VNDQqJwY4
bSRWhpo5z96nIWebz7PyWRKd2RUVieM0uBcNTsYWLkSIumVpoaUBTryqbpRc
XoTcoCdDfSUG8N281eFw72KMzU1pvF8YIPNNrYXl0BJsmNeuTfGho+5mXAPL
0BydZ4ZYtfV0sPLcNEzOMhy5Em8neUWHNLDoWewWC7xXlWSb+zMQI430WL3P
EpUhYq1dHQM1ZYK4ZeXLEV5t/G7hCwZuKk5wPpFzQA/rG/lBYIiPBl5fbe6z
gnTd0m/VOYbwFA7Kk4etEdp3taei0xALX3Jb/EttkD5fc2zQwAiC1scR0aZc
1IfMW2f6GUEo7X9o+xUX/cPi9LwyI/BGK4scvG1RsIiuH/+TEc6p7p3l37JF
ZlbzYCCdCau7gaVjUTxsRNen5euZ8PUJHjw/ysP0kQ2N3ANMRHWcmiTz7VD/
u4HbmIKJ1cMNa6+T9tiu5A0vm2Li2iGeVtJoj47b0wnudsZY7TyZe8/DATvl
NdHhYmNEBXunCrodcCGmV9NUYQxfjrDykXAFGskM/V+vG8NaczrX/tkKRFTp
cdjTxvhSKOnPS3XE3fGuoF5rE9i3Fr8u1F8JszSr09tCTbDrO3HAreqVeCAS
nP2nwATBApnxAhsn/Fu83SXnkgkEXSGfGyqcsFWp6pE/NUGHUlJGX++M8Bz7
cgaDBYO9H8twV2ft/e5rrixscss477TTBZk890GzSBY84khDy79c0JW4bri7
gAXzFq1zR6Er3IbPmL69yMK5qNgb0R+44Q3hs6ftIQtTnUfLUOeGhkjy7btZ
lq7/3NKHru7IJHw4PVZs2JGji5I73FEVadHjtYGNwzT27ghHPlyyORrTVDaG
HpSO1Ur5ODqVsvhYJRvFQzca1O18pHHj+ifa2HD825KaowkQtjvpyBcDbNis
8Xq/RChA6biCL5pjQxu16s9HFQIkBOfXqM0J3C8Kv5LyWIDF4U2jTd4E5kY9
ZPpWFM4FJLWeEBMY1PPd52VNITx5ytt6OwGFxeYPM2woFItw+5LOe4N2ytS2
FHa4et7ojSYwIf9M1r6CwkTN6fXzOwiMlIzIJALdfdjmqqQEAirbWvkTPwrP
GeJgSkKgzadlv+lGCrIm9fUunasivlkVEEDh4MtNvC3pBAKPKuUyIYVW7qgq
PoPAnelJeWUQhc5p0a1TmQS6ujcp/LdR4PnNaGb2E2h8GpaVF0kBXhd+Kcgi
kDcT43k1ioK+nvgiO5vAGsf9CptoCqpjHV52OQRklc2Kt7G6f8micVEugZMX
LmVR8bqct/bQbzpLle2eKQkU7jDesVIPEOBr+hQDSRS+b682KcwjsMDsSRaR
TKHux/Q89kFdf6c/PP1SKIQuF43U6nzPb3I2N5XCIzX8efkEvo55o2hLo/CU
53Pmss7/AaXc/oY=
     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz2lM0wcYBnBEe9DjrxaHIFcpp1y2/wqiVnnUIhQ5zIQOQcqhE4sUXFUO
xY3CUHBKpwiSEaLIFPCaSFtBRJzMIHiBOupBgjpAM6RFtwHVies+vHnyy5Pn
w+uSmvXl15YWFhaR5vs/b/rX3m/azkGVfODomIKCOXQPNX0HBzac2CS3LApk
L89GJ+3iwJi6ambCDgpM5Zpe1j4OWvTVfV1KCvimrodpZRzkRaaVnsihoKbT
0O/YxMFQT5ciVEVBbpxosHSCg6gxVUTeMQoWFeqNKSprqFrcMtOuUnBkrKJG
cXEe1r7cWlDDoCI4PNZjf9cXGO/m9jhvoOKbD8cX2D+3wUdn4T67KiqqbqZW
M6m26LgcZ3XpBRXMfP9JuqMdPLevLFLyaFBGFg6mrFuAgpjpE2fTaJApNwqX
7LJH20lVUWMjDZUlglS7Ugd4p2VWq4dpuKk74viV1hHiPGN9jxsdy/rfN9fe
c0LZQfGmMBkdgRK9dtsLZzBGVgyIK+iw/tPlVEgxF+JkfUj2AzoEDU+kiXNc
wBC5OypnWUGifNTHq3dBd8y5zEKRFVxH1IUey3lY3bT3wFKlFeoe3j3Jv8XD
Hwntdfw6KzjdiSx+E+8K6/MBLk56KwSLovVnRlyR2Nb7tpjKQHzrMSPnWzcc
rYzq6QpiYMmL6hXtHHe0tB2qYMoZuPqdq0lR446V8p477hXm3se4567QA2TS
7cfTneZ99PJ0wQ0PjG61WzNgYCDYUaJ+LPHE3rrwifm2TDhP/rTHfdATTovl
jqY1TJyWKB7lp3uhNCk3wiODCfeGoveqGQsRWdI6/rKSibRLCaG3KhbCvqx3
FfMGE9ECjdVsrjcc3kgtfh1mQnB9/VGqzhuZ0gaagc1Ca6eiZNZqH8A3eKiL
ZGHmzggN7vhgrq9b9nopC2H+WWe8k30x/m/Iq2X5LAhTOVT7UV80Psq6TTnB
gu0pk0+ryg8fOBPNzr+xUBef0pFI+KPF8H5ewAgL49cOlqDKH+tyaeMONLb5
/6n5fX6LYNovLIc3G26ckXnbWhdh8eg17g/hbOy3ZGVIvfigrBhts1Cw8by3
+M1xJR+TOoeM6DI2ip53VA9c4cPYN02MnWfD6609OWUpwOrDdk4/32ODuzTo
s41EgJh30Tuuj7Jhig94/fiwAP8EFZQ/oxN4UBhzWf5EgKLyX37/7ElgakSo
meFEYlAbVNMoJqC3CN4V5Eyi7kJlu1cIAd2C8MVZXBJ6UW5/vdk7o5I1AzwS
Terud6fXEjBoD2mueJKwsWy/XxtGYPj7YY1CQKIv5wyvKoLAQ95x7VMxiQjr
nKDvYgg0iU7tnrOWxFC1If2T2T9KLwSEhpJwej2rcm8sgciDnVqNhESKy9z+
HCmB2++MWnUUid0nOz5lxRG4fiNMFxJH4i8//lvZJgI1zzZk528kMT9hqmHA
7Py/ZYHN8ST8zmbI4hMJLPXareMmkuDNSGyOlRHQqGt1H1NI2D7YSYlIJlDe
eD6b3EyiUaI50G22svNKoHwLibySesvQFAL8yXu6/q0kEmobX61KJTB77tNs
9jYScbyroR1mG7yHAsVyEunagtOizQTuio0Te9JJXPSb/thq9jnZB13TdhLO
MuG6JVsI/Ae9B/lD
     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz2lQUwcUBWBAJIEsDyMiW4CA7BCTh8YFWk5VwCgRRYoQFCVYZUvRgAgR
pOAWXBpxabDICDoFNC4sSSxU0YrUDoiyWJBCBzoqpYpgtWUrjH39cefON+fe
H4cnS4v4wsTIyEhCzf/7Ab/8SU0KBwSqeZYqGizp7mr6Hg6GEzwdaIU0xP1+
LXx7BgczC71nZilPndW1M3M5cNk7kPrmBA2CqUedu7/mYHtkxbxmNQ2lTaPd
3BoOVOGr5ekaGrKiAwcKxzlQvogrulNBw+KCnrH4/PmImUy9YdxMQ9Hb86Xy
m1ZIy7U6GTaXjqB1n7sffbQAvDyfsMYgOvZOa+zs+6zx0jTr0aX9dBQ/kJUw
zGywkqi70FBLByOHP0Hn2qK5tatdNUyHQlIwEL/eDutj2cVpPHPEKWL8l2XY
Y/OBKrzbYo5vVEKZbaEDbmgYtaWF5nhgKOJu0XMhOHY4P7jRHCu739eVtznC
+njSyqhRc4jEPfrEQSe0D2q12Q4WmP+adzn4iDNefDBlHZBYQFj1PGqbJQ/9
H3piPlNaQKzo6nCp5CEmTDTTctUCrkPqAvcAF8SZvJ7O7bHAlc7HZYJmFxSu
0ipDjRlwbJUcGZa6YtXDsoAGPwaCAsN7KoZcIbo2LzI1igFp/bkxzsFFSOGM
JVTnM7BssOSTuxw3mFUmB8dqGWjIc52Sl7ohfqhfc6yDyn3GlI/93ZFtkvgV
f5r6Dw9IFt53R1lJkW2WExNBXLH6mdgD17OffJqymgmniW+VbgMeOF2bu6Up
iYnvxPKunGRP9P3obvrhJBNuVYfe5xt7oWHTxXMZtUzsro4NbT7vBcc//5lz
tZuJcKHOnHD2Rs7ZveGvJpgQNm48Y2bwxlzOyPfb7Vmob5KrTFf5oNi0JWU6
gIU56WE6tPqgxW/nTFYsC2v5aRXeO3xB2tN3ueay4C/jmNm/8cWziZBbCy6y
YHN5yqc+3w+9NwvNF91l4Yo0/t42Nh95Pq9p6j4W3t05rkIxH1J627nJSRbV
f3Jhh99iONYEN8ht2FjEGbJKrF+Myi+l++OXsnHUhJka5SlASEilNiKSjb72
I8MahQAs2QFViIKNQ333SvpvC6CWKC88P8WG54g9OWkihEOE/US0lg3nFcs/
WouF+OjhVXbsJzampEv/eHZKiNGuj2TvIBtPCyJrk54LsaS82owxy8bkkL/O
2JHEpre+nXMXEugxCspY7kSi9WY0N5uywW7dkjRnEgc/jZSNUE7fsEPX70Ji
zo67vZ02BEb1J3W3PUgEtiQdvGRH4NXhVzq5kITotx8uLXMk0Omi0feuIaHo
fhiS4EagJvDyPssQEuv7vdp+oXw66sbS0FASdQHpkrXuBCTHm/Q6MQnjM/oA
Pw8CP/81pldvIPFeZvF03JNA4/21huBoElb7CzpUvgRKf92cmRNDwtoje3ya
cs7fcaI6KYnqjXEL5H4EVnjuMzhvIyE+P45NfAI6dbnh33gSlnl7wm0FBM5e
vZ5JJpDI1IysPkFZ0XRblLSThFCwlZylLJhoM3TvIhGw02Z2UEiAmNebyUok
wcGu3giS6u/9UrQmiUQE99qth5QfrxkbVyaTMLn4Mk/kT0AbN22oSaHut1qv
q6L8H39m8Bs=
     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz2s01AkYBnDJtub616jWZVyGMEaY+RtKtB5WMay07SZsQ0a51ZTctiQV
cmhZRdJpmt1oqba02WbG0ua6nWxFbrmk0oWhxKTjkLaTnf3wnuf8znOeDy9H
snfzTl0dHZ0g7f2fLU7lHTW7WLjW888nricFBvq2RfqJLGTEGs/OaB3x/Lfg
yBQWMpvnHjWto2C+RNFJP8RCV6JUGupFAX/+TnfsTyyMOZYqc30okLdO9ZnV
sJDALns47E/B/lDP4fxZFpoX+ybkbKHAOatfE3XUEBXjN4vL9lBwcrJULr22
DJQffr+l9ysFXgFbbHPvLEcoGb+mrZeCfR/KTEyHViA72v/UqcVUnGmRyGhL
jDDu/0Lj40oFLcNpTt/MGA2PhLFVEiqSgrKGowJNkBvhOd1ZTEVEUpjL6hRT
FI5IeexmKk7nCSTG+WzU2l+PTpygokV10myr0gxPd0Yn7DOiYW3fuxvl7eYQ
FgTGV3rT4CbqV8Y9s4AP/eO2jfE0GL7mVKw/Zgnpec2fP5bQILg0ECI24KDL
fP/AunoaREk9XVYXOQjoyU/f85IGa3VRlq2HFdJjhpI5NDoudN8/z79tBZUu
5VyOMx3m94KOjYdbwz2rZdGmEDq8PIP7q9TW2H2zOu/VATrC605pWJkrUe9a
sND/Cx2rn8nW3WLZoEKu3JzyNx31h63npXIbdK7+Umig1vYOmvT7LrYIS4pk
TlIYCA/2SBA02WKH4+W0FzwGvMxERb0iO7RVHnlWG8CAxdzZdJthO+ynOj24
uZuBSpG0JyOBC73PDRt1ChiwuZT97ugie8iD2zx2VDMQe/17v9ul9ngeyE6v
bmcgWKCgEJY8WB84xBZPMCBo2FS8RMVD/Ok6sQmNibpWaZ6ejwO2fpxY2MRl
YnHy1wrcc0CTkya1xJcJf6e9Vbztq3A4IPZFj4QJFwlrienEKvjzW0euZjJh
VDHvUHfUEaWTmZlp55i4EB7VKGY6obe8yvhVLRNv/zqehzNOWP9GxszoZmr/
f/9Fl6Mz5ge4CdNTTKxkqZfF1Tkj39tllkchkKtL3x3C5aNjxbuBtTYEhjqP
jZcl8bElckYuBYHsoUbZ41o+JIWR7MwwAtw3puR7XQGaRgs6tqYQsHRfs7BC
JMCYpdCbXUhgPtx1rLdQAB3OxRqzSgIPsr77I35AgCNfqVc+biDwXu2iWGRO
wn7pBwdZH4F+Ha+UNRYkKt1DZXr9BFQmAcK9liS6FrI/26N18sbtisdWJKgx
G+5igMCUskBRa0fiiixnuXqQwGjOqEIqILHtUMgN5ycEuq3KlIO+JPKn7xKN
LwnUeFakGmwgcfpJz6DdCIETIdWufn4k/ALrfz6hddDxVqVCpN1f4BhLRgm0
TWuURRtJLOjHdeqNEWho8letDyUxneMtEr0mIH/0bVpGGAlOori5RuuMmQi3
G+EklioihCYTBNy5qSpLMYlid0PahNaKonLVv1EkGp5+c7BgkkDJ5atpZDQJ
c2HV3Rmtk1pr3eJ3kHC883KZeIoAf65d1RdDIq+MfdZRQ4BYOpjGiCPh2W70
sFTrKd6Im288iWSBDu2T1vd9NbPpCSRc0eMR85bAlYgPqppdJA6mFsd2aP0f
Un4EMw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->NCache[{
     Log[100], 1.1555195077431666`}, {4.605170185988092, 1.1555195077431666`}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {2.995732273553991, 
       FormBox["20", TraditionalForm]}, {5.298317366548036, 
       FormBox["200", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["30", TraditionalForm]}, {5.703782474656201, 
       FormBox["300", TraditionalForm]}, {2.70805020110221, 
       FormBox["15", TraditionalForm]}, {5.0106352940962555`, 
       FormBox["150", TraditionalForm]}, {4.248495242049359, 
       FormBox["70", TraditionalForm]}, {6.551080335043404, 
       FormBox["700", TraditionalForm]}, {2.3978952727983707`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.700480365792417, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.867534450455582, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.941642422609304, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.075173815233827, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.135798437050262, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.19295685089021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.247024072160486, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm]}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm]}, {2.70805020110221, 
       FormBox["\"\"", TraditionalForm]}, {5.0106352940962555`, 
       FormBox["\"\"", TraditionalForm]}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm]}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm]}, {2.3978952727983707`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.700480365792417, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.867534450455582, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.941642422609304, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.075173815233827, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.135798437050262, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.19295685089021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.247024072160486, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.914122846632385`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.201804919084164`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.60727002719233, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.761420707019587`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.89495209964411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.012735135300492`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.811242831518264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.216707939626428`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.50439001207821, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.72753356339242, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.909855120186375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.064005800013632`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.197537192638155`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.31532022829454, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {18.420680743952367`, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.914122846632385`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.201804919084164`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.60727002719233, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.761420707019587`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.89495209964411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.012735135300492`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.811242831518264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.216707939626428`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.50439001207821, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.72753356339242, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.909855120186375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.064005800013632`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.197537192638155`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.31532022829454, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->NCache[{{
      Log[100], 
      Log[100000000]}, {1.1555195077431666`, 3.992581185490676}}, {{
    4.605170185988092, 18.420680743952367`}, {1.1555195077431666`, 
    3.992581185490676}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {18.420680743952367`, 
      FormBox[
       TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.508657738524219`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.914122846632385`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.201804919084164`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.424948470398375`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.60727002719233, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.761420707019587`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.89495209964411, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.012735135300492`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.811242831518264`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {17.216707939626428`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {17.50439001207821, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {17.72753356339242, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {17.909855120186375`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {18.064005800013632`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {18.197537192638155`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {18.31532022829454, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {3.4011973816621555`, 
      FormBox["30", TraditionalForm]}, {5.703782474656201, 
      FormBox["300", TraditionalForm]}, {2.70805020110221, 
      FormBox["15", TraditionalForm]}, {5.0106352940962555`, 
      FormBox["150", TraditionalForm]}, {4.248495242049359, 
      FormBox["70", TraditionalForm]}, {6.551080335043404, 
      FormBox["700", TraditionalForm]}, {2.3978952727983707`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.4849066497880004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.5649493574615367`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.6390573296152584`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.772588722239781, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.833213344056216, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.8903717578961645`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.9444389791664403`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.700480365792417, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.787491742782046, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.867534450455582, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.941642422609304, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.075173815233827, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.135798437050262, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.19295685089021, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.247024072160486, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.5756278542793407`*^9, 3.586661071590429*^9, 
  3.588414912085755*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"texts", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Text", "[", 
      RowBox[{"DD", ",", 
       RowBox[{"Log", "[", 
        RowBox[{"{", 
         RowBox[{"60", ",", 
          RowBox[{"\[CapitalLambda]", "[", 
           RowBox[{
            SuperscriptBox["10", "2"], ",", "DD"}], "]"}]}], "}"}], "]"}]}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"DD", ",", 
       RowBox[{"-", "5"}], ",", "20", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4832494020158253`*^9, 3.4832494614582253`*^9}, {
  3.4832494914919434`*^9, 3.4832494946241226`*^9}, {3.4832495257299013`*^9, 
  3.4832495880554667`*^9}, {3.483249619663274*^9, 3.4832496695541277`*^9}, {
  3.483671446834*^9, 3.483671448833*^9}, {3.4842071104136*^9, 
  3.4842071207446003`*^9}, {3.4842071946066*^9, 3.4842071949365997`*^9}, {
  3.4842072323656*^9, 3.4842072391596003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"fig1", ",", "fig2", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["Re", "\[Delta]"], ",", "\[CapitalLambda]"}], "}"}]}], 
    ",", 
    RowBox[{"Epilog", "\[Rule]", "texts"}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{
  "Figure", "[", "\"\<turbulence-frictioncoefficient\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4832474351493273`*^9, 3.4832474394655743`*^9}, {
   3.4832475710671015`*^9, 3.483247574320287*^9}, {3.483247866517*^9, 
   3.483247867412051*^9}, 3.483248035251651*^9, {3.4832482601145124`*^9, 
   3.483248279797638*^9}, {3.4832483131595464`*^9, 3.4832483448273573`*^9}, {
   3.4832493605314527`*^9, 3.483249369808983*^9}, {3.483671492546*^9, 
   3.483671494494*^9}, {3.501505925559619*^9, 3.5015059320619907`*^9}, 
   3.50544973170039*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5756278544383636`*^9, 3.5866610717484465`*^9, 
  3.5884149122587366`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwVz3s01HkABfDxGvP4KU0oY72fUcN8lUF2f1eHNFrZVBPT8dzKYzDldbZJ
WaKj2pKkF7O7aksvWjXG0SpFs3FSqSwpm2pjpRDHhlrs7B/33PP5555zbePk
YVt0GQxGiDb/d5Og4kGNjIegt/sKNQPTtDHLqYi1jQff88wNSUPTdNSri6HR
GTyctZ5ymDM2TU+VqNqpXTwYapTtYZ+naY+pu4/jD/Hg3pIe0240Qyubhzst
a3goDQuuLicz9Hfhfr37PvIQ7ftZmr1zhnbP6xqJzZ2PCzOioCTOLF08VKpM
qTZBc/XhWBafATp4g9Peu6bwzzGIH1cysP3Tcb7FczMsihx/7WOugxNNcWVc
5kK0Lmn7/uoJHXCzBRMsS3Pcc5kYpTm6SAvJ641dzQevJTj1RY4uotIiPEUZ
Fig5Qjz8h3VxrFAYZ77vC2yK4/L01uqhSV1subHWEju8neWddXrw7Ry7VnHf
CnOLTH34JvrwEnfVJry0xocBWWqwTB/zB21PBxbYYKCg9eKO3/UhPP9UEmls
iyaRgcWhhQYQpz15ZFdpi97oUz2ZqQaw7y/Kc1puB5Fl24rXjQY487jtZw+N
HbZ4jZ+LYTNhdS+kYEBqD/+f9M4clTBB+4V2neu3x1rF5fakciak9UdHeLsd
QIq3GTzoY0L0suzLGzxHjNr0aS65GeJ6jv1UitIRV5xWVjJkhhC5jSjaPJ0Q
8YvSs6nKENLQ5UnCW06ofbMxOm7QELSluKhD7AzGOu+UEAcWrCdOKRx7nTH5
j+ZKfiwLZ8UpT7KTXBD1Sn6HnGTB8fyesVydRXDe48vkdrAQ/+umIE3pIviK
QkSRFBuhQhV7ro0rsqreci/QbAhvfnOEqXbFXxYR1owsNuqbUwr1V7hhHiM1
u7iSDb30r1W454ZoaXGDVRcbqwTyc64xi5H/7Ma/J9kceMbxmBbvFqNnZfPH
GhEHC09PudXnLkF6YMPq8gQOzkhjGyPnCDC6t9VEUsrBh4b9hTghQPudCdv1
tzja/5MLHi1xxztBgCNnmAMHXr9JQr07zH6jLV8s4GKvLpUscfGAuaNp19oA
Lp63FwwcT/MAXy6osZBzsed5Y1lPnQd2tcxXi49x4fLegkzqCvFOMhQ+28iF
jY/3rJlYiPcvamR+/VxMSZf93XFQCMHtV4lmXAoP89ZfTXwqRNmg7+VYQmGy
31OlY0WgyJ8OTJZQ6GLQGd7WBFt7C//kbqSg5gcvldsQVF7fnnhJ6/Q1Maoe
O4LR3XFRg+EUhmt/UNU5E4QZDDfEb6LQl9+nShESlDnw18TEUHhsd7y2O4DA
iGnVtiqJQo3f6UzjlQRnV+eM9Wt9WFK1LCiIgP/HdqMCGYWQ/c21KjHBsOk8
29vJFFpGR2qL1hAkD21u9JZTuHlrlTownMCnQ9PtmEFB+WxdVnYEwY/CT+Jm
rbPHo7yuSQnKvbqrYzIp+Lhkqm0iCXQLlJKyLAqqogr151gCyl9mZbyDQsmF
y1nkW4LZQZulVVqnNdd5JW4myH148KtgBQWPifvqzq3a/QMlwvydFObO684y
SiBwyHfn22Zr/7u+8QpIJJgzVThxQ+u2gJGPiiQCQ0VFq3QXhUtRn9Q1MoKE
Y4rDE1r/BzMt+YE=
      "]]}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz2s0lAkAxvFxGzPeVDusDYsxrhFm3glZte+TQ4wabCLGSUata1YxbGul
KMKqoZJip1xSardOMjPSlsJ2OQebaCkpXTZ0nUwWo4u1H57zP7+Pj3Vs6trv
tWk0mnBu/7fdteavxmQWbkXO6GnvUFMLGfZSxlYWTI6MdCfvUVPRT84Eb5Sw
EHp067G+X9SU5qC8Z94OFjzXfIySVaopruZmb/x+Fubv84kyvaimZB1v+y0a
WYjIbPvYpFZT2yOWDxdNsvDkfUjE9rj3lFvegEqcawSv1pid4oAJquxNuSzl
nDE0FfFuN0wnKSowzL7g5peIu+L1Z8T5KWrbTIWZ+QMTRLbEFdIdNNSR9tgq
gr4IoU0H5Ib1MxSR7TrFsDCFjir9UePEBypNmDcsXm2GOmWgpHn1Jyo6LZLv
KTHHs4aLi8VFn6nDhbxY06KvUZyjcLGqnaXalWUW6xUWaK+ufpgrpuGbfnVT
TbcluK/++PX0Exo8BAOKhMdW2DgbO1YQqQWjl9a1fvlsPPt0+dXxv7XAa7gX
vmGhNYpLN5mt9NWGIK3vDueUNSqHuAKNUhs2I9I8e28OllrX0y5xdFDX21XN
vc6BocXzGrfdOrDsFOaPiWzw+e7H7uZRHVDLgwdOjthAgocz0yt1IWo5pGLl
2GLe7XNWnGpdeD6uWnGFZYfDx89k2Gp0cWmnjSZFZofRuJ+jgwR68HRWZXXx
7XG88HVggEwPomDvJN41e9xRxhsteqEHykIgvStwQHJnnZTNo8NqqjLLbtgB
9UKdS4PZdNQLUvqykxxx0XloLKaNDruG3epcrcUg9/6wfitTH/Hno/yvly+G
7YK9oawgfQTz5MwFbCfEF5TqCUv0wWsNOUBXOoHV2On4rlsfLR0phbo+zji4
jV8nZTKgk75Gjk5nrDbazy/2YSDANfWkU8wS2MxererKYYAfy6Kbv1qCsGz9
yGMKBhbVapxbcl1wIifE+7CKgTqR+OqG+a4IqtkVmmDLxLvLxYU44ooV7Ws4
euuZc/+nv7rj4gblC4/O0yVM2LJGjBNa3NDiRaQcvcJEgfa8LeGOXORPDaan
jzPxoCd/rCKNC76w57OHjQF2P7haNdTMheunVL+GEAM4vjYnp7V58G0zfTS6
ywBsr2WzJgIeqiVdcfSzBtCI3Efv7uPhxNGngm0DBridt+5C4j0e0gMzhKW6
BKZH+HItSxLj88sPDboQGKBRkmVWJLg+pe5lrgSUZoFLU9kkHl3PuOnvRiA9
KEY+xCExHMxslXMJvFWUyJsdSNwOKJ/cxyfwfM9zeQqPxKG+sIoVXgR6ORWK
+74k3Ht0G8p8CTQur81YuIrERounSav8CJSGn3X39yfh4v2v5Yc5C4s7FHIB
CdnSG6LN/gRujasU0iASYuN11h6BBFqvBSj9IkhQP9q97g8mIBsMzcyOJPGm
MqOjOIRA9kS0R5OIxI5cdsm33xHwcsxQsjeQSGyTjtevJSCX1ig/iEkEmxgb
SsIIHDz9eya5icSB6KxUh3ACaR3NHombSfx0XtgxOGfuVLeyP45ES7EvtTKC
wIIv7mcaJpAoOrYlfmLOb53+8fBNJPGy1yD3VCSBLl/VZFYSiaAt1iUiEYHf
omeUjckk6s5dKDSMIvAfmUMIyA==
      "]]}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz3tUkwUYBnAYGwy2L+HzhuCAMUDkun0kYuDhUUGcxm0gCROUq1wcyFQg
ROSqoCGYchMJwZOhmYVuIwwRXIodJXUYqKzEDAJLLh5iTENbf7znPb/zvH+8
DzcuQ5RI09PTC9TN//umW/PPbWkkcuq9uH4KGkyZDpXMPSSmpQ3ez9tpiHl+
MXjHPhL9zh5kfgcN2pOyB+yDJFppITOKThr42l7VruMkmhiJx+2VNDQqJwY4
bSRWhpo5z96nIWebz7PyWRKd2RUVieM0uBcNTsYWLkSIumVpoaUBTryqbpRc
XoTcoCdDfSUG8N281eFw72KMzU1pvF8YIPNNrYXl0BJsmNeuTfGho+5mXAPL
0BydZ4ZYtfV0sPLcNEzOMhy5Em8neUWHNLDoWewWC7xXlWSb+zMQI430WL3P
EpUhYq1dHQM1ZYK4ZeXLEV5t/G7hCwZuKk5wPpFzQA/rG/lBYIiPBl5fbe6z
gnTd0m/VOYbwFA7Kk4etEdp3taei0xALX3Jb/EttkD5fc2zQwAiC1scR0aZc
1IfMW2f6GUEo7X9o+xUX/cPi9LwyI/BGK4scvG1RsIiuH/+TEc6p7p3l37JF
ZlbzYCCdCau7gaVjUTxsRNen5euZ8PUJHjw/ysP0kQ2N3ANMRHWcmiTz7VD/
u4HbmIKJ1cMNa6+T9tiu5A0vm2Li2iGeVtJoj47b0wnudsZY7TyZe8/DATvl
NdHhYmNEBXunCrodcCGmV9NUYQxfjrDykXAFGskM/V+vG8NaczrX/tkKRFTp
cdjTxvhSKOnPS3XE3fGuoF5rE9i3Fr8u1F8JszSr09tCTbDrO3HAreqVeCAS
nP2nwATBApnxAhsn/Fu83SXnkgkEXSGfGyqcsFWp6pE/NUGHUlJGX++M8Bz7
cgaDBYO9H8twV2ft/e5rrixscss477TTBZk890GzSBY84khDy79c0JW4bri7
gAXzFq1zR6Er3IbPmL69yMK5qNgb0R+44Q3hs6ftIQtTnUfLUOeGhkjy7btZ
lq7/3NKHru7IJHw4PVZs2JGji5I73FEVadHjtYGNwzT27ghHPlyyORrTVDaG
HpSO1Ur5ODqVsvhYJRvFQzca1O18pHHj+ifa2HD825KaowkQtjvpyBcDbNis
8Xq/RChA6biCL5pjQxu16s9HFQIkBOfXqM0J3C8Kv5LyWIDF4U2jTd4E5kY9
ZPpWFM4FJLWeEBMY1PPd52VNITx5ytt6OwGFxeYPM2woFItw+5LOe4N2ytS2
FHa4et7ojSYwIf9M1r6CwkTN6fXzOwiMlIzIJALdfdjmqqQEAirbWvkTPwrP
GeJgSkKgzadlv+lGCrIm9fUunasivlkVEEDh4MtNvC3pBAKPKuUyIYVW7qgq
PoPAnelJeWUQhc5p0a1TmQS6ujcp/LdR4PnNaGb2E2h8GpaVF0kBXhd+Kcgi
kDcT43k1ioK+nvgiO5vAGsf9CptoCqpjHV52OQRklc2Kt7G6f8micVEugZMX
LmVR8bqct/bQbzpLle2eKQkU7jDesVIPEOBr+hQDSRS+b682KcwjsMDsSRaR
TKHux/Q89kFdf6c/PP1SKIQuF43U6nzPb3I2N5XCIzX8efkEvo55o2hLo/CU
53Pmss7/AaXc/oY=
      "]]}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz2lM0wcYBnBEe9DjrxaHIFcpp1y2/wqiVnnUIhQ5zIQOQcqhE4sUXFUO
xY3CUHBKpwiSEaLIFPCaSFtBRJzMIHiBOupBgjpAM6RFtwHVies+vHnyy5Pn
w+uSmvXl15YWFhaR5vs/b/rX3m/azkGVfODomIKCOXQPNX0HBzac2CS3LApk
L89GJ+3iwJi6ambCDgpM5Zpe1j4OWvTVfV1KCvimrodpZRzkRaaVnsihoKbT
0O/YxMFQT5ciVEVBbpxosHSCg6gxVUTeMQoWFeqNKSprqFrcMtOuUnBkrKJG
cXEe1r7cWlDDoCI4PNZjf9cXGO/m9jhvoOKbD8cX2D+3wUdn4T67KiqqbqZW
M6m26LgcZ3XpBRXMfP9JuqMdPLevLFLyaFBGFg6mrFuAgpjpE2fTaJApNwqX
7LJH20lVUWMjDZUlglS7Ugd4p2VWq4dpuKk74viV1hHiPGN9jxsdy/rfN9fe
c0LZQfGmMBkdgRK9dtsLZzBGVgyIK+iw/tPlVEgxF+JkfUj2AzoEDU+kiXNc
wBC5OypnWUGifNTHq3dBd8y5zEKRFVxH1IUey3lY3bT3wFKlFeoe3j3Jv8XD
Hwntdfw6KzjdiSx+E+8K6/MBLk56KwSLovVnRlyR2Nb7tpjKQHzrMSPnWzcc
rYzq6QpiYMmL6hXtHHe0tB2qYMoZuPqdq0lR446V8p477hXm3se4567QA2TS
7cfTneZ99PJ0wQ0PjG61WzNgYCDYUaJ+LPHE3rrwifm2TDhP/rTHfdATTovl
jqY1TJyWKB7lp3uhNCk3wiODCfeGoveqGQsRWdI6/rKSibRLCaG3KhbCvqx3
FfMGE9ECjdVsrjcc3kgtfh1mQnB9/VGqzhuZ0gaagc1Ca6eiZNZqH8A3eKiL
ZGHmzggN7vhgrq9b9nopC2H+WWe8k30x/m/Iq2X5LAhTOVT7UV80Psq6TTnB
gu0pk0+ryg8fOBPNzr+xUBef0pFI+KPF8H5ewAgL49cOlqDKH+tyaeMONLb5
/6n5fX6LYNovLIc3G26ckXnbWhdh8eg17g/hbOy3ZGVIvfigrBhts1Cw8by3
+M1xJR+TOoeM6DI2ip53VA9c4cPYN02MnWfD6609OWUpwOrDdk4/32ODuzTo
s41EgJh30Tuuj7Jhig94/fiwAP8EFZQ/oxN4UBhzWf5EgKLyX37/7ElgakSo
meFEYlAbVNMoJqC3CN4V5Eyi7kJlu1cIAd2C8MVZXBJ6UW5/vdk7o5I1AzwS
Terud6fXEjBoD2mueJKwsWy/XxtGYPj7YY1CQKIv5wyvKoLAQ95x7VMxiQjr
nKDvYgg0iU7tnrOWxFC1If2T2T9KLwSEhpJwej2rcm8sgciDnVqNhESKy9z+
HCmB2++MWnUUid0nOz5lxRG4fiNMFxJH4i8//lvZJgI1zzZk528kMT9hqmHA
7Py/ZYHN8ST8zmbI4hMJLPXareMmkuDNSGyOlRHQqGt1H1NI2D7YSYlIJlDe
eD6b3EyiUaI50G22svNKoHwLibySesvQFAL8yXu6/q0kEmobX61KJTB77tNs
9jYScbyroR1mG7yHAsVyEunagtOizQTuio0Te9JJXPSb/thq9jnZB13TdhLO
MuG6JVsI/Ae9B/lD
      "]]}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz2lQUwcUBWBAJIEsDyMiW4CA7BCTh8YFWk5VwCgRRYoQFCVYZUvRgAgR
pOAWXBpxabDICDoFNC4sSSxU0YrUDoiyWJBCBzoqpYpgtWUrjH39cefON+fe
H4cnS4v4wsTIyEhCzf/7Ab/8SU0KBwSqeZYqGizp7mr6Hg6GEzwdaIU0xP1+
LXx7BgczC71nZilPndW1M3M5cNk7kPrmBA2CqUedu7/mYHtkxbxmNQ2lTaPd
3BoOVOGr5ekaGrKiAwcKxzlQvogrulNBw+KCnrH4/PmImUy9YdxMQ9Hb86Xy
m1ZIy7U6GTaXjqB1n7sffbQAvDyfsMYgOvZOa+zs+6zx0jTr0aX9dBQ/kJUw
zGywkqi70FBLByOHP0Hn2qK5tatdNUyHQlIwEL/eDutj2cVpPHPEKWL8l2XY
Y/OBKrzbYo5vVEKZbaEDbmgYtaWF5nhgKOJu0XMhOHY4P7jRHCu739eVtznC
+njSyqhRc4jEPfrEQSe0D2q12Q4WmP+adzn4iDNefDBlHZBYQFj1PGqbJQ/9
H3piPlNaQKzo6nCp5CEmTDTTctUCrkPqAvcAF8SZvJ7O7bHAlc7HZYJmFxSu
0ipDjRlwbJUcGZa6YtXDsoAGPwaCAsN7KoZcIbo2LzI1igFp/bkxzsFFSOGM
JVTnM7BssOSTuxw3mFUmB8dqGWjIc52Sl7ohfqhfc6yDyn3GlI/93ZFtkvgV
f5r6Dw9IFt53R1lJkW2WExNBXLH6mdgD17OffJqymgmniW+VbgMeOF2bu6Up
iYnvxPKunGRP9P3obvrhJBNuVYfe5xt7oWHTxXMZtUzsro4NbT7vBcc//5lz
tZuJcKHOnHD2Rs7ZveGvJpgQNm48Y2bwxlzOyPfb7Vmob5KrTFf5oNi0JWU6
gIU56WE6tPqgxW/nTFYsC2v5aRXeO3xB2tN3ueay4C/jmNm/8cWziZBbCy6y
YHN5yqc+3w+9NwvNF91l4Yo0/t42Nh95Pq9p6j4W3t05rkIxH1J627nJSRbV
f3Jhh99iONYEN8ht2FjEGbJKrF+Myi+l++OXsnHUhJka5SlASEilNiKSjb72
I8MahQAs2QFViIKNQ333SvpvC6CWKC88P8WG54g9OWkihEOE/US0lg3nFcs/
WouF+OjhVXbsJzampEv/eHZKiNGuj2TvIBtPCyJrk54LsaS82owxy8bkkL/O
2JHEpre+nXMXEugxCspY7kSi9WY0N5uywW7dkjRnEgc/jZSNUE7fsEPX70Ji
zo67vZ02BEb1J3W3PUgEtiQdvGRH4NXhVzq5kITotx8uLXMk0Omi0feuIaHo
fhiS4EagJvDyPssQEuv7vdp+oXw66sbS0FASdQHpkrXuBCTHm/Q6MQnjM/oA
Pw8CP/81pldvIPFeZvF03JNA4/21huBoElb7CzpUvgRKf92cmRNDwtoje3ya
cs7fcaI6KYnqjXEL5H4EVnjuMzhvIyE+P45NfAI6dbnh33gSlnl7wm0FBM5e
vZ5JJpDI1IysPkFZ0XRblLSThFCwlZylLJhoM3TvIhGw02Z2UEiAmNebyUok
wcGu3giS6u/9UrQmiUQE99qth5QfrxkbVyaTMLn4Mk/kT0AbN22oSaHut1qv
q6L8H39m8Bs=
      "]]}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz2s01AkYBnDJtub616jWZVyGMEaY+RtKtB5WMay07SZsQ0a51ZTctiQV
cmhZRdJpmt1oqba02WbG0ua6nWxFbrmk0oWhxKTjkLaTnf3wnuf8znOeDy9H
snfzTl0dHZ0g7f2fLU7lHTW7WLjW888nricFBvq2RfqJLGTEGs/OaB3x/Lfg
yBQWMpvnHjWto2C+RNFJP8RCV6JUGupFAX/+TnfsTyyMOZYqc30okLdO9ZnV
sJDALns47E/B/lDP4fxZFpoX+ybkbKHAOatfE3XUEBXjN4vL9lBwcrJULr22
DJQffr+l9ysFXgFbbHPvLEcoGb+mrZeCfR/KTEyHViA72v/UqcVUnGmRyGhL
jDDu/0Lj40oFLcNpTt/MGA2PhLFVEiqSgrKGowJNkBvhOd1ZTEVEUpjL6hRT
FI5IeexmKk7nCSTG+WzU2l+PTpygokV10myr0gxPd0Yn7DOiYW3fuxvl7eYQ
FgTGV3rT4CbqV8Y9s4AP/eO2jfE0GL7mVKw/Zgnpec2fP5bQILg0ECI24KDL
fP/AunoaREk9XVYXOQjoyU/f85IGa3VRlq2HFdJjhpI5NDoudN8/z79tBZUu
5VyOMx3m94KOjYdbwz2rZdGmEDq8PIP7q9TW2H2zOu/VATrC605pWJkrUe9a
sND/Cx2rn8nW3WLZoEKu3JzyNx31h63npXIbdK7+Umig1vYOmvT7LrYIS4pk
TlIYCA/2SBA02WKH4+W0FzwGvMxERb0iO7RVHnlWG8CAxdzZdJthO+ynOj24
uZuBSpG0JyOBC73PDRt1ChiwuZT97ugie8iD2zx2VDMQe/17v9ul9ngeyE6v
bmcgWKCgEJY8WB84xBZPMCBo2FS8RMVD/Ok6sQmNibpWaZ6ejwO2fpxY2MRl
YnHy1wrcc0CTkya1xJcJf6e9Vbztq3A4IPZFj4QJFwlrienEKvjzW0euZjJh
VDHvUHfUEaWTmZlp55i4EB7VKGY6obe8yvhVLRNv/zqehzNOWP9GxszoZmr/
f/9Fl6Mz5ge4CdNTTKxkqZfF1Tkj39tllkchkKtL3x3C5aNjxbuBtTYEhjqP
jZcl8bElckYuBYHsoUbZ41o+JIWR7MwwAtw3puR7XQGaRgs6tqYQsHRfs7BC
JMCYpdCbXUhgPtx1rLdQAB3OxRqzSgIPsr77I35AgCNfqVc+biDwXu2iWGRO
wn7pBwdZH4F+Ha+UNRYkKt1DZXr9BFQmAcK9liS6FrI/26N18sbtisdWJKgx
G+5igMCUskBRa0fiiixnuXqQwGjOqEIqILHtUMgN5ycEuq3KlIO+JPKn7xKN
LwnUeFakGmwgcfpJz6DdCIETIdWufn4k/ALrfz6hddDxVqVCpN1f4BhLRgm0
TWuURRtJLOjHdeqNEWho8letDyUxneMtEr0mIH/0bVpGGAlOori5RuuMmQi3
G+EklioihCYTBNy5qSpLMYlid0PahNaKonLVv1EkGp5+c7BgkkDJ5atpZDQJ
c2HV3Rmtk1pr3eJ3kHC883KZeIoAf65d1RdDIq+MfdZRQ4BYOpjGiCPh2W70
sFTrKd6Im288iWSBDu2T1vd9NbPpCSRc0eMR85bAlYgPqppdJA6mFsd2aP0f
Un4EMw==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     SubscriptBox["Re", "\[Delta]"], TraditionalForm], 
    FormBox["\[CapitalLambda]", TraditionalForm]},
  AxesOrigin->{3.4011973816621555`, 0.6931471805599453},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  Epilog->{
    InsetBox[
     FormBox[
      RowBox[{"-", "5"}], TraditionalForm], 
     NCache[{
       Log[60], 1.1555193872492895`}, {4.0943445622221, 
      1.1555193872492895`}]], 
    InsetBox[
     FormBox["0", TraditionalForm], 
     NCache[{
       Log[60], 1.8693289320152804`}, {4.0943445622221, 
      1.8693289320152804`}]], 
    InsetBox[
     FormBox["5", TraditionalForm], 
     NCache[{
       Log[60], 2.3389970822763546`}, {4.0943445622221, 
      2.3389970822763546`}]], 
    InsetBox[
     FormBox["10", TraditionalForm], 
     NCache[{
       Log[60], 2.678675752619533}, {4.0943445622221, 2.678675752619533}]], 
    InsetBox[
     FormBox["15", TraditionalForm], 
     NCache[{
       Log[60], 2.9414369872242356`}, {4.0943445622221, 
      2.9414369872242356`}]], 
    InsetBox[
     FormBox["20", TraditionalForm], 
     NCache[{
       Log[60], 3.15437504137515}, {4.0943445622221, 3.15437504137515}]]},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {0.6931471805599453, 
       FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {2.995732273553991, 
       FormBox["20", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {5.298317366548036, 
       FormBox["200", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{3.4011973816621555`, 18.420680743952367`}, {0.6931471805599453,
    4.007333185232471}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{{{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {4.787491742782046, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.438079308923196, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.8289456176102075`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.1092475827643655`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.327936783729195, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.507277712385012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.659293919683638, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.7912214627261855`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.392661928770137, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.043249494911286`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.4341158035983, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.714417768752456`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.933106969717286`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.112447898373103`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.26446410567173, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.396391648714276`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.997832114758229`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.648419680899378`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.03928598958639, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.319587954740548`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.538277155705378`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.717618084361195`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.86963429165982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.00156183470237, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{0., 
      FormBox["1", TraditionalForm]}, {0.6931471805599453, 
      FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.575627854495368*^9, 3.58666107180441*^9, 
  3.5884149123087835`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 31.5 Application: Turbulent channel flow (p. 581)\
\>", "Title",
 CellChangeTimes->{{3.483758979964306*^9, 3.4837589816734037`*^9}, {
  3.5030312067866*^9, 3.5030312177446003`*^9}, {3.588416147249674*^9, 
  3.5884161507771516`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Figure 31.6 Mean velocity profile (p. 581)\
\>", "Section",
 CellChangeTimes->{{3.5030314211205997`*^9, 3.5030314249435997`*^9}, {
  3.5884162245534945`*^9, 3.588416238729255*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(9\\)\[NoBreak] symbols\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{3.5756278689801865`*^9, 3.586661071991441*^9, 
  3.5884149124908066`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data from Moser, Kim, and Mansour", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<data/turbulence.mkm.m\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.482567270790024*^9, 3.482567281131615*^9}, {
   3.4827539038255997`*^9, 3.4827539171836*^9}, {3.4830776836990643`*^9, 
   3.4830776899984245`*^9}, 3.4837590140992584`*^9, {3.505371153021758*^9, 
   3.505371158278059*^9}, {3.505371490374054*^9, 3.505371490525062*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Names", "[", "\"\<`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4837609105737305`*^9, 3.483760924134506*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"profiles\"\>", ",", "\<\"Rey0s\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.575627869075202*^9, 3.586661072023502*^9, 
  3.5884149125248027`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Global data", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData["Rey0s"], "Input",
 CellChangeTimes->{{3.482640075636177*^9, 3.482640078285329*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"178.12`", ",", "392.24`", ",", "587.19`"}], "}"}]], "Output",
 CellChangeTimes->{3.5756278691002555`*^9, 3.5866610720494905`*^9, 
  3.588414912544822*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ka", "=", 
  RowBox[{"Rey0s", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.484021017698646*^9, 3.48402101793666*^9}}],

Cell[BoxData["587.19`"], "Output",
 CellChangeTimes->{3.575627869121228*^9, 3.5866610720684843`*^9, 
  3.588414912563815*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d", "=", 
   RowBox[{"2", "a"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u0", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]", "=", "a"}], ";"}]}], "Input",
 CellChangeTimes->{{3.48256881153815*^9, 3.482568811764162*^9}, {
  3.483761932613188*^9, 3.483761947070015*^9}, {3.484020969422885*^9, 
  3.4840209787434177`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Delta]0", "=", 
  RowBox[{
   FractionBox["\[Delta]", "Ka"], "//", "N"}]}]], "Input",
 CellChangeTimes->{
  3.483761363780653*^9, {3.4840210251800737`*^9, 3.484021025448089*^9}}],

Cell[BoxData["0.0017030262776954648`"], "Output",
 CellChangeTimes->{3.575627869152256*^9, 3.5866610720924635`*^9, 
  3.5884149125868077`*^9}]
}, Open  ]],

Cell["Universal function", "Text",
 CellChangeTimes->{{3.483763098727886*^9, 3.4837631010420184`*^9}, {
  3.4837632075141087`*^9, 3.483763211584341*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sub", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "\[Rule]", "2.37"}], ",", 
     RowBox[{"B", "\[Rule]", "5.55"}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", "0.1062"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"1.277", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483762174517024*^9, 3.4837622361875515`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"flo", "[", "s_", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", "\[Pi]"}], "+", 
     RowBox[{"6", " ", 
      SqrtBox["3"], " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "s", " ", "\[Gamma]"}]}], 
        SqrtBox["3"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", 
        RowBox[{"s", " ", "\[Gamma]"}]}], "]"}]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", 
        RowBox[{"s", " ", "\[Gamma]"}], "+", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         SuperscriptBox["\[Gamma]", "2"]}]}], "]"}]}]}], 
    RowBox[{"18", " ", "\[Gamma]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fhi", "[", "s_", "]"}], "=", 
   RowBox[{
    FractionBox["A", "4"], 
    RowBox[{"Log", "[", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Beta]", " "}], "A"], 
       SuperscriptBox["s", "4"]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "s_", "]"}], "=", 
   RowBox[{
    RowBox[{"flo", "[", "s", "]"}], "+", 
    RowBox[{"fhi", "[", "s", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4831527699455194`*^9, 3.4831528848560925`*^9}, {
   3.483153810065011*^9, 3.4831538126601596`*^9}, 3.4831542710383773`*^9, {
   3.4831601368408823`*^9, 3.4831601377619348`*^9}, {3.483160191503009*^9, 
   3.483160191894031*^9}, 3.4831620338243837`*^9, {3.4837057666310916`*^9, 
   3.4837057844981136`*^9}, {3.483706161017649*^9, 3.4837061633607836`*^9}, {
   3.4837632211568885`*^9, 3.4837632263331847`*^9}, 3.484023225916949*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "y_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      FractionBox[
       RowBox[{"a", "-", "y"}], 
       RowBox[{"\[Delta]0", " "}]], "]"}], "+", 
     RowBox[{"f", "[", 
      FractionBox[
       RowBox[{"a", "+", "y"}], 
       RowBox[{"\[Delta]0", " "}]], "]"}], "-", 
     RowBox[{"f", "[", 
      FractionBox[
       RowBox[{"2", "a"}], 
       RowBox[{"\[Delta]0", " "}]], "]"}]}], "/.", "sub"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4841915969736*^9, 3.4841916353306*^9}, 
   3.4841916771535997`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "y_", "]"}], "=", 
   RowBox[{
    RowBox[{"f", "[", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{"\[Delta]0", " ", "2", "a"}]], "]"}], "/.", "sub"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4837637894633937`*^9, 3.4837638264735107`*^9}, {
   3.483763912080407*^9, 3.4837639132984767`*^9}, {3.484021045133215*^9, 
   3.484021053448691*^9}, {3.4840216245893583`*^9, 3.4840216407672834`*^9}, 
   3.484023227184021*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Profile data", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"profiles", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}], "/=", "Ka"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", 
   RowBox[{"1", "-", 
    RowBox[{"data", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.48401593758608*^9, 3.484015959807351*^9}, {
  3.484020335069602*^9, 3.4840203509395094`*^9}, {3.484021075368944*^9, 
  3.484021077874088*^9}, {3.484021579430775*^9, 3.4840215891793327`*^9}, {
  3.4840217957921505`*^9, 3.484021826343898*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"data", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", 
       RowBox[{"PointSize", "[", "Tiny", "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482642400907175*^9, 3.482642406251481*^9}, {
  3.484015001218523*^9, 3.4840150034806523`*^9}, {3.4840211142441683`*^9, 
  3.4840211770387597`*^9}, {3.4840214595249166`*^9, 3.484021460690984*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {GrayLevel[0], PointSize[Tiny], PointBox[CompressedData["
1:eJw1VQlUFFcWJYoeNhPZI0EGCILI1ku1KBx5L40mio4SiQaVTRYRJrI0myg6
YKKAooKAyGIgCYILIYhADDAYGGQTZJFV9gaatbtARLGVdqop5p9Tp+qfqv/e
ve/e90rP3f+g1yoZGZko6pLe6TUL/3/aqCxRd/9IwrqDs2q8OzlwfUT7eMwS
CVHyfaXpuTWw5KVK8sQkPGrLVgs+2wO2T4cH9d6QkB2wQ6HrNwGwxHkRybMk
TCUXKgXmzcFDL/vypkkSuM0nOsZ930G1jZW4YZiEg3tuRxpyP0FeeXfC1W4S
BgIvXxvlrcVK9bQB9eckfJbB/rXIUgn/jJqx9qwioaXj8IyFtTK6+uW5hReT
sPfIpW2dF9WwrLdn36FcEszjsxaZAk186fdE5V0KCT4y/lGyu77ACiPnQs9o
EpoaqRWng6cfLO1IDSFBRQ1q+jp0UV6cVXzTnYRW/d535+30MTXJLtV1PwkB
z2PaBrK+xDVMr+q5bSR4Wg8euNplgDELNvX2+iQc/tSs8Da5CV3kDK0iFVbO
Txmi8sbzr07PiYAqRsCOBiPUiBzR4HaJ4NT4+3tzNzYjS1FOvbtMBCo//t3w
yy5j7FOIUeZmiuCEdAmMscdR/UxElAh+JnNr9oZtQeOFP/ZHu4tAFAEcF/EW
5Jq+fuTDFcGVH6iAgSY40ZWoqasngn9cnP728YAJOur0K+ZLhGB/NcVPxdYU
Ez42x6v2CqF2r2XsV1mmmHT2hxz7EiGsd9xeVPfGFNMeywyejBfC7uEzavnf
mOFQ38tGVx8hRGv0PH+baIYmVXn9zK+EMGnIlMvrM8O5IpWtAk0h+EsJ6Jnj
22sVtuHCGaDeah/1NMewUMktUeXKPtsc8xN06/Ykz8CHe3Nt/+SbY/qQQetl
7xkar44F2ngoFj3cNgNKq0yiNY5YYBvor66SmwGq2il+NywwKeNP+ydd03DL
T5rQAi+EP8u4d2cavhu5k14tw8Dbnc7jkbxpcLpetbBZm4HHZBQP7bOZpvlt
ZWBUy08OcvLTIGk/PWn4LQP3ntoQ8rhtClxK9yit+hcDzb/0GvBIn4JFByrg
TwycfbZhaa3HFMguC8zAczIBWgXGU2AnBVjCwEvco/+2JidBCrfnOQOPrhfw
Gx9NwuslKoGAgXYTuh+iwyZpfhIGFjeRTpusJmFZbg0mzti4lde9nwCpHdrM
mCiy5mnxyiegIlPLon8nE9fZss13RUxA81sK0DEm5nwfEyu2moANUkA8JjqF
xqX1LI5DRrVuAS+GieaZcJxfPE7n+5mJjQ5JhnOB40CJOXymiImcpMtTa8zG
YafUMPVMLB2w8Nw5LoCgkwnCiEEmKhaH9sVkCYByr2/5aybWq56p1DoigHOU
3UrlWXhQonOncL1gRS8WLr7i2QTXjkElRaeEzcLSuZCrrufGoIMqL3M3C2+J
jW4Es8ZovzixcOTKzdVdglGg3Oc2FsBC8d2cIEgbheVwF1l4fn+Q/cK+UVr/
VBZulIj47ZIRSPycIvw7C7dsNeJ/UjACX1j0G6ytpPCc/jTF0W2ExtvOwglu
4eMPn43Q+SdYmKa5Jr6hgg/LdnzPQvl5vSvyp/gQshyQjUndQqrifNo/umyM
+zr0yObaYbo/WWzkltWlHQgaXtGDjepWDQlZOsO0/ofZmP0kOc+9fgiW29+b
jb80bSR4QUM0/nA2HuP7D77SHqLrHctG2Y8fRFFXBqGoLrQiM42NjV/nn5Dp
G6D994CN6zPmNx03GQCu21iLfhkbzVcVVjiF98OmtVHJts/YWB0im2lV0wdn
pYK+ZOOZ+TUcrkrfyrxho9yFyOxRp16QHu99x8ZCrfv1BTkvwVjaEHIEdv7t
vdWV7IFlu2oSqBXY7mhp2QNZFD0DQwLbzTuq5s51w353qmMIApXEPsHX/tsl
VX+PEpdAt+bfe7+T66Ln3QECAx6UnYjb1wlh0gI5EyhJct6ec72Dnne+BObE
5FdOtrbT/RdKoO+l/I+HVdtBkxonDj8SaHfNeV7o8IKOd53AqYxOhTeJbbTf
0wnMLpZ0Gb1oBWl5THIJ1O6YrWtQboUcSq2CQgILJAn+KQda6P78D4GyLuKg
+xuawX05IYEGjZ72colNIKbsEfyCwPJvPIJ3KzbS3/cT2NKyMOh7oYGed+MU
P2/tRP/FOnhKtdPJOQLzZNf5jp2qpfUSE8goOZaXP/yUxr+ag0Xe90Vhh6qB
Uj+3RpGDwWbfZyTVVtH5VDnImF9t93B7Ja2XFgdb4mLPux16AndrqAGsx0Fk
K/q4WJbT/jHiYMHrIr6u5l+gR6VPMOPg5yUuTiNvimm+LA4G3GB4+bYXgrS8
CpYcjO+X7eN7/EHHt+Kg/c27wlmde/CMasf5HRyU8ZXK9ys975GDkWcjXUz1
Ulf0pPYPWyKKtWNX/g/U9ytrmR+1/x/1mM4/
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1.}, {0, 21.263}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.02, 0.02}, {0.42526, 0.42526}}]], "Output",
 CellChangeTimes->{3.5756278692672234`*^9, 3.5866610722315054`*^9, 
  3.588414912675832*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"F", "[", "y", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4840150115821157`*^9, 3.484015020211609*^9}, {
  3.484019801898106*^9, 3.484019804183237*^9}, {3.4840206533488064`*^9, 
  3.484020656752001*^9}, {3.4840210924289207`*^9, 3.484021093053956*^9}, {
  3.4840211303510895`*^9, 3.484021134298315*^9}, {3.484021189769488*^9, 
  3.4840211937257137`*^9}, {3.4840215996249304`*^9, 3.484021600176962*^9}, {
  3.484021838359585*^9, 3.484021839563654*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV1Xk01N0fB/AJaSS7srRo7MbMYJQ2fG5lrzyJSCRbkl8hlWSnVLZSjwdJ
UZZCdpIlW5YnSyFCspZ9Zr71FKLwu/64557XP/d83u97z7kUR49jZ7hIJNIs
Xqu7yZnJjpqp47pzMb7chryaiOegtOeQ1A5o3lC2YoCtmZyQVCSlB1m1l3+u
+usW+ZCriqagnJczsupDbT2Fj6QsIKbLqWnV8lFb01dkrGFKPT591X9MnOId
FO3gW52h/6qnb3TVO8Q5gFT4lUOrtnKef31fyhn+Dtkutur6g9Klb5JcQD/L
6IM+trqcTv5PmXPQQuJErjqJyz5TIfV/EBQqrLNq8mjoU0tFd/Cg5Y/rYZcP
d7a9sfAEx9+tt1ftedTZxDbuIvTOuMitekDt1sFoqcswQRE9cBA7NlmyRsHm
Ckielms8gG0ilKVdleQNSy8KDqz6Jad1JyFzDXjO6ivsxz5vZ1d4y8EXQv41
iUTYsu8IxvZUP3BTaJsC7Ds5ospmioGwpcwoRhdbf2ta2tTZIOD5sr9XBzuw
MVG41iIYYjmlkqveoUWLto4LgZZo6ev7sFM2/nUzQuoGcETLlnZh+7XF11uW
34DjXgl8q7YMG+aSswkDJ6+fAlrYG2YvBlUk3YRnDFnSDmyfrlgflkw4mAaZ
R6hhm0cNvHxVEw7ebZtOMrAZeoqzNxwiwPKcpSx99T6LSi9uTY2EyzYmSVRs
s78/uZkq3oHhDm4tBWzaIblM6aY74LP7+Vu51b65z0+Mn70Lk7f+PS6Lfbps
uaDaIgb8M/2tZLA3qsQwTsTdA0eHApIUdgi5SClcKhbGeGF6PTbV8N7tQs9Y
MFMI+kzG7gzzmOpvioX1BZMNvKvvh5uWzfD+B5iFuwK5sBuX0hhdnXGgXVh3
Y2EtzvsjbqdM1APgkvaeGsMu0bgSZ/TlAYTu3G/6BdvO03z+4t5EuCi5I2sY
O48tVFY/mQh3XscY9mMfm7yt7aafBHZ0Wcl27IQB34Mly4+hNyVc+BX2/i3W
aYPHk8HVs26iGHv65K615JxkGFra/rIAexvrmlMOPQW860x3Z2N7nNNSIH1O
AVGWa+cjbFHnvOfpu5/CUUPvUyHYJ6yf5H37ngZhtV1t+7GJfov1T6XTgbRM
6dTBvmlHPmN+MB2G2gvf7cEucvKQfhmbDp0PH+drYAu664T57coAfudECQp2
Q2jfSd6AZ7CYs3xxmUcTMV+I8G4hZ0HbpLFVEfZbRoN9m3oWyNeXOuVi2xf4
VARaZ0F5kZNrJnb0yyHPkawsUOW/cjIZe7Impz/jSDbsUfUZicB+3G1coPH3
C1Ap/OBrj82/EmJruC0PyrjP963FTjhnZUczyAPhFDI/CVu+i2Yv4p4HP7io
Oxe5NZFuZo9T/+s8KNBd9OJgl2XGlZQy8uGMe3PsR2y2Oavy0Lt8cK2f90zH
Pv48vuWSQCEsSU6G62AnnQo97EIphCNtL1q0sEdFL7Sd2FkInu2cterYHgEH
3uucKoRttVNOstjhx9id63IK4Qe9uIEX+/WfA58eHi4CQ3OH7e+4NJGCGWfy
TWQxZD/TVbfClg4y3Hv2STHI3Jf8ZIotnJMSub60GHzGRPwMsBfJ5gyz0WIw
MXV4uhO7vab00uDuEnjQ4HpTDNtXPWT511gJ5I02pLat0UTvhMTFGagUfp4m
aezDvvpuDyT8LAPuedvA3ytMJMgoGXtLLgfxyKon37HTotWjfm8ph6jAI68n
sDsOK/XZ6ZdDwp/vnz9gq7aIX1KIK4eSeyZV2dhDTURG4a4KEFgcJZ/ENqxN
F2zzrYSjfePl+ctMJFEsMrhmTTXQiwZ8DZaY6OXowdb32nUQE1yl8u8CE9W5
PdpszaqHbupiReMsE80q6gjlXGiCpw6ZK9e/MxHXQrbwZoVmIMVHJv7FYiKt
FfuX5rmt8NejpJYv40zUemPHu0bqe+C3vFpJHmEimZiZhUxOO1hfogULfmKi
mfmhwW71TtAScF/7vRPnm65oFrzzAfhmFWoim3H+rc+Ir1+7oMmHTvxTy0RR
50pcUuQ/guRgZebdV0w0h7K/ugb1QMrufdNcuUx0mVlfvOlNL8jZJVm5peL8
ufWRHZRP8O0/krJYPBP9dut6qOLbD8xtdnHrI3Bf+9ctu1R8hqsNlhncAbif
p5SzBRKD0FnjZzB6gYmubj0tO2I7BMY/dwnV2DERjXWcv+fIMOz7/DF0wpSJ
xIS+kesXh2Hu1RwlWJuJeKof5skljcDRtl66FJWJ/rejoo/v0ChUL9XbF4kz
UbaxY0rV3Ci8bjs3sGlZA83OSAuPx32BYY7kzQsTGqjE3JA7Vu8reIlWb5xr
1UBBRmHJxeNfYc0FywvGhRqIMmDSmxo2Bi0HKqzF4zTQ3l03YqWY45D0Ll9z
5LIGst32fmHNh3GQdQFtBXN8fnP0qGfIBDh/YuduVdVACTx2l4/JTwKR4KY8
v0YDiQ2WPOWqn4Qqrf8ee3ero7UBIRZ7Lk7B/YhbPE+S1REp0y5vVHQaspWI
ON6z6sgrMS9atG4aujoW/Ba3q6PXqrfJIu4z0GoVkRv1RA1pdUm03fecgf/u
6GzkSlZD+f7P7olfmoH7t2Q6rySpoadtjdKSPjOQ50w3OBGvhm57rKXLhM6A
rWzdZ3K0GjpWFGpGj5uBDKGJ4U0+amhib0CicdUMaPt4GX08rIZETLxooYIs
OOeeeOTYNwZKqRXi3yvCghRywC0ym4HU9+RMfRdjwceFNO7KKQYyVZ7McJBi
QXWPWIH0FwaK4LWj7JdnwbAuzfFlNwPxvDHeRNrLAjEd/7VO5Qw0t49CCjzD
ggtc3WvcQxgorKhqcKcrCxJUpYXeBDCQuKrta7YbC+4rHygT92UgTel431Oe
LJh+1NCS48VAnr82zGr7sYA2nbP3pRMDTRX/mvodwwKJZsk70voM9Jne/uFa
JQuQ9BufFR4GSp4RCeCuZsH7IxLelDUM5Jhprhhdy4I5ulAJLNHRlHyPT0oj
C/gkTvZ7ztLR3ObBrU3tLBi8/ulP2hgdiaxnnRUfY0FMqMfEkQY6Mhhf9ydX
gA0im6t4XEPoiC/NOH23MBuaH5hncwXQUatDpGmdKBtQw2hwgg8dmQ8IPumW
YENNiuTdEg86su/aaPCHwoa6WW/+4lN05FcnF2OsxQYGPfL5q910lP8Y5L/a
sYFvsHtP+DQN/fD9sc7BgQ3nLceNosZoSMvq2cyAExsUBdKp4cM0VCEkVNTj
yoZfgedUPD/SUGPw4P4WLzYcLrS2+15LQ/2OAacLb7LB3dFCszCehniVKhKD
c9nAJsiiL3RoyJjbI3Apnw0Zt+tMmnbRUNSQrKNvERvEagI4fRo0JJIQoXL5
FRt+2guKjynQ0Ba+k6/O1rGh7AnBHyNAQ8yZX92mH9ng//lH//Z+VXQqT0tk
6zIbnsdKPLBwV0UvT/4SbCdxINXzneEtF1UkyFu+4To3B6i2nQLZdqqoxlaH
PEXmAF/qMqnBVBXJrtdbKRbjgGk7L1WboYrGnc3Yh1U4YC6434c0TUW6wmIz
K6oc+HU5YkhphIriK7omCxkcGBPsN9bupSIj0RNfJXdw4MHyRja1kYqyqu36
v+pyYPwGn/umJ1TkLn3+rb8FB86MijT0HKOixgZ6k5oVB6Tt+zwyjKhI5iJR
P2rNAaXxXn1bXSpqb/KqMTrNgbTOt5l+KlTEvHKtVNyNA9E/3lL9l1XQ/Pub
6S+CONBlVWQtnKqCjvoZpZ4O5UD4tX/jNsaroOeK65+IhnFAzpDbdiFCBZ0M
iE7yieBARAf5vbWXCqqkxv6t9w8HTslKBbmBCgoOexLyOQvPk6wturlTGQlc
XWfikMOBQM2qdRn1yijR9YLoeB4HvP8RcCeXKqOiQ3tSiWIO9Nx8Sj/6UBmN
i3TUc1VzoEOt+V6ngzI69JhEVvnAgaO2GU6NY0qo965Le043B/oO3Oez7FZC
ziGtCcxeDtQnfU1+Ua+EAp0TVLQHOPD4ReaFzKdKKJ+qfuivCdzXq2ZGhY0S
2lR6+s6V3xzgmpiPnK5RRKnPGywXlzjgki9VsvuFIlJPVJUJIhEgcJI4vCNe
ERkHzOfdXktAes9Itep5ReR/8G7HQyEC8mYE/hoWUUR8O2cfbBcl4Ki83ITd
ogKKU7RxTBcnIFZd1ubaqALK41P6kStFQEPx5pGrBQpo9H2VeJ0cAXP7nw2Y
mSggj1r5AQNFAvjdxcBFTQH9KYxIb1Em4Mvx+WqSuALaGGep1U0nQPjOcG9F
vzwysuVYTe4i4NHI/XHCWR7lTG59KHiYACU9Zx2mjRy6/SjMftCUgJbc/JJm
phxyPsZWyDUjwJl3qDCYTw5tqazMP2JFwHU9zRrVYlkUcdemMcqRAIqQXl/d
EgW56L2JtD1DQNKbHTbRbRR0YIFqRnMlYCbm1FndJApacFzsb7lAQP+6AXEt
LQpy1Xrwff01Am53BPek22xHejOk0k9+BHR4MIfeU7YjmRRX/6xAAloLk5wM
22TQR77d60xuECB530LwRO82pD/wcUv4XQIuD2ywF2vdgmRviButyyBAhwit
fywriZZ3+wv0PCeA79u57PIgCdTH/tKZkU3APaspg+G+TSjGquiUQQEBjlFl
BqFhG9EK9dilsEo8f5z3JeNKUWT6U2GDQBWeb0lRTcpCFH3uuPuY+wMBvzMG
4m8F86FXN+edPnTj+34VlNbw3zoUu++0SmovAX2WLjdTHXnRoXRG8YFBAjZP
1R410OZG5T5tb0OmCFCO0ddwr1iAOPrOu2Ys3McGh5Qtt+bg4miSBYUgwNTm
ddMVsx+gfPj8UM1P3Ef5vKB74xTwrOlKi5knICBEokbSEv/rJfvc7BcJyI6r
5k182weVbqlq6ksE6NdKGpJb3kK8DP/sygoBIsq21/6mTOn+H+dK6rA=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5756278693072276`*^9, 3.586661072263477*^9, 
  3.588414912709837*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"fig1", ",", "fig2"}], "]"}]], "Input",
 CellChangeTimes->{{3.484015031392249*^9, 3.484015036180523*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {GrayLevel[0], PointSize[Tiny], PointBox[CompressedData["
1:eJw1VQlUFFcWJYoeNhPZI0EGCILI1ku1KBx5L40mio4SiQaVTRYRJrI0myg6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      "]]}, {}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV1Xk01N0fB/AJaSS7srRo7MbMYJQ2fG5lrzyJSCRbkl8hlWSnVLZSjwdJ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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1.}, {0, 21.263}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.02, 0.02}, {0.42526, 0.42526}}]], "Output",
 CellChangeTimes->{3.57562786931923*^9, 3.58666107227651*^9, 
  3.588414912724887*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 31.6L", "Subsection",
 CellChangeTimes->{{3.482643765153206*^9, 3.4826437723036146`*^9}, {
  3.483763270085687*^9, 3.483763271376761*^9}, {3.5030313889286003`*^9, 
  3.5030313927836*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wdata", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "-", 
         RowBox[{"F", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], "}"}], "&"}], ",", 
     RowBox[{"Drop", "[", 
      RowBox[{"data", ",", "1"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483763273402877*^9, 3.483763342634837*^9}, {
  3.483763836037058*^9, 3.483763836643092*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figa", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"wdata", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", 
       RowBox[{"PointSize", "[", "Tiny", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotMarkers", " ", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\[SmallCircle]\>\"", ",", "Tiny"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.483763350084263*^9, 3.483763353235443*^9}, {
   3.4837640208186264`*^9, 3.4837640218176837`*^9}, {3.484020567945922*^9, 
   3.4840205722181664`*^9}, {3.484021214269889*^9, 3.4840212301167955`*^9}, {
   3.484021471156582*^9, 3.484021471899625*^9}, 3.4841949637906*^9}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzt1flTU+caB/Ckwh0EsbigwkVuqFpqFRSsilD5nkLdgAupXhWVJeybCrIp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    "], {
     {GrayLevel[0], PointSize[Tiny], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 129], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 130], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 131], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 132], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 133], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 134], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 135], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 136], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 137], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 138], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 139], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 140], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 141], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 142], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 143], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 144], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 145], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 146], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 147], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 148], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 149], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 150], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 151], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 152], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 153], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 154], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 155], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 156], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 157], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 158], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 159], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 160], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 161], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 162], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 163], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 164], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 165], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 166], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 167], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 168], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 169], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 170], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 171], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 172], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 173], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 174], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 175], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 176], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 177], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 178], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 179], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 180], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 181], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 182], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 183], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 184], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 185], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 186], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 187], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 188], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 189], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 190], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 191], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 192], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 193], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 194], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 195], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 196], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 197], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 198], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 199], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 200], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 201], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 202], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 203], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 204], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 205], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 206], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 207], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 208], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 209], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 210], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 211], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 212], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 213], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 214], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 215], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 216], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 217], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 218], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 219], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 220], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 221], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 222], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 223], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 224], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 225], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 226], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 227], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 228], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 229], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 230], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 231], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 232], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 233], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 234], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 235], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 236], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 237], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 238], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 239], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 240], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 241], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 242], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 243], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 244], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 245], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 246], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 247], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 248], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 249], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 250], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 251], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 252], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 253], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 254], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 255], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 256]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 0.9999247006931317}, {0, 2.2384789186254537`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.019998494013862635`, 0.019998494013862635`}, {
   0.044769578372509077`, 0.044769578372509077`}}]], "Output",
 CellChangeTimes->{3.5756278693942385`*^9, 3.586661072361521*^9, 
  3.588414912807848*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"w", "[", "y_", "]"}], "=", 
   RowBox[{"CC", " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", 
      RowBox[{
       FractionBox["\[Pi]", "2"], " ", 
       FractionBox["y", "a"]}], "]"}], "2"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4825692817320433`*^9, 3.4825692850282316`*^9}, {
  3.482569628968904*^9, 3.482569636892357*^9}, {3.484021239664342*^9, 
  3.484021240228374*^9}, {3.4840218782948694`*^9, 3.484021916646063*^9}, {
  3.484040704112644*^9, 3.484040704666676*^9}, {3.484041424897871*^9, 
  3.4840414281050544`*^9}, {3.4841931653456*^9, 3.4841931685425997`*^9}, {
  3.4841932005596*^9, 3.4841932010066*^9}, {3.4841939929426003`*^9, 
  3.4841939933746*^9}, {3.4841947733115997`*^9, 3.4841947734326*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"w", "[", "y_", "]"}], "=", 
   RowBox[{"CC", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["y", "a"], ")"}], "2"]}], ")"}], "2"]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4840406972082496`*^9, 3.48404075298844*^9}, {
  3.484040787759429*^9, 3.4840407880184436`*^9}, {3.4841930613216*^9, 
  3.4841930615016003`*^9}, {3.4841933360346003`*^9, 3.4841933365615997`*^9}, {
  3.4841941523066*^9, 3.4841941645766*^9}, {3.4841944187546*^9, 
  3.4841944243396*^9}, {3.4841947762166*^9, 3.4841947767046003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fit", "=", 
  RowBox[{
   RowBox[{"FindFit", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{"wdata", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "0.8"}], "&"}]}], "]"}], ",", 
     RowBox[{"w", "[", "y", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"CC", ",", "2"}], "}"}], "}"}], ",", "y"}], "]"}], "\[Union]", 
   " ", "sub"}]}]], "Input",
 CellChangeTimes->{{3.482637179294516*^9, 3.48263720121577*^9}, {
   3.4826373988990765`*^9, 3.4826374171831226`*^9}, {3.4826380303171916`*^9, 
   3.4826380340894074`*^9}, 3.483760296592613*^9, {3.483762554210741*^9, 
   3.483762596751175*^9}, {3.483762712707807*^9, 3.4837627290877438`*^9}, {
   3.483763669424528*^9, 3.4837637071896877`*^9}, {3.4837639841365285`*^9, 
   3.483763984547552*^9}, {3.4837643156384892`*^9, 3.483764315885504*^9}, {
   3.4840159889580183`*^9, 3.4840159893810425`*^9}, {3.484016026647174*^9, 
   3.484016028162261*^9}, {3.4840168186994767`*^9, 3.484016819119501*^9}, {
   3.4840199820224085`*^9, 3.4840199872267065`*^9}, {3.4840200758167734`*^9, 
   3.4840201307149134`*^9}, 3.4840212497999215`*^9, {3.484021935673151*^9, 
   3.4840219357971582`*^9}, {3.4840256996364374`*^9, 3.484025704440712*^9}, {
   3.4840406850725555`*^9, 3.4840406856085863`*^9}, {3.484041186824254*^9, 
   3.4840412353440294`*^9}, {3.484041449112256*^9, 3.4840414492722654`*^9}, 
   3.4841930639356003`*^9, {3.4841933450685997`*^9, 3.4841933875636*^9}, {
   3.4841934241716003`*^9, 3.4841934268115997`*^9}, {3.4841934787806*^9, 
   3.4841935068286*^9}, {3.4841935810856*^9, 3.4841935845366*^9}, {
   3.4841936796136*^9, 3.4841936895966*^9}, {3.4841937586546*^9, 
   3.4841938006486*^9}, {3.4841938350536003`*^9, 3.4841938722366*^9}, {
   3.4841939119826*^9, 3.4841939121696*^9}, {3.4841939827665997`*^9, 
   3.4841940372125998`*^9}, {3.4841940682316*^9, 3.4841940717195997`*^9}, {
   3.4841941755366*^9, 3.4841941933886003`*^9}, {3.4841942452086*^9, 
   3.4841942713566*^9}, {3.4841943250076*^9, 3.4841943529416*^9}, {
   3.4841945987176*^9, 3.4841946178796*^9}, {3.4841947533736*^9, 
   3.4841948023956003`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"A", "\[Rule]", "2.37`"}], ",", 
   RowBox[{"B", "\[Rule]", "5.55`"}], ",", 
   RowBox[{"CC", "\[Rule]", "2.189181744909556`"}], ",", 
   RowBox[{"\[Beta]", "\[Rule]", "0.0001277`"}], ",", 
   RowBox[{"\[Gamma]", "\[Rule]", "0.1062`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5756278694332438`*^9, 3.586661072557544*^9, 
  3.588414912902834*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figb", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "y", "]"}], "/.", "fit"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4837640261419315`*^9, 3.48376403749158*^9}, {
   3.4837640969089785`*^9, 3.4837641125508738`*^9}, 3.4840160117423215`*^9, {
   3.484020496777851*^9, 3.4840204970998697`*^9}, {3.4840205576533327`*^9, 
   3.484020564092701*^9}, {3.4840212571953444`*^9, 3.484021259833495*^9}, {
   3.4840213204189606`*^9, 3.48402132075498*^9}, {3.4840219049803953`*^9, 
   3.4840219051284037`*^9}, {3.484040768110305*^9, 3.484040768602333*^9}, 
   3.4841930796286*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1Hc4lu0bB3A3hZREKLusUpKEpPK9SyGjskLJng0e6zVKRkhJ02sllJGR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1}, {0., 2.189181744909554}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.575627869457287*^9, 3.5866610726135125`*^9, 
  3.588414912927863*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"figa", ",", "figb", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*FractionBox[\(y\), \(a\)]\)\>\"", ",", "w"}], 
      "}"}]}]}], "]"}], "//", "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<turbulence-channelwake\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4837641218614063`*^9, 3.4837641255596175`*^9}, {
   3.484020435184328*^9, 3.484020440781648*^9}, 3.4840205109006586`*^9, {
   3.484021302313925*^9, 3.4840213318376136`*^9}, {3.484021420294673*^9, 
   3.4840214326653805`*^9}, 3.484023431163688*^9, {3.48404089512957*^9, 
   3.484040899539822*^9}, 3.4842189449343195`*^9, {3.501505983471931*^9, 
   3.50150598695113*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5756278695882635`*^9, 3.5866610728005705`*^9, 
  3.5884149130668983`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, GraphicsComplexBox[CompressedData["
1:eJzt1flTU+caB/Ckwh0EsbigwkVuqFpqFRSsilD5nkLdgAupXhWVJeybCrIp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     "], {
      {GrayLevel[0], PointSize[Tiny], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 129], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 130], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 131], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 132], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 133], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 134], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 135], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 136], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 137], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 138], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 139], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 140], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 141], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 142], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 143], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 144], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 145], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 146], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 147], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 148], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 149], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 150], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 151], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 152], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 153], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 154], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 155], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 156], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 157], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 158], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 159], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 160], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 161], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 162], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 163], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 164], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 165], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 166], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 167], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 168], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 169], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 170], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 171], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 172], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 173], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 174], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 175], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 176], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 177], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 178], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 179], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 180], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 181], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 182], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 183], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 184], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 185], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 186], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 187], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 188], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 189], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 190], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 191], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 192], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 193], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 194], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 195], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 196], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 197], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 198], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 199], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 200], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 201], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 202], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 203], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 204], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 205], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 206], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 207], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 208], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 209], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 210], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 211], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 212], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 213], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 214], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 215], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 216], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 217], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 218], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 219], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 220], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 221], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 222], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 223], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 224], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 225], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 226], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 227], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 228], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 229], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 230], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 231], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 232], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 233], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 234], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 235], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 236], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 237], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 238], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 239], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 240], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 241], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 242], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 243], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 244], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 245], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 246], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 247], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 248], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 249], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 250], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 251], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 252], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 253], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 254], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 255], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 256]}, {}}], {}}, {{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV1Hc4lu0bB3A3hZREKLusUpKEpPK9SyGjskLJng0e6zVKRkhJ02sllJGR
vYpEEWVEoiWUIuJ57ryRMn/374/ruI7PP+dxnOf3us71Dp4mzuxsbGyD9Pn/
re888rp+1Fxr1drZKq8LBLlEW5QxIKKKCNvS0P97e1piSpnIfkjP9X5k0P4m
LhvmL38IfJP+TZ60Ddrfld4RMUOocZS2B23ZKxJZi1JWaJHmMjlNe07fMcFe
3gaHg2Ym3Gn/iOhutI+3xzUPOxlX2hZO07U3RZwgKbpz2JF2o7ZoVUOKC+7f
jtC0o60ss6d4UsodY0La66xpp7Db5cplnEJDkW+CBW3uwfB7R+U9IBUnkm5C
u/pzV3uDGQNL/9umaUSbccRJ3zreCzfnap11afdtvagdK+KLS3+2eWnSjktb
Wy933A93nESNt9PW58vb/STlH5R4+z/bTLuS1aZGSQVCMeG6lRjt0zY2pRft
g/BLzyhEgLb0K0ppXcZZhL4JUV9G+2qBwEZj+fPIeatrNRVOkAckMjNHXUNw
fHl/4w/a55uSVz01C8XSG2NPB2irqivGWsWHwU3Vg/GCdrrQ4ajLIhHI2C+Z
Fkf7bHtC49HqCKQZnY2Pon008jO7zPFI7LE2lQqgvWLKK6QmJQp2pf8MWdEO
6I4LGJe6BAaStdfSNr3SV/mw/hJmzQeaOGkr7ZefirC/jEjFzN7JMDrPsiov
iYwYeDcWPeqgbXzr48lD8lfRpTyoG0pb0UAmV7T5KlpqNCxO0ebmOP192PUa
upoE/5jTtn20UFJndh3Nl+1YCrSFFK4rWcbfgBV1oqAtlCDDuMs2XBKJg+uT
Sr/5EILcpHsjupQRh4PnVfcO0O6K9BztbY6DwdiPy/W0ZTkU85X++Rccm7iS
wmg3zWcqdXfFY5JDNn3+PN3vr3g1qStJeL6443hfMEFWbPOL1/uaBJvtTJ4q
2jYM02kvzWRkr/2lcZ12EZPvUeNIMtbUTfPtpW0yEr375IEU3N0glJdyjiAT
+4K0KxZSIWmscX3XWYLcK26V2W+ehv2pHXK8tH8c27GUuyANWbo9O/uDCFJy
PNCxYEs63Ae2952n7emuLsf2KR0pJQH81YEEKeBUlJOlcQ+G/VwqawMI0tLq
btHPiUws7Uxx9PElSKrXjOeeaBa4inWnNGhH2XA7m2pn4WbrHuEFH4Isc/QU
rYzLAvIEOS/SXumxJ/LsjmzcyH1w55Y3QT4P/3CMM/g+pL9eL0xgEKTKA35O
ce48aGs7uxmcJsiXSs/t2pXz0HNCaoSdtl1JQM15qzwcifGdfnSKIGMrBxhf
8vIQt3O2UZ72SH1Bb7ZRPoZjX4jNuhNkas/Bkm23HqAidLj6qitBLl8Ms9aV
LMLtw4rd9g70vNwtbBR1iuCldYuNl7Zst6Idv0cRjLYeeVplT5Baue8ce2uL
MHXz/eJy2o9y4yuqlIqhnHHWq8iWIJmm448NXhWjf/KDwqA1QZrnJLT68JYi
cynJOX2U/t8nwg1d1pciQ/pJQxztQYEz7ZZqpdAsnhdSoe0ZvK9jz4lSNMR1
BJwyJ8hLJswuroJSnMiW1fhgSpC1c/s+3jYswxnurvT0IwQpZ8waaYgpR9iP
GdWBgwQpGqKr6Xq3HAFnngm70F5VkB7DU1WO4aLRoHE9gpzhNlUyHizHVb/T
LdO6BNlZX+XTr1EBb713Udw6BBmkHLbwZ6gCymq/AwX2EeQrPkFBJbIKuxpE
GS92EqT/q51InHyEpEervtVuoPNTqhh6yV0Nw/80H22lnRmrfGVWvBoBQ9rS
d+UJ8rXhhg82B6rx6QJXcbgcQW5uFfSRi6/GVR1mNSlDkAPNVHbpjhpI187f
zJEkSN2nWSvbgx7jxZSjzwYhglxTzt9PEHXg8A/e/ZWN3leD2m0du58hKeXS
q70dbOSzk3fErMYbIcy2/M6KBDZySn4PX8GZZrhmT4gJWLOR7H/zV4nJteCb
/a5PMkJspPqiXaVpYRt+dkeHCSUtoi1C9VXTpg6wKazol15cgNT1sb+5rE5w
+nr3RBssYGx6oL9HuQv9Mi2ciYnzyPxR07Ly6husjxqwbG6Zw0qJ+9S3b934
KstfcGRqFlfcK1zSZd9Ck1fUL0l2Fr/J/G9uIe8gLCB81UpjBr4qjeXCDe/x
gr3LZZvpXwwUNsa8Xv8RBxWiP2w3+YPZk923FYJ6kX2k9sGQ0TQ27+VacKn5
hLLWfcY5Zr+he2+9a8mafizrz5gzIKfgL2Er/cV6AJLDRodNd05Ccdx8+Tuj
z9hSbGpSuP0XVvP95G6c+Yxht+2x/oL/YUnd7SKZlC/wxOPLSpwTOKVa82GZ
wSB06o0jHtRRyD/okP7k9yDOjU7eFwlmYmpMdNVw/Fek5tl0shzGUGGqyxG3
/xtUeLj0dkuNIkQvMq18+Bt6SKWEP1zfsb5P/31G5BC+NBiQA+xD0NwRESei
Moxbul7mdZ8GYS3Z8Zd4MwyjgX1P1o98xlRL7CAj7DuMpxK1qbI+JC6x8TWR
HYGPs69GFPERq/sr7rE3juCztctQUvRbLA0OM9vpNQq9HQ5iBVNdYMu1KRoU
+AGf2NQs3vsd8E4uihV49gMv+lYNsx97idrN0dz8HmN46FwrxKhsAL++t2L4
ynEsef/w0cu/tfi0pfNN4ONx/DQ02OjDVoG0Mf5gjrpxPDzhEfPvl3I45JrK
xz4dx+QA+3Trs3KMyr4LSG8aB3tLyqJvZDl+i/VLNHfS9f4EhjxcXg5+nnFX
waFxrKhpCucRL4POMNdcIS8TokJss0sMS1CcCtlvNkykifCtMe7Jx6+gX1z2
9kw4uirkzd7Lh7rF/bE+RyYywqQedDDyUcPHV/bOjQnhwZWbJ1fkoym0f2+r
NxP3XuKYsm4eeh2CbUujmLDxO5wf0pADzg01yaGFTKj8Gals7c3CQQ7P8/PF
TOTVb6usLszClQFph6AyJpxlypO6w7LAn3hZwfchExf0TXdf2pgF8WXHHro+
Y0JHoURj2j8TKmN/eg69ZYK5rOfoT8kMnChS55dYYEJ8SVZGbmw6Ko/9WdnJ
xkJZqkR4sUM6VnJWr7jAwYLXxa7ksR3pqLfewz3KzYKJB7vn/PM0SPPsXyxf
zULu7PErqv6pGHYyZhoqsJA8pLHgyrwND9HTL8+ZsRCtwFP2UCEBTc+3NG+1
YCF/caqP70s8pLyoxkErFsj6ywZvEuPR2exdr2fLQv+Fze5py+Kh4hdYJXiS
BSdFfe4jP+Mw3RGV9SCEBTX/8cItXTcRGnk37FMeC+1q0SOOr2PB68+lb1/A
AscuZx8fx1gku50RGC5iQTFjVE3n9xWUGezMoMpZSNDZsFld8gqG+V83stex
YNa42vKA/2UYpLJxK7xhofrrlreGhy7i/TWXzoIeFnY1OwfeH4+CU1hbosp7
FqafSp59EROF806JCrv7WIj4dczJpi0SxZuUDQ5/Z+G7YffRgaMREK6yveo3
y0LwjzWrHG6EISPn+dGZeRZqWVqWmrvDoJy8WSqEjQJj4ovCp++hOBg8XRS9
lAJTbUw1eG8ozmlfe32bj8J8yc5J37lgDHY8EXwmQ6G+TTU1ZVcgPJ/K9unI
UyAWi4QK8wIwV3o5q3Ujhd8OxxcsxQIgFH9UvWcLBZkvEzXnCH/oWbMsRnZQ
sJCtFOb64ouCEYnbKw0pHBEL/BjKZCD6TqRd/yEKtfrXmhPdGHAyYcoVGlOw
S3cYPdPqCfHHj4uNLCj83cTx76q2M7h87XjTFQcKColzvBIL7nDZ3xBj7Uyh
yejSlk5Bd+z7u8lY0Y0C27lTtYlb3fDXYaa39QwF90j1HA8vF7ipJ03wBFKI
iS9aaiTviP1jbFUfz1K41DbH3nrCAVLpbufyzlPgYOm4uibZ4+0yDS79CArh
y3gHF8XtcKDvrfilaxTen1aTS80/hnU3tQYtb1K4EJ/vXWdthTmd7Psb/6Xr
vdwTvVXYEuXFfiovkul+1sevWHrPHNIRgnpc2RRGDD1iGiWMsaBxjvddDgWv
4xUKt/mP4APza1d2PgVqREwpS+wQrluUndApoXAtNKjtg5Y+Tq8QkxEup3Dm
q1dijrse9J6GjwxVUjhlvm61QZYOFjeZ+EQ+puezJE1B4rA2Pg480jCn97If
P6vTvHYvKuPWL8g+oxDyamKP724SHgs/oxubKURoznKPftSEfpnlobgWCu1Z
3h+eaGlAzq1+tVM7hQ5CmhHRqIZPr6+lcryhwGX7YjuH+jY8jJp2fNND4XPK
umV3tJUQt8tWIeM9hTohp6bjtpvA+NnE8u6l812n1GxWJw+DLKXyff0UVkuO
qyY7ykD+WHygwBcKd95laWoZrgM734LW4FcKM/Mzy7L/E0V/g/OS0mEKN11s
I3p6hFAd0P4ybJSCwW/5/Vv38SN+i9o143EKZuvcLYs8eeA1mGK2nqKw/zUO
DJ/hgGHCEtGJCQrDEm/3JS7MaG00PD1QP0lBUKQ3xlRvQmsJ0Z15fZp+//mv
9Nb5fNX6XLHrpN0MPV/GbbsQg9daj09mbFWep/Bw2/W/ukYlWglSy6cWFyks
rhhvf3v65+7/ARgfoSY=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\\!\\(\\*FractionBox[\\(y\\), \\(a\\)]\\)\"", TraditionalForm], 
    FormBox["w", TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 0.9999247006931317}, {0, 2.2384789186254537`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.019998494013862635`, 0.019998494013862635`}, {
   0.044769578372509077`, 0.044769578372509077`}}]], "Output",
 CellChangeTimes->{3.57562786964227*^9, 3.5866610728075686`*^9, 
  3.5884149131108723`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 31.6R", "Subsection",
 CellChangeTimes->{{3.4826511718678455`*^9, 3.482651179015254*^9}, {
  3.5030313281296*^9, 3.5030313345916*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "\[Rule]", 
   RowBox[{
    RowBox[{"KK", ">", "0"}], "&&", 
    RowBox[{"A", ">", "0"}], "&&", 
    RowBox[{"B", ">", "0"}], "&&", 
    RowBox[{"CC", ">", "0"}], "&&", 
    RowBox[{"p", ">", "0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48402449192036*^9, 3.484024521164033*^9}, {
   3.4841946545875998`*^9, 3.4841946563775997`*^9}, 3.501506245644926*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", "=", 
  RowBox[{"u0", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", " ", 
        RowBox[{"Log", "[", 
         RowBox[{
          FractionBox["1", "2"], "KK", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["s", "2"]}], ")"}]}], "]"}]}], "+", "B", "+", 
       RowBox[{"w", "[", "s", "]"}]}], ")"}], 
     RowBox[{"\[DifferentialD]", "s"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.484024351139308*^9, 3.484024472567253*^9}, {
   3.4840245185918856`*^9, 3.484024518981908*^9}, {3.4840248722121115`*^9, 
   3.4840248733101745`*^9}, {3.4840409730700283`*^9, 3.4840409844306774`*^9}, 
   3.4841930912216*^9, {3.50150624850709*^9, 3.5015062691152687`*^9}}],

Cell[BoxData[
 RowBox[{"B", "+", 
  FractionBox[
   RowBox[{"8", " ", "CC"}], "15"], "+", 
  RowBox[{"A", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     RowBox[{"Log", "[", "2", "]"}], "+", 
     RowBox[{"Log", "[", "KK", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.575627872786665*^9, 3.586661076490004*^9, 
  3.588414914901111*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uave", "=", 
  RowBox[{
   RowBox[{
    FractionBox["U", "u0"], "/.", "fit"}], "/.", 
   RowBox[{"KK", "\[Rule]", "Ka"}]}]}]], "Input",
 CellChangeTimes->{{3.4840247899844084`*^9, 3.484024792721565*^9}, {
   3.484024844926551*^9, 3.4840248490077844`*^9}, {3.4840248916532235`*^9, 
   3.4840248962624874`*^9}, {3.484025449544133*^9, 3.4840254507071996`*^9}, 
   3.484025717961486*^9, 3.501506251389255*^9}],

Cell[BoxData["18.729898235034792`"], "Output",
 CellChangeTimes->{3.575627872870675*^9, 3.5866610766020346`*^9, 
  3.5884149149761195`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rey", "=", 
  FractionBox[
   RowBox[{"2", "a", " ", "Uave"}], 
   RowBox[{"u0", " ", "\[Delta]0"}]]}]], "Input",
 CellChangeTimes->{{3.484025021682661*^9, 3.48402505069132*^9}, {
  3.484025457080564*^9, 3.484025462043848*^9}}],

Cell[BoxData["21996.01788926016`"], "Output",
 CellChangeTimes->{3.5756278728916783`*^9, 3.5866610766720343`*^9, 
  3.5884149149951267`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DD", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], "A"}], "+", "B", "+", 
    RowBox[{
     FractionBox["8", "15"], "CC"}]}], "/.", "fit"}]}]], "Input",
 CellChangeTimes->{{3.4842080796506*^9, 3.4842081199765997`*^9}}],

Cell[BoxData["1.977563597285096`"], "Output",
 CellChangeTimes->{3.5756278729176817`*^9, 3.586661076705071*^9, 
  3.5884149150141273`*^9}]
}, Open  ]],

Cell["Check", "Text",
 CellChangeTimes->{{3.4842083867746*^9, 3.4842083874606*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"A", " ", 
     RowBox[{"Log", "[", 
      FractionBox["Rey", "\[CapitalLambda]"], "]"}]}], "+", "DD"}], "/.", 
   RowBox[{"\[CapitalLambda]", "\[Rule]", "Uave"}]}], "/.", "fit"}]], "Input",
 CellChangeTimes->{{3.4842083382406*^9, 3.4842083789086*^9}}],

Cell[BoxData["18.729898235034796`"], "Output",
 CellChangeTimes->{3.575627872939684*^9, 3.586661076769128*^9, 
  3.5884149150341306`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"udata", "=", "data"}], ";"}]], "Input",
 CellChangeTimes->{{3.482651259313847*^9, 3.4826512615759764`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Umax", "=", 
  RowBox[{"data", "[", 
   RowBox[{"[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4840255693639865`*^9, 3.4840255753103266`*^9}}],

Cell[BoxData["21.263`"], "Output",
 CellChangeTimes->{3.5756278729646893`*^9, 3.5866610769760895`*^9, 
  3.588414915057132*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"udata", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", "Uave"], 
    RowBox[{"data", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.482651253688525*^9, {3.48402542763888*^9, 3.484025434669282*^9}, {
   3.4840254711783705`*^9, 3.4840254722724333`*^9}, {3.484025534035966*^9, 
   3.4840255360050783`*^9}, {3.4840258550673275`*^9, 3.484025860168619*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig7a", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"udata", ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", 
       RowBox[{"PointSize", "[", "Tiny", "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotMarkers", " ", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\[SmallCircle]\>\"", ",", "Tiny"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4826513447647343`*^9, 3.482651359059552*^9}, {
   3.482651548947413*^9, 3.4826515539977016`*^9}, {3.4826516599927645`*^9, 
   3.48265166725918*^9}, {3.482652278548144*^9, 3.4826524260835824`*^9}, {
   3.482652535542843*^9, 3.482652571317889*^9}, {3.4826526281071377`*^9, 
   3.482652670135541*^9}, {3.4826527198503847`*^9, 3.4826528149908266`*^9}, 
   3.4826528654377117`*^9, {3.482652896385482*^9, 3.4826529136524696`*^9}, {
   3.4826552868152065`*^9, 3.4826552876532545`*^9}, {3.482655373039139*^9, 
   3.482655375720292*^9}, {3.482828956477*^9, 3.482828957387*^9}, {
   3.4841948582346*^9, 3.4841949053546*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJztlvk7lYsWxwk3khTXGA5KcjoqKhk6vqXBScKpI2SeEk+GTFF0bZciChmK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    "], {
     {GrayLevel[0], PointSize[Tiny], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 130], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 131], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 132], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 133], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 134], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 135], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 136], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 137], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 138], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 139], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 140], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 141], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 142], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 143], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 144], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 145], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 146], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 147], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 148], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 149], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 150], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 151], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 152], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 153], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 154], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 155], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 156], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 157], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 158], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 159], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 160], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 161], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 162], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 163], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 164], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 165], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 166], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 167], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 168], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 169], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 170], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 171], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 172], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 173], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 174], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 175], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 176], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 177], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 178], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 179], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 180], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 181], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 182], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 183], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 184], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 185], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 186], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 187], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 188], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 189], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 190], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 191], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 192], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 193], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 194], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 195], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 196], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 197], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 198], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 199], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 200], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 201], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 202], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 203], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 204], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 205], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 206], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 207], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 208], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 209], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 210], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 211], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 212], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 213], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 214], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 215], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 216], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 217], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 218], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 219], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 220], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 221], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 222], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 223], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 224], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 225], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 226], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 227], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 228], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 229], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 230], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 231], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 232], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 233], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 234], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 235], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 236], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 237], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 238], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 239], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 240], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 241], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 242], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 243], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 244], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 245], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 246], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 247], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 248], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 249], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 250], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 251], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 252], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 253], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 254], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 255], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 256], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 257], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 258]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1.}, {0, 1.135243754834021}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.02, 0.02}, {0.022704875096680423`, 
   0.022704875096680423`}}]], "Output",
 CellChangeTimes->{3.575627873047697*^9, 3.586661077552193*^9, 
  3.588414915145141*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "y_", "]"}], "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"F", "[", "y", "]"}], "+", " ", 
      RowBox[{"w", "[", "y", "]"}]}], "Uave"], "/.", "fit"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.484025659697153*^9, 3.48402566978773*^9}, 
   3.484025735437485*^9, {3.4840257680293493`*^9, 3.4840257810500937`*^9}, {
   3.4840258175881844`*^9, 3.4840258309399476`*^9}, {3.484040855250289*^9, 
   3.484040855761318*^9}, 3.4841931036636*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig7b", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"u", "[", "y", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482651420230051*^9, 3.4826514511898212`*^9}, 
   3.4826515649013257`*^9, {3.482656014308817*^9, 3.4826560148068457`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1Wk4lG0UB3DktSV7C5FkzZYUWvAvW6KUaCXZUilRWkRZylIhKk2SolDI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5756278731017036`*^9, 3.5866610780472302`*^9, 
  3.588414915201149*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig7c", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["y", "2"]}], ")"}]}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Black", ",", " ", "Dashed"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dotted"}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4826513772935953`*^9, 3.482651415350772*^9}, {
  3.4826515715967083`*^9, 3.48265162091953*^9}, {3.4826560077644424`*^9, 
  3.482656008752499*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV1Ak01tkbB3CVYipry8RYC1MYI0nLVF+RYWxlS1RvimxlSwlNtkEqon+v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     "]]}, 
   {GrayLevel[0], Dashing[{0, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7ZX64uKBl6F2DGDwwX6BqH9bl2SLPYzfyLFZvVNy
CpwfEblw/YePS+B87v+NMe5y6+F81cB3Lw53b4Hzy89Z2s/4shPOF98ieI+R
cT+cv+2R85nzNofg/ENZc6Uj3xyB87+q2fKvzT0O5zP9XC0grXoKzjf7n7At
eN0ZOP9Mi8m5Y1rn4Xz5Ca9/rnx3Ac5//f3+vasGl+D8Ja92n+Lruwzn88ku
f//kyRU4vydza9oClWtw/jeH1U8y6q/D+SVGR7aIHb4B599fd6T7ouItOP93
1pXZmlW34XxtR/Z/abvvwPnuixTTN4rfQ4SXbLzSw5j7cL7Om1Du674P4Hxh
/g8cR34h+Cz7Z69XnvMQzs822X2T0/sRnL/aM2nBvm8I/tfXUgLPpj2G87cG
uzNPcXkC59d7tM7f8gzBV7zrdWNx61M438q8ZYqk0TM4P0bu/E/Gywj+11O9
jwoan8P5M1jiSoJUXiDcf2/rIqYjCD5rbWOIZeFLOJ9hZdz6R0Kv4PyiWet7
hQ4h+Hu1OzgE817D+YJeRTpNfG/g/Du6Fy5X7kHwN8yzV3kS9xbOj11vJij7
D8FvaF3YeGfVOzh/7QvZ2Xw+7+F8pRYRD/ZlCP50ee6v//8j+ACgshGH
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1}, {0., 1.4999999999999993`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.575627873119707*^9, 3.586661078075218*^9, 
  3.588414915224152*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"fig7b", ",", "fig7c", ",", "fig7a", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*FractionBox[\(y\), \(a\)]\)\>\"", ",", 
       RowBox[{"HoldForm", "[", 
        RowBox[{
         SubscriptBox["v", "x"], "\"\</\>\"", "U"}], "]"}]}], "}"}]}]}], 
   "]"}], " ", "//", "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<turbulence-channelprofile\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390217586182786*^9, 3.390217634746786*^9}, {
   3.4826514289825516`*^9, 3.4826514635445285`*^9}, 3.482652064152881*^9, {
   3.4826528281905813`*^9, 3.4826528323718204`*^9}, 3.482654246486704*^9, {
   3.4826551305392685`*^9, 3.4826551439750366`*^9}, {3.482655678602616*^9, 
   3.4826556809267488`*^9}, {3.482656046857679*^9, 3.482656047860736*^9}, {
   3.4840259001109037`*^9, 3.4840259041611357`*^9}, 3.484041408109911*^9, {
   3.4841949237916*^9, 3.4841949320586*^9}, 3.4842189398080263`*^9, {
   3.5015063137448215`*^9, 3.5015063315908422`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.575627873250723*^9, 3.5866610782132387`*^9, 
  3.5884149153641863`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV1Wk4lG0UB3DktSV7C5FkzZYUWvAvW6KUaCXZUilRWkRZylIhKk2SolDI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      "]]}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV1Ak01tkbB3CVYipry8RYC1MYI0nLVF+RYWxlS1RvimxlSwlNtkEqon+v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      "]]}, 
    {GrayLevel[0], Dashing[{0, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7ZX64uKBl6F2DGDwwX6BqH9bl2SLPYzfyLFZvVNy
CpwfEblw/YePS+B87v+NMe5y6+F81cB3Lw53b4Hzy89Z2s/4shPOF98ieI+R
cT+cv+2R85nzNofg/ENZc6Uj3xyB87+q2fKvzT0O5zP9XC0grXoKzjf7n7At
eN0ZOP9Mi8m5Y1rn4Xz5Ca9/rnx3Ac5//f3+vasGl+D8Ja92n+Lruwzn88ku
f//kyRU4vydza9oClWtw/jeH1U8y6q/D+SVGR7aIHb4B599fd6T7ouItOP93
1pXZmlW34XxtR/Z/abvvwPnuixTTN4rfQ4SXbLzSw5j7cL7Om1Du674P4Hxh
/g8cR34h+Cz7Z69XnvMQzs822X2T0/sRnL/aM2nBvm8I/tfXUgLPpj2G87cG
uzNPcXkC59d7tM7f8gzBV7zrdWNx61M438q8ZYqk0TM4P0bu/E/Gywj+11O9
jwoan8P5M1jiSoJUXiDcf2/rIqYjCD5rbWOIZeFLOJ9hZdz6R0Kv4PyiWet7
hQ4h+Hu1OzgE817D+YJeRTpNfG/g/Du6Fy5X7kHwN8yzV3kS9xbOj11vJij7
D8FvaF3YeGfVOzh/7QvZ2Xw+7+F8pRYRD/ZlCP50ee6v//8j+ACgshGH
      "]]}}, {{}, GraphicsComplexBox[CompressedData["
1:eJztlvk7lYsWxwk3khTXGA5KcjoqKhk6vqXBScKpI2SeEk+GTFF0bZciChmK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     "], {
      {GrayLevel[0], PointSize[Tiny], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 130], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 131], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 132], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 133], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 134], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 135], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 136], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 137], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 138], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 139], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 140], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 141], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 142], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 143], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 144], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 145], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 146], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 147], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 148], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 149], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 150], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 151], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 152], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 153], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 154], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 155], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 156], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 157], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 158], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 159], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 160], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 161], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 162], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 163], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 164], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 165], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 166], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 167], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 168], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 169], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 170], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 171], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 172], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 173], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 174], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 175], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 176], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 177], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 178], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 179], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 180], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 181], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 182], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 183], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 184], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 185], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 186], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 187], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 188], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 189], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 190], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 191], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 192], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 193], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 194], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 195], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 196], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 197], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 198], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 199], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 200], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 201], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 202], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 203], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 204], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 205], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 206], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 207], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 208], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 209], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 210], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 211], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 212], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 213], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 214], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 215], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 216], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 217], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 218], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 219], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 220], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 221], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 222], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 223], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 224], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 225], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 226], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 227], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 228], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 229], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 230], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 231], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 232], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 233], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 234], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 235], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 236], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 237], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 238], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 239], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 240], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 241], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 242], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 243], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 244], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 245], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 246], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 247], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 248], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 249], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 250], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 251], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 252], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 253], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 254], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 255], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 256], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 257], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 258]}, {}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\\!\\(\\*FractionBox[\\(y\\), \\(a\\)]\\)\"", TraditionalForm], 
    FormBox[
     TagBox[
      RowBox[{
        SubscriptBox["v", "x"], " ", "\"/\"", " ", "U"}], HoldForm], 
     TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.575627873305781*^9, 3.5866610782922244`*^9, 
  3.5884149154081774`*^9}]
}, Open  ]],

Cell["Fit error estimate", "Text",
 CellChangeTimes->{{3.588416394466097*^9, 3.5884164044493065`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rms", "=", 
  SqrtBox[
   FractionBox[
    RowBox[{"Plus", "@@", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "-", 
           RowBox[{"u", "[", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ")"}], "2"], "&"}], ",",
        "udata"}], "]"}]}], 
    RowBox[{"Length", "[", "udata", "]"}]]]}]], "Input"],

Cell[BoxData["0.008107116972424827`"], "Output",
 CellChangeTimes->{3.575627873354739*^9, 3.5866610783222694`*^9, 
  3.5884149154521437`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 31.6 Application: Turbulent pipe flow (p. 582)\
\>", "Title",
 CellChangeTimes->{{3.484027132692404*^9, 3.484027134656516*^9}, {
  3.5030315259066*^9, 3.5030315346406*^9}, {3.5884164088808956`*^9, 
  3.588416434809198*^9}}],

Cell[CellGroupData[{

Cell["\<\
Figure 31.7 Pressure driven pipe flow (p. 582)\
\>", "Section",
 CellChangeTimes->{{3.5030315431516*^9, 3.5030315468316*^9}, {
  3.588416558689885*^9, 3.5884166005292325`*^9}}],

Cell[CellGroupData[{

Cell["Princeton Superpipe data (2004)", "Subsection",
 CellChangeTimes->{{3.484027277142666*^9, 3.4840272930815773`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(34\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.575627897410759*^9, 3.586661078496295*^9, 
  3.5884149156162024`*^9, 3.58841651941794*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<data/turbulence.princeton2004.m\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.4824844969850664`*^9, 3.482484554123335*^9}, {
  3.4824846011680255`*^9, 3.4824846077214003`*^9}, {3.4827537494276*^9, 
  3.4827537858076*^9}, {3.48307623267807*^9, 3.483076233290105*^9}, {
  3.4830762977317915`*^9, 3.4830762985758395`*^9}, {3.4830864839063754`*^9, 
  3.483086492837886*^9}, {3.50536968287267*^9, 3.505369691096141*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Names", "[", "\"\<`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.484027805704898*^9, 3.484027812076262*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"Cfs\"\>", ",", "\<\"Ds\"\>", 
   ",", "\<\"Karmans\"\>", ",", "\<\"profiles\"\>", ",", "\<\"Rey0s\"\>", 
   ",", "\<\"Reys\"\>", ",", "\<\"u0s\"\>", ",", "\<\"Uaves\"\>", 
   ",", "\<\"Umaxs\"\>", ",", "\<\"\[Delta]\"\>", ",", "\<\"\[Delta]0s\"\>", 
   ",", "\<\"\[Eta]s\"\>", ",", "\<\"\[Nu]s\"\>", ",", "\<\"\[Rho]s\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5756278975127707`*^9, 3.586661078544284*^9, 
  3.588414915656209*^9, 3.5884165195199504`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Karmans"], "Input",
 CellChangeTimes->{{3.483076323521266*^9, 3.4830763243993163`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1824.7`", ",", "3327.5`", ",", "5108.5`", ",", "6617.3`", ",", "8536.4`", 
   ",", "10914.`", ",", "14849.`", ",", "19778.`", ",", "25279.`", ",", 
   "32870.`", ",", "42295.`", ",", "54530.`", ",", "76478.`", ",", "102200.`",
    ",", "127920.`", ",", "165700.`", ",", "216980.`", ",", "284260.`", ",", 
   "530030.`"}], "}"}]], "Output",
 CellChangeTimes->{3.575627897544778*^9, 3.586661078570304*^9, 
  3.5884149156761684`*^9, 3.5884165195489335`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"profiles", "//", "Dimensions"}]], "Input",
 CellChangeTimes->{{3.4830874065771494`*^9, 3.483087410477372*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"19", ",", "57", ",", "4"}], "}"}]], "Output",
 CellChangeTimes->{3.57562789756981*^9, 3.5866610786003056`*^9, 
  3.588414915694216*^9, 3.588416519574916*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogLogPlot", "[", 
  RowBox[{"profiles", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "All", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.484029104186167*^9, 3.484029118994014*^9}, {
  3.4840292271071973`*^9, 3.484029228077253*^9}, {3.484030835778208*^9, 
  3.484030852716177*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwBoQNe/CFib1JlAgAAADkAAAACAAAAAXzONJ6u+j+CXdqI0Gb5P1SfEYB1
S/w/TEgeGzgM+z9m9q8IecL9PwRXMT5eavw/KcsmBR28/z/xBBexKRj+P8Px
xOHQvgBATVv+R+qP/z9p1yTWncgBQGLUMJhqiABA+HNsVc97AkCXx0Et4R4B
QCxWV0oThwNAKfm87oG6AUCTm2QxeUYEQLkMqtAXIgJAuRNjl1r1BEDagzua
0I0CQPeFR4ak4gVAcrGapKkCA0D3U6qyJrcGQJDiT52CbANAAEdpBSyWB0AX
azNuPLgDQBU+EgdUeAhAOzaurfoJBEBet2evqD4JQE5VAERBTgRAJXa2W/k2
CkC/e4bEYIcEQGubRccLFwtAPMce93DGBEC41AG3LN4LQFD6XQ1q8wRAg7dK
eWm0DEBl4gg+vCAFQIQ9jqEThQ1AiDNBw6BEBUDtj1+n01sOQO6TFvlzaQVA
fx23IkorD0AFmWcsIYEFQMeU6sXEBBBAg2vt/u6jBUCDfmZm9WwQQJU7GknU
xgVAB2esW6TYEEAaS7YxSecFQIzu04JaRRFAEIZ5oJEPBkAzNviT4LERQPyG
GHI2LAZA02djdaQdEkBbBBjEP0wGQH/Yj551ihJAcqtSzy9oBkAzl8t1+fYS
QKX5qkdyjAZA5WuRp+hjE0Dfy2dsYqsGQDyEWyEVzxNA8aPXiWm8BkDMaAQ8
LT0UQIyIVA1U4wZAUTLT9RWqFEBvZKVLZAwHQK2xA3FlFRVAK/UlHs8pB0AS
TFc0s4IVQFz0GH1hSwdA3+Shn/HuFUB4A0kF+WsHQCLkaW3dXBZAWMSAH3aF
B0BgZLHWysgWQN4qIhT6rQdArbdgX801F0BJj+gyq8QHQD73N8RZoxdAbiOv
MSDuB0C/R7xjGBAYQO9e1gg0CQhANtbS9pl8GEAQ8op3ISkIQK1vMiYo6hhA
TUsr+e9DCECrbri70lYZQI2tUJXzbAhAhDVq76jDGUAcEOM6IooIQD1WQhzZ
MBpA48AWVdmtCECFLiRt7p0aQIbngLW9zghA2dW+5OYKG0BVZ1IMMPQIQCtC
wwvpdxtAzfogdIQYCUCEHLddt+QbQCjBsDZHOAlAckGtQrBRHEB6JD6ze1oJ
QIkoXEzEvhxAh0ZnzbGACUC8h4lS1ysdQJuOLcWOnwlA3Cn5tMuYHUA25EDw
ILEJQPkqoJq8BR5AOzG7L2u7CUAH3j/MPmgeQMg1ya72sAlAGxF5AA==
      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], PointBox[CompressedData["
1:eJwV0H1QkwUAx/Gx7XmePeOdwV7YYOsoWDQFKeBIOn9whBD4BnRTPIImhAgc
FsUkYtMRbwqiqLycCnU7PRyIiW4QKJEKU/GOdQQBIkKBqZwLkKAjgeyP733+
/76hyolLYzIYjJDX/e+S5OviD+RMyBNPnNEVM7C34GL80BITudNvbpmxt8Ed
bkdxQRsL/jmp+XKdDZroth88rrBREmlff1bMBDuSO7hSRSBm1rLRqZ6Jskie
drSexC+/5fbvlLGgrZtTz8VSSDUyFVmFLDT03nAM283BO0qGbHmIBaPG9f53
Ahqhiz41r/hsJJ5OeFffR+OfnoErB7azkcnyt5m6xsXR5Vbe5io2pn+e4R8q
s0WzsLP3xS02KlWWVm26HR6n1ZUr5tkQfrJRsBpqD1mcw4cDAgInvb669z3p
AEVBTOaF7QQUuwrmeasOMI+Zsg4eIMDlLXj2TToiZlkid6ghkFJh2ylOcELT
qbXGPdcILCcq/cw9Tmi7FKJPshAIFqVHqnydkTwsMO6fI9CW/bgju8YZMsN4
+t+OJDQp0ZrBNWeIa8+PH/MlMTtaHUtmu4BvbfAx7yDxyjQSb/rVBdSR9EXH
/SS2FWl3CcJ4yOPW3jxcRMLNUjcZ1cpDkO3KX0QzifCgfla+uyvm73fe2vzg
9dcqL2N0iSucN0xyUn8nIczp0Ia/dAVz4E5EBknhxzFmwOVkNyxFTag9vSg8
b49/9u8DN0g3rf/5IoqCIaqBYQ7mo0ytUmV9SmFcP3y56wIfYpfdZcUaCp4J
+6SDLgIoi4SMJj2FxhbvEg+NAIa8dQO/l4JJ6ShKmhXg4wwc0U9QCPJrV95U
CtG11Pr2zjUKI8bCrhO9Qhwn7LoCJBx0+EbEH90kglW9eupuIAf+t7UBFQ0i
dF/3W3RVciCdmBrn2rlDrmZGL+RwQKxXez865A7rlj2p7x/noKYx9GDKjDti
Pws4NtXMQZhxRDcdJ8Z7fX9UZPZzkKZxe6L7SQzzyYLwwOccpD+8cS9PIcGw
6OnYFzY0dC3W5Lp6CRQNuU93+NAYD7PdaiA98PKqREhspfGWQZ/TkuuBpKKV
4J4MGrfvuoVenfQAnWFKay+nkVZrXDi8zRPelZckpU009nWXsr/p9MRgtXtI
bj+NkVJVbaWPFDFNhde/fEZjQ+DoR2dOS/F5xLnMLjYX6m55lZkhg92TifN5
Ii6+nctvDw+W4VF5+d6LUi6c4h4OxWXIoDNZLRYBF/8B7BhzsA==
      "]]}, 
    {Hue[0.1421359549995791, 0.6, 0.6], PointBox[CompressedData["
1:eJwVkn841AcAh8/5/jwcx3HucJgfEyvPnksNPXy4jo3R0FJTDck23WYzy+Om
jB7nmWFjMdRESzqL5sE2tGZbIoqW32MSeiTMXPkx5Tb7433ev97/XvvYxPCj
XA6H47nJ/74dKify1SQUcVluk59w8fLnAqJ3LwWnK6NOmhkuAp+V+ZqY0ChV
NX6qUuijTSufSzJk8H5/fHZxrT4YTlkGtcBAUX3W9COSQAw14KZZYUFP96X7
HiLAmVTvV2t46Gvvi5eqCTgfUcQ2NBqg7e5SxNIdAo2/qr7TJhpiNu/SO9uX
CUiDtYP/2BiBpy17ttWKxL3Lodv4enx4ZQrNu0JIOFZ4vRLYw4dT2q5flMdI
5FyNLTmrMUbS4r0Co0ISJtemxr4KNIH/E4vl6zUkqiqL0jbqTFC+dCLXt59E
ip6MN+smwMYXP8o7tSSkjIE7/bUAkq7W5loxhcTo0sUDeqaQGB3JOLqdwo31
30YuvWeKppqJ+4/CKNR19A3uHDZFkd/xhZRkCi1jFwsS5GYISzvx+9SXFH6Q
1m1Z/dYMRLujfKeGwsO0deNeiRAlbPjz/nco5EzPuwxkCpHaoSOezlFYeto1
U/uXELRDQ/0jPo3Xx9rCDkaZw1n/tajdL9KoO+3FFXWaA6vjs1v20BA+Tsno
kVlgOjvZWZVI40plIGIqLJDbd3+b+Wc0PJX9r04ZisAd6N7/QjWN1PqwNReV
CG+sJNlkttOgY5RR/g9EuHvTIrtylMbHD6+3OERYIvJt3el8DoNi6cyQQZsl
OlMXcjOlDMxOes0edBOjt+y5xVZvBvbenvrnSsTYeMJLG9zDYPmUa7o1KcFk
q09IgHKzPx/nMZ8kQYrAYn04b/MT+dRy97gESQd2CfMvMJh4fK5mNNgKA6Ke
8tvNDILDZRHvNlvBZ14nLBxiwO0/VB/gbI01Fz/N7hUGh3Njq38qtEbTSWFX
hYiFWuC6tINjg6ziM5NXPVjMeeu/+UBpA3GqQLoSwuKPxOiQjhEb7CsyvFCg
ZEFElPWvBUjhpxPMlKpZBI32hho0SnFLFujvXsPCsjBP9q+dLQ5H71PF3WBx
hiwZZ/NtUaVr8oibZrGDiA0aWbcFZ9ZA7EHy8HNPg2JVZoeM85dz+PY8uN8k
XdMT7PC91thq2IcH12804boKO1RtjRdHRvLQ7Zo1kTJkh+OqP7v2HuOB2+Po
8LeRPa6NJ18M+ZCHt6r4tS/52qP8VtAHLQk8/AddpHmB
      "]]}, 
    {Hue[0.37820393249936934`, 0.6, 0.6], PointBox[CompressedData["
1:eJwVxXtQ0wUAB/AB+/32+/3Gc2MPZIwtleik5hEW8zC+ycOTBg4iCQJTGnIG
F+AIiRIMFEGeCcR4iQcNJi8lRTSoDglxSCl6ZKSGRDwCGnAEKkpUf3zuI49O
CIkxZ7FYyv/8/wWvLNmEnoM0dllrV5oFPv94bPpAMgXSwe3oQaMF/Iu3315U
0PhkJLR4iMtG4Y+zQ5luDDKHig2u77ERYROl0Fhx4Vs26na4ho3JD+OUu0SW
yA7/unZmlI3gIoPGd8ASPorx8iAuAfUHjR2aQSsU/aU5ct6TwP2SxMD4HGuE
rX5lOhNGQLvFR2f9qg1mvmMKxCkELt+NqX9uaYsqfX5Ei46AbR2lyUu1xXxy
41OXTgI79sx135mwRSVhdJI+IrDPlCEVh9lhvinI78RjAkU3yKT87+1wyvHP
mBMSEv19fXmMFw+1fpm1Yd4kGmQdddxWHiz0vmJBFInYp3oXPz4f/QXHH4yn
kVifXinOyOAj2HjxjxerSURytYeap/lYaG4RB10lYcbimt5+xx47b4W8nzJC
orThctxUtz1+UTycph6TuCn6ZtF1iwBi19KXU3kcNHuxlltLBNCqs3PMFRx4
6i3Ta9YFkIw1ZfmpOKgKySk6GS+Euzpw6+lEDkozuMc8RoTY3Ssa/qeAA/Xf
l4xXfEXIlod4C9o4iGjpMmjbRWApTudl9XLQ2BnL2yQVI0AqtFWNc/BK5XBI
UJ4YyqldnWNmFO42mb0VuCLGHeFkapSIQmbuvUGBxgGmI2slN7ZR0CU1HNw6
5IDrDtX2sSoKSpsJU5vXBlTwOtaZRApvjNT3jJ3bgITwxdcMuRTOHzMo/YWO
ID66ubreQOFaazPDO+6I38zzDuv6KAQ+eBj1ZN4R6YUXVRd+peBRNVVnFiVB
zVT0IckChW06z7LCAQlSdEuqZ9Y0BjpzdWGvO2H27HVy70YaT+7HXP293glj
1w48u7eThndzZFeinRRT7s57AyJplDPZPzumSxHPjqsyfkrjW5mV3fyMFMux
fHV0OY1Ho+FJ0nedoVg6e4vbTmNwWJ/u3ueMYhuuBzFIo93nqFDsIMPuqmrX
TbM0jJfEbZV7ZOip8/lJSzFYcxl5k8iWYV/ZsO65C4Os4JWKwm4ZqMneAKU/
g1PJq9tFSzJklFALm/czUKsrzHQvyRFKRuywTGPg5a46ab1fjh+0Hj0JOQw+
u/KCec6Xcsw1rGXOfcFgUR5K3+6XY/M5++X8XAb/ApD0dS4=
      "]]}, 
    {Hue[0.6142719099991583, 0.6, 0.6], PointBox[CompressedData["
1:eJwBoQNe/CFib1JlAgAAADkAAAACAAAAXCClg6SvCUD03etTaCQEQP5i15Uo
fgpAOYwv5ihvBEAZlmyAvjkLQEArfpLnpARAfFgdBVk2DECqRPSD7+UEQCW5
aRgwFw1AfiZvu1cWBUBd5rjcGiEOQOzwfPDJSwVAnAYF9w/UDkAVZMkLQW0F
QF3kx2QGzw9AEPnT2GWYBUCZgWUnYkEQQE4voFKtrwVABOeANKqaEEAzkwmG
IsQFQJGUwgkFEhFA66KS6CPpBUCmFGqfKnwRQIkGWrBoBQZALUQAH1jtEUC1
eZuacSsGQMKrx5yHXBJAbIDZWI1TBkDL9GP47cASQJHYt+utaQZATYN/URdB
E0CgGTiMWIsGQCciUtU8shNAmtXnGueqBkDYABMkLxgUQDn0PYSOyAZA2ZtC
V/yDFEBc58AA/+kGQDXFxcXD7BRAVSAG37gCB0ARmlH3U1oVQD0wrBleHwdA
uM1vQJjCFUDmfpOjjkEHQDunRw4uMBZAR7omKWpiB0BhvbIpn5gWQByJu0PT
egdAp8dPGVsEF0BXyUgOtpwHQHdb4ZXNcBdAeTg3+XS4B0AQ10uIzt0XQOoX
rQlk0AdAZ62uPLxJGEC0KXHbtu0HQBEeR2yTthhA7KfTGJgICEDs9ros7yIZ
QOyrBEzuKAhAb6p5hU+QGUCXrCwuE0EIQD0ui1Ne+xlAJIUYwpthCEDQQ6Dm
82gaQLJp0VvJewhAC69d8QPWGkDHObHZEpMIQPanrPp+QRtAbDeHJ4GuCECK
bTRj3q4bQMDomSvkxghAOO7H6CYbHEDSa5nLv+YIQHQ6jDv8iBxAUJqANrX4
CEAcZCTF9PQcQMKOIzJnFQlAvE6b7PthHUBmFW4qoC4JQAO7RGd/zx1ACR6t
EPlJCUAKhL2ESzweQH4k0tvmZQlA3sS9w9GoHkBHGqPvmXoJQGUvJYxZFh9A
SRI3xDWVCUCU6AN7CYMfQALIG5CKsQlAoxgxZ+HvH0AAlbF/28sJQIJjIXOF
LiBATJY+qC3qCUBhI53AEWUgQEb2yp4VAQpA0oP2K4+bIEDruXxr9h8KQN9K
5pkS0iBAa3LH8nM7CkC0lQ+ieQghQNRoU4avWgpArxMrzwQ/IUDQpemdenUK
QD40gRmPdSFA+XYLyamSCkBhc9xID6whQKOXn2LEqgpA9YPUz4biIUDoxvAo
3bsKQHJ4AQ//GCJARjToyBXCCkBhfk9vR0oiQISRZQpBuQpAzZ12cg==
      "]]}, 
    {Hue[0.8503398874989481, 0.6, 0.6], PointBox[CompressedData["
1:eJwVxX1QkwUAB2Astr3vC+NjsAEbX8OLhWtmmKMVHz9RJn4iCAwpwdYGjOSg
CyTNDkHZWYxCQIcUwYg44QiLgAhG7ISA5EhIuOFEaagZ12aA5wKHUv3x3MOX
5yYon3NwcJD85/93Tp9wnm12grC3Xvqr3hFZ2VEP5AXOkPz98OHIiiPyfmz1
s29hovdsSKWAS4Mpct21WuSC0X8E8W/to0FRVXtP5eKKk1+ax5pyacguNIoF
zm4oPiP2vFJPw8Sw/VhVmhtqrNrxy1003Cr7y7Bw3w136nSstTkaeu99pS/Z
7g7MfNfGX6fhmvxIpO2CO7x2penuetIxZRbPzzqzoDykLVoW03FS+pu0uoAF
Ts5M6TeH6Ehz6o+4+gcLn24M7yrOo8MXeX19hz3AfKyhgmvo+DCg/YMNP3nA
yBzIKe+mo1ERdtAe7gkXXs+6zzQdz6fnxDDbPdFQHvHu5CodI9LjqR4sNpqn
RBNGDwbyB0u014vYKLu0uEX9EgObls4PxS2wQfuhWDt1kIGZSssQmcTB19q+
cyMqBiyNDZJX+zmoEbSyXlMzEKBIuXVG6AXzXpGB3sCAfIdsa3i1F2Jji0Xb
9Qx05QTFMhy8oVw0XZCbGCiQJu4bOOaNF08FNF+1M2CgFTqF3vRGUhZ7YMmT
wA2rXLgpxgc25s8JViGBTNVqkrDDB8w5a6gtloBH9PngfH8uypXz9psZBEZk
g2JjGRelKR+FRhQRSLkm2z9r48LEbWFHf0FA4ajNUil4WDLtNrZ1Egj70zr9
/iQPN9QWVekwATEvLtM5whcOKyuXcm8TeBoc7Jvd6otvG1WXzasEIp9tW+vh
+IGl2SY/ziKxcf2xpPysH2oNUeF8EYkFy66ZkkU/2LcqKx13kEiMr/9ec8Qf
q2uqmospJBrMyZm8MX9w5pOjNYUk7JX7JXfDAtDyaKQxQUPizbLOqKymAJiW
kwWdzSQ2143n24hAuP3CMZ82kBh2fF13ICoQsrFPXpkzkXjwQr+ityAQJW2W
oZ3LJGybK4oS2wKR4/5UlOBKIfiUVnp7PhD6YqOkO4SCu37PaIoPH0+G3zj9
uZTCO6myrtk4Pg68Z21yeZuCrtcvWqrmo3ttUVdVREHTYm6Y0PPxsrLnmaWW
gvbj8Y7UR3xUXJmriOuhsLe2XW0KCYI6Ru6TdJ1CWUbok/ijQUif9K5X/U6h
VHM0Y/RiEE6IBju49yl8ll5X6joahIFy9obDdyj8Cx3RhNw=
      "]]}, 
    {Hue[0.08640786499873876, 0.6, 0.6], PointBox[CompressedData["
1:eJwVkGlM0wcAR7G0/R+wUqDlLFjKEc4wQCZly/iJAQpbilTYFJVlHVeGUFDk
UOTYAlUEBwFUDBsocuhmKZhhJYvocDgNNsoxyIAqjKLIOGwsihth7MPL+/S+
PBe5QpbCMDExEW/xvxW6e6o0Jw5WJv2vR4SykOUuI/WLHDQsxq8b5SzMrWWn
HeuwQKJfan13BQvFpefnzGVccMNCIl9qWAg/LZkuvM1FTfTOj5P/ZGGmRd/X
B0t4/hgVUGVkIfb8xNzzHyzhPLEhOGvFhiGoayHayQrm8W2Z02Dj+33DA08K
rBDbvAtDMjbiU0K3YdQK7ipdg0cWG09KunKNEmuopqrDemq3+ustg1491gg1
4N/eLjb87/fKckQ85Eo8G1mP2SDWDu/wreeB9WqS+auRjYgxm4tLb3jYvc24
wLAikGGm9LDL50P0qOiAvy8BbUzklHiBj9XjPcGRUgIvWj7SBkpt8NBNurb3
awKtiKkr77OBIuP9cF0FgYr1XeN8N1so64oqT1wmUNxYtfmgxhY3lg8mHbxD
4I50ZM/tt7b4aVwV+WyKwHh4tZyfaoeVW4Eeoe8ILKYnMta0dnBjHzH8TJEg
4yqt8aE9TAg7Q7kfic9nxZqbHfbwycnLaogiccld/bqS54BrBx4Oy+UkUjrI
woRSB5Qcl3VPF5KoSXL/RrLkgPjFMu+xOhLq7EnGyH5HvJ0+lypRk/iEeWP/
q0FHDLV1C9q1JPKWbCseBwgwY5EbO68j0XmpTDfQLMB6Wlj+GSOJv3q53y6b
O4Fpqlx6akHBvv3ZWHCBEwwnuz2YPhT0aXxLpd4JrbJZ7j0xhRNXDGxjnDNy
fJsjXyZQmMt+wdH2O8P+y/l0fToFIVdQNeqzHY6z6mO5ZRTEFx/oJi5sx74k
weErTRTuzp5N9jQVYrDxKSP0JoWqwNqjtWIhrvUHHc0cohB2jrPyh0KI6lnm
xqN5CuOEI32hXQjdqdTUGBMa+b6r3stTQgSfSt75nQ2N4iNfmB6ydoFyuD8j
PZDGu+ysxNfRLvjlzadfqaJoSDvVM8WlLlu/qq4Op9AolW4o/ul1QenpDq/d
J2nEIbupZGmrz/ygKegyDYHQK+K5qwhaX567XEOjxK/zbk6iCBveQcFRozTy
6sP5jFoROsz3tmyu0khwuBqSd1+Etvf2bLJIM/w2wBlZ2RAh+u/f85NtzaBp
lRRm7HAFOKKCzxzNUF506JYmxRUhNvUBIp4Z/gPLEHoc
      "]]}, 
    {Hue[0.3224758424985268, 0.6, 0.6], PointBox[CompressedData["
1:eJwVxXtQ0wUAB/Ax2n4vRdjmxmQbbNMEOQIKgSXRl2ctUeIxQYEwhEJE0Ii4
ECFUaOBA8QaBvBYwuOsPLoMgkGwJqSUiHm+V6MFchxqeICAXUv3xuY88KTMy
hc1isVT/+X/GNeO2rZct9Krdui4jB6+3578dXmuL5svHZj36OcgkU/aIntti
XXgmp+t3Dsx6xiM1xw5/xmZIDTQX6smm+hGLHQqjZ1QdrlzsL6rsqk3jYeqK
qD8ihosH7z0NuHCFh1FNWXxwJhdxGvqPsUA+1vaa1tl6LjL7CuM0TXws+8ep
T7dz4Z00VzOzzIdm746O+z9zwWrx+bz3qABVYxfG0y1c/HApllM5KUBUcKR4
miLQyfN7MzV0MxqIe57+LgQm7i2eo3s246DbtYt5agIlxYbsRpkQ+5XaFdlh
Am023tFWdUJUb/+K51tMQFdY9z1jI4L9R4Y7fzUR2FpWPsnPEiEqOsiyZiLQ
vxptypgRwU0VEqCfINDb/by/QG0Pc7NxmFgisLqE7Mhv7bHBcz69zo6EcClm
W4xUDL/KOpddziRizb9F++jEeGkf+/G2IBKKiaEP2hfFEDdqnuQkkohYOZPW
krgFo4F313tzSRzovOmeMLgFob+GnzqiI6ETli60qxwQgSqfgSYSXnZnw8aM
DtD+s7spvpdEQ2htloknwQvt1MCHUyTid5RGDuVLcOlZ+ETZAgnt9Ype10cS
fCJrbbjKoVB0ee6Gb4wUd0byuhVSCqwTi7clP0kxOJ96bd2DgjZm+W+vV2V4
0BxI2YRRYNaO+1XUy+B8cpPGmETBYO45N0s7Isg23r86m4Le5alJneMI40CJ
8ItyCiUjoxmvmB3xo7dA91obhY8HbpjLnZ1wtFjAtTdRSN51ayMv0QlzZ/uG
9CMUrKa0zHilE+QJlayX5yk4ftPy1huDTuD1CdY92TTYIXuiCthyOCSmWB+X
0Cg0GHyDVXJszXNLoHfSmK4I+vJiphynJY8szeE0Op+cdCJb5XB5WGr2SaFh
dejZp4335ch+/5C1vIBGg0uY1JWvwPmbhZasGhqx7xLHWtUKlK1mF1V10Oif
bg5w/UwBfl3O15IhGjUlG9v0XQrEPsxNE1loCMXdUtljBTTCu79ctWbA/m78
hFGpxM7kiYVcKYM293eGth9QYsV5NtHai8ERodq9/rwS1YedvQtCGFh5bBgW
XFciuSdkU7qawYtWzvDBFSWYffL8W0EM/gXu9G7v
      "]]}, 
    {Hue[0.5585438199983166, 0.6, 0.6], PointBox[CompressedData["
1:eJwVkm1Q0wUAhxFi/5e1m5s4Joy5MUAars0ggRj2Q8RuCkxGkaAlGMi5QvCa
llp0iHiCbMqLYNyRsuASUGxKHiBjEjFRpqeUMu4QwZkEYoAk2CyIPjz3fH0+
POKd2ZoMVxcXl/BF/reuP+qDypmlEIYlBfpPucMmW3WwOpWDU3VNZguLgfJu
3murujgotilKCDkDpqQj2qD3uHjo73TkJDHw1rT7U0E7F9L7wZ0z+xhg0aVf
tscsw+djr/T87xiIPcF5RhiXYa5aTQ03MzDdrr1WFOQBr/zbStUgAw155tOn
9B5wu22o93zFQBOx5zlr1APFbQ7vO1wC5u0GnTR1OZzbQsxjcgL2Iueh3bbl
mLslzKvaTED9qbqkJ5KHqXBSEJBNoKG37kKFiYe4uwJ+TDEBN15OfyjfE4WH
pnd8+wOBbo3zp/kKT2SYJowGK4E/mt+gigg+EpT2xMDfCURltrzLzOLj2ECL
NuYfAoKYXINygI+qTY6sYT4J665AXkD0CsRNsVUMGYkzN7J8Wn9cAadqZyY3
nsSw3eVcjacXvtaUKGu0JEQf539fcNQLEsU9XUkuiapaGfvpn16oHlVYPzGS
yL3Emlqa7I2gsQfKuGYSNxvZtg6rN258tuWevIuEIeVtPypEgBG2Tv1kiMS5
mryhrjMCnHUL+8V1hoQPh/2y9nUfiBcqH21hUhjzGqfePOCDx49eNFSKKJyO
k3SUPvGBokUZLY2gEPJz72RhghCqr/YLC9QUuvmD11UWIbhz6qCKXRQi7cUB
aatXYnak86/AAxSa2vo+nKxcibKD6xUzpRRC17pfLXMVge29uragnkJf5pSn
OUwEhiMxXddB4XDW1orL2SLsXzM/srePQpXssfxynQiT0qS08nEKe54NZYQM
itAcPRoa70aDzD0SNcsVo+2dfONDHg1VavzxVJUYOaym+1w5jdb6EYvxGzHq
lgRfGY+hYeswrku/IsadhYbjph00Xqz5e93VCTH0moiwch2NnsaFGqnEF+bz
H21t1tMYCHiQ2ZnsC06aIyGrjob+Url080nfxX9S7iZfo/HFxJJbVqsvLg6q
I9faaZzItgg1//pCJFBEhc4u9hh0203BEtx8Pmvv5jAxEpz/W5RWAk1o4fyo
lImu9Pd/7T0rwfmybS83bmCCOhlr2dQvgWNifXFrChOmCv9JC8sPgRtlsSot
E+YeS0T4Bj+I4nMuJO5lgkB44+F9frh+rMt5cTcT/wFP8Xwv
      "]]}, 
    {Hue[0.7946117974981064, 0.6, 0.6], PointBox[CompressedData["
1:eJwVkG0w2wcAh9PI8n8Jp0JSKYnknxQzkhvX1sbst1Iv7WhvQ2ljbk66xVy9
xFYzWdFiie02b8GceWlLrNdVzOhwh956bNoLojO3XW9uK8VUK4dtpWYfnns+
PN8eWVrWGxo2i8V6aZf/7ZwUvFrswEeHVdEjCeKi/60Wh4ZsPrYs6cmPE7hY
+mbRKrfxYTg52qTI4uIj8fzsoVOusP9gt/hWc5GjDdlS3nEFm5s/6TTIRUDn
6IH5BDc4znxewvudC2XoZ1RotxsyT3OMqTtcqMolxX0hAkQzJ8sHpAT8u4qc
JpsEaIp8UW85SiAsJHbm2KYAeaOHnUzJBB5xDMqz2UJIu+OG/sklcGonuuLG
b0K8oFksjjIREM3N2/bG7UNR5OvPvdJLQFzuvJQ9sg+l7IcNzTYCtGrWweTj
jsuDXpk3/iLwQYp/9E67OxTc3LXvKBJXRiDQuYvg68o8Kfcl4Wgoa/fQi8BJ
ZK8cCCeBdx9qtIsipFR4Pp5IJjH5bbRa9eZ+6KQDwTIdiRJZm2fs8H7UpiQm
plaQ2DroV3XL1wMFc5Zfu8wkfIKNKy4mD8RlVdPa2ySYZ+2fiJ55YHj65/mU
eyQWPn7woTzDE9PsqwvDyyRaCzn6wBlPRC1cyWCzKLDWcu5nRIghVh8yLQkp
+N9UOkZ0iaHNqhuvU1EIHrvOchBLcFMWtNlylEJrqZB70SDBWI7ncYmawkaA
nv9oQ4LUsUC1dx6FHru+ZuttL1DaXk2fgcKQX26HxeqF7ZbMQnkrhZ9OTNen
SKRAgdk7vIfCTo61WhovxVLbV4uTP1JoUwqSbhulePX9wJev3adAPKkpWR+W
gvmlM83FTqGh++rYyqYUxwJbivZQNKJahdMPAmSwfD1y3sjQ8L+bE3Q2XYbK
S9IJ80EaldefegU0ylBQfzhMEkujIM2cVzspQ/zyp51TGhq3SsT+9wgG5svL
2olCGqs6n6m6MAYnCoNS+VX07vfG8ZU8Br3xZ+wb7TSa3zknO3ONwUiotTNx
iAax7tr4dI5BkPzLkN5ZGgmnM5WX3OVIj1ElLazRSD9i6/83To5wQdVqpCMP
DrMq68VSOci99vdKvHnIb4B+eUAO5Rcc5wuv8ZBk1Sjz1+Swze6pO6/mIe6P
cBvreQViyiL1NToehlwqv7+QqoBb4PGpWCMPXUlOE+u1CvhF+HT01/Nwl/mz
7NwdBQZ9+3pimnngcUzjfdsK/C3aFrvt9v8AxKBvMA==
      "]]}, 
    {Hue[0.030679774997896203`, 0.6, 0.6], PointBox[CompressedData["
1:eJwVx31Q0wUAh/EFsd/bFRMYwmDshe2cGMZVEO98SdTTMtisiLehvIgBIpCx
yyQwc8BVCIiCw0ExElAQGxYdJbKBHSa+JCDxli+8U2xQFup2kf3x3OceUdJ+
RaoNi8UKeNr/fvbF19JWW0ecCM9bVB1gw/zSfnNPtiNK75nv1layccuiP7p5
wBHH719pMnzDxnuKhZy4aCe8dlORmDfChrHNN3FrvxOUReGT5yxscGP0DUtv
c8EbSNIXSglU5PPJMD0XxfOdVkMogapvtRU/BDljsuOra27pBKate6b6tc5Q
FFeZkwsI7ArYWL99xRl2psj6Pg0BTU3rUkr2WvjqE2XxPxJYuH77w9bxtRg1
ZQjshwmUD6Yks990QWnNlT8fmwm0fWS+MGpwwfKcuLWAQ4LM7OQPrXNFaBT3
VqAXCU2Zqn1ToysKgri681tJdL/8gkHhwkNwV/eThTQSUSGySu98Hux4dZ9U
FpJoCN/J/mWOB+Xf1nVKDYnojfI6QuEGscakLmkhkTzcJ7PpdkNWTZRusYeE
w4OB3iyZO/bqlHGb75EIsIxd9zvpjleXj9hJLSTGchPmw/51RzqR9eU+ewrN
HUW1Tul8KA/2G0USCrM3C6b/usPHI2/9ii6QAmsp+jevCA+88uRww/3XKXSJ
5tN8LnhAjWGrYQ8FW5uOYqO7ABdtnJvoQxT8LSUf+JQIsMa2w2A6RuGwxu9c
8z8CeM701HyuoyB7316x4COETWnq5envKKSpw7cMpAnxlmZDy9UbFJKrnd+N
rRUi0hib+XCKwukH03zOoBBdo4KKeiuFO5PNgRdpEZ6RnxyfeY5GgvGafBYi
VOYkHTghpRFUFrLyq0oE/gypSvCnEZC5ahxpffoe6kEvOY1D+ziXYqZEyJjp
jAjZS2P9YpOPu5sYhSWN6zfl0xD6bndQy8VoqyPG4itpVDzOCLtaJIauqi6p
9yyN4FVNkrpLjPO84hEHAw1ledmOqYdibDON9HKGaHxf+/GuyA2eMKW0RIea
aFT/cWpidrcn3vldyzljxyD9+VlBTrUn4lW3R1Y9GLxYX6RbvuGJLQ3GS27+
DMYnGiS5dhL4PWqaK9nJQNt4fGg0SIKf26stTpkMam05x1JzJYhojxWHqBmc
YvezlpskCAxcyHtWy0DKmvgp+64ER6ZWj67RM4hz1VpnuVIsHpQLp40MvGPK
t+1+QwqZ6nTfjj4GLZcHz5zNlyLt07Hgzm4G/wE8+4xg
      "]]}, 
    {Hue[0.266747752497686, 0.6, 0.6], PointBox[CompressedData["
1:eJwVxXtQ0wUAB3Cisd9+v1/JhLHBgLGxLUuHCJ4ODqyvuqM6QIO4cRJ4KI7i
4egEBI6QZHmTHYcOMuUZQ9SRSiCPqNyhjpHISxsedsJiicpTvQA9efX443Mf
0cGMaJWjg4ND8H/+f111Qdo8wcGZ/b0fq9qY6Bo+FMPI5uB5vnvS3H0mDC45
+vIRDr686antXWaCYjQGVX3mhmSl0ImQELD3JB3W3XVDVMOA7eluAk26CnVw
HBeaa2uOlWoC1Rs7Gos7uHB90MTWaAik7k08yQAPbxC8AfYVAq3u2XEu9Tyo
WmbrS3sIlDkJ2suXeeDv7w8p+5NAItP8yJjljiuNG2RZywTiL3wSMzfujnOO
abav+CxkTBqIS1Ee2De3qBsMYCGloFE5bPFAXHjHi9UIFiaoUMuajA+xy1jI
nS9Y2PNDvzPjMh/hQYqmqpMs5LU8M4o8PXHQxJ9PP89CjWtBcnuhJ7aN3me+
6mTBOcwK+Zwn0nrDpj/tY2H2pfjqnVgvmCID8oxPWJgWR3F+MnuB11pUXeJA
4juJcdCwyRuzx54mpnNI7DBY5SsV3gg4sYtRKSOhHzLIdjgKMD+aW+v7PomO
jR4XL6sFUJ5yODMRTeLszIKm6KEA3rWKnREZJPLUptjtH/kgI+aUtKmQhCXh
ViG7zQd+XuYT8rMk3FYeb0ljC6EjOWHtF0gc73T/eihMiNq2yIipX0lwZ2xJ
pQVCNPgJ4sfvkSgIfieF1SqElfnNmy+mSKSWF06NTglxsbu5+NYyibGufO4R
oQiNzfrNWesoKMsTrP5KETKjRNYBCYXA6Ej2gxIR/ipW6B9vpxB7M2iBbRZB
9fsrS/8eCjwfxW+vX4twaenIj/WfUyDSA02L/r44cGxmW10uBXXF6nhesi86
VLm36/QUdr7VYAqt8cVSm1/+pIECcyQ/vMHqi3cXE+w9v1DYOuJfOU2K8fZQ
a2XKPQotSQ27jBBj4mfu93ufUMi5Pg6nHDH65c8GZKsUFh5uNquvinFDtHz4
PVcafQGj6+kJMWpGOkO6NtB4zqmpK+dLsGCX/WHbTWOrfei2c5QEgSnf+l2P
p1FSr+gt00qgqNqne5lNg+TdPbpmkuCDaW9BcymNvxOyrmkXJJgNWgqUG2kc
0hJK101S5E6Ez354g4ZFV2U+fUCKoMxVt9xhGtpiiOhzUqQyQ50yH9HYAqJI
MyjF0bpum2WSRnfXmLjvHylWFoeP2+00/gXOLoMx
      "]]}, 
    {Hue[0.5028157299974758, 0.6, 0.6], PointBox[CompressedData["
1:eJwVxXtQ0wUAB/Ahs99+v98QhzLAwcYeDHncKSELnR5f3YBrUxBOSTFSFIop
xMOkQO4gEHQ+GJjxvOYLFDzhgisCRJIgzhEij8Zj3UIxEZFnEEmgVH987iM8
Gh8avYrBYGz9z/8PNtweaYy0RU+p/uolDoF94SY9+7EttAeDZpJkBNZaZ7d3
e3HBSdSHNR0jYDWcb8Ov48I7sBeGbALG5wNPFB52MJrm/ZquExhSRTrxv7dD
g3q8VdtBIHlxISufY4+Gm0+IaDOB9I2Zxb6l9rgT7PbB/hUCKtV4x8dv7CHX
X5cX8Vjwrc6b+DvMAfHBe1s1m1loDN8S4dntAFcNJ/J+MAvyQwcN2u0bILYx
yztiWNCWtlq+rtqA1LL+Xz7MZmFbyK3RKCEPhf3nYV3LwgOd7O47GTzcYipf
qO6x8M8Ze0090xE+7vmOm7tY4KZEmf2THXHlq5qY6ZcsfJIW1d5rcsRnFUs9
1GoS0uQD65b8ncA0vJus45Kgpp5bMWqcsLomdOSBKwklWsrX8PlwenQxI2An
iam815Y7cviobFG8agshEeU+Z1v0Fx9rjF2nFMdJ7KgbmfX4SIC3prNxwkwS
qb8uHDtsEIDZY1LmFpMIHpjJ8+M548XJL1vaK0hwmko6ekKccfJSrtLrRxLu
6vZFw1ln1IqH7z1+RCIJyqelzc5YCvcQFDwjMXd170TrvDMKRlVKgqCwJThj
2ctDiJVXu0OL1lPYtMpv4bcjQuxDfpZURMGCWRNrLhSitk+tF8goTCZ0OkR0
CeHGHGzse5/Cei99uoApgk21W3tGGIWveZeHx7eJMBS3+LJIQ8F7qPuhXaII
55bH+rvOUehLsUqkK0TYFF3/dqKEwnSVbs5iWIQvjt44UlZLQbMxp3rAVoyC
ls87WW0UuD/p6FC1GBfKU2J8jBR+cDol6s0U43Zrz1jgLAV5mTqLUS9G9B7D
7koLGnyu1n9mUoyOPxcGf+bQ6HvPl4qVSpCexug84EnD5P9UU3BIguwrMgUv
gMaNrPMV8/kSrHO5qwsNpyHbud264aEEgY1F5qUkGrprl8e8VyRo1ta2uV6g
YTf0rOS0zAWVs8Xlb76h4ROU4Hk81gUJ8rj6iGYa0/eFRvVNFyzv0sfKu2l8
67v2onzIBSeiUom6cRpGZvink9ZSnB7N8fBlsJH7XdlUeYAUW0/QZjsOG4W/
Hz5jTJNCvSe+ydKWjaD9lfw/qqRoEAQo4ths/AvClH4W
      "]]}, 
    {Hue[0.7388837074972656, 0.6, 0.6], PointBox[CompressedData["
1:eJwVxXtQ0wUAB/Dxar/HxitgMAZ7MkAnjyA5DbqvOvHBGo9oGoItXhW3IY8l
GgUC3nEgggUJeHSeCcpbpSNQ8kCcUZJBqTxOkUkFSNC2EhSHWv3xuY8w+UBc
mjWDwdj0n/9fx/xmoLPcDb9lLi2cUzPxvLlkp+WJG7x1v5snCpioZA8H9SVw
0DJyLWtLExPtFXwvapqDywF+G7m3mZjraQ8OjnfHpbVdAcVLTHRzDtxgPXCH
eV7UUehIoC7hh5Ujmz3wSa/pIdOfgD98YqV6D9x/Mzi6PpLA1+bM92KkXOR9
ds02W01AyJsJnC3k4s5Z0TG9joB83HDKfZWLmtKyrPOlBAISVB/p0jyxOzyn
tKiNwMo+ufWjMU9sqL0+VX6LgOLbLuu35Tx8eHb/vu0GAlMN/0gSO3l4/kzN
/dxIYH2At2tAoBd6tN2EvwOJI6oXRkuDF2o/sJrRSkns8niWu8XGG5l2zW0d
m0gIU+cu52R5QyISqzWxJG4FZZybn/TGqSGPS87pJKxcnjDsdvBhdn1flpRP
4tWyBb2lkw/f+ranF06QGE98dGjNXgCHhp+clGdIsGfHKlO2CfD62sRfdVdI
HMwo4rEOC7CncPVd0zAJhXgx7OYFAb7cYKy484BE83JJQdisAHl/fv/LK49J
3BgtZr/DE0J+em4m3YpCtl+MeDJOiIHQyKlQHoXD+QsV3DIhNu40rZxfT6Gq
3z/2734hYoz3GM6RFHpcVAeVy0JUxlutDiZQaPnx6ZlImQgr5Rmm7DQKFv2Q
rTlZhJMF1KiygMLAd42fttSJkD4qu3q6msJS1XBW4ogIX1wMdqhvoVCW71VT
ZieGzlWjX+inMK0d+Co3XAzbwZfFwaMUdisMH2tyxVhTjSacmKJARfVGRLeK
sY3tuD/5MQUixhA1NC2GNizV6bgNje6tMq8dHAlgLzqk8qSRPKXUFiokMJ6M
UGpCaeQaS7WpxRKkLSr2Ho2ikVO8vWD6igTyiPGLjok0OjKbdJRJgjGy1V+X
Q8PQdPx6ltQHLq9F/fpWOY2Q7pL4oCQfNK0zJvc10yiq2dPaWu0DN66Gs/cq
Deflyfummz4QLNm+sLlNg7C3rBoYUkw0slvvLtJQDacqB8OkCKx7o51vw0LK
iL1fl1aK2t6uvrs8Fn4W5/2R0ihFZ1WJjBXIwjGZa7XnPSnGFRlJLeEspMaF
2EQ7+SI/JWTzgJwF/vxLlXqrLx7q29IsESz8C4cDd6o=
      "]]}, 
    {Hue[0.9749516849970554, 0.6, 0.6], PointBox[CompressedData["
1:eJwVintQ0wUAx3eI8HsphBGMMdiL7eCGsgoSAf3KZAHiBZxDUhS3VB67pSAa
sMgpD4MjRTxxIq8jZWRAvErkESDmIV6EB0aBobzayoQTAk4Rjf743Oc+dx++
+mjkYQsWi+W7yv+uV93pKNU64GqOqmTsa2v4Pdj4w+SIA9bd1+xEqzU2Jae5
GQIckT4RpzeNWOM73Wz9SLcj5K5Op2YtCaQv/xY078NGZLuHu1ZIYDDvsbi3
iw2JRK/k+xPgK9dofbhOeLYvq0mnJpCUsCFqsMoJ4X9MO/6URmAooTblJcGB
f+Jpz8QCAk+rx6Lz1Bx0Ple3l1cRaDG5+94e5WB4++jpuTurXaISahTOGA5W
ZAw+JKAt3ZDZ2uqMgRUHu64ZAlbHJ14clnKhkC142NmQ2MovZywKuZA1LJ65
KSCR0zdwedbGBbrJ/IGY7SRWRAbnR6dcUPHqrlEdTqIypJmnMLtA6q/x+11L
YkT3ibwn0hV3s1jvpeWRKLzC2xba5oo+ndey2kBCOnjRm3ibh/LCG9lvakgc
d6+7EB/MQ1j2hXGbmySqI9uu1ep5mGg8EXuyn8Sxj3cXjzbzkHXr/nTTUxLf
qu0zBX/zUMD/zLb3NYkndmPSX3l8+EVwzR/QFALyk6qNe/h48lFN9o88CtXd
dv7nvuLD881c4oA3Bff0OMFUDx/2rfm8sx9SkEU0fBH+ko8VnetDOorC60ya
+45MgKR2U2rjUQqVrEDb80cEkI4vTHyfQaFNf3HqaqkAYZPn9i4WUOhtiikT
DQnQujvGz6KGQovLwt5hUoiUoV9K+tooXFPaLBVBCGLNXO70zxTYR3zReVKI
3C1NzEEThXWOz75prhWizE6z2DlP4caOLQfqpoSQ2xfOKhgau2JTonI4IiwH
1SVed6Kx1OhYsTZChP3BoWbzJhp7+kPW6r8UwaJKpenaQYN9S369pUMEpUTv
UbOfhlVRmLFyXoTumVTGJ5XGp2X33mVL3eCnkJ7PyqVxYPzSRrnKDRKO+HZF
CY3oEDwyXnbD1hOVn2c00PBuv3JI0++GskMthn/v0dislBX/aSmGpr7x2INx
Gu3rFZ5SfzEeWw4HbX5BIyHQYOQki9FjDJyZfIsBAkyWr6rF+KvX9qCVBwOR
KDjwn7HVn9FHD29j0JEwHV5sL4F9Mpq9lAxiUsrN0WESzO2Lfx6rYhC6XuKV
c0YCrySfSHk8g2T3ZsuiJgmoS+/HLakZ/AclHXdZ
      "]]}, 
    {Hue[0.21101966249684523`, 0.6, 0.6], PointBox[CompressedData["
1:eJw9yWtUkwUAh3Ecg72XcTloOIGx+0Z8WEwuQiz4EzoZGSgBBZjpDFLBZkch
jUsCrsmlQCDMOCCnIwwOxpFQyCA0YomyRJHeMBCIAg55lgg2VDCqL314zu/D
I9Lp41JZdnZ2If/2n6N1tQbvozx4nV2z3XmKg55NvIb0aR7qy//e38Um8HWb
ZYciagPcvvCzD5UT+Pl6c1GGZQPGwlSxZzQE/HruskojPLCk/pL/xm4CrW0/
dL0z4AGKbTzzTT6BLu29PEbhCU2dVak/TeD83BFtXpsnlu9bJ7Z3E0gZbXJq
WesFqbKyou8WAeZNi4/vQS+wPp62bJ0isDCexnlrxgunJvoY21MCRUsZA91x
fHzfz+6tdiUR16lckffxYet7dCPHl0T7y6nswiBvVNnUsn3RJEKvXBkPrfHG
7EZBYvROEgUXfFi0pwBBzVOHjFkkdnk3JNuKBYhakZXdLiGxupnfcHVegKwb
h69NniNR1RvwkKsUYscr8QvSThLfOktPafYKEThRnRF9jYSVl2OO/FyI9GR3
yZMxEhfmF4fSbgqx+sLuzZ6PSLwraM6NdxBhG2NwuEtQWNevPrwrRARl0vH6
pvUU5v1bC816ETYJqxZzpRT42WHtuY0izMUw7rpwCn8FTWTdGRNh4TNdhTKW
QkL88DCxVgz37F/3qHQUwhWqtEytGHWsHkVJNgUn84yp/kMxklwuDQaXUvjp
WbnDzg4x3H7Mb7l4lsKhJ/pK230xVJMeq4JWCl8RyoQ/xRIcfy8u4HQvhQql
+fnCJAmudj62XWIoXKzZ4hZRJoE5ft3S1j8o+JXWjT8wS8CcVKtVKxT6TWyT
ZEWCF6c5dQZXGix1XgjPX4qHiUTIp1IaHRxG73xAipKg6sawYBqRZfnW+Xop
MmIHD/hG00i7HC/Zx0gR4PFSWbqORpFj8LkRJxkc1ca82SM0tml+Y1wjZWgZ
XubM5tMQGqG1PybDquH1SV01Da3pWW1OmwxNTPFQYCuNoQ8GOxtnZBh9dfFY
vpnGncxcE8mXI9v+/YPrR2kUiA1rLK/JUUXGtLMf0Ki9t1eqLZbDmpIZaKC4
GJgscCn9To658NXCXgEX3RvLz+csyXFz/ycJlf5c0MwvxmSlArcCKjUpMVyY
tjxnjnlbARe3jpN7UrlIqO3tYtUo4ChI/Ggki4uo65Pll28rUHvCLe7pCS4i
llsW5zg+KDraVk2WcfH7SALxONjn//8PA7h8Hg==
      "]]}, 
    {Hue[0.44708763999663503`, 0.6, 0.6], PointBox[CompressedData["
1:eJxFimlQ1AUARxeC/F9qtHIu157/3bgGApUdg59rAyHIFRAoaBIIIRP3JeKw
cVQ6K4RRHHJNqYCMKKkUdMwA4XJYNEiJI0gYC7kh66K4IEn2qQ9v3of3+PFp
4YnGHA7H+wX/eSbb6TePU9bIiagPWeISaF5kdfkGa/ieubTh5kXA9Ipr7esH
bPD14TDtbBQBixoLfdY9G1jGRNvsLSAwUPJ7bUUED1y77qncCgJrWxzog9M8
qNdkVFs3AW2QePC23BabrZ5ZfDRKIFoWlHt8wBYjJRpe0AKBv1RX2DqJHZiM
LXFcAwEj+5ebPYrtsNbqXr7PjMQ9x5GP41ftwJ5ovDUtI6GaUnh1JtpDOHbT
f6uCxLWIyB9cJ+wRz28oT44jYbTtKcfU3wFhuidp29NIjG+iqvo7HaCtgYuu
nMT3lROFegtHGO/9MuV0M4k/h3M9bYIdUbu0vPzPNRKG3oa8dqUjDr4bdSxh
kERsubva8htHPKgech6YIRHgeb+w8u8Xf8v2oveWSPBS/I6/JeSjTu7NiTKh
wFRoMpXv8LGhDQqv2UbhpNdU2/xpPnxOPNs6LaNweF0zJunnY6xA2lknp3DW
PDErZJUPMlbRTu2jECFcC3vkJgDXlxu8K4FCgj7mA8kRAU6amFxezqPQN+lx
bP9ZARJXrN3blRRCneuvvzQuQIBTas6uRgqPxbd6LEghonVZzNxlChltQvkf
vkLIp9SvOvVTWK82+KXnCHHqXEGy1wSFysEmdVSHEMXTDkszGgqGq3Gq9Vkh
5lee/7jbQMHh/a47HVYiDOtXbv9kRiO1VSeIDBFB+Ulgr6UNDZUisry+TIQk
+6pstQeNB7Iyl9LvRBiaZH/VKmhQPTsPKZdF2Ei8dHQ0nIbOKa7zyGtiVDV0
7dmZQqNFk1c2eUgM86YZK0ZJwzl04VHYF2Jk5X7e/ryCxn3OHo5qVAxVsmaT
6Xkasg77/ExjCdLcZgMbe2kkXfUp1MklaAp9ON4/RGPClhDw0iVYr4z5MHuO
Roz5V9ZF5yUY5hM7bqzSUFywSvCZkqCldMfchc0MrGODivq4LJ4GXF+U8hnc
HVkKNgpk4VfgrdSCAduqfvNxMYs3XM2s8t9mcMNWz/u5m8WT2l/8Lx5l0JXR
29K/yOLhzd5v95cwSCnN9E0XSeF2Juvcnc8YLLwyP+9yQIrou/NVXs0MVost
ybhPpchhk4iKiwx6aqo9U/v+7/8CKE17mQ==
      "]]}, 
    {Hue[0.6831556174964248, 0.6, 0.6], PointBox[CompressedData["
1:eJwVxX1Qk3UAB3AaBM/zex7F1AgdjD17YxwgeSjMgPxCCmnDXUDWaQQjo8BA
SwQKphRCEWpHEFEg8iJJoGI0bJaAtAXhYYM4EFIyiO2EEZMXd4QC1R+f+3AJ
h6Le4NnZ2W37z/9/85LiY/3ZjdCVNJp5+yj0j7TbqFV8uB2+OL4nnQIvYnCd
/hAfvpKxEGsRhZ3lDYlkng/rAdWxiQsUqGlJqzDJDbFlmVs6jBQka1U+C7Nu
aG448YHjBIWe5OCeeJU7pPmVU78+RkPLNBXbD7vjdP5YjYWj0TEtUPoECeC3
3kubv5mG+GBOXmuJAAFF3kc+f56GY/gxlXmVB1IsH+UExNGIa0l0ufSeB27q
YoJDj9IYqek703DPA5GNDoPjn9B4Vrm75Y6vENllpvLVVTTOtOfpzWohYkTP
aDu0NFxyX84Yqhbia8FDjd5IY2Auvq9gSIi6JdunDpM0rqTsX2MhHPqpgVSz
jUb5uQDiEsbBnKQ8RRGCvGhyLSGDgyLgff8ON4IZ0Rf7Ry9y8M0J9BFsJeAJ
/tKoRznoidomiSDQeRh+ctwgQlPIO9RUFAG/KtmpPlKE7tAnWWEywXDtnH5P
rgiM8+0j3lkEtdalVP4PIvAs3N2pQoL+UNPiufsizIdrmgeqCdYUZFtrZWLc
nc+98Ohbglsx9xj/WDGkLl8ViroI/p5+LVZdLEZFH1M0dZtgfHWb2vmGGItp
f1T6WwjKH85oO1bEGC144tq2RYKoth2VugAJ7M/mnu5dy0CQ96BMkSJB+m/p
na4yBjHbd7fcr5Hg3YrjFcsKBnVDdjHnhyVITOXCLOEMSlZE1B1nKRK+64xs
jWVwtDeosDtcijGDvTbwIIOMBNM+o0aKockZoymbwd5HVq96rRTGf+pO3Spl
UNMTbXaflKIw3/RZVS2D6IhXg7/kZJjLfrsoS8eg+PqKoXevDJokxaY/f2GA
tv7Q9pMytAVxE2SEwYHBpc2Kn2Vo5ryTmuYZNEX0uaoXZTi+a9lhxYlFYlpI
lf5pT3xYryLdAha/LzReLXjTE6WZ65S2LSwcm1xfd6r0xOPLs/PrI1gYFqql
Lwx44kppluZBHIuwTTtaAhk5Ui+/qL6ZxmI23H77U2Fy1BzOd32ugEWnyHmc
yZSj08Xt+kgtC9suL83VS3K8wkvN8tOyWNrp15BmkqNscAO11cAiwyrsOc/3
wtLCjxtP3mBxeS7Ko1npha6q7+Pf6mLxL2qQhl0=
      "]]}, 
    {Hue[0.9192235949962146, 0.6, 0.6], PointBox[CompressedData["
1:eJxFjmlM0wcAxcuh+D8aHBawQ6Cl9MR5bLqMtsgjG0k3IBwCYpFBy4QWgkAr
lEOyMTaVQ90G1ETXDNSksziqA9nhEAkqiRCEETYIx0BwMhApFvGg2dZ92oeX
l1/eS97jqvMTDrsyGIxQp/5z77R9na6B/qgrrNnZOrYJ/Z6Vgvg6f0hn5Qmq
lU3Q97ef9Vr2x+H9isQpkkDa1QOSZH0AWqoyLbESAoxQ5cGj8wGwsZMznigI
/Gl9qE7UBcLAZF38SePM3Q3j3QOBWLvCaNlXSiC7RDa1ezsHqc8yUV1PQH/v
8rbINA6eSctkejMBS/sG4eYaDp6+3+A++jOBif7EOPNdDrqyXdabhwh4BQZv
jHNwIKsaPec6T6BT/d3IgT1ctM2vurEcBKZlkRMLeVx8cyjL5mCRKNL2jsma
uVh0+b1JJiKhP7YWlD/NRZGKvfVxBAlbmzGp2zcIilKpzZRAIhddurCoIFzz
mbjX8xGJAvb4jd8qg/Cid8Hj9RISkS0nbd0dQVh502Pdr5aEoachSrTk5MKF
mj4TiY1FDdsUXB5uyddaL7SSYJ0Ii5tK4WHHqfLm3V0kPns+mlB1iocPC76S
jQ2TcCn3JQN6eCjV5ad7LpKwlxtVx17ycBYViXlrJEb0LLlyVzBkofbMCA8K
d6Or03KygvHinbLX5vwo6ONJ5tDXwQhZjMkb3EGhflDeKBwORrxpivICBc2h
Lfxlgo9ydYxKmkyh13qzPDucj3Fz1V8+GgrMLxllKcV8NJ7pixYaKDR1quds
V/jI+HFgpqOaQu7MlkvXHzj7DO+aV+cpzHK5GelsAbTfrn663urc/7sjtz5W
gBT53Gl9FwVjkvzz2uMCPKQU2sEhCr9Mr5RUdgqwZ6CxwD5L4bR1r3f6qgDf
c0O01lUK29/YKx8RC0EWP1KwN9B4K3rlaJxKiNtRphNZvjQYsW0Pao1CdEv9
bToJDbri6p3ifiFUYTGXPOU0bpSydWvuIiimj1D6eBoHWcNLvlIRtO9e06o0
NDQRY3GfFIhwH7n/hOhomDiW6++ZRXjkCFduPUPjYu3z/s5JEW765Dgmm2kU
Whatbt5icO2vXirbachC/JrsH4jRJ7LH5tx3/jvPSf21Uow/zPlfSGZodFjV
Ibd/EOPj5QR9xVMaj9PumAxPxHg79fIukxsTS6GTSTv5EgwNm8NVLCaOK/ef
U6X+zy0XNnsdqZOAd8tocVBM/AuXsXkS
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{1.667631346011831, 2.1},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {2.995732273553991, 
       FormBox["20", TraditionalForm]}, {5.298317366548036, 
       FormBox["200", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["30", TraditionalForm]}, {5.703782474656201, 
       FormBox["300", TraditionalForm]}, {2.70805020110221, 
       FormBox["15", TraditionalForm]}, {5.0106352940962555`, 
       FormBox["150", TraditionalForm]}, {4.248495242049359, 
       FormBox["70", TraditionalForm]}, {6.551080335043404, 
       FormBox["700", TraditionalForm]}, {2.3978952727983707`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.700480365792417, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.867534450455582, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.941642422609304, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.075173815233827, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.135798437050262, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.19295685089021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.247024072160486, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm]}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm]}, {2.70805020110221, 
       FormBox["\"\"", TraditionalForm]}, {5.0106352940962555`, 
       FormBox["\"\"", TraditionalForm]}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm]}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm]}, {2.3978952727983707`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.4849066497880004`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.5649493574615367`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.6390573296152584`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.772588722239781, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.833213344056216, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.8903717578961645`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.9444389791664403`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.700480365792417, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.867534450455582, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.941642422609304, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.075173815233827, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.135798437050262, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.19295685089021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.247024072160486, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{1.667631346011831, 13.274277271776858`}, {2.1, 
   3.634951112088381}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {3.4011973816621555`, 
      FormBox["30", TraditionalForm]}, {5.703782474656201, 
      FormBox["300", TraditionalForm]}, {2.70805020110221, 
      FormBox["15", TraditionalForm]}, {5.0106352940962555`, 
      FormBox["150", TraditionalForm]}, {4.248495242049359, 
      FormBox["70", TraditionalForm]}, {6.551080335043404, 
      FormBox["700", TraditionalForm]}, {2.3978952727983707`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.4849066497880004`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.5649493574615367`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.6390573296152584`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.772588722239781, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.833213344056216, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.8903717578961645`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.9444389791664403`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.700480365792417, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.787491742782046, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.867534450455582, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.941642422609304, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.075173815233827, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.135798437050262, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.19295685089021, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.247024072160486, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.575627897691792*^9, 3.586661078797304*^9, 
  3.5884149158192124`*^9, 3.5884165196979733`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Universal function", "Subsection",
 CellChangeTimes->{{3.483763098727886*^9, 3.4837631010420184`*^9}, {
  3.4837632075141087`*^9, 3.483763211584341*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sub", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "\[Rule]", "2.37"}], ",", 
     RowBox[{"B", "\[Rule]", "5.55"}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", "0.1062"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"1.277", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483762174517024*^9, 3.4837622361875515`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"flo", "[", "s_", "]"}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", "\[Pi]"}], "+", 
     RowBox[{"6", " ", 
      SqrtBox["3"], " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "s", " ", "\[Gamma]"}]}], 
        SqrtBox["3"]], "]"}]}], "+", 
     RowBox[{"6", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", 
        RowBox[{"s", " ", "\[Gamma]"}]}], "]"}]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", 
        RowBox[{"s", " ", "\[Gamma]"}], "+", 
        RowBox[{
         SuperscriptBox["s", "2"], " ", 
         SuperscriptBox["\[Gamma]", "2"]}]}], "]"}]}]}], 
    RowBox[{"18", " ", "\[Gamma]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fhi", "[", "s_", "]"}], "=", 
   RowBox[{
    FractionBox["A", "4"], 
    RowBox[{"Log", "[", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Beta]", " "}], "A"], 
       SuperscriptBox["s", "4"]}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "s_", "]"}], "=", 
   RowBox[{
    RowBox[{"flo", "[", "s", "]"}], "+", 
    RowBox[{"fhi", "[", "s", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4831527699455194`*^9, 3.4831528848560925`*^9}, {
   3.483153810065011*^9, 3.4831538126601596`*^9}, 3.4831542710383773`*^9, {
   3.4831601368408823`*^9, 3.4831601377619348`*^9}, {3.483160191503009*^9, 
   3.483160191894031*^9}, 3.4831620338243837`*^9, {3.4837057666310916`*^9, 
   3.4837057844981136`*^9}, {3.483706161017649*^9, 3.4837061633607836`*^9}, {
   3.4837632211568885`*^9, 3.4837632263331847`*^9}, 3.484023225916949*^9}],

Cell[BoxData[
 RowBox[{"\[Xi]", "=", 
  FractionBox["r", "a"]}]], "Text",
 CellChangeTimes->{{3.484034552022765*^9, 3.4840345728499565`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "\[Xi]_", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      FractionBox["1", "2"], "Ka", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Xi]", "2"]}], ")"}]}], "]"}], "/.", "sub"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4837637894633937`*^9, 3.4837638264735107`*^9}, {
   3.483763912080407*^9, 3.4837639132984767`*^9}, {3.484021045133215*^9, 
   3.484021053448691*^9}, {3.4840216245893583`*^9, 3.4840216407672834`*^9}, 
   3.484023227184021*^9, {3.4840274236870475`*^9, 3.4840274279182897`*^9}, {
   3.4840276534581895`*^9, 3.4840276556483145`*^9}, {3.484028082192712*^9, 
   3.484028105462043*^9}, {3.484034365720109*^9, 3.4840344107566853`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", "\[Xi]", "]"}], "/.", 
    RowBox[{"Ka", "\[Rule]", "Karmans"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Xi]", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.484027667078969*^9, 3.484027676122486*^9}, {
  3.4840277340608*^9, 3.4840277717219543`*^9}, {3.4840278643582525`*^9, 
  3.4840278746928434`*^9}, {3.4840344165030136`*^9, 3.4840344492258854`*^9}, {
  3.4841998377556*^9, 3.4841998426986*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1Xk81E0cB3AlocOVFBFyLnbbXbuo8B3JLXIUIkWuVJQuiRzRU64kbR4J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     "]], LineBox[CompressedData["
1:eJwV1nk0lc8bAHBZIpUtFSLJLst1L1fJt2eKEkpZSiRlCfllSSSyJWSvJAlF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     "]], LineBox[CompressedData["
1:eJwV1Hk81M8bAPANZZWIdFCS3GGt3bW76XhGlKtUiA65i0qoSPkm8aPW1SEJ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     "]], LineBox[CompressedData["
1:eJwV1nk0VO8fB/Cxa7MlIkvWIssYM0xSn0eb0GKppMXWkGTXgizxwxehlCQU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     "]], LineBox[CompressedData["
1:eJwV1Hc81d8fB3BRkUKkZCUzZFx3uVflfUJmlMgoOyspQiUyQyorP0n4yp4Z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     "]], LineBox[CompressedData["
1:eJwV1Xk4VG0bAHBRCNmSXko+hbINM2OGEe6nkrX0yhKSJRKSJS32LSQqhexJ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     "]], LineBox[CompressedData["
1:eJwV1Hk01V0XB/BrSCoRKZEhGTJ3XXfgJvuQylAiQoWQqR4ZUj2UISLzUElC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     "]], LineBox[CompressedData["
1:eJwV1Hk01N8bB3DRoogsZcmSNXuM2czguUWypawhiaikLGmlrNHPGpUkfC2F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     "]], LineBox[CompressedData["
1:eJwV1Xk0VW0bBnCZm4ioiCRDyXycyTl0P6lk7E2UMVOmfJUhKRVSSGWoXkkS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     "]], LineBox[CompressedData["
1:eJwV1Xc81t0bB3BRaHBnpIfslWSFe3HXdUR2KimUyEwe2TIjfpSMqHQTQmWE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     "]], LineBox[CompressedData["
1:eJwV1Hk01N8bB3BbkcpOEYnsoWkwZpjpuSGy9rVkS7IlbUgpZIlQWdIie5Gd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     "]], LineBox[CompressedData["
1:eJwV1Hk0lN8bAHBRSNlFxpaSIiTMyvTcUrJMiz0qZUlICBWyfymFREgislRk
y1rZl6hEJaWyVEKWmXmjn1bpd+eP97znc55zn3Oe5V5VF1+ro/x8fHzf8Mf7
mx+dfNkyZbv137iCWlEHEy01Jvl9kDeAr+ZOa3jWz8nIqpLfAe8erl/F85ii
WtQZ9T2wl+zPz7NFz0BltrwN5D8wnryDrZagVPhPxQHem2R28rxg7nrVWd0J
GgZPZfM8HdPf4ZzuDE2n33jzbO/2ozFF3g2kZRsMeO4wJtW1Z7lDcZ36/G1s
3XXMiv+peIKmg2wZz1n8R4rW5x+H2R8XD/MsPBqdZ6fuAzLJMct5fvixr6fd
xg88VQVKbmH77XMzP5h+EoIKBXfxPLz5vHGifCCkBGe5F2Kn5qxuWX/gFLBa
dWYKsM3Fi42ask7DRvZOD55ruc/IhEow5A7ws/KxvZ2cKs87h0B14p3KPOy1
vYTOmvyz8FnylSTPl0qlNlqqh0OQd+2DXOydSgUFU8ciQJ3iy89zeGemRKtN
JARVlxjnYBtQtBId0qMgurKmPBs7d9XecxflY8BweFE7E/tsz9UOu4cxwD09
xLiGbRf7kX/dgViQit2KMrBXzp+MqM86B6bvkgzSsYP6U4PYKhfgIMu9PRnb
OmG49n7LBfA47Z56GVtnh/p8jPNF+N42fSiJN8+qupNK+fFgmxbxPgHb8sp7
rz3ql2D5s7fB57G1LNYVkbouwZf7P8XO8fot4P1l4lgSZLtlZcVgH36weK/Z
5jJ4t/rcjMJepXFZZ396Mnj8Y1qexY4SrtpwQT4VRuWDzU5ga+5Kjqv0S4V9
IsPM49h9sb5Tg12pYH8zQMOTtz8CWnd1TqfBDnfahBt2598Cnf6+dIgrVvp+
gFfvt3SySsI1SHmFfE2xa7acSjf9fA3+hLS/2Ynt5Gf94yQjE3ZtPEM2xi7n
iD/omMyEEeWTb5nYVpNxRl47s4Bvc0m1HnbGcIhxzeINyN28rpOEvU3RoWDE
NgfYObdz5Xj76khdJlyaA6NSB/xlsJXZwa6l2rkQ7r/njyi2rydlPd9QLjxT
ds3nw5ZyK79TSMsDYdI61lg7E+13uFn+dbYADjV/XCzAJgZtRPJIhXDR0F7o
JvY5J+Gj1saF8M9PXjgbu8rVl1SbWghNxyPnUrHFfJixZ6m3oM6i3ysG+1H0
O0fBsNugKes35YytVyIpqChcDPXmFkpy2E90Hh3p0S2GzrYvOlLYR+4F1Yc7
FMPa/57SRLETaz/4fSrGcZILWQB7sqV08Nbuu/DIpP8lt42Jbrw2u7flSglw
b2Rc7cBe8S/q4C7lcggV0LP1ws7wtHfSMimHyarxBDdstX6tI5I+5ZCqqt7o
hL21aMB1sLEcbjqwhKyxHxSl19TpVICF7sbthtgca3aDRW8FKGuyLUWwbe9c
7Q4QrYQuvZVv81rx/T4UzXJXrQQp/ck1WdijUid69pMrwe6ymUsatm/Y9ufM
Q5Uw6XK99zz2BStOn1BpJfgcCdztjd24sP39dVYV6CW3fdbHXm/JnWyPrwbq
hR9+jS1MRIrYxTh2sxqq7bPW1WBLlObGi9Rha3j1lGD/FrbWsRytBuQWIZiF
/aKlLmCEVgN3Z2PFQrBDdKMWf47XgIBkxSkD7F5xGRkdVAfT8Y+z85qZ6Ewv
HTL+9wAkwhlb3Zrw/HRqxp8IPwRFTzlvR+yCRN2EP4oPYc5RM2Uf9kvWhndO
Ox/C4xdfO42wN3XLBKxPfwh0t/k+GewPXcStSmo9vFc4H9jeyES7WgvFekIa
wPT9ikEStly15MiSJc3w9EmccmU9fq9GjZ89N2qD1Y79ydT7TNTmla3gwO6A
hFUR/zGqmWhenSleeqILLrrJhS+UMxH/r7sSCuufQrYjmuspZiLKvyO11mXP
wCpzg51HIRM9izHo7dR8Do93jK9OzWEilcszv4q4L+Bd6N+NeRlMNPPjw8hr
3T64dIewS0zG9U3XPxW79Ao6NFgJehdw/Uq3ibGxfnCyTDMyjWSiBM8a91y1
NzCy9fH47jNM9B3dHfOIGAAr+t+E595MFKjXUS3b/ha+J/2d2+mC6y/riH+p
+h5Gw+aH+OyY6I9X/3WNkEGwjveirjTD/domtOhePwSV5BpRkhHuT57qsXty
I5CTY/FVUhvPQ+nw2k8HP8DyiO7tIsr4PWPbrhjY/RGic95y94gxkbT4V+GO
3x/BejDOZ8WCEVrafL18XdYnmEuOuPR0yggdN6h/t9xiFEYXVv250m+E7pq5
5DZ9HwUUeEhUu8kIzc+QJCbSP8N9172hjbeNUI31LoHUHWMwaq8gm5RohCJM
Y3OqJ8bg2w7FLL0AI6Q6bP42P3Ycdsz5qjraGyEGNSZVXm8COr3ajXIoRuig
8vNfS15NgImWheHxVTj/08RRv6gvgGerIM81RBlLnQKt1CYhcp9pfucjQyQ9
UpPH3zEJodHNkaxMQ7QsLMqGfnIKlk7lSk8dNUR8RU7lo1LTYBPgZ6a42RD5
Z5YnSrVNQ2u38+lHMwzUuClOWNJnBrYZOQYH5DAQpV+uJ8VvBsr+XPsMNxio
IvR2skzADPj7eqWtyGagvJ5O0uqgGRCJvfIsN5OB4nyXaatEz8DEh3T/tjQG
sqqKttROn4GiKr/xT/EM9IURlmnWNAPLTM8diD/DQJLm/lrRYmxgCaZMW7EY
KLdVfAVDkg2XluukdpszkC69dGpWmg0OQuUkYzMG2rNx8pazPBs+tkrf1zFh
oIuCTqrb1NjgQ7om9BMYaGm7mSwfgw0Mx/7zlvoM9N1QlS/8KBuIQyWN0vIM
NKT94lVwAxtqjzLOu32ko5wZyTCBZjbM6fG7F47QkUuRtXpiKxvk5Ir7xobo
aEptICi3kw0LXfGsw+/o6LvCiFLXCza8MVkavb2PjiRF2MdkxtngVNQ91NxO
RyYTQgtlohx4XTbpGFNIR8sLzAppEhyYpAurpeTT0TPn+D1tUhzI9finfuMm
HVkPi918LccB8+Nreiuy6ehI/yqTBVUOPC2TNWtJo6Ozbesum1E4sKVJe1Vs
LB1V3AC1MScO8HufoCW60tG3kG9Czs4cyAgvLXZ3piOK/e2ZYVcOaB4v/ck8
TEf14uJVAx4cuCOVIDfhSEedkSPbuv054ND434yCFR0NuoQdrjzHgZBOY3kS
oiPBDfWZkWUcmDsooAIkOjIT8A3/W8GBzLkXa7rl6Cjhw1qXkCoOrE7jc7ZZ
hevPuKgReJ8DFUrJMU4SdKS43PH+sTYOsIpOlOwTpCO9mZ+v97zB52u+vbs1
S0OHyimSSou8evZWTz6ioVrHn2Iv+Lhw4+eYyss2GhITfLjyPwEuLB3KItc0
01DLQabwlDAXVoqI6fo9oKG1Ijv+VUtzQVd6n0hFCQ1NuFlyWBr4vOa9rxYp
NORD8n4SasOF7KmxNwkONNT5SLtrsz0XaBYi+57b0pDKSaJj1IELBmYp0Sus
aOhFl3+L6WEuDDxZaPEzpyG9U8F1Ml5cWJgoNWUzaOjH83OFJRFcuBYVTLtC
oqHI2JtRQ8VcOH3C7OjoKyoSPSNk7lzKhXN/SRVnn1NRpscJqYlyLpTcSXNe
2U1FVRb0fKKaC00htgHSbVQ0Ifmyg7+ZC3WbtaOry6nI4gafsMYrLkzL1P5d
c4GK3ia5vyh9zYWQ8+qOKjFU5Bb1LEPvLRda9H3zpCKoKNwtQ8NomAtBj3bq
DwRSUYWmrsXeL1yQCDpS23eYimTrDl869QfHA0+GOutTUf6dR3a//3JBKg61
pWpTkW7mJpUIPgIkBhppDzZQkVnYj/K4ZQTkPVqM61egolDjpJfXxQmI3pA3
YyFARaPPm2Ta1hGwz8UzmdtLQb6tasMm6gTs/661uOIxBS1UXizs3kjA3Lb2
bJlWClqVbkd5rU1Axk7y2fFKCjI9yLWfpBIw81X6xek0CiqdVLouxiJALHxJ
R68tBcVlxx4Z2UPgp4UkfoBFQW5WnPVllgS0Dc9qt2ynIMWGhord9gRkidMb
xTdT0MWkA50JLvj870T9rGUU5L6jPf7gURz3t0/s+k1G239pWmp5EHCme014
M0FGv1x+D3afIKBSN9RO9B0ZeVCuzYoEE3DP0+jK5ztktGOGr+79WQJ6OUPz
lCwyUsn1CC0OJ2Cr4YVp4yQyerOcJmQeQ8C5+9c5YYFktHP4jeKFJAIuFYrq
ixqS0ZqUraP7UwhQ/+Cj/GQTGS2Y3Lq9MY2A3WHzpcqKZFRdcUrvcSYBLh6e
rpF/DNDaGBlToVsEdNhNnz5abYAWaaGiA3cIYE0bCtFuGqB3nM99t+7i/md0
OXkkGqDL9lWHTO4RcEtfQKrG1QB5r1RYJ1tNgF3rk9K63QbItDV6cryWAE6x
3JYxigH6p2kVENtAwDM71sFTggbo/YcHNNtmAi6EhZXcY+uj2lTVRbU2Ahrc
rT07X+ojn8WvcR1dON99OwfBDH1kXrV/T+pTAoZs+iU5QfpovUeLtFsPAQXz
vVaq+/XR0MukGwKvCBBWlEjJldBH98/9cH31mgBSvYuU55QeSjU8rJH/loBN
9GC3wGY95Pe1k+s/iPNpG3P3p+ghi0Kd6u0jeP88LitfcdZD6o7pwVKfCPgn
4icbqqWH+MUXt45+JmCt0tkSw7ktaKT96NLKCQKs0onSyntb0MOgnidRUwT0
Ja6JtPfcgtK1yUmWbJx/1s38l+wWdHI0y0aVIOA4HL++t04Xsa4uJc3OEuCh
oRUru1MXbWR5f2j5HwGSZa0LfD6b0dIl/QWXfxAwX1lX/vWbNvpYY+h15DcB
E9kb4iNrN6EGr/zNun/xvmhPPqz/oo6yI0Jnj2P77iJ7zfOtR/8HGGEdsg==

     "]], LineBox[CompressedData["
1:eJwV1Hk0ldsbB3AZImVMukQypkIyHOccznl2kUwpMl+ZSVKkiSJxkcxJEhKZ
SskcGSKEChlLxsjsnPPWr+Rypd/2x17v+qz1rr3393n23tIuPubu7GxsbD/w
WP8auc92N8xZ0p91192duE1HnLrivmNiGlBAYktct/rDlPQyMT2ozWuNWPek
hFzIFQVTuCEtcnHdxh2fSh+IWQApb8p23XIxkrl/pGzhp7oOed2rRq73nBUc
4OLb7QLrng/ra3ZOdgYNd//RcWxrt6W6RDE38OByyFt3s654ZVO6B/zKb/NY
t6osrfin1GmINKqSWnc6u9MT+ewzEDGv1P0Fm2ci9JGVwjlYDlO4tu7qLz0d
TRa+UC2aK7lu3+NuRvbJ58Eq/XHVGPbI/pu6sWIX4fMF+sAodtLDvxrk/74E
/nVd9us2EijQeZV+GazmZz6PYL9gtWsSUgEgO5hTN4zt7eBQetP5KsQkGsmt
W6aTUNmVfQ1UxS79M4QdVyisaKZwHXgDbPYNYh+WzMmZOxUMoYeFLn7Gvt6S
Kvja4ga8ajGtGMDWICnF2iaHwM931tKfsDO3HYuIEgsDZ46sh73Y1zruNVtV
h8G7zOvPerCtwr+wy/4dDg2lX0q6sbcsng+uSY+AX/xqeR+w/fuS/BlSt8Dr
Do/me+wTMSMvqhpugWgjz8Z32Cp6CothzlHgsjX2Q9t6P8sqz0tmR0MiIW3S
gm12Z9DLVCEOjmtfW2jAVjKWfSLeGgfVymk36tfrzeE9M30qHkTG6PyvsB1f
rpXUWyRAzBGhrTXY2/YkqNgk3wZqxpfGcuwQnrLdt8SSIJnYUZOHvffI7chS
3yRgnw0uysHuCfeZG2pNApWbommP1s8Ph9JTlct3ocV+yDoDu+V3jkpfTzKw
Nzecurue90eyplTMffCjTH4Jwa44cCnZ4Ot94F7wMAjGdvA9sXSemgoZj8Tz
A7GLmAIvm2dTQfW5iNEVbPPZSB2vw+nAmjum4I2dMnJVt2ItA+gGrVoW2Acl
bHNGLR/CULOxsNn6ebXT4uIpfAj6en++HsXeyQhwLVTOBPW6/3kfwfY5TZJn
G86Etgfc26jYwm5Fj3PJj4CHp61OEtvGNqvo2/ccCM2N8B1NoCNiyIL3kXgu
6Bz47T+IHeHA435CNxccLtcHfMQuc/URf5GUC70JCm6d2PznaOHXtPIgr+Tq
cB32m9DPdhuD8iGYY/vfadhqz4Q2SvAUwNuTP+KOY79VeePUoVoAGnPxmcbY
TiX+NddtC4C3zq9AHzv2xZjveAF2IG++DvZsQ+FQ3tGnsO/fQF1F7Ix+w5ID
d57B378OblqLp6PNf0Lsj+wsAvFXwy3Z2CmnrR2U9IvAJDxh7QG2XJ+Sk9C5
Ivi8qVslBZv+5JPrUF0R8Pou+cdgv3ySXFGpUgwWOb1lF7GZJxi1xp3FsNEx
pUkX2/LxvfcX+Eph+s9Lw+E4fL9Phpp4SJdCqXhyYj/2hPDZDhvNUrifuNTb
ie0TdOgD7WQptKQaotfYt8yZPdyFpcDilK3Pxa5bPTSYZlIGOSJ+lmex5c1Y
s03R5aA//njiVywdiQcfoZ7KKofsrqN3WdiChZnRvJXlkNO0A6axV3hOqJhN
lMMjdMC/H7urofLCKLkCsi3IN8qwr6qGrP07VQGzN11nzmJ3CoiIqKBKaD98
XWA4ho6udFIg5edLKNm3WPQgGvdPpWLqLU81MGg9I3ewc2JVY/6TqAZB6ymO
KOxuk92fHQ5Xw9yOZ+TL2Pvei1yQT66GGdMSPVPssVYir1SrBkqM9aZXo+jo
yOtc/o6rtbDy7L2JBfb2cqHRDRvqweKwacJCJH6vJnTbP+g0gt1CPsf5cDpq
9Hqww5bRDLvYXBcvhNDRogJNoPBsK9witnzTDKIj9uWngjvk30Flk7Ebtz8d
kf44vTjxvB0uqRq1ZfnRUXuYRmfL3g9QZScd3eFNR1IJC8tPWF0wfd8mbcid
jhaWxkb7VXtgTf7M2xYHnG++5h1/XC9wf2StnbHC+SXzicnJPnjM7loUcpSO
Yk5XeGTKfYTAuEabm3p09As9nfQM/gR7XZXZNlHp6KJac7lo0wBIvXD3CN6P
8z9vju6WHgQli6zjVFk6+s+rL23P1SGQ/ur09LAortdB7jWPmmHgQMshJzbh
+jySPlWyfRRSZVluxis0dEXSUWbcfgys9LsrdRdoSIlhufnT0S+gWm7sFjlE
Q1sFvvE0r3wBI4XQSb23NMRZn1Ykmz4OkubcXJyVNHRGo+bzJuMJKD1n6teR
RUNPDV0yX/2aAAdPh3CPaBpaXBAXnE7+CmFxiou/LtJQxYkjHEl6kyAzyZXQ
ZkdDwQbhD8unJyF1RW27N6Ih6RGjgezwKZA7Of7gjhwNUbXCksTUpoFfc6l6
gIOG7Hd+WN7QOw3CRwNrciZ00OK72AnfkBlIahbNMK/RQSmcDhfN5WbB00Nn
D9sdHbR1tOIRe/MstH2L5o04pYO4gkIsKOfnYHnD0CMZdR3E9sShaEJ4Hr/P
58csV7WRX2pRrHDjPGReuSP6p0ob1e2L5BE6twDeXaqKhd7aiNS3vSPRdwEK
/coSA85oo+LA/NsiFxbgtmar3mEvbfSoo0X8L/8FYFPzDxw8pY0ifbiUpUIX
wO9eguyqizYyLws1U05egNXjBSk7bLXRDDUo1fDVAhy/mLH1jZ42EjLyUwrl
Z8CVpj3PY8S0UeZrgc1UIQbMN2racP2ljVQphXPftzIgM2v3WKCoNjJVnM1z
FmOAykffIM+t2ihqo4P0QTkGRBi96zzAp404mwxF2agMiKkcNo9m00a/tKXZ
rrszoLRS/fbRaSoaVu7qDahlwAdSj09GIRU9XBAK4qhngE758WNjT6nI5ckJ
hdjXDJAjimt3FlDRnNwn/8wWBnyz5CHfz6OiXztGJVu7GGCzdMM38CEVCfEy
TolMMSDZK7N7OYGK9Ke5V5/zMYHHbPnkKz8q2pRjmEsWZMKgmKBiuy8VtTtH
mzYKM4G8YYPSwDkqOjHCn9W/nQlWPJL9815U5NS3TX9VmgkCaYoWKy5UdK1R
NsGQxITJckKx3pyKijNAbtKBCUYG3x1bVanox9Uf3M7OTGjdHN6bqUJFJOv8
hRFXJnSeHpbxV6KiGgGBsk+eTNDzuaS3S5GKWm6MHnzvx4TLrkI7raSoaMgl
yLE0ggl9WtPWFnxUtHF3TeqN53h+7dCAgBkKMuTwuf67mAkBvrQgrikKihmT
cblaxoSBKaf6uAkKEkqJ2nOxign64ozplBEKkthkV3WqkQm39vJtj+6lILWF
f/tNPzJBoeSC1fgrCjpZRBKSXGPC9M8FO9k7FPTC7l/+LjYWsJ5Uvt2cQEH8
G6u3/MPBggnusgkihoIa7Gk8czwsOGjQ+7UggoJkePX+lG9lgYGCRPt8AAVN
u5kxTfawIPXp5e4IRwo6J+79NtCCBXUhMpxtChTU8ka5db81C6bdP4XyylKQ
1HmiecKWBRKCvDX6UhTU1erXYODIAhWtnVzPtuP9XgqoFPFiQfd4ZO5uHgpa
+hCR+yyYBW62Uh2dM2R0IzwrZLiABU9Hn0ftzCIjvivcRs6FLFiILRyrTCej
VM+zwtNFLJirjk8zSCGjMmNKNlHOgs0DfY3H4sloWqi7mb2eBQV8LX++BZKR
cQYbz55eFnh1F0+dtCKjgXiPrsJ+FsSY/zxub0ZGbiHtKWoDLLjV7fv4mAkZ
XXdL2aMzwgKZd6M2IofIqHivqvGxGbw+r+kuQWUyEq10jLv0HwtMFc/efMhG
RtmP31it/GaBIM+WyZ4VLaSauk8qmI2AwRYuv6WfWsgwaKkokouAg6edfwjP
aaFA3fjuNAECdqXcfx3VpYUmPrwSaZTF/6/oeaukayGf13Ij+goEhDV1rhnf
1UKrpVG57xUJSETBbyzitNC2ZCtSvzIBdTTXRfkbWsjAnmU9q0WAOE2GvcpF
CxXOSqbxmxCQLmfZIiSrhSIfhDuNmhKQ37bFMUNMC7mZM+Wfm+H5Vgw+cAhq
IYna2uKj1gQkXXnOZ7FKQlHxf7fEuBDwxHBtx0QPCXnoNUXbuxOws2N8jq+N
hA4t7zVT8iRgr84hy411JLTssjL0/iwBwYEGZMs8EvIk3f/OG0DAmnfQd+XL
JKS3wFY5eI2Af0qF+EJPk5BUpmdgwXUC5vUHW+LtSejjJjK3URgBXSoSQe8P
ktDhkY8St+IJyPnP5KcDDwntSqRP2CQSsKI8sUtiWROt6uflK94lgC2ftvnC
nCYqL76k1pZKgKrlYOenNk0kEyZiwJ1HQCWfcXtziCZaIwfyfXpMwKXPCv33
z2miz8yvPXlPcd5xz6l2O02UYF12Ur+EgAK1/d+kDmgi7y07ZEXLCbiqzntI
YYcmMngdOjv1ggCZWmLeilMT/dlrfiG8lgCK75nV770aaHDsJdmyHvezENE1
qjXQiyTpNblGAvSrohqOPdRA59a+RTa3EvDV7ZxHprsGMiqzMU16R4BS70zY
bX0NJO/ZsNWtA/fv9+//dctroOHu+AyOXgJqzdzqfEfVUVXEkmtvPwFR1fe+
Ha1UR0najnuyBwhw2Skc7Rerjny/tbD8hgh4HN/hedlJHRnnqpQfGiUg5uQF
wYH96kjBLjlAeJwADbvkqh8raohdYI0+8ZWAUY//zS02qKHRJnfO0mkCfrRw
jbfcUEPV/h1vQ+YI2Kby2naOrIaSlTXjzRgEyFnnqRyaOYDOT6RbSBMEzMbd
+lMSeQCZ3OMU//6dAH8PhqvRXweQoon3WMNPAsz55qsiY1UR54a+nIQlXG/d
zGPUov3oS4W2l9MKAXZ374hsv6+Mar2y96v+JqAmMqv+85U9SFst1vE5ts8R
Ta9FNnn0f2lEIJs=
     "]], LineBox[CompressedData["
1:eJwV1Gk4lV0XB3AhpDKlgUiEEJLxzGuHSKRESkmUUMlQKqmIkHl6JKHIGBlO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     "]], LineBox[CompressedData["
1:eJwV1Xk4Fe0bB3BbUcraRpZXllJI4uzcT4qypFdISrKFlCitCvHDi5AQskS2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     "]], LineBox[CompressedData["
1:eJwV03k81NsbB3CRJcmWdIkrQqVI1jEzPCdLmHCzZ2msRSKUylK2n1yVonIl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     "]], LineBox[CompressedData["
1:eJwV1Xk41VsXB3AhlDJVikjKEEUynMMZrFWJDClTMiRTlJShAQnxUipKrosi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     "]], LineBox[CompressedData["
1:eJwV1Xk0lesXB3AhTgNCKuJKGSLTPRnPcc7epStzAyWFIkkoiooyxEUiNLgq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     "]], LineBox[CompressedData["
1:eJwV1Xk0VW8XB3CZpUwpkSGZkiHJ7N67n4sypkSDkpAilSmVZIgXGSP5qVBk
KsLFNWRIQpQSSSlCIdEdDk0i8T73j7PO+qx11ll7f/ez9qPo4bf3ODcXF9cP
/HDeNsenXrdM76NIqm2ZN06nIl5zGf9RaT3Icrad43h7zs1surQFNIjTZjme
kFWOvKBqD5Td+6Y4tu0eqLot7QS94pQhjpWT5AqXFZxh5uDJLo4XbY7dcFd1
BW7lgRqOv0X3t7tnuINZ4JXbHB/wnHuUJu0JXWYhkRy3m8vUtWWfgJR0mjvH
Okrkip8KJ8HrhBqF42xut2KV/FOwVPt5HceCY1F5+1V9YTx6hGGE3fCpr7vN
yR9CX8k94th/j6eNS0YASKblJHA8vPWKebJ0EFyL8JHhOD1nfYvK4XPgVEj/
aIhtI1pCas4+Dx0kyOK4lv1Sn1C4CKO1cqs5Pu3qWnXFPQR2pvu3GGBvekVo
b8y/BG/f8/lzfLVMYrODajj4JM616WPvkCsomPaKALEfjt4ch3dkij1xugxq
Nd8FOdYz0Ex2zogED5M5ih527trdsQnS0RA/vCFcF/tS9432/Q3RsLE8gZfj
/TGfuJUOx8CqetMr27BX/QqIaMyOBd1TnpE62MH96cFMhXgwqu2x0sZ2TBqu
fdgSD196dldqYWtbqP6Kdk+A2QXxdRxP0OsC5PITgdfXpV8D2+H6oI+96lWI
kxdSVsfWtFUqlum8Cgkyt3w3c/LmOf110isF1v72qVHDPlq/VPnYKRWMdfoN
VbHXqqdqH8y4BqJTjaJK2JGCdLV46XSIKf0gLIu9xfJaXJV/OnSUCvNvwO6L
8Zse6kyHUK6Bv9Kc88Oj+UD7/H9Qf9Z4UAq741+Bdn9fBggba3qs4fT7I0Nf
IekWBMo03xHCrtl2LsNq/Ba4B0fsFcR29XecCzDJBE/nDysEsGks0fr2qUx4
dXK/Iy/23qk4ks+ObGiWC3qydJ2Kbg6HmNcs3YEDi1u7vmNTZZ0LRvblwDgK
NJzF/nbIkE+wLAem+O1yCWx55sVjZVq5oNP71JOJ7XfSQIXrYy4Qh3offsGW
8KTdLzTKA8tnOskD2Aed79JmZgugKD11sg6bGHJamSdTCJ5jL77VYMe6Ch53
NC+EiVVaDDo2/ZifTG16IWiVuH2iYYv4kmMuGRaBz1BC9j3sp1EfDvGH3YNJ
qw+HM7B1S8X5ZQVLoGXls1/+2M+1n7p165SAxaGMcF9st8rgxnDnEhB7dYXn
NHZy7aj/55ISCHnyZoUX9lRL2VDRrgcgv3l1rwv2nbfWlduul4LlX6LKElt4
OdLFUp4GixLN12Q4eZ084Kq5kway3DfLpLCV+zXdxH1p8Gf3w6eS2JTigWND
j2jgnfnimwh2fXFGTZ12BfwZNxbkwWY5MptsX1XAfJ5s6rc0Ktp3/8aLs6ur
YK2Z9pta7OwjUXYnFKtg2iX7Ah17TOJM90H9Kjioumt9BbZfmFkP+UgVpO04
b1+MHb+X1SdQVgX3t40nZ2E/WjQbzLKjg/sWYecIbBUH9lRbYjX8DLunYIEt
E2Fp4nW3Gqz4F/4AtlhZbuLKumq4LPa52xR7QdBR22GsGvJnTvlsx+5tqTs7
YlQDz5r9fDdhh+hELv35UgOyE3x5y9eo6JWopKQ2qgMDb8naWuwLr4zh5s96
4DuyN1YKW0S75stzwQb4M49uS2AXJOsk/ZVtgMBMm4rV2K/t1D647miAT8rl
XTzYGi8kz6pkNICKaGUvkUpFo51EUZVhI2jqXlLsxLZ8UijSHdIEYUYt/YHY
UtXiIytWPAZTj+jzzSl4X42Zv+whtcKb/UY6K65SUavP7Q3OzHagbpYv5k6i
ol+qZNGyM52QtSq0aDyeirjnH4htUOkC4fgiN7srVGSw7FbrWP4SnC5Vpt2K
pqKX0XqvOrb0wOV59SBaJBUppDLmi9m90GC/L9QgnIoYc6Mjb3X6wGDed01p
CO7vW2OXyNU38OmeRXn4edy/3D1iYqIfNsamxwoFUlHSyZoTucrvQH/80OGk
M1T0Gz2Y8I4YgGvXNLbu8qaiIN326nVt7yFhjaeH4DHcf3l74mvFQRhUKxj4
4kJFf336s9RDhsDxvnrMqf04L6rA0onGj+Clddv/+26cT56iV6XUCIQGWXr4
WuF5yB3d9NllFOiWjMRvCO8z5j7hgV2foPLt0bFVxlS0RnRGsH3hE1zgfryJ
sRXff4+zaErZn2HkoTW9S5WKTuk1fhCyHQO5Rzt9tspS0QNrj9zm32PwgKL3
868YzpMhIzaZMQ7Lz2M12/nwPnK05Em3mIDKkYiF0j8IRVjF5FRPTsCyR3lz
OAMhxWGb9/kxX8BdviYqbRghE8PodGndSegXU5bQ70bIRb5nfsWbSRAI916T
1YTQr67kMf/Ir8A/t5r/+32EbvK6Bu1VnoIgh+3dz9IRWjNSk8fdPgVOF7of
C0cgxBcW6WQcMA2DN6pFBj0R4ip2pY1JfIN6Ad+Ks9YIBWbSkiVav0HjPzWH
Z2oIPdKIExT3ZYBTi5t7zgqEDPqlutP8GdDDbsvgw64IvXdN8iwD/CcIv1Nc
COV1d8isD2ZAl4fM+tNLgOL8+LQUohjA62DbkjwPaC89ykErgwHq20sNywhA
X03CMq2bGfA9+2rd/iFA4jaBmlEiTODKbD4iXwEo94mosIk4EySXTQVvlAPS
MS6bnl3DBAmN3BSRMkD2m6eK3KWZIN/Yq71QDCiB31WRqswEHV3eqLZ8QLxt
1uu4TJgwtW1BSO4GoN+milzhx5kwkcnYMxoK6KNW75uLTUzwSRmx0LEAlMMQ
D+N5zITaletUAswAeRQ7qiY/YYI3oXO9AgGaVh4Izu3A37dyi2mQ8f82jMh1
9jKhTz/GVsQA17+S6SX5hQnKeuL0RDVAOycFFstXs2Ca9WbXHiFAQgXWhUZi
LEiV+LLeVQDQS/dE+1YJFpS+75Pz4QPkOCxy960UC6asZp6FrgDk1r9256Ii
CzY5y9slzVPQpValVGsDFtDjKtUdpimo4g4oT7iyQOR5dZBzJwX9CPkh4O7O
AsHY3GndpxRkcOAeY/gYC3RKHE1WtlFQo6gofcCbBWIfaa5VzRTUcXmE+iKQ
BVv2cFOmaihoyCPsaFUsC74TEtGT+RTEr9aYebkc1+Pw5YlwOAVZ8/iF/6tg
ga5beueNSxSUNLrJI4TOAtHflcKKFylI/GaCetBDFvwptzDUCKIgWaFDD71a
WdD3s91PzoeCdBl/3tq/Y0Fe6Y4nZ/dR0BGagbjcEgtUN3rM1KhTUO2hPyK9
XGzYSfP1uKNKQSL8Dav+x8MGC/GH4VFKFNTiQhacFmRD8J/sWLIcBW1aabFc
vYYNur+kw8LEKGjS04Flp84GXsbru9K/ychX5vTzUCc2/G5jKh5+REYdT7U6
tx5gw3kF86Lb9WSkEEC0jzmz8Tx1Jz7UkFFvZ2CL1VE27DFeZwLlZKR77mKd
pA8b0qwTfjTcIaO5ntjC0ghcz8scR49wMrocczfyYwkbBv1a86sMyWj1BQEb
9zI22MuJ8thtJ6NM7zMSkzQ2jHqFPP+oTUZ0W+N8opoNpU4J/BMqZDQp/rqd
+zEbWn+rB8asISPbO1yC6m/YoGfzqu07k4Tep5zoLXvLhszHkpTZryTkGfny
pu57Nkxs/V0wMUZC4Z431UnDbGjMcz9X/J6EKrbo2O7+yoYGMndUYRsJras7
evXcXzaULBgm6d8gofz7T/cv/GNDrvvMsvc1EtLJ1FCI4CLg3cWqwuREErIO
m6PF8RHgEd95sDiChELNU15niRKww27muqIXCY31NEu2KhEwefLFzg5dEvJ7
ojy8U5WAmdT/lsc1SGixKqHwxWYCLGpHWExlElqbsd/grRYBDfshoHkdCVm5
sA9MGRLgGbHNyGHeFJVNyWWJ2BHgYhbXV1pviuJux7iN2BMgKTVYb1xhijz3
slTKHQjoOxIVmlNkimSbmip2HSBA05B8eibNFCWkHO5I8iDAKKFS6vJJU3TC
oi3R5TgBHXvUDpe6miKz+S0Omt4EDCqVmhU6mqJ5j4WhF2cI+Et/tP0XyRR5
G9yaXXmRAKv6CwG9q0yRBYOrbvASAWK/DlipcJkihVzv0JJwAih3m55v/2GC
3gkZCdhEE/Bclm4U8N4E7Rh+JxufQsDDPgtCMMcEbUyjjB1MI+ATc5N7Z4oJ
WtxZdG/zfwSICjWVKFw2QdUV53SfZRJwfSQo9spRE7QpWtJKoIgAc9t7V0LX
m6Alo9DVA/cJcI/bKO7EZ4I+sMb7ih4Q4N+5PBY/a4xSD9CP7Kwk4Jqg1KHx
TmN0etUGpXXVBKg2b/dlVRojqydRU19qCdAN3WOzKcsYLW/ZezamiYAfyw88
On2M0eBovdG+xwSU0tqLRR2MUW264pJyK57fkWkBXQNj5Ls0E9feScBinkbW
9UUjZEM/aJ/eRcAz8z1mKcNGSMW7ZY1nNwFdizv4PzYZoY+vU+7wvCGAFL+1
I/OcEXoYO3fszVsC9OnF35PsjVC66VH1/PcE9PRpaL5QNkL+Mx3swCEC6v9u
72LPGSLbQu1qsxEC9F7anA3uNESqhzIuSnwmIJyLFtGZZoi4RZcoY+P4PNw6
TV7tbIhG2o7zVk0SkJvIH2wsbYgagrufR04TkHJ//uLQawOUoaWf4sAkQFvP
y5R92QAFjGU7KRIEbNbo3xWqZIDsbvDKzM7ii0cyg2BX66PNdqdHW34SsLfD
tTFdSx/xrugvSJ0j4E7l3Pp/4XroU42pj9sCAfJvNaIK47ajJp/8rTr/CFj5
e/OV7s/bUMdH4rTzEgF+lvo+v7hU0P8BcVkJNQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 10.},
  Method->{},
  PlotRange->{{0, 1}, {10.501872366908826`, 35.15801920469508}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5756278991449766`*^9, 3.5866610803044915`*^9, 
  3.588414917262384*^9, 3.588416521176146*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Xi]s", "=", 
   RowBox[{"1", "-", 
    RowBox[{"profiles", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ups", "=", 
   RowBox[{"profiles", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "All", ",", "3"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4840347041564665`*^9, 3.4840347375813785`*^9}, 
   3.4840352948742533`*^9, {3.4840354249186916`*^9, 3.4840354285619*^9}, {
   3.4840354739174943`*^9, 3.4840354751465645`*^9}, {3.484035515615879*^9, 
   3.4840355159999013`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[Xi]s", "]"}]], "Input",
 CellChangeTimes->{{3.48403549569374*^9, 3.4840355061753397`*^9}, {
  3.4840357814120817`*^9, 3.4840357816150937`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJw1yQlI03EYxvE50YzwIGQJLcwsTROP1KWW7vHY5SycUIZUDEEqRUqlIgv9
m2JGyRQLM0hDjTzWsGTkVjoRaxFSaXikOUNzTa1mISkqdODvfeHl5fN+fTLP
pWXxeTxe9L/9fzdmUbyHU0Xl2exi9oBMMGy2zZJdkK09nq6eIXvgvmu9rmaK
7Il7N8Lfv5oge8Gij7HrR8hCbN3GSeeGyDsRFlC3XDNA3oULRx8ISs3k3TCW
PIrM7yP7Yf7UNd2YkbwXKh/Xk+JOciCCzfs8YlvJQchUGNaEDeRgcKOn367e
Jocia33t1pbr5DAofaqUwsvk/ZDFOPqG5JDDYTQVfnqWQY7AmStL5WtyciQM
N0MlhgiyCCEWzUSIN/kAyp53XpxwIkfB891HfsLCD+ZolOb210wOkGPQpNMv
t7aRD6KxMEfdXkY+hOxJZ/1UBjkWSoezfxyDyHEI/fXUT7DynVmM7PGXER+6
yUCLpte7qIiZAyxVUqcjIurxeGiq7Su1fmM9HrP+w3E7NMy8BNyRN9aqgqgn
wKFZlJdvWmA9EeWaioDqJGYuEdX+itGUnnnWk+AuKYmr9mfmkqCdrhzwLZ5j
XYLyS4YKe7+NdQmWVroPF//+yroUVnHzVI8bMyeFVuU+aHOzsi6DaJOL1fbz
C+syNJvtuaudM6zLkVrBJbakTbMuR119R7/jm8+sK3B37OqJ7YEW1hUQPhE0
8NXjrCfjhdjSfsxvhPVkCOSp614Fg6wr0Tt93ppe8Jp1JdRDXo+b2gysp4DX
1VXpvCg1bfQUdAzyLPzNRtNfAm4VOg==
      "]]}, 
    {RGBColor[0.6, 0.24, 0.4428931686004542], PointBox[CompressedData["
1:eJw1yQlI03EYxvE50YzwIGQJLcwsTROP1KWW7vHY5SycUIZUDEEqRUqlIgv9
m2JGyRQLM0hDjTzWsGTkVjoRaxFSaXikOUNzTa1mISkqdODvfeHl5fN+fTLP
pWXxeTxe9L/9fzdmUbyHU0Xl2exi9oBMMGy2zZJdkK09nq6eIXvgvmu9rmaK
7Il7N8Lfv5oge8Gij7HrR8hCbN3GSeeGyDsRFlC3XDNA3oULRx8ISs3k3TCW
PIrM7yP7Yf7UNd2YkbwXKh/Xk+JOciCCzfs8YlvJQchUGNaEDeRgcKOn367e
Jocia33t1pbr5DAofaqUwsvk/ZDFOPqG5JDDYTQVfnqWQY7AmStL5WtyciQM
N0MlhgiyCCEWzUSIN/kAyp53XpxwIkfB891HfsLCD+ZolOb210wOkGPQpNMv
t7aRD6KxMEfdXkY+hOxJZ/1UBjkWSoezfxyDyHEI/fXUT7DynVmM7PGXER+6
yUCLpte7qIiZAyxVUqcjIurxeGiq7Su1fmM9HrP+w3E7NMy8BNyRN9aqgqgn
wKFZlJdvWmA9EeWaioDqJGYuEdX+itGUnnnWk+AuKYmr9mfmkqCdrhzwLZ5j
XYLyS4YKe7+NdQmWVroPF//+yroUVnHzVI8bMyeFVuU+aHOzsi6DaJOL1fbz
C+syNJvtuaudM6zLkVrBJbakTbMuR119R7/jm8+sK3B37OqJ7YEW1hUQPhE0
8NXjrCfjhdjSfsxvhPVkCOSp614Fg6wr0Tt93ppe8Jp1JdRDXo+b2gysp4DX
1VXpvCg1bfQUdAzyLPzNRtNfAm4VOg==
      "]]}, 
    {RGBColor[0.6, 0.5470136627990908, 0.24], PointBox[CompressedData["
1:eJw1yQlI03EYxvE50YzwIGQJLcwsTROP1KWW7vHY5SycUIZUDEEqRUqlIgv9
m2JGyRQLM0hDjTzWsGTkVjoRaxFSaXikOUNzTa1mISkqdODvfeHl5fN+fTLP
pWXxeTxe9L/9fzdmUbyHU0Xl2exi9oBMMGy2zZJdkK09nq6eIXvgvmu9rmaK
7Il7N8Lfv5oge8Gij7HrR8hCbN3GSeeGyDsRFlC3XDNA3oULRx8ISs3k3TCW
PIrM7yP7Yf7UNd2YkbwXKh/Xk+JOciCCzfs8YlvJQchUGNaEDeRgcKOn367e
Jocia33t1pbr5DAofaqUwsvk/ZDFOPqG5JDDYTQVfnqWQY7AmStL5WtyciQM
N0MlhgiyCCEWzUSIN/kAyp53XpxwIkfB891HfsLCD+ZolOb210wOkGPQpNMv
t7aRD6KxMEfdXkY+hOxJZ/1UBjkWSoezfxyDyHEI/fXUT7DynVmM7PGXER+6
yUCLpte7qIiZAyxVUqcjIurxeGiq7Su1fmM9HrP+w3E7NMy8BNyRN9aqgqgn
wKFZlJdvWmA9EeWaioDqJGYuEdX+itGUnnnWk+AuKYmr9mfmkqCdrhzwLZ5j
XYLyS4YKe7+NdQmWVroPF//+yroUVnHzVI8bMyeFVuU+aHOzsi6DaJOL1fbz
C+syNJvtuaudM6zLkVrBJbakTbMuR119R7/jm8+sK3B37OqJ7YEW1hUQPhE0
8NXjrCfjhdjSfsxvhPVkCOSp614Fg6wr0Tt93ppe8Jp1JdRDXo+b2gysp4DX
1VXpvCg1bfQUdAzyLPzNRtNfAm4VOg==
      "]]}, 
    {RGBColor[0.24, 0.6, 0.33692049419863584`], PointBox[CompressedData["
1:eJw1yQlI03EYxvE50YzwIGQJLcwsTROP1KWW7vHY5SycUIZUDEEqRUqlIgv9
m2JGyRQLM0hDjTzWsGTkVjoRaxFSaXikOUNzTa1mISkqdODvfeHl5fN+fTLP
pWXxeTxe9L/9fzdmUbyHU0Xl2exi9oBMMGy2zZJdkK09nq6eIXvgvmu9rmaK
7Il7N8Lfv5oge8Gij7HrR8hCbN3GSeeGyDsRFlC3XDNA3oULRx8ISs3k3TCW
PIrM7yP7Yf7UNd2YkbwXKh/Xk+JOciCCzfs8YlvJQchUGNaEDeRgcKOn367e
Jocia33t1pbr5DAofaqUwsvk/ZDFOPqG5JDDYTQVfnqWQY7AmStL5WtyciQM
N0MlhgiyCCEWzUSIN/kAyp53XpxwIkfB891HfsLCD+ZolOb210wOkGPQpNMv
t7aRD6KxMEfdXkY+hOxJZ/1UBjkWSoezfxyDyHEI/fXUT7DynVmM7PGXER+6
yUCLpte7qIiZAyxVUqcjIurxeGiq7Su1fmM9HrP+w3E7NMy8BNyRN9aqgqgn
wKFZlJdvWmA9EeWaioDqJGYuEdX+itGUnnnWk+AuKYmr9mfmkqCdrhzwLZ5j
XYLyS4YKe7+NdQmWVroPF//+yroUVnHzVI8bMyeFVuU+aHOzsi6DaJOL1fbz
C+syNJvtuaudM6zLkVrBJbakTbMuR119R7/jm8+sK3B37OqJ7YEW1hUQPhE0
8NXjrCfjhdjSfsxvhPVkCOSp614Fg6wr0Tt93ppe8Jp1JdRDXo+b2gysp4DX
1VXpvCg1bfQUdAzyLPzNRtNfAm4VOg==
      "]]}, 
    {RGBColor[0.24, 0.3531726744018182, 0.6], PointBox[CompressedData["
1:eJw1yQlI03EYxvE50YzwIGQJLcwsTROP1KWW7vHY5SycUIZUDEEqRUqlIgv9
m2JGyRQLM0hDjTzWsGTkVjoRaxFSaXikOUNzTa1mISkqdODvfeHl5fN+fTLP
pWXxeTxe9L/9fzdmUbyHU0Xl2exi9oBMMGy2zZJdkK09nq6eIXvgvmu9rmaK
7Il7N8Lfv5oge8Gij7HrR8hCbN3GSeeGyDsRFlC3XDNA3oULRx8ISs3k3TCW
PIrM7yP7Yf7UNd2YkbwXKh/Xk+JOciCCzfs8YlvJQchUGNaEDeRgcKOn367e
Jocia33t1pbr5DAofaqUwsvk/ZDFOPqG5JDDYTQVfnqWQY7AmStL5WtyciQM
N0MlhgiyCCEWzUSIN/kAyp53XpxwIkfB891HfsLCD+ZolOb210wOkGPQpNMv
t7aRD6KxMEfdXkY+hOxJZ/1UBjkWSoezfxyDyHEI/fXUT7DynVmM7PGXER+6
yUCLpte7qIiZAyxVUqcjIurxeGiq7Su1fmM9HrP+w3E7NMy8BNyRN9aqgqgn
wKFZlJdvWmA9EeWaioDqJGYuEdX+itGUnnnWk+AuKYmr9mfmkqCdrhzwLZ5j
XYLyS4YKe7+NdQmWVroPF//+yroUVnHzVI8bMyeFVuU+aHOzsi6DaJOL1fbz
C+syNJvtuaudM6zLkVrBJbakTbMuR119R7/jm8+sK3B37OqJ7YEW1hUQPhE0
8NXjrCfjhdjSfsxvhPVkCOSp614Fg6wr0Tt93ppe8Jp1JdRDXo+b2gysp4DX
1VXpvCg1bfQUdAzyLPzNRtNfAm4VOg==
      "]]}, 
    {RGBColor[0.6, 0.24, 0.5632658430022722], PointBox[CompressedData["
1:eJw1yQlI03EYxvE50YzwIGQJLcwsTROP1KWW7vHY5SycUIZUDEEqRUqlIgv9
m2JGyRQLM0hDjTzWsGTkVjoRaxFSaXikOUNzTa1mISkqdODvfeHl5fN+fTLP
pWXxeTxe9L/9fzdmUbyHU0Xl2exi9oBMMGy2zZJdkK09nq6eIXvgvmu9rmaK
7Il7N8Lfv5oge8Gij7HrR8hCbN3GSeeGyDsRFlC3XDNA3oULRx8ISs3k3TCW
PIrM7yP7Yf7UNd2YkbwXKh/Xk+JOciCCzfs8YlvJQchUGNaEDeRgcKOn367e
Jocia33t1pbr5DAofaqUwsvk/ZDFOPqG5JDDYTQVfnqWQY7AmStL5WtyciQM
N0MlhgiyCCEWzUSIN/kAyp53XpxwIkfB891HfsLCD+ZolOb210wOkGPQpNMv
t7aRD6KxMEfdXkY+hOxJZ/1UBjkWSoezfxyDyHEI/fXUT7DynVmM7PGXER+6
yUCLpte7qIiZAyxVUqcjIurxeGiq7Su1fmM9HrP+w3E7NMy8BNyRN9aqgqgn
wKFZlJdvWmA9EeWaioDqJGYuEdX+itGUnnnWk+AuKYmr9mfmkqCdrhzwLZ5j
XYLyS4YKe7+NdQmWVroPF//+yroUVnHzVI8bMyeFVuU+aHOzsi6DaJOL1fbz
C+syNJvtuaudM6zLkVrBJbakTbMuR119R7/jm8+sK3B37OqJ7YEW1hUQPhE0
8NXjrCfjhdjSfsxvhPVkCOSp614Fg6wr0Tt93ppe8Jp1JdRDXo+b2gysp4DX
1VXpvCg1bfQUdAzyLPzNRtNfAm4VOg==
      "]]}, 
    {RGBColor[0.6, 0.42664098839727194`, 0.24], PointBox[CompressedData["
1:eJw1yQlI03EYxvE50YzwIGQJLcwsTROP1KWW7vHY5SycUIZUDEEqRUqlIgv9
m2JGyRQLM0hDjTzWsGTkVjoRaxFSaXikOUNzTa1mISkqdODvfeHl5fN+fTLP
pWXxeTxe9L/9fzdmUbyHU0Xl2exi9oBMMGy2zZJdkK09nq6eIXvgvmu9rmaK
7Il7N8Lfv5oge8Gij7HrR8hCbN3GSeeGyDsRFlC3XDNA3oULRx8ISs3k3TCW
PIrM7yP7Yf7UNd2YkbwXKh/Xk+JOciCCzfs8YlvJQchUGNaEDeRgcKOn367e
Jocia33t1pbr5DAofaqUwsvk/ZDFOPqG5JDDYTQVfnqWQY7AmStL5WtyciQM
N0MlhgiyCCEWzUSIN/kAyp53XpxwIkfB891HfsLCD+ZolOb210wOkGPQpNMv
t7aRD6KxMEfdXkY+hOxJZ/1UBjkWSoezfxyDyHEI/fXUT7DynVmM7PGXER+6
yUCLpte7qIiZAyxVUqcjIurxeGiq7Su1fmM9HrP+w3E7NMy8BNyRN9aqgqgn
wKFZlJdvWmA9EeWaioDqJGYuEdX+itGUnnnWk+AuKYmr9mfmkqCdrhzwLZ5j
XYLyS4YKe7+NdQmWVroPF//+yroUVnHzVI8bMyeFVuU+aHOzsi6DaJOL1fbz
C+syNJvtuaudM6zLkVrBJbakTbMuR119R7/jm8+sK3B37OqJ7YEW1hUQPhE0
8NXjrCfjhdjSfsxvhPVkCOSp614Fg6wr0Tt93ppe8Jp1JdRDXo+b2gysp4DX
1VXpvCg1bfQUdAzyLPzNRtNfAm4VOg==
      "]]}, 
    {RGBColor[0.2634521802031821, 0.6, 0.24], PointBox[CompressedData["
1:eJw1yQlI03EYxvE50YzwIGQJLcwsTROP1KWW7vHY5SycUIZUDEEqRUqlIgv9
m2JGyRQLM0hDjTzWsGTkVjoRaxFSaXikOUNzTa1mISkqdODvfeHl5fN+fTLP
pWXxeTxe9L/9fzdmUbyHU0Xl2exi9oBMMGy2zZJdkK09nq6eIXvgvmu9rmaK
7Il7N8Lfv5oge8Gij7HrR8hCbN3GSeeGyDsRFlC3XDNA3oULRx8ISs3k3TCW
PIrM7yP7Yf7UNd2YkbwXKh/Xk+JOciCCzfs8YlvJQchUGNaEDeRgcKOn367e
Jocia33t1pbr5DAofaqUwsvk/ZDFOPqG5JDDYTQVfnqWQY7AmStL5WtyciQM
N0MlhgiyCCEWzUSIN/kAyp53XpxwIkfB891HfsLCD+ZolOb210wOkGPQpNMv
t7aRD6KxMEfdXkY+hOxJZ/1UBjkWSoezfxyDyHEI/fXUT7DynVmM7PGXER+6
yUCLpte7qIiZAyxVUqcjIurxeGiq7Su1fmM9HrP+w3E7NMy8BNyRN9aqgqgn
wKFZlJdvWmA9EeWaioDqJGYuEdX+itGUnnnWk+AuKYmr9mfmkqCdrhzwLZ5j
XYLyS4YKe7+NdQmWVroPF//+yroUVnHzVI8bMyeFVuU+aHOzsi6DaJOL1fbz
C+syNJvtuaudM6zLkVrBJbakTbMuR119R7/jm8+sK3B37OqJ7YEW1hUQPhE0
8NXjrCfjhdjSfsxvhPVkCOSp614Fg6wr0Tt93ppe8Jp1JdRDXo+b2gysp4DX
1VXpvCg1bfQUdAzyLPzNRtNfAm4VOg==
      "]]}, 
    {RGBColor[0.24, 0.47354534880363613`, 0.6], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.5163614825959097, 0.24, 0.6], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.6, 0.3062683139954558, 0.24], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.3838248546049982, 0.6, 0.24], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.24, 0.5939180232054561, 0.6], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.39598880819409377`, 0.24, 0.6], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.6, 0.24, 0.2941043604063603], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.5041975290068142, 0.6, 0.24], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.24, 0.6, 0.48570930239273163`], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.2756161337922776, 0.24, 0.6], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}, 
    {RGBColor[0.6, 0.24, 0.4144770348081764], PointBox[CompressedData["
1:eJw1yX0sFHAcx/FzRlTDH3azuSYRJaFcV+Tcx3FP7jRsPcz642ZZxaSysdS4
xmSTHaPUP1lc8lQpLOfprE6sUSNF5Bg6JxU1K3O2Hub3/W7ffff6vr2TMxJT
uBwOJ+zf/r+bsyIOqM2+3be4LGYPqCNsu0ULZCdcGMlta50nu+F+qGm7dYbs
jtEK5zOeU2QPzE1q4raOk/ngiWr1olHyTqQJMoqtQ+RdeKLJahgbIPui5+FQ
+auXZD/4pp6S7O8i78FxeWhneSs5AEH9+9xE9eRAJCsNNn4VOQjasbNv1ivI
IUjZsN3cdoN8ACrvUhX/Cvkg5OH2PsFp5FB0GHM+PU8iC3Du6mqhTUE+BENx
iNQgIAsRbNZNBnuRD6OgsyVr0oF8BO5vP3IlS9+Zw5CfbiqfGiSHo+Zx2+/6
BvJRVOekaRoLyBFInXJsm04ii6CyO//HPpAciZCfz/x4a9+YxUid6BO86yYD
dbper9xcZi1gLpU5HBNSj8IDY+WLfMtX1qPw2f995A4dM0eCW4rqyoRA6hLY
6YWXLhuXWI9Goa5ob1kMszYaZf7KMXXPF9Zj4Cq9Hlnmz6yNQdNsyaBP3iLr
UhRmG4qWTVbWpVhd647L+7XAugwWsX66x4VZK0NTguuw1cXCuhzCLU4W6495
1uXQ9y+nr7fMsa5AfJE2ui5xlnUF7t5rNtm/nmFdiTvj1057BphZV4L/lFfF
1UywHosusbnxhN8H1mPBU8RveGQOs65C7+xFy8nMAdZV0Ix4PKppMLCuBqe9
vcRxRWbc7Go0D3PMXOcO41+1nBVx
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.},
  Method->{},
  PlotRange->{{0, 57.}, {-0.1016999999999999, 0.9972866}},
  PlotRangeClipping->True,
  PlotRangePadding->{{1.1400000000000001`, 1.1400000000000001`}, {0.021979732,
    0.021979732}}]], "Output",
 CellChangeTimes->{3.5756278993570013`*^9, 3.586661081152602*^9, 
  3.5884149174064407`*^9, 3.5884165212641745`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ws", "=", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"#1", "-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"F", "[", "#2", "]"}], "/.", 
          RowBox[{"Ka", "\[Rule]", "#3"}]}], ")"}]}], ")"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"ups", ",", "\[Xi]s", ",", "Karmans"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4840344969276133`*^9, 3.484034511292435*^9}, {
  3.484034600761553*^9, 3.4840346988761644`*^9}, {3.484034745869852*^9, 
  3.4840347509741445`*^9}, {3.484034821929203*^9, 3.484034944021186*^9}, {
  3.4840351636587486`*^9, 3.4840351668829327`*^9}, {3.484035331236334*^9, 
  3.4840353472992525`*^9}, {3.484035656436934*^9, 3.4840356675735707`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "ws", "]"}]], "Input",
 CellChangeTimes->{{3.4840349627692585`*^9, 3.4840349666414795`*^9}, {
  3.4840382207076015`*^9, 3.4840382291830864`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJw1031I00Ecx/ErsH4FQoWmQqGTGaUlTnvwobbPnFPnLETN/hiIlaMgUZEm
PkEXZEGEGdHzMJ9YUZKTQkNNl7p8aDpnhKGZJprMSHvQHiyl1b47+HG8fu+D
4w5OdCwnWbuaMRbh+P7NzvFZNhEpjBwJNrfTD7D48cXCrGdkAbCrj3d0NpI3
ACmtbWcUT8ge4In9wyy5luwNlv7w1XhzDXkL2FupudTWKHPaD7xYLTubYiT7
g3n5Xhx4XEcWg90UBa/a1EneBnaqukh8soe8Hfybu3dU7RA5ENxfWG8t6SXv
BJvekdEyM0AOBuswHI1Nda0PAZNrUrUtL8kS8Kdbxzb/HCSHYiIy7pJ7usth
MPXpZrstVvJu8HG9p3LJtd8e8Gv3fVTtZvJeMF192XlxA3kfWJLczSO/hhwO
1pVUvPi+ihwBlhny625EGTkSTH8vU6x7RI4CS7uin626Qd4PJs5dSJu8Tj4A
FjIV3qQtofuWOs47/M6Q7dpPBlZdKA/KMZABFli6q7yizrmeO9waZSh6c4e6
HNxy2jPI/NxpLgfbaC3Q5HdRjwa32xqKAyzUo2HKbj70YM5GXQEYpU1tg2Tu
8MGezLy0UeoxYKKvt/p1I9RjUPlCd0HSPkldico/86NVoinqSrDQq9LQlBnq
sTB9aj780ctOPRY8T+F3bmKeehx4dNjY9OUv1ONQ3nMiS1SwQD0e+NAqyfD9
QT3ecf/Kub6hJeoqGH3q9dkVK9RVMHXnL2sXHO/i/0hAUmDj7e8rq53mCWCD
Gs2aSjfqauSqFK89rGupqyH4GCW2ZYF6IgRFr73Dso56IvxsorGA3wL+ApL/
/VE=
      "]]}, 
    {RGBColor[0.6, 0.24, 0.4428931686004542], PointBox[CompressedData["
1:eJw10GtIU2Ecx/GHoW6Qt3AvojJPZRZr1Jq3vNR+3u8vUiMYvqi0WGBeoBqa
0RNUUr2wQA1q5iVvoaWpkFHOU7qRK7R0FCQatopATdPCFI0W+58Dh8Pn+R6e
29bjhZknZIyxCOf7/+t65nU3z6o4Mt710wDE03mhOpNkBeoSEy96ZUr2hWhr
M68Ir8lKiEaP1j/FL8kbwPy0Xy+ltZI3g1vNhgv6Hp3LAlipojLL8YC8DUwp
FopeUg8EGxK8WoKfkYPA41ZV07f6yLvA19+ZHXv/nKwCi7RZbb1NZDWY3tsY
eL6S1t8Dnm+qUv3spq4BM4VNmgI7qO8Di99+tXnvfbIWXH7uRoO6hxwMZjn0
yv5BJIcAf0PUlgHpvKHgjsbOj+EWchh4fTQrKrCRw8EW3bLKlVbyfud88isZ
OW/IEWDXmsdrhkbIkWA9fUsB0dL/UWAOcdRcJq0XDV6V8bnfMkQ+ADalNExW
vCAfBDd/a1S3SPvVgWllmswF6XwAS92kyBlud5k7PSjYB33qqceAPawJwOEu
133xGPDcjnWOywN0f7HgsunO7rJB6rFgUZ5H3OXD1OMgap8K5olR6nFAn6J2
rd5OPR6s4a73vbZx6vHAiiYou3qCegL4r6WTPmNT1BOApsc2xdwX6ongu9ut
xunv1J3ecV0+5z5LPQlCb23ymOUH9STUufl/yvJcpJ6M+RnPIIf9N/VkaIzF
j/zyl6mnoKigozrXsko9BQp97M4zGxlcPRVHk7LVtXkyl7nTq0UlfgY36mkw
6LesLRzzoJ6Gt09SStTLcurpEPzLu2ZOKainw7e0reL2iBz/AKNtAgE=
      "]]}, 
    {RGBColor[0.6, 0.5470136627990908, 0.24], PointBox[CompressedData["
1:eJw10WtIk1Ecx/GTqW10E1uSUrrpjDlseM0tL/vNqZuXxMRisoQtcISIvjAv
INWhfCEWtSB6oShhJUyWaGCWibOaGUYxMZRUqOimFTJNSSZWi/33wOHwOV8O
nHMeyZna0soAxpjKO/7Pvs+tZlVx9jKby0ELYHPGpJFTr8gCcJGsqrLVQQ4B
M43y+aX7ZBFYKVoN9zrUPh8AU8zP39YMkQ+CWQaFdbCRxeDlN0JT6kfI0eD2
ydodA/1kKXhIvM3ZN0A+DP4kSlLW/JAsA7tafrkmvYUsB2swTm+t3KXzxINF
tlTw3c/JCrBsw0r80CNyAvDDaLCbXpATwTfbwvZ/ekZOAsv9KlbKJsjJYI2N
/e+Fk+QUsJ09nc4I//5UsG5BXNOtcfJRcJX0p2bqNTkNrLqnec7iJCvBY41p
vU/9VoEJF3+trQ+Tj4EFT+pG123kdDBpcZDhcRc5A0x/bnb60k26fyaY/UHE
yfNd5CywjV0xuiP+91aDmVvk+h7//wBYW5NoVULvy712tl9JvThBXQNWb+6b
HX5DXQNsdnapwqepZwOnLYqOTRd1r2XR1juOt9S1gK57KTpmgboWPAB7r38m
sxyMvUx0Fs74ew7YicxrhRc+Us/FWJirTpL8hXoueM6yxyP/Tj0PH/Z4zGeV
y9S9blcOHspwU9fBHTU16BxYpa5Dgi29IahpjboePFSStZC3QV0P1/YCi2XR
Qz0f4sxEqST2D/V8WJNDUk3ibfD1Algxs0/+LsBnXoCS8XGH9ncg9UK4t74F
hjuDqXst0prMFQLqRbCq/x6vCRJSL0JJaaSiuliAf4Hn8rc=
      "]]}, 
    {RGBColor[0.24, 0.6, 0.33692049419863584`], PointBox[CompressedData["
1:eJw10W9IU1EYx/HHJC3xX2qpYdhKyswi05aWbj/d3JyT0LIg64WFUUGa1htp
RfdFZlYTpYZlICPKQRmaiSkYrYj5b2pQqaktTRGJdMsSpBx2Y88uXC6f+4Xn
cM6RnDx/8NQKIkoS3/9f1+OQk8Kvomim/TX/AAUsF3epmtirQDRZW/uzhh0I
emI4PJhbLXc5BKSsk5V2NLHDQN/jrvpHtrIjIOzQNk5ZOtgbQVmry/rS6tmb
QONVbTZFAc+PAhUf1URW3GVvAdUETp4tb2FHA+n5fxQnzOwY0PP2+ZzcN+xY
UH173oWIfvZO4K1M/Sm7m70LlJLTG/3Dyo6DcKu1zJL9nr0biNcGt0rcjodg
N53pfNbHToAwNBdz7rPbe0AJEuNYWC9bChrxnTmQ5F5vL4RBs9m01MNOFPeT
f9GW6u5JEO4dmZOFdrL3gdYGRRsC3PexHzSxoVivb2Yng5pGfWIKK9kpIOm7
pW2XG9gykKNy/ZjmCp+vHJQ2/PXLnUY2QHVqT1XDQ5cF0X6WF3Pb27mngiTX
jxeW8/0Jog1F8aOhVu5pEObQ2+IY4C7aeL+7Z+ojdwXMesel4IkR7qJjs9IV
djYpgUSl7VvBKHelOF/z6HfJBPd00LW2nEPNbEF0+KJsWj7NXQWjvdyps85w
V4F+helnF2a5qyG8GlrndDq4q5Ft8H6ss85zz0Dghyibr/8C9wyM5/U/MB1b
5K6BcXHAI7HqL3fRm0uCzTnL3DNBdqkuqMsDrp6JKji3rrnt6TJpMVyqq/S/
uZK7Ftld4cn2ai/uWbghfWrxOe3NPQvml3WmkGYv/AN2CAN+
      "]]}, 
    {RGBColor[0.24, 0.3531726744018182, 0.6], PointBox[CompressedData["
1:eJw103tIU2EYx/G30paioSnhH2ErKlIstVrpXPlT5+YNc04CNdICo4uXChGl
iLf9oRErjBQzLHWiqEVplq281ZxtooUmLDGlRerwUhYoFSl1as9eOBw+53s4
LzznnC0n8pKzVjPGQoXj39m+voXz++0Pdc76HroAtmjb/NhyLdzOdWCTlo2D
2U1kD/B8lxsVb56SvcFn8gsS7j4h+4AZS81lqjbyJnD/k+f98lvJYrAxzS5t
eSV5K1hFvSlZ3Uz7bwPL9fhjDu0h7wBUuV55zEDeCcSWNLpPmsj+gL/M6OrZ
Tw4Af1dbpJb0kneDv/7IKy8NkIPA5uTHs1LfkoPBFN4GjdbhPWAG6bTYMkje
C/6zO1qTZybvA5syWWp8HF0Cvna8oXjU8fz94J0rG5Q5jv0PgDkfLX2l7CCH
gE24Fd8a6CaHCvPosKkLmshSsMhhWZ2xlhwG1tKi/aR1zEcGVuhytlRVTD4I
NqSVllVfoXkeAlueM27PbSeHC/dX5ISkOwzwxJWRrhST3RxgmYEz6a4D1CPA
l1O+2BrIPAJMEnzM9cIw9Ujgdp9B5z5CPRJc/bXKL3WMehS4/vJ7OI1Sj8LL
R16yH1MT1OUQz2szdSYrdTlqziTJy29+ph4NcdkH37TxaerRsAZm3TG32agr
kOn2bH3b4ix1BaxHWq+PhSxQV8Ij7UX9kOY7dSXECy3NDzIWqcfgXKd7X9jS
EvUYBFmrLpZk/KIeiyR98khv2jL1WOF9Joo8JcJ/8X/FCd9LTd3swiq7eRz0
888Vp32dqMejsDqgX/fbmXo8krIPr7maKqKegFOdK/eqR8lc8FJRl9RThL8e
KQhZ
      "]]}, 
    {RGBColor[0.6, 0.24, 0.5632658430022722], PointBox[CompressedData["
1:eJw10WtI01EYx/HHZSt8YYq+cDTDppiYiLU1L6n7eZnzBkYGWaCNRi9KKLI0
RaHzRk1IEC9QZGrFUITwWhka+09dNs00KLCM1HTgTDBCQ1K0xR4PHA6f8z1v
zjlHL984e0VGRLGu+X91j1866n49alaYdbwBYW7ui+60sA+C5E1d8yl9bB+I
/jhZn6KH7Q+iw4pAWyU7AFTq17Uiq2ArQe3Buo33XRa3g0Ayz6f2yhdsFei+
7+DV8T2HQMxpQ3I3JHYoRFpPSvzsCDsMIud57fydMXY4pKam4ASPaXYE6Kfy
bqH1HTsSIksemu+7dz4KVPK13fJ4gn0CYqGm1WIeZZ+EiDZFKutsbLXrfOTk
Yr2drQEt6Vq3xt+wT0GU9zxZfmRla0EvL6we/zPEjgZJ2aO9DRZ2DKha7nVz
8xU7FnT7kJ/fWgc7DhTvulxeC7/faVC3ukg93MaOB22HfTtS0MhOAPk7Aqo+
7P1HIoTze6cm0MrWQRzbmdotGGYDlCSbT/CfcFsAIq62wm6a5J4EUSQGz1wc
4+5ybPiWLcbOPdn1f80+moqP3JOB0gKTVvmJewok61Kv4dIMd5fnuhduvf3C
PRWSPletVc1yTwWFRkw1rC5w1wMhuy0lAz+46xE0MPNw2+HgnoY278UHJm8n
9zQYE43l58ZWuRtgfBaVaWpZ426Aj1T/WVP9m3s66ozXMhqd69zTIXkHVIZ5
bXLPQJAoihhc/ss9A/CsUq2s7XDPRN5ATHF5jgfcPRPT61G1xfX73KYskKpw
Efn7uWdh+nrivfMjcu7Z6MBQWZniAPds5KnH9cYaOf4B+Tf8xg==
      "]]}, 
    {RGBColor[0.6, 0.42664098839727194`, 0.24], PointBox[CompressedData["
1:eJw10GtIE1AYxvG3MB2WGWYiJrRlibQlpjOnXXxMp/MSiJfopoSgFJHZxb7U
hzOxJBVR1CJvVCI428qwi2HSbOl0ImZZUSGhaRulmKKJRZfF3h04HH7nf+CF
I8s5nZa7kogi7fv/6Vjfo8nPy6/EvfEZX4A+WFd7FtWxJaC+hsp3mbXsdSBv
/5YMVVW0w96g9kbZ5Nka7r4wTlyWxPY8Z/uDxhds4cJpKah40LWit4u9GeLK
x7li+QB7C0T1/kH9FzM7EMIwoGxf7mMHQYzqDTVHnH0bqP+MbqPawlaA8mPm
W8zOecGgw68vDXb2sEMgTL2q8gvOeTtAHRkRFddM7FCQ54+hwn4jOwyUpytK
H+1mK0H33KsVBU/Y4aCRsjltdjt7J0hjNvjcqWdHgFTqqaAewf+lAgXc/tOa
18E9EmScujgY1Mw9CqS8aqJAPXsXyKesWF/1kL0blDbttsnq9B6Qb9u4Tt3N
3gtx6lDt2ME+djSM02lN7mUv2QDVeddsODngsLBbHh9sTbdwj4Ex/3PX/QZ+
L2KAqOvHs0PfcN8HkrbcXLI4u91qU2l501vusRC/NAeUJn4v7H6sKbyhe889
DrCsrTj66hP3OEgf6CVjCxPc1YCHYn2qfJK73Vu1t4bbrNzjIc0NkJ1w+cY9
HtBmuaXnznBPgHjU3F+qmOOegFR5feLMuXnuGlTS3eRl8yJ3u2WdtvqvS9wT
UUCLw+aI39ztnhU52xv/ck9Ca4PL8E/LCjh6Eowvsqc8vFwcpmQcG7JJNbOr
uCfDtuapWRvixj0FkpKMsPDzbJECVVZrpmHEFf8AAV8Cmw==
      "]]}, 
    {RGBColor[0.2634521802031821, 0.6, 0.24], PointBox[CompressedData["
1:eJw1zXtIk1EYx/EnpSzIGlkhpKAm0cXaNMtL2X7enfcW/WFIF1MscGgEsYLy
NczCLhotjDAa9aY2E7qYppLTKXhJys00S9RCc5U4FS0Us1rs2YHD4XO+h/N4
pmUrMxyIKMi6/5+2NSUn5w/RhhOini8gzBzsyM2vYS8HXTX5L7a8YksghOrN
kvw69lrQhW195QWNbFfQfIp34lf7ezdrP5C2odHePSBcF6U9o81sLwizjoU3
Bw1sb1D66+moST17E2g4Q1eY38LeDBpz6Wx9Xs/eCgpJ+JI3b//fB1Q7PntZ
Y5+/A2RaP1F0vJwtA4k3LPLsZ2xfkBepYi1VbD/Q1OrMsSI1eyfoV0mZ2vyA
7Q/Srnvnu+qW3OZdoH5Vl49fGXs3SHZWrSvTsgNANadXXLpXyQ4EpaRc265q
YAeBCjSJPXoDOxh0P6x53LmGvQek/qRT9L9g7wUpXMzZgr2HgO5OC6JXG3sf
yNthZZuliy2HIOpHlFX2DtBCQuXj0U6bBUBINZZaGtq5h6LpvaK9xNzN3Wqd
iIonJu5haFIYcoPrjdzDAGXeW3lLL/dwkH917jnxI3erXz78vnhkiHsEhECp
McB1mHsEKFLWOhg+wj0S6DCVXuxjC5H4PJCcc6zIzD0K2lOHs1TdP7hHwcNd
PfQoZJJ7NJpK3D2rJ6a4R6O7oPBPbdIM9xgkS7Oqexd+co/BU+3tpDd9c9wV
kFGWc7zTb+4KaPcPGN22/OUei+KR1OJvdUtg67GoGG1bc6jB0WaKQ85R6RnN
naXc44DMdM2VjU7c4zF3vlUZc5ItxENSK1EbppfhH9QECy8=
      "]]}, 
    {RGBColor[0.24, 0.47354534880363613`, 0.6], PointBox[CompressedData["
1:eJw10HlI02Ecx/FvluuQdMGQoLDUDLEDa54d+vGam1tZiikJMkyZaWyRjsCu
n+JRWeCR9YcYYRmawpypIVlO8yBRKtDC8sLGQrH6VZRhkBn77oGHh9fz/sID
j2e6ISHTiYhCV/b/077EcNJOzn/6ezecL0Cj51Lry8q77VwHEjyOl3omsqUg
7WJTw+mrbBnIyTXPKD5gbwYNxPdVFtezt4LSFhU3C1vZ20EV41TV1ML2Ag2L
1proe+wdIH2/dRvq2DtBblGmb66OeV+QrjBmT66Z7Qdyz0qL3NjG3g3CSHN6
kuO9vaClpDn55Udsf1BYT/74qQb2PlDWEf/s58Xs/Su+YvBWVbDloAWdTT5T
yf8TAMqY67qecIt7IMjL1i87Y+YeBHrnPJvnYmEHgxIzQ9yC29khEH77T0nM
w+xQCHnqCw/dB9gHQK4lZfMpHeyDEJav1coye9mHQF8abngXd7MPQ6iunT4q
f8EOA8kD5RkfHPPhoDUX43W6ITZAv1qe9a1nC4DQXL6hIH2EewSoqibHaHL0
CFiCO0LGPr/hHgnsOtZ1wmOUeySEyYnBxPNj3KNARl2Rwect9yhY2vWhE6b3
3KNBml6p7sc09xVPN1boTTPcYwAX0/3O0o/cY6A1vcot2GTjroDF7NP7UjLP
XQHtFp1nf9gC91i87rIpUmNF7rHQapVtfurv3JUQn3o86Qz4yV0JS2O+UdW4
yF0FrfSS1a/7D3cVLLa6k4HVy9zj4Jssu229swr2HoeZ2ZxBfe1qu0kN5dez
JluRM3c1pMlD4uMpCXcNUoLqS3pK1nLXQMxeMrSOSPAP3iT9/w==
      "]]}, 
    {RGBColor[0.5163614825959097, 0.24, 0.6], PointBox[CompressedData["
1:eJw101tI02EYx/EnMx2UYgfKSNAsD80Ds7ScLvdznqbTFRFkptnMbizU8rCb
iH9UNO1CQSMvksoDpGToMDCRNs2RWlBNh67DWE0UE8LUDtKMVnt84OXl837h
uXt3F5UdO+dBRFLX+Xe7Z0FOre0XfboGDPwA2jfd8VnezxZBuCu2jPUNsv1A
+gF1WO8wexsoQKEOnXzK9gflmFJMRQZ2AGilQL0YpWcHgcrmp9anre0PBgWJ
Tn7QlrP3gpqURaR5wA4FVf0ySwefsMNB8bLHausNthhkl5Z+0bWzI0Ho77p6
4Q472rWvxEcnqmdLQGcSAut6Gtkxrv5o8x9Ds9zt/SBd/k2xo5t9ALQ4nHPb
3MGOBY2E5JsEPTsOFDVmHVH1sg9CqDvvtdr5nH0IZFHZpsUv2fEQnNe11SFr
XQpKTqjyql5zAsgUrIp5ZmQngmozPWVxQ2wZKDBP4ksv2Ich7Nw61bxnhJ0E
YfsRUd7lMbYcQs+GrM7c12wA3o7fBssbtwXAWPE2w5Y+zj0ZVH/cXjFk5p4M
o9WyHNw0wV0BY86WVyccFu4KCC26tmLZJPcUGOfE7ytnrNxd1iZ9r/Cxc0+F
sFqzvNTCFlJhVOyKbotwcE+D/ZPm7PiVGe4um1s31eTNcU/H/YZ1hZPt89zT
QeXigsgdX7lnQBLqrzkd8Y17Brq7DXJhdom7EpLc0Y33Gn5wV2Ih9laJ37UV
7pk4Oqsd7Zt2cs8EnGVepYWuf/F/shB+SlN8qdrDbSELfo2JlaNKT+4qhMfa
Pk4ovbi7rGzW+9Z6c88Gfhrf2cJE3LPxcNU5S1pv/AXXTPtk
      "]]}, 
    {RGBColor[0.6, 0.3062683139954558, 0.24], PointBox[CompressedData["
1:eJw102tIk1Ecx/HTMjUl0Bphw2CtMosuprW877eZOnWVdNNCSK21kYIXimQI
PhYFEmSGQmbCUF+YGUmzqaQ8MzNzqahQ4CUwiRbN+63QzJ7afwcOh8/5nnPe
nR3pWae1IsZYiDD/rY4xo2C871zJdytPG2BnkzO2DTntDjZXVvx4i9Ne4BSj
sXp9F1kMZgxT8mGdZB+winO9unGe7Asmy35omWgjS8HGgkJnDtSSZWDamqnn
5kbyLjC5f/U97yqyH4Q3stb3xJL9hfv2wuUXeoXD+8CqC/bolGbq+8Hq0/ry
91aSD4J5Bbd/mcwnB4BZ6tqt9gt0/zBYSsQ6l0ATORAsM61BV95CDgILbLe9
G+fJR8Bstzyubm0kHwVz98gLSH9FloPL7e72X+ogHwMXl9m0e6qbHAxure1m
xsv35BCwjYuGCkMXORTsab3Ic9TZw8CKC0MltjfkcKEny5rtH8gR4Ab4G9v7
esiRYBvM001ipxXgSmYj5jc5zwOcp+nkcIPVYQ6wNPm4ht/vp64EkrxLtdZB
6oKLiiL7Wj9RV8Hyp/e6uOgjdcErI/OPFoaoRwErqsSqnGHqUbCc51Ofqcao
Hwfn11abaBqnLvhyv0Se9ZV6NMYW+UHzKRv1aOBXT134zh/UYyA1iNWlkknq
McAlhbLj4jT1WLDZVNmqZI664Gvy5pGEBepqGDVn7sxIf1JXg1N3XnkrXaYe
hwe3B77ZJ1apxyE1SVN2qE74F/9HPIybuSFRi8hhLh552qW7ucUu1BOAFL+C
Ur0r9QRkl8tyBtfcqGvQ8OTE2ud8d+oaNI/+bq187Ya//fsCDg==
      "]]}, 
    {RGBColor[0.3838248546049982, 0.6, 0.24], PointBox[CompressedData["
1:eJw10XtIU2EYx/FHsTTS0FhkaDUtSpaT6XKpqfs5NZ0XCKGCwiCzG0QGYZl/
6LHyQlqCeOsGlkr+YaVIqaG2NNbFsoVo80IuWMy0y8lUSGe22LMXDofP+Z7n
5YXXLyMr7ZgzEYXbnv9v+xLVukca8ZRy8Bl/ABKuf1/d9YHtBgqQL68xvmR7
QshZ1C/petkS0IC6vrDlOdsb1D6inPVpY/uCpq9mmwM72VJQ3oLKJDaw/UGm
0TGv6gr2VlDYqluGuDK13dtAdTJNecUZdgDo9gbI1j5ky0BNWyJ/ifU8Hwgq
w96hyVp2EKjE9fDC8E3+XwHyLp5Ma2plB4OyWyWLWR3sEFClWZ6rdFgJks3p
8+vus3eCJqb7RMtTdigETz2mqnrZKtCXb+XGER17F4Satpw5Ux87DNS8bOyu
72GHgyI3Dx3s6WZHgCIuRN0bfc3eDaG990WwxjEfCeFuqHAp6BU7ynb+gdKi
B479okEFxiLzsOM8apAqtT9Dplc7rlfIc1GX/31nt2BzdeP5xKp+7jEgSeaS
oGALMdAZ0z1yhg3cNcDK9MbiWraggW695UhRzRD3WOjCM/3CCse4x0LYLnS2
HGVTHEzuBqeGgM/c4yA9cfyJyolN8SD/UmvuRzP3eAhvTzt3zVq474FU9Jdl
XpzibrPbuuaTIT+4J8CwceKGl0XkngDPnv2hlSUz3BMhaj9FBG6a554IRXT1
b63sD3ctxAOjlTOlVu5aKM79vObnTrD3JHQMzlrfS5ztFpLQ5HtFni914Z4M
4+P08eivK7gnI8fDekeb6so9BWfHd8j3vWELKWiZP1Rw2ccV/wDcngHg
      "]]}, 
    {RGBColor[0.24, 0.5939180232054561, 0.6], PointBox[CompressedData["
1:eJw10QtIU1Ecx/F/mTMyY2LYRKGZNoYOcZrZfMyfptPNBxIV9FBMKxeZSg8K
LLxJVGSB+UjDByohiW0uTZqaTKxEo8jSYKlYYoVIWoIaBlmL/Xfgcvnc74U/
5xzf7IJ9J9YTkcr2/H/b188YPJxuDIoYs/AHCLlRKp/ht+yNoL5Sq7y3gy0G
jRw2Xgl0eCto0TIZbuhiS0CKmrpznZVsH9BZZZFsqo0tBYV0rVzoa2HvAJG7
IiKxKMZuf5Bp+d6A5DJbBpJmVs64trDlIGOh1Rzeyg4A7VeYR2VlbAUEQXlc
jDfsIJA29TusT9nBoGCvBwV5JWwlaGE6eEvhI3YI6IPG7DpnYYeC0qrvZog6
2btAS56Hbq5rYIeByqV6k5uj7wbV/MkTVdezw0ENp6arbpjYe0BybWCP7Blb
BeG13vmlZYAdAdL31FsqutiRoJ3pZ8x1jv+jbOej+6gOc+w/GjRs9MyOdsxX
AxUeJsPAO3YMqDt328X8V2yAPG4H9MTxPMHmvKGF5tAX3GNBsUfGNZmD3G02
F7T3qnu5x4FKOk5H+/P5CHHAwdGTg2Wj3PeCjn6qWVOPcbe5+Hy7d84493iQ
T/4Ga+AE93j0b/LunnWa5J6AfplvVXX5DPcESA/Ef02WfOGuASmvb3drYgsa
CAZ52lDqHPdEZE097qud/8E9Ef1tI8+vNi5yT7Ldd84T91tL3JNQaPDLWLvz
i7sW4tbfKqfiVe5aZKVNrFzz+MtdB0nHuFFsINi7DvqMIr9lTye7KRmfZ12/
bfZy5p4M6fyqy/tBEfcUXKptKp2QuHBPQfqx0Mj7ChH+Act37Ss=
      "]]}, 
    {RGBColor[0.39598880819409377`, 0.24, 0.6], PointBox[CompressedData["
1:eJw1z38s1HEcx/F3fsSqSYWZbM6vZhd2RH67l9/Ojyl/yOqKSWvTipSopX37
4zZbfhQqibn1i34SSXdjnbolCzNaJrKjH6Zp9MNN+qFr9/bdPvvu8Xl+fuzj
nJWbesCEiIIM4//f+M1LBbFDe9+h4ac8Ac26KsXhrUNsSwhZ7bW9YVq2NejN
2cGhEiXbBrQ4YNalu822B/3QhibL69mOIGqPVur8pUaLQJnd8wHTF7m7gGpM
yuwzy7m7gbIbi2zLL7C3gI4lYKflQ17vYTgPnYr6Zu5i0Ium36WzT9ieoBve
DVMbb7K9QcfrVJt7rvB+CcjK8fJ0ynXuPiCHtZVK8S22Lyg02/O8vZK9DaRP
yXXW3Gf7gcrL+uRRD9j+INlul35JC3u7oXdtiLjziB1geG/lpI1LAzsQpNr7
s2hAxQ4ClZzSdlArOxiU595vrl25LwQUWLM8O9HGDjW836dxsjuPHQY66mZl
N75yXjhIfDJ+X8bKfinomrq6wlTLBoQCdYlo/0ujBYDkTSr9wmPuERCm6wal
0h7uBheq52R/+rlHgl5V/920NMQ9EsLB4YKKjhHuUdDkH8kp9mYLUaCr722p
/DX3aMCrd0/wpbfcoyE4vft0YmGUewx0pc+++4zquMdAU5pTG17zkXssdHdn
Gr7Uz3CPhfD83vjiyGfuccj0SrXudJrjHgdlq2ubIuAb93iIJkJcz7TqucdD
l56/i5YWucugmyuUmGp+cZdBcPfVN48tc0+AZsqk6UPLKhh7AjzSos+12JkZ
TYlI/zq2vkptzj0RO5L7M9astuCeBIl/cdrpGbaQBFGIvE/hZ4F/0xD4sw==

      "]]}, 
    {RGBColor[0.6, 0.24, 0.2941043604063603], PointBox[CompressedData["
1:eJw1031IU1EYx/EnSadgGmEvkqlpmajV1HRNbfttc+rURETtj6hMkQQtQ6RB
ZFyTQalDNEowq38MZYXENBIznaEVNWy9KIsyGpWVzJdhVKJmt3w8cLl87vdc
zjlw7/bC8pxiNyKSi9e/+8qYVQoq/xbjm+cD/AD0OSLkhtXG9oSgnkqpkz9h
rwe1R4+rbN1sPxBMGU6rib0FpA16mOtlYQeAPpzVlbmblCsOBpV4tRgrWrmH
gJztU4dnmtg7QB07w5ojL/D8MFC/q9ihuc0OB9k2qbzrjDw/AlRdHGE+ZmZH
gYZOJI12XeP5e8T5ZXNrQuvZUtAGaYIyoIsdLfas3glXNb8fA9ol736l7+Ue
C2GhqHT511P2PpDLfPk4BthxoKaOxWfWVceL+3dm1Uwa2DLxvPq8SXUHe7+4
vuHuiOIxWw5BcsXebx1mJ4ACr0/s9rjHTgQ12nIamvrYSRAeJA+5+z5iHwAV
jb1uKLSwFaAfh2qr6lfPpwSV0/dO39X1AJrT+tYc4f0KgHD+pA8cg9xVoEoP
/3npS+4qQNcTHrjRxl0NYd2p9qA/bEEN2H9HvZi2c9fAUmrMCw8Z5a4BXYoL
0sy+554MyuidyG19xz0ZBX3N3m36j9y1ELbeT4ze+4m7FuQuG47d/I17CtAT
Oh5P09xTUPBlacgwPMM9Fdn5RktNvot7qvh9LS2UHZ3jngbbxcRzSVU/uafB
EqmolXXOc9ch22FarFpe5K7DadWgzEcv/hf/RzpsirdGh8FtxUI6gg82Slxn
1nLPgNTup2pt9OAu+ubXkW3dEu6ZKKm8ddVc4ck9E7Mx/nfGnBL8BecJ9uk=

      "]]}, 
    {RGBColor[0.5041975290068142, 0.6, 0.24], PointBox[CompressedData["
1:eJw10HlI02Ecx/GvR14ZuTBUtJq2xIbotPKo3D7euimZFiFUSGSZWoqEKIX+
zGOClegIowMtRcojjEnmkZs6SYsyKwgSbJR2SGbSITjKFvv6wMPD63k/fP94
vI/lpWZaE1G4ef8/Leu7QnCy6lMNPNfxBYSLU8PqEAPbAfS58VKPTSfbBeTl
+Unk3cJ2Bf01vVgMust2B4W1Tfk0XGV7gRLsvLJlVWwxSHMo4r5jl8JiHxBs
sgPaOtgS0DXhR5a0he0LMm7tN9Q0sv1AWfq4U21X2FKQ8/uRxPo6nu8PGp7J
LC14wD0AJL6Qo5m7x5aBCjZJypO72UGg9J4hk7+WHQxh7PCHh/nD7B2gI1/H
VScG2TtBGy4fv966+n4XKL9SWejSyw4BeQQMuGKEHQrhYFOyk87ADgMVp/d4
7nvEDgctF3U+zbvN3g2S9p6Lahli7wHFG0Tq3NX5e0H2XWmTDf3sCPP/Ofu3
To6z5RC0gUuFtY/ZCghlm/X7FU/YAJV7v97oO2qxYPZ4lV+kcrVHgiarRRnq
Ce6REA6Ymj2PvuQeBUoZfRZT9Ip7FIREybsbgW+4R4OW1CVbdG+5R0M/p6l2
rJzmHgOxvOF8aY6RewwybN3EvwZnuMeiaWF+u0/dR+6xyOhsL5lfmOUeB6qX
NJx2/8I9DmLVtorZ8G/c42G0mqip0C5yjwcFN0r91vzkngD9yhl5n8dv7man
LaWtTV/mnoiUdSfv3Ar9wz0RQq5MJDetcFdC5tG9fvasNSxdifzAkRTctLWY
VBBMbtFOEXbcVTCOSYtT2+25JyG/rKK9edqBexIEjbZW12GPf6q17js=
      "]]}, 
    {RGBColor[0.24, 0.6, 0.48570930239273163`], PointBox[CompressedData["
1:eJw10HtIk1EYx/HHRSY6UmFKhJKaLhWRd800S92vctN5IW+YhIIGhhRdFCkJ
oleaoKCCwhQMusgYiFZzOpdZTFEjL5FgpOIFyT8UEp2UKyikN/bshcPhc76c
wzlv+LU7BZUyIkqWxv/Z/Tk1Ypv2tRi85OAFjB4Irnj1F7YPxDm/2aNR0+wA
0FUr5lUTbAUocnV5/cYU+xhopyN28LmdHQJKjcjtk9nYYaCShvSh5GF2BMTx
3kndg3F2JMg/zGCPHmQrQcVOWW+gZ380qPv+9VjlS3Ys6FT2mpBiZceBcmsj
mowOdjyo3keh+DbAFkC+Rfl24yu2CjRhvGeA57zToAGH5kTDEFsNmmtq1cse
sxNAU07lvMvCPgMq9e7aiuphJ0r/x7GtCPfcPwkkJI7lm/rYZ0GbFoNvsec+
yaCRzsia3x6fA9Xan4a+aGefB4n2IPPxDHYKqHqpXD3yjp0K+vmrKOf2M43b
aSDrkbr+FjNbA1osWNVH97IBak/b6k7od1uUPF1rGf9o5X4BZOtyTbcOcpcs
1DWVes1wvyi9v9PUHPqGu2S5usWimuV+CfS5UCVrZIuSe8aUmzc/cU+HeDm+
bLfxK/d0kHFxzxazxl0LsTpwf6WLLWqxbtipeZi0wV0HGpYHV4VsctdB9C9b
XmhjUwZGO/6uVETtcs/A3CPT9oZ5j3smwoLW8hZnfnDPhGirr4rxc3HXA291
Szsf/nDXQ+w/KZfpD7hnYX1iqpLyvODuWQiYNDXHPTnkNmXDaf2+q9Ye5p6N
uxW3hMIr3txzICjkHQvvj3DPQbl5Xzda4o1/IB/6lw==
      "]]}, 
    {RGBColor[0.2756161337922776, 0.24, 0.6], PointBox[CompressedData["
1:eJw103tIk1EYx/FHzXkLCVHooqAmYZL3yzRNf7pNnQ4MQ0oyK8uQFPSP8o8y
PFSWCN2U/igLp1SoaBdvlZpOlzcqENNWpmlOU0hialIhSqs9O/Dy8nm/Lxye
A8cjKz8125KIIozPv7dpGWJEl9zOYX60mz+A7Dpfnb81wraF+NVxxLL2HXsL
kH3NoVo2zHaGyJVLNQVa9laIjLLfd7yH2K6gyaaN7RU9bHeQQT3RqH3B9gT5
fhvMmuhle4EsJW1+8c/Zu0B1syXh1p1sb1Dyg8t3PdrZPhDdJxtcKvrZe0Aj
vqlrRQNsP1BkabfnuT52AIST3tewQ8MOBBXVzGSkNLKDII7b6rzk5h4Mofo5
77NsdgiE5EPVUSfzPKGgoXTt2spTdhjoxFiLzcFnbCnE9a7Sh19es8NB9Wr9
TJt5vghQoPWCtLGDvRdCSoblXPN+kaDyFdjnNLOjQIuHXaLqzOe3D+Qc1fBI
UcuOBgmlhco1JcbkGBBNV4a0VnIHqN/7e5pjvcnC6Jakqrz0x/x/LCi/71B+
9kuTRSzEvTZFmm0v9zjj+StvOP7o4B4HMd8zdLvsDXcZxOapi5JTA9yN1oVJ
i7PecpdD1E0Vz61+5C4Hfar017npuCsglsILPzdPcldgeve6PNprmns8aPh0
+twFPfd4IPPqeOLSAvcEaFrHywvOLHJPgNo/Z3DMfol7ItTBoVesZle4J8I9
8sBo0+QqdyWObageBOn/cFcCJTYBxdvWuSdBM/NeVhhrvCf/exIC2vPGMi2s
TKZkFBRF3q8u28Q9GfufnK35qpJwV+Gm2yWZwsqGuwqGqqKdDloJ/gLwUgU4

      "]]}, 
    {RGBColor[0.6, 0.24, 0.4144770348081764], PointBox[CompressedData["
1:eJw10XtIk1EYx/En0bCL5h9CGhpTlqmVlvc5y1+pm9NBEohUJmE1UkILSYW0
juAEzUi7gWFkGTjNsMBWZHlBXTPT1MoUlbx3U2dlRAjWYs8OHA6f833f9/By
PFIzD5ywISKZef5fLWMxkjykU/o1Yy28AXHpgXG4eZRtD9IElBWkDrOdgKZ7
WzqzB9nOIIf5ZhT2s11Aepfqgx9es90gShPkWeffsCUQekmDNqyP7QlReTX5
5HIvWwqRvJC+lNPN9oLQ7Hj0vdZqb4gL5VeCVEa2LyjPf39+qPX87RBK+5Z1
adbn/UDvtSXuX7rYO0FvJ4LCVR3sXRCyyqSAQGsPAEX4ry/cav1+IGjyWIFf
l4EdBOowtiqeW98PBqnSquf729khoLMDhrwiaw8FzWly2/CSHQaa7jVsrm9l
y0ApszWmuRp2OMjVsfRxm7XLIZxhKklsY0eA6r490eY0sneDPid5p9/QsfeA
cjMmlzrvsiNBTyuFd7Mukq8XtDZR6+vSaLEwe+VHj4P6Ife9oPIJt+OqJu5m
r1K8SM1v574P4q+nJrPvFXez7erzbGd6uEeBlnXy6jMD3KMgsuzcF5WD3KMh
DgeHZI4McY8GxYzW5R8Z4R4DseK2oV06zj0G5BkrfSeb4q4A/RyVqvUz3BUQ
n8LvDGm/cleiKqrhV7d8kbsS1OnYkV1s4h6Lo+eKfK4/W+IeiyrX6I91m35z
V2HckHJRevsPdxXExkP3i4dXuMehSmKk2TGCpcfhtM6rtuaUjcUUb/5fpwWf
bbbc49F3+abXLclq7mokNGVEXDPZcVejzC++omLaFv8AB8AGgw==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.},
  Method->{},
  PlotRange->{{0, 57.}, {-0.4537179201293071, 3.224981142477535}},
  PlotRangeClipping->True,
  PlotRangePadding->{{1.1400000000000001`, 1.1400000000000001`}, {
   0.07357398125213685, 0.07357398125213685}}]], "Output",
 CellChangeTimes->{3.575627899450034*^9, 3.5866610813797245`*^9, 
  3.5884149175024405`*^9, 3.588416521374151*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"wakes", "=", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Thread", "[", 
       RowBox[{"List", "[", 
        RowBox[{"#1", ",", "#2"}], "]"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Xi]s", ",", "ws"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48403613524732*^9, 3.4840362277126093`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "wakes", "]"}]], "Input",
 CellChangeTimes->{{3.4840362290306845`*^9, 3.4840362328459024`*^9}, {
   3.4840382312632055`*^9, 3.4840382368325243`*^9}, 3.4840384659456286`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJwV0HtMk1cYBvCPErBuQTeDBTIMdoIEcFzUEcWs74cdt1RNAYVFNtI5Gh0o
Iq5MLpEyENmmFoIOcYxbKyJULGNcWi5fV6kFVunFIIzallUobVG+6aowQLfj
Hycnv7zPc5Lz0o+dTuJSMAzbi87bO4CfuOeMjYSZKOp0aqiSiKNNqGxzJGDx
5pf5JweJTPFnqZwnJOB21leKez3ELx71HdVm5OSBoWLmb8SN73dp7xtI4B94
MIkliQhTdxTZ/Qj109sfmmVCYpMXP9auR37MUF7Q9UBEUO1StRrlC1lQkiwB
3pFGWqkKzb38fhjvEoOs5NbHuQrk6/RQl033wJH+XceUDDmrucD/xAgk0j2+
gC7U/8fDe59ID6GqkPc+uY38IfUdTdEoHEuQrvo2oPxcEKd/fhz4k8fHV64i
K1q+jD2sB+7a6qV3LyJHpx3m9v8BLHolyzcf9fu2GGnLWoiLct0WlvV2H3GX
PNK1ICMKHvceJUE+xnOo1Bo4UegsX41HeXPd5piVUZD+GB4j3Y18rdUngVBC
mElgCPND7/PuXin374Sy/q48gxsyO9rNM08Inpo/KfsXFgEbZhe+/KsJSk8N
VxvVyBnh/zbsvQLCju6l223Idbcy/Hkd0FyQxWkvQ06pqnM01UCm0b3bfBTZ
P8eZYvkJWC5f/+e6Azl8dk8vt4gIf/HrdtryM/TfSVNLthAyp5W7Hw4iN+dH
h5xugVaB3O/8eeTgCx9V1osJU2Ws26FI5IF9LQVTP8NNokZRan0KfPU3m0OU
v8Nc4ARji+ApYO9rzqXlDcO1+OaaxB1obtd1FgaowUUUeSaXWAB5tuxQ26IO
ygUVQVWfLgAuYfQOaXVQFZgweWDIAfjBkYzcFANsjClhVAU6AKO/qH3Amwax
5bJ6W7EdGu/zLkYQFij/VlpBDtugcY00NNFnwbk8eLD41TxgO6sZO5PnwQoi
89CGeZA/kx1Z8LKDOHGjzrbBCvxc5tayGRIi11GttuezwN+/yzgneA4iFXlq
pesJVI4cP0k/5wR2BZ/ZmmQB3DoQwfFbgtp6ybDr2Azaf8zimH4Frk8Vff5B
sAkkPnfrsuvfgG8nrYHCmQa5Ku8114nhA2BqT9n+CNjBPTdevaHgtHj2mvdZ
HWDatDT3Rjdcbsmxpp4dgZwE5oSnZh3O0XvfEbZJgeojidC9puJYX99l979j
CSpz1K5Qr8clOsxEWS8jturoxoBVKv4/EAXM7g==
      "]]}, 
    {RGBColor[0.6, 0.24, 0.4428931686004542], PointBox[CompressedData["
1:eJwVzH9Q03UYB/Cv48fWyUCDW15CjEPhxF0sRCoyn+/5Y0BE50Cj21G3/FET
RUHTHUjyJQgw8wYHSCowfgq4CcjgZOj2WbgNWRw4QDAWI5nMyYCvIgUCVp/+
eO65173fzxNw8GT8EQZBEB/i+X9vpoQfpDloKDwTQpFxZhTFedjjmKJBl3J4
O5SbUbLyi0SxjYYqgSCLHW9GFezK5uIJnJsU2mXub+jqhW0PjBZsqXvjUlo3
snZE0h0jNBDeYVPZsY3ozbcowbNBGiijVvK9qB3e23JlsbgP5xmskgRbE5w5
UMXJ6cH20Z3UsduhK7th+6lu7F4uu2HbHZj+6ofmR134fvdqiLNIA8IA9peg
wl5/dXZo5C6827N13cdNuB9pMpo66+FgjHrFV44t8pRuOleCqNFv+5dLcP94
eWnICxUcWV35eW0+zssjrOWbWlBsQGGsbzr2nsC866G1KCrSJTD0GO4zz16s
4bWjLpTxx20Rzg3C+8OjOiQ5t5C3Ek0D+U84z3CvG6kv8veqw3HfVtc69r4B
hVplllB/7OodROoJE8q9ozprccP3L10T8n2MyGfgd8Yu5xz+x/wxLqkP5aTo
i8f7sC9ct1T0DqDa5o7FphvY7ZpF/x1GVJNxTKzIxbbpBrWZ3Sh53L1jQjQH
VGncJDL0otg1R/914eH8sY/EKvsV8efbgjhLs0Bp7XW8Bh1KHjOED2lmgQhj
8OPna1GjTOd//jz2JxtZSf1KZC0UuH0Wga3nDuu9qlE9KuvOsc8AcbPCnzzQ
BlPBD3f6yWaAOtSy1pZ7D0qja8qEPGyGs1WVqYc1dRFpp5ATiI88Et2Y/ZAn
K9hStMcJujA1Vzs+CEXBMaOfaqeB1LDkr6uHwWtv9s6i4Gkgaq55ViosoJy8
1BeY9QzIZX7Q/svjkCdVF9B6B1ALi994DT2GhSVNXNbfT4Gsv2Vi0U/ADnUT
Ws+nQG1VGqVOByiFXmaHpx2ozT8xabdZiGCy7I4XT4DbKY8eMsxBXQ+dsqyy
QZWr30SCx0vYV0DtboyfhOczHkG24b/gSmWr3sX0J/Clac3ex1/BL48ykzaG
WCH1RMvlQ4ZV8L3FkTPEY8AS7Qr+7m2CvAtWxedBIyCO2s+TH2aQnOh9qxtO
m0G8mpruLXEldZOp9sTT90Eieuf1/NfupHhww83aG2p4cDsmnfeKSRKdnZfc
nwsQ1y+/beYoi2w1E1bGG11oXYZCVjbAJP8DIHPRjw==
      "]]}, 
    {RGBColor[0.6, 0.5470136627990908, 0.24], PointBox[CompressedData["
1:eJwVzHlMk3cYwPFSLNI4jjDWqUOhAnKMcYxjoIPnVYTWdRJKPKrIUkzoXL2m
jGOywasQ7DzWEtycGKoBZBZrQyUdtCI/xl6oYcy1MkFpLQyklGO0MByk1bnf
/njy5JPnyZd96EROAZ1Go6Xg+X+HkvzkkzY70MQRyt0KA+KwHuttk9gjue93
7v0ViZWCfcIJO5D+4eICCUL1XnJV7Si+C7tI0/QdVPdNvKHPhJ1DSAQ3r4FF
s8WuGcKONplubGsHv7fJzOlH2CINs5BQQFzE1eXaAdzbX+OXUNQJRXtusCr1
2Mr+E6vVraA782PiqR5s3ygFpVLDzCdnVU902PcC2bvLfgI+2ysP2nDv4v7K
41urIFr/rm+qArs4d/DVQhM6tFPrCriOvbEqj/T6BZHDnz50XsbeLliIau9A
BS9dF9ecswMxmytQCvsQjy3jBXyJ+67zrLcmehBni3twzBH8n2ENSg7XIx06
bW4/gF1S0jrK7EeHy5aqXVzsNc311Po+pL0Qm6FNwG7wjCj9vhfFWKSmmEDc
SwmZ22b8DVXdays2MfD9aHPZiIhC/r8/pW+fnQcyNPeDlp8pVHmMqn02MA80
pu3vpRc61KjSLCtasD36OV0vFKjh9BHh7SrskCyGQCtH4mcemtED2NwvhgfP
Xgae22ev3aOwlXfX7/laDrGLdzezVv4C2sobwZz3FCAe6U0YvI+dXxXJbW6H
W9LuwPJy7POl/otsNVhkmYysJGyq7kJihR5uois9ldY5oBXlq4Z1D2Ey7HHa
BukcEK56ecq6QfiO23CFH4V9UBR9zWUAt6akk6fQLBDhm2SN6A+olkoianZg
cxqmNwWboSZs5/DHXTNA0gkf6XMz+GScSasJm4HuB3EUb8gMyvFLA8EV00Dj
p37LK/8Tqku0Ejtlg26WoZAdPwlLK/d3VfwzBeSOeaczcgas0DTa5T0FY97O
/MPJ86Dk+xht3lYYq0vWbPjQAUmrPa22hefgCDRqKPUiNOntx5xtExCr2FrM
KF2CbAmZfitnHEg/dpo5cwWuylsp9/4xMLh/JBLZnPDDk68OvhNpgaDUuBB2
6L8QoGZdpwtHQBbvmygMciM6wXJ77+YhkBFDb0Y+pRMsbvbLtYVGyO7tRenL
q4ju8c+t+wofgOPV1Kp1lAchfLT2TmOLFhz+6cL8PE+C1tFxycORiWTwetdx
BpNoNdIsdKYOZedsjD6a5Un8B/7ewlQ=
      "]]}, 
    {RGBColor[0.24, 0.6, 0.33692049419863584`], PointBox[CompressedData["
1:eJwVzwtMU1cYB/ALDTCdFAau4IYhDU4E2dDAGjSz3x2FQlNmWudjY27pjEbF
4Xhkm6NO6kAe00IbbBCW1QZRFCpWEOQy8HSEtTzKS8fDFsrTWnn0Voaz4RF2
zMnJyS//f758h33s+wMn3AmC2IPvm/cDmTgm3U4DwfMuPGunUAJr0Gh/hu2z
ntbB16EU7RdHJNPYxHR5+ctS9Ie3urZkHLtadWjooBLKC6P6DRbsODX3XIsO
rA176YYh7Nnd2czgRvALkPFfPKZB9qHw3oyhBXaHlb0uMeE8acOlnthb8MMh
DSvHiD2haLLyjqPmi1UfZ7Rhp30pCC68ima/+bV2pBm71Hf6dP4DJGZ7fw31
NJDxkmXet3r0kXGn7747OL9PLYoP/oWOCaiVoOvYt6jkjKBeJBs+2bt8Fffb
uAmDok50YnXlytv5ON8n7t4xb0JCtkIY9DPe73LjJYOoHyXsZYREnsH9KKF/
I7sfNaOs0YfJOKerThnv9qBT0qW8lUTsYUf4d097EHV5VzwVjedFszWjgd0o
0lpsiQzGNm+y79/TiXL/rP/R4oH7Q3p91WoX2tz31D12zoH/I8m0ftqJclLb
S8ZMDpBdO+zgBhjRjdqG13eqcf6u3w6VD4Uqss5IanKxJ7emyeV1KGXMs2E8
GVtn2RieWoSEbqfXGRHYnPbVsPNatGuxbjvLtQCEs+i9UcEvkGL+O/pJK3bs
yPhYyT24XawPvnABW53A4GsrwKrge+znYHsb6h07KbiJSttybPNAsPOOpuY3
wrPQQe7WYmzV2ShLgAlUiRWl4oh5kDnI7gfOPnCr5KRnoDmQaco6u2b+gbzi
gjBl3Bzo5c4s/0kzKEMFw0mPZkEfkRTPo83gE3+RqwydBTImzjp13ALaKbkp
JPsFni+oXEqfhLyfqAK63Q5EbpP487pJWHK1fpb933Mgtri4NnhzKscfMZ+D
hs5fk5rsoBX7DNiZNiD+DZQvvFoAjtdbNvvLGZC1DrPW1pxQaaRTl+unQaTy
uik1LYKoQMa7fWAKfJ9ss25ivoIyta6d0TUBE8m9v1d95YJrI+ePvh9uBY2r
zy1GsQJB91nX3SVm0ISk++vF69AC1prD24eAoDlSvw43kpUoWg3MHAAFuRb6
zhUGqZ9Ksx3J7ICRc9Ii5m8epORx4N0b1RSIOrZ8Qis9SaKpSe7p5KMCTo1h
40kvUjdAWN03NCP9Q3XV5jpP8n/y/9MM
      "]]}, 
    {RGBColor[0.24, 0.3531726744018182, 0.6], PointBox[CompressedData["
1:eJwV0n8w22ccB/AvGhlrlLaXuZsV12sdtdFbOTXr53sdweksoT9GuzbrnU0p
Ss1oexr0wraYOFyq14oGHWFGM5rEj8cimnTJzI9rZEFkfiQRNOuOsYrrnv3x
3HOve7+f5/PH8/hfzklKcyYI4jhe/++HOKyIXKsdOO29nSKKFMXSn6usS3Yg
1i2+j3XfQkbHp+fYC9iLOrr2ahs8oDV01szhfr7b94LfeuDeN++PPZ3GXs4v
OPXgZzD2RNp7dLiv5KtrWRLY+xaHsTyB86AvcgPzu+FoYP1mjRbnhtJ3eXX1
8NWZRnqZClvQokpKFiN5yQ9heQrsbM/X6uMI2S6WdurldiBZ2ftyCAVi+dM+
Awl2fHkrbVGF3lMd8fywDTsoSunu9Qxdjpdt+wjxvImHRclhw4gz9eXoq1rs
p3Oc+lsalObY5r1Zju9fif48LWUUJfjzE3yKsBn7FaW8URQb6XIwJBNbEWn2
02mRHN2YeZKKz28NxpTmqFH6zXXudhzOl1S6Rm8tkn0XGiM7hnPXmUdcvQaF
GKumQ3yx+3f2xmYNozt9koJpCu5TLvB/ie1D+3//w/nkygsgZndzazSDqCxL
WTOrxTb0WZIL2lBTZ89mmxj75HhUk/IhEt3IZLffwe7q4v3JE6OMWdeeuVTs
QrdMPouLEpyuvHYJxh7jRdYKSyD078eH6VtrQDhWlIeyeyHDMHJscgC7UJAV
cb4XWquGfIuL14CTuDM5cFoFRj6DkhiOc3bI8nl3DbQggaLMvAocx+k1yyMN
LAU8P/FO1SoQYUcvuueNQ12cSMAKXgXy7ohCRJsEp+bw3Dy0ApzkF/cDUwzA
raoIrI7GlhZPkbv0UB0QP3Vq0AZDP+2L2lyahT0xJSeqA2zgt8pji1Qm6Jiv
1B68vQyNGczouuoF4H4tq7ArreBXO30gdcYM61sDH9/+xwKmkLR7aokFzNA8
N+hhAfbuJx6SdRt0sPaMWz3MYDrbXWmIsEM49Q2z9eUieKbKW8ZKX0Kzyp71
SrIAfvYucceldWBWcD5qTZqHa/20kQ82NqC+oUvp8qsJQk33b5Zf+hfu6m9d
eDvICExp0uRwqgN8uulCZ7YBv2ci1SuMIPvB2H72sA7/l8Ymm92JpMcxHd7X
x0G6KmNcObCLHJq/Zj53XQ2FwuBnom0KyZ7w/rFJLAPm1U9cKlKoJCGVVrr+
xUDp/TsNQj2V7BonjM5ucpS+UTQQ6UUl/wObINfn
      "]]}, 
    {RGBColor[0.6, 0.24, 0.5632658430022722], PointBox[CompressedData["
1:eJwV0XtMU1ccwPFLkbq5WHCQDmKZAg58EGBpV5EIv7sxXsNN0G0wMtiNjdmE
uI0yUITIdUiBzIZHIcqmhQENiAgtXWfLw1OwWEEUcEORaguU1hbquhlUQons
+MfJySffX37JyQk48sOhowyCIPbh8/p+j06NzLU5gZBrdDI/GSSwp/Q2ixNo
2UXl3g4E2Z3paZQZd2Z992ysEi5tlnZJTLj/EcVQ+ing10ruxE0D7sRWP//h
MjCqopyq+9gnvbsXGcXw9jt0vP0edlsQPB/rRu/vangpGcNmbGgeKVOh/C+a
2KV67HNb+o6NqlDvmbYPhEN4v4m/4/BzLVrM+rlruhc7XhG733ADpQZszgQl
9sGr4tkTehSm3+MVfdkJ2vr6oGi3CXQkSePiNOJ9S5ySnMFbiH7w7d3VOjyf
zAzO3KJHR9dc594qx71gpg1duo2SA6qTOYW4z1U2IpkOJUS5B4XnYO8VhHGq
h1EvOvXoWsbr+bA75toR9F3RssiViL0Aja7RAaT5JSJOw8PzRYrfbb8NonBj
lSF8G+5/fuXY86Ifne1TFhg8sLUHdD0ShHzGHzI+WvoHiHLmptyVa6j0uE7y
eAz7J09vb2c7aulSvbzcgb0fPy5dCs2ncqgrZ7HlXCF3qAmyHzNVpgzstZ2P
3s2qg2S3Y+vuodg+Fl/RXQVEPOsJZq88Bdpu7OD5D0L2zDDvrwHskFfj61lD
0F6l3Xb69FMgPmTMRvvcBmN1vMdnfNyjxMUjgjsgQ+eHSq0OoIV0X0qGHiwh
UzH+Vdj7druGI0egPrH5fGqoA//fRS9e8SS4tfJzhWgJyJNZAj7nbxBVVeyq
+XgJtIMLPQnfTENNSNKDA9cXQWuSz+XdfAiecWdiakKw4w5z+YEG6JwXjwWV
2IEIDh2XOOZAdEJT4dTZgNyxLi1Qz8PyysCnJS+ewHb1dMOaxQJWaDVdZz2B
Jpb5goBlh85Uz0kbywpUDFX0ud4B/I1vWG3/LQDVEvGJQOqEVr3z+KrSDF7a
2ile+TNIqaBj2w/NQzWVnVRnX4YGqVznPjoLWpZv2c5NK3BhuvjrrbuNsJ0W
hvbZVoGjYDcyqBkgN4gCF52voB+MV74Mvg/p6sj8ooNuJDsxZc03bxImliPE
+bXupHb+R2ta3i0gAnPMZKYHSd3zvdrSoYGJ72Mq0m4wSUKtFjP/jUftZH9h
od9GUj5JGBlv9qJ07mgcVckk/wd2Pcxj
      "]]}, 
    {RGBColor[0.6, 0.42664098839727194`, 0.24], PointBox[CompressedData["
1:eJwVzHtMU2cYBvDDneGAhbGOKAs0RFDphM2CHcl8z+aKJcyFqzompCHBKQTH
ZbhMjZ5CBygIbQoyrjouGYUW61gnBfErFDhQcFAUUBhlFnoRyjoIioKb+/bH
mye/PHleZuo3cWn2BEF8hO//3E3FcrItNiB2eu0scqtHRxhTtMWIPWve4Zlf
g9JlJ47zF7GH6kQziZWo3r2hQ7KA7e3bksARQ82VAxNDc9iKeuZSTgXSKyNs
ymkbqA0/uB7u60de71KRTydx/2TDEkb1ow/2Vm9KxrCFo85lgz0oL/Emo4C2
AVU4tyYMHkHdgp/DcvqxJUdHZSYaLafkdzzqxpaPsBUvh1As0z0ZOrEfyuQV
X9FoPx381sdS/G84W7qLq0WpUapt3xvYZz9Zb6H7ETXz9e9bFdhJDy6OdvWh
tFfbpTuK8F4zyCk9N4KimaJo3+9x35lwsOy6Bh2JcAgIycD2fH4/b1iNutH5
P+4kYZ+S5sc/7EWnL2wUbvOwb7lJWFkqpCoJ5arY2LqSNUGKAoXoy+dC/LB5
tJzRXouEPZ3n5pywOVzjnj4KvMcf23+68hcQAY3/tp7qRAWZA5L5MWy18cLo
niZo6lBuStuw2Vc0RKAMGs9n8NuF2IwSoUyshPR5Z+VCEnac1cXPrIRouzOv
HVjYPm1PpNxeCF3/JZDxYhWozC8r508MQfrsIPtB7yqorXENbiUT0Fqu9rt0
aRWIGu+KdzJGQC+KdPoiHDs4cr85XgstqKq/wGQF9dnFntt1E2AMmjr0XrkV
yIiq0ykfTkElr7EqlmUFwr/l5qZ2Auyaw7Nz0AoQXM3V0oZpKCwv3iv+bAWo
bd4xtmYKxEFRM5/fWwbqDi+vWvoYPLmCQ+KgZSC1HmUnJxdAZrg2FnD5Kfj/
KnOd3zBA4XeqYtuABUh31tsxwUuw8aL36OXnZiB3C34abzODCZoX7nmYwT8t
gHnGcQVksZ46i4cJSEGyS3zaKoS7uJosa0tA/dY0fJW1Bs20LXOrcxFigmuj
VnPXIaaYOtwaZwAR0RH9kn4G1Q2KAQftnyBidllqlzfhx0cXT+7ap4cs4tk4
ffAf8L3NuGHPn4UsG5X6fv1ruAv69mOB09Ba5zi+pbUjGbyYVz65OlAPpBjd
vRxJtSHLdDx3GPj3Lf48mxPJn/SRN7WpwPLmXVoQ6kISXV3XnP+ORK5FCQfC
vnUhFTpCb/9GN+IktybKdc7kf35W0ik=
      "]]}, 
    {RGBColor[0.2634521802031821, 0.6, 0.24], PointBox[CompressedData["
1:eJwVy39Q0ncYwPGvcOq6DfWqMe/Sa2bLc7lBm3PNO3tYzR/MNGFXTc815vIs
k1Pz1shtgsnIWQ496aiuklPyB/44S1HAyceQDXNcCU40mdBEAWWCLlcWtvbp
j+eee937eaLyitn5JIIgPsLzcr8lYO0tdfuAoEyl6k7IUSp10uBe8IHg0eG7
fGE/Kuz8/CjHgfsFc/zzERW6TrnR3WDH/WPkChOq0dWf3h//zYp7xW5Lq0iL
bMpEn9KC/TR7Z+aCCm1+Q5CyaH7ZP8vbptWiPbFXnjQY8X+tnDYxfwd9c1hG
rTJgr5Fr6md1SFPZ+sFpHb4/PrSa4kNo6di57mkNtj1fUSMcQawoyhfQi+3c
Mqa/rUHvGnaHJbVjJ2X8VflUi/KYan9EI/aAZ+28RIUEUwX3nkmwzdRl8det
KH/Df/HV89jyn71QfAulR9WlR5zF3kFwP/V2odREcjTtFPZKaIFTzEMaVP7n
QA72Y2kLz9WETny3JvKnYctev78npAHUF+jJ6njsaa4x7r0WoNnEVtp2bPpZ
nqJFBsLB3jPWQOz+sk0/Xu+ArfcfkPZ7vEBkZ198hzsIVVx9w6wRWyTJnEA6
aO5WPmlXYDfuv+Oh9ENT+SlOhxCbN6NgTvdC4WyQ0p6DzdziKhb0Q3rAyRfk
OOyrqwL5DgPQ/7m9i7q+DMRO0msGrxEKZ36NnxhaBoEcOdhdBmgTD2+vqMDd
n9HRPj8GtrqUwMwE3HNN17yDo3ATSXVVzr9h+A/mqNQ1Dgsxk/sixdgKOaOt
0wyX0pqkrDhspo6fqDFBgDyh9DTyAINdeQ9GJkEkro6t/8QDRHwfv1z+AOpj
mFMHtUtAKJsXn39pg9Dkyn31MUsg2EszfRhuh865WmM0fxGIZLp+9oADRN+q
q316NzDumq+dszhgbX0og//YBQ+tWSVfiV3gBLldG+ICWemxIu74EnSyQk3u
ECe8Gcmz3UzyQULwK0736jwMSyOj+pZXQG7wcZ/1OmBcVPPfwKFHkFUtONDG
noMsWlHfpP9fuHKjR08eewg9skuHfresw+Xp73O3vW0DOlFEORi8ARG3qI0k
zgzIWFZTROwL+AVsHUd2WaDOkVvnVgcwqGlZG+FlJmibN2zOGSQzhudKnEfL
RqGEQzsjuRzI4JjDu5oVamAUHJdURwczCJWqNmglBa3/oGennQxm9JgIG2mT
BoUNhPF0q0GM/wFRCtq9
      "]]}, 
    {RGBColor[0.24, 0.47354534880363613`, 0.6], PointBox[CompressedData["
1:eJwVyn8w23ccx/GvmHRqC7tzud4xzkxt2o67qLa78c5pEYfWj1NOd73vGReV
NemKumlHtIRNHWmo7nrajbAEWxKkbSp8Uk3onKzTUfUryUX2FQRp15WT3uzj
j/e973HPV1CuID2fRhDEMXy7P6yz9KZheQMIcmFl6b87kPyFKyR6CXvy4pmO
ukbEf1au7rdhCwPSaoIy0M8s/Xt2y+5+s1t2rhZNNnnm+S1g0xjFJU4pWpwj
U/a+wB45pb9R3YGY0Z3S6Enss5vx9Vd7ES9SUGc3YotnCEm3EinIS13TT7DH
nbbbJ35CQ78YJSOPsfkGWyC7DX1cmB17SIvtfVzxkqFEmQmsAUk/Nvdq3KEi
Ffps9IBPtBybWXA29v1+lJuocfnfxWYbe3Ize5FwmvvHdhP2duYyq7wL5b91
XfeqwY55VDbzlQwlBTUm+X+LXZASUThUjRI+dw8O5+26QhCcKEYPUdn8/Rxs
B5diWW5AweXXIhcHO29Z+0N6E9LURcRpIrE/ogy+X6sg3NQwFx6IPe1hLfbS
QdVA36U5D+yM/KPeR9Tg+3SGFru6DsKtCBNdNQ7XzuslC+PYxUmXO5kj0P6b
elPetQ4EQ1S3kn0P2sp4ZHcV7jvft/rmD0PhAl1tzsF9XXY9uBpBktu5HfeD
uDe3mk+yHkPEq979zK01IFiHWXlzeD9riPxrEPudK6e43DGQNegCy8ux3ygH
9Z5jYGqM9zgZtQbCnsa9lblG6EAtw9coBxCS27wSxRj8HToV82GDA3RH7h2d
WpuAZk5bS9pBB7APpGpPB0yCmzTqm4toFYQL86MZpVMgaqj9VHxiFYgSbpUg
5DmIQxOnk4dWQKfmH5tXzIJ3XGWMOHQFiORhH+4/Zuix1o8HVywDYZaL+QoL
iEo1tRt6O7C9FO2amkV4vTWYUvFmCUjF06LKDyigQGoeYiyBThUy/Dt9BXrS
vCfsDApIP26QIcYBUXvepewvbfCnloo/k+AE6ejG+e2+RSBJTn9Y0itIrRUe
l6VbwTkQcF8T+S/8eEepdx+zgE5eVpIo34RbL6586RdmAtLnO1sYcoG/inmX
Rs6CjmrLOdy8A1owdZ/e/xw+yfK9aWtxYzM5qW/3FU2Axcob5be6s3XWC1RW
0RPgbFxQUFUebPLZvl/buzTgkzXm7DPR2cSDB/V0ZzzKjuoQPRLtYSsnCBPN
8yFyFm4Leo109v8QH83T
      "]]}, 
    {RGBColor[0.5163614825959097, 0.24, 0.6], PointBox[CompressedData["
1:eJwV0H9Q03UYB/AvQ8ZMQfpxRAcdKcFwgKxzcUHA8w0DRpOFXiUtzEF41UhA
p9tlHs6DcEre4IZBdxEJw2CCjQkXQ+QzYYtBmDFYYyBzsbUBE1AkRTeqD388
99zr3nfvP97bC0r2H6YQBJGIb+MzLou/1c8vA9HccjSgow/tTfZEpriwdzra
ZqEXFRvLurscyyD5nmEa6bmJLu3WbZ2z4Vzdx6V36dBE7ebC0BnssDRulFmD
7NP87GcmsbP1e/QFCAWnXFakTGA/OchdiVOjIlZJ1dwt7BL3pG96L/qZL1Ka
Ddiv0D68Iy5F/T/dkv86iF3PLiDyL6FXBblpcX3YJ9aMiTe70fuZu6/Lu7Df
SL7KtXyNdg3FBKW0YdsSixekLaggS+MJa8QmezvOfFGHJOZPf39au9EnCJDS
qtFhr+ebLWex+Unhss5axNlezQn7ciNvf/Zf1ACZSb4R8UXY0ryzDLsKL3Dy
zi887BVd9kVjG3z21Wqlh41tiMzTS9SgqWKma1jYcSMWA6cL4q2y6fhwvJes
iLquHISK69dE0344N3GsDsZv8MJtCyXNvQQSb4VYFDkI5Ud08pnRJSDeSjpB
FQ1C89Xux21KbP0Ozmv9Wmg6WcS/UoF9PmtT8usDIJihdt/lYYfzmIHEEHB8
Pv/PNxb3vfT8ZEOEAZgr6qjgtUWQBL9L450aAcGUnjV+A7vT7x1l7m1olWnD
y8oWgfS3e5DpD7BWZ/hxExZBKxzLtGaMQwuqGyh33gOi+j2bcMAIf9NNqS/L
7oHWYlrdUT8BF9lNdftisbOfGz1gN4GPIuHoMeQGSZNUUZhshkqZdGfN227Q
zjOmjzstUEPPMu/tXwCtOPUfYYANtqWfSa2hL4Bk/dzqwyYbtM9eGI04PQ/a
tNBdihg7VIo10mXdHNj+yv9kvMwJq2s3sk8/coHN2Lz1HG8enKC42x/ogh/l
PofMLW5o37dtbC7QCUQp42Dsi0uQ4E9zzj1wADMqJP/jmAegGFo+8vSaHVQq
BBLXQ8iRSva07p8FZu7wlkb5I/juB5XOd8QG91lVgqDyJ1A/eSovlGGFHJd4
uMfhhbDO4EYKfwpIbwm1+BBB9oH1ygdRf0L0R/mFx0QUMpid4w0RjkFQ7ZvH
h9mbSO1sqfOA0ADRLOvMBJtK8o0hHc1KDUSzG9SB5/1JoqfnAvV+BiIfa6es
dBqpGiOslM29qHXd6yLE/uT/CUfLOA==
      "]]}, 
    {RGBColor[0.6, 0.3062683139954558, 0.24], PointBox[CompressedData["
1:eJwV0X9Q03UYB/AvQ36XP4rbEc4TIUFNgxNuV8h4vlDKOMDQUsjjrkkuFtP4
YYktDkYYwZGNxUjJTIJlMDCX48cmjM+QITAHuaUiDOaatE3GGCAixzD68Mdz
z73ufc/zx/Nsy8w5zKYQBPE2rrW+62rBj31PnEAg2rzQpkHJMa7tDCv2B+nc
10Y16DN9UVvrJPZ8jeCnVzXo10j1SzaTE/gwnsDh9KN7Ip8TmydwXrcvDu3r
Q48NrBTfh9iXjgxlmRGiMq6KGfewg3N/UE0rETcqp9I2hG2KjJ7d04ius85I
Rgaw2eKZa+2tqPv3oerbvdj0HQ2Vm+rR69np8Xu6sAlajrs2AR1JiOysbl2b
t5csX+fAm/1vbGQ0YTcUh2XFtaPMRIWLdgW75fhw4c7LiD+SNbwswt74Vs8/
jkLEXnF95/cttkrSo7F/CEnbqpJoX2JnMNzW7ZVBQrR7SDgX++RxaVatAm4i
3njHMey9PdbbZgScrxbKXExs69e+n1BbQVEZsV8Rhe3tezYisw3CjQJD+FZ8
n/zBwR2LvXCuU3bG4IGdeLJj+8wg+P81Som3zwB/VVnAvTEApafU1RPaGSB8
nvEu8fqh4Y+2500S7KYWit/4ANTzuKzmc9iCkuhA6y3InvBse3RsLU8Pltvv
QJLbp6vuu/E+Hfpiy7AWIuZvhFKXHEB4tDs7/LWQPdYX9bfSAXzhHOPpy3eg
UaDaWlSE7Sc7OCbVgLHqgMdBugNUHQGeMd/fhd/QhVullmkg0zaJ2Bo9/Bt2
P3aLALuiIna46wHUMOsvHNo9Dar/hj73r7gPbmJ6Xj6yg8pleHpxYRTKBOU7
he/agXTFp9bnjYEwLHEkuXsKVEcRqzneBBv2l8QKw6aAH6psTJWZocV8XhtS
/AT4H98NpOdMQlmBotyptoHpGdK3v2eFhSVlSvGiFcglrSQmZAosIH7Uvd4K
QTx/pijQAS2HNuhs6y1AfgRxvfhPdC9vi21uEog5VvCLwHkQ9ztPLcseA5FN
lxuSFiC1nP9O42Ez1CW//81s0HOo/UWqdteYgM/sO6EOWoaLDwszNu8yQlWp
zmKffgG0P6lXKKwxYKUl14RLCLILjM1HQx9A3Sv8UYqCQlKZqSsBp3Vwlr1Y
li9YR6rMuZa00wNAZoQWizieJEsfcK1BooDc2uA8/aoXScjl5z1nDyDpzymr
E4XepFRHGCk+N5F8fKXrcqcX+T8v9tHT
      "]]}, 
    {RGBColor[0.3838248546049982, 0.6, 0.24], PointBox[CompressedData["
1:eJwV0H9Q0ncYwPGvmJLLzHbOudOm5spGkmwYV574fI9VypmdeVft3NwxZ6t0
ZZvnj9wOcRpyUyMTf7RflWCRWeHMCaZ8GRq6/JFmKoIiGQH+hBy5JjT32R/P
Pfe69/PXE5qWlXychGHYXjT/b8r1vJoHszZQ3WXZT9FHiIMxzm1Miw3wuAuL
GzqGiTOPua33TDbAdlDXfLQ9xDV6t7fVaANevlPzWqUmnoi80gOnUB8E8XnZ
H8QzPSfxDS1y2wTdEdhC+DOvS5hPkOd/yDFFKIjMqKwy6wAyd5VhtEuIu5zc
xvFeZKNOv7nmEqG8MVCl6ULe4/XT0L5yeC/jYxa1A/kqhSW8dAaOxNHvV91D
/vkdnPLmHdjVs9OXeRNZGhbzwi4m0tgKZ9AV5HI8adRaR/DGTwyuipAF5M9W
x36E4y5n+YZS5IBSa7K0GRJCLyYEnUPOafZzZskhLto9LDITWWSiFtDl0E4U
TLalIFNeagqv3oCT3zr4znjk6fkuu6UdFGW0/Yoo9A9fDT5XrYZIg1AfGYz6
8wWhdkIFJfdbcvUeqNe25L80doHfowkSa34JsKY1badYCcWnu6um+pFjgkdT
lJ0gvtP6981G5Og8Zr3uT6gvyOTcKlkCXpu6+wNWF2RMebZOpyBf2837flcv
JLidWnOPQPc5g2X820qgLf+23f/VImBFWr5pTA0ZugdRI53IjMS+NIoGpEJV
MJe7CDzuOhD+OwCGiwc8DjGQaxpy46v7oIGoVRebFwDzS3/No/XB8/DR2C3C
BVBpUzfmjw1BdXx97eGIBcA9UxtK64bATcL4+htiHlRvWz7n144CXyh4v3If
8t700D3n9VAZzh4/qJwDXjhPIftCD5v2F8VWhs+B0XvITbLjKTTNVPSHFc5C
yIkvf2e4PQV+nkJg67YCtrXMVTBuAserzsTCFQvw+r8idTgsYAbJtNLHAiH2
rZT0c3PQdHjTsNXHDCHr32o6+eESMMjrzdYXJhjaMn15s8UOkh7b6dWWZ+Cr
PLpbJFiGJAHvI2nyDNjZhuiId1fg8q+ybveHRqDF1vzFpvwDddrvPg2kGMB+
TCdaLnNBULP/FRJHB7RsW0WoN4Z3gOHW0e1jIB9xuB75kXD/+CRXQPYwSINK
qIUh63DVzFnzsexe0LamTsbOeuCcxwG3xY0KyN/o+oWdSMYxubzC036AODu5
k3rkIRmXDWMGklc7IVv5pKg4kIz/Bw6Z0aU=
      "]]}, 
    {RGBColor[0.24, 0.5939180232054561, 0.6], PointBox[CompressedData["
1:eJwV0WtMk2cYBuAPOsoURQxLV0MXIGhh0AkMhoHZPt+YchhC0KjbmJgOdVTO
k002cVCVIBkSwILFqCjYIQVaaktjD5S3qQXRwJSDo7ZQjpYKQseCqOB07348
uXPl/nMnj29a7r5jzgRBROL7PwObCi51P3MA2Tx5Y3vUMNqzc20be9YB/PSd
kYz7D1HOYJGyY8YBhK7cFKCVo4Yw4wb7BPajFOlvQXI0XLPuqNcY9hIa3SFR
omkLN3G9CZtVdzVfUYNo7CYRexj7RGgh09qKMsNzy+392J8qV37WNaF27smW
kV5sYjMrKrYQum71C3ruYsteXDLQT8PWjG+iP+nE9jlcM+3WBAdiw7SCDmxp
nkm1Qwzb7wV5sMXY+1mqIWYVpMWr1xjX8X5+6FEPsh/4I+l/rtbgPj7xOWm6
A8ferF1wO48dskWUm3UWEnyrEhi/Yi9OhrjntUFsFMUvOBP7cYzKbQ6BBp0a
vZOCnSSsTqUqgFe4XLoWh71M+7bMqR7U5SG71eHYF314so0KCLZWWoK9sev+
zaIKr0GJVnHS4oJdf3yy9rwMPnj4xDl6fhGIgPggDbMTzmUbBWN9i8Dv47l0
IwPclCpfiltwz9NcQwIlNJ7K5LaWYG9LzlZd7YSMMapyPAVb9tUTzmdiSHA6
/o7Cwr4vpaWxFRDyj5xJe7UApMBTJjEMQIa5O3xItwCEOv3DgpwH0Fyp9y4q
wva8EKiJNoC1KsYlKQI7q3exMcwIfyCh4ZztORBffGeOOdwDT/0fcz6qxFbl
tms5WqiNaxTuZWGflWeytyJwEkX8eALNA3lw6IeeqiEorSz7uHrXPBCHxuve
coah2j9+ZE/XHBDFP7V7HTHDpt1nONX+2Iyc90xBFmibqujzK34G+vVeajtl
FEoL1GUOox30TN9a4cVpWH6lSyxemQWfA7ueJtBnwAai8S73WSBCS703NsxA
295NA3Z3G/AlAUm9iXMQ4fq+zb40A1zrbd2VBQeI7jmyVxXToG99dPfMjSVI
LuN/2bxvCv/7SMfm35fhcr3MSHkwAXkSv9S3FS+hznT6kFegFTzEq5GU4tfA
uE277sw1AzfJslLi+Q46wdp6kPkX0OVmqYeEIGlxyW/o+QPASy30e0GjkPqp
PNvX+b0wYXezbdjiQnIH6ZKbLWrwWXjtOthDJQmVqoL6dwz65UpDuYXuSsoG
CKvzOg1K/j7s88ssKvkf/WO8/w==
      "]]}, 
    {RGBColor[0.39598880819409377`, 0.24, 0.6], PointBox[CompressedData["
1:eJwV0XtMk2cUBvCPVsBbwE1tiLAAIrJVLnUibko5naLCkAkkImHdbBDjVoIg
TFCmWKOwJlwKFgUv2AoVyk0q0MFXga9qFXQtk8KsUKi1YC9cVnXYdZSNvfxx
cvLLkzzJyfFNyUg4RsIw7Es0S5tal3v1scUKHOoGqTJtiDgQ7vCnm6wgX80v
SN+iJk6o86UdkyhPkV5/SlcQt7cpVpv1VsBeXHiu5gqJ4YoVqZ7jyPaBZT36
BmJCy4pd+RJ5ThEey6wmKPQ6EX0YGZNGCvXbIS00o8isQmY9eLvDdIVoZeU0
avqRq0glHqxS6K1X8Z88Qk6tP72+tBw2sZN2B3UjZ3/NiF9+jzi0f9t9fsdS
H6O7oLoVgvu2rKE3ID8RLxTPdEFKNO7wEiCLggWGj+8AR3N8YL4C+aebuGff
NeLYgqN41S/Ibl6VpoO1EONbFuN1BnnDqstCah3s30n2C0lDDk8NLPMQgozI
G+tMRrYdzPCVt8APP88VOqKQS0uUzD13AS+i7cVDkaOTN6poEgjR8bQh3kt5
z0dfNXbApfvtOVrnpXsvv163UQDrfh8h7Z7+EzD8u39OD+BwMV3BH1cic/MU
nVgb1N6V/t3QiJzpr3JWtEBNXhqr6RLyF1WLM7p2YI+7SF8lI2Nb618/yIQY
px8XyYHIJze5UcZwoL1v20yxzwJGPRP1/ZEWYI8+Dh3qQa6RVfDIChDz5N75
+bPAOSXj+hztB13ZPudvwlDOFOO2D7/CHaLy4UXjDHBMN58D9MGbgD8iPuEh
58qs0f+q4EpUTWV84Axgv1X8t3ZeDU6isJNZxDRwjg+d4nVqoJDH/aw8chrk
WSfY54I1UB4QrTnQOwXYjYn1WOkwuO+9EFEeMAWMoKff7rw6Cs2GEqXfeQtw
vMeNOR9GoDAX51oVZtAXP/xr64ge5uw9sedtJpAXs69HVL0BI4he9bqZQN9k
EcxWW6A53n3Q7GYEzqPmMbtmCsJclxvN7yaBFZSwphv9QdRnTZ9vnwBhm197
wY73EMfl7BEnGMBHt8svv80G125JFORnetAnZR3G5u1Q9fIs05OqA701l0aW
O8DrHkVAYo0Cx/9zW6t2EbpB15S4+QXIDSTxpMSJQYmKW/DIHoRPEyOLJJRl
DLkh03g4ux+S3mnd+TJnBkvt0VLbiENcrOrIShdXBtbVVeLydh9B234u8azF
lSEZxHSkFTLCZxdTWRDqyvgfBQvIhw==
      "]]}, 
    {RGBColor[0.6, 0.24, 0.2941043604063603], PointBox[CompressedData["
1:eJwV0n9Q0mccwPGvOiQ3J7uusTwtVi5tapOm07OUzxdN0yM989J27RezeTnR
bNbJzaXhSOdSjtDKrbm8ipLQOQd4CSpfaqBeI0PzB2WQv0JUFJleWdDcwx/P
Pfe693P3PJ+7Z1tOUWauJ4ZhsWi599Cb3Eu6OTvwmP6XBcP/EAfinDviZ+2A
zYRuv6I3EMeHyjsUM6gnLCbXxPYRVyO1vtYJ1Jt3m5gGBTF8weebABMyLmXZ
9FJiepyd9qYROYnWc8hHQ1Djb4rjh5HNpakFJClwoopqrPeR83wuC4obiT/Z
JdKxfmRb8+Jn9jpC3Xy/vvdvZMmO4IawH+GD/E8TdnUjqx25k4ktkLU/sqte
gWygMn1rBMRHfWHvxN9CrsgNlX0lI3JSlc7AJmTtsbgR+W/AGzs28OqC+3zB
ikdQLeS6nLVv/YS8kb4HAuXA2naeFfi9u6erLI4KYv8er6AIDnJIrGKIqwIV
Ufrk9hE0v/MoZ/1FP+T9sFrlTEHdIav/GidAWUNPUkYh10lc9/QERJiF4xE0
9/tt6fz5SjjbJS8ZJ7nn5WbNJ0hg04NHngkLS+j+yvYBRi/wC7X1Jv0S8MgX
jWq9Dq63dby4JUV96++WXd4dcK2Uw245iywyZArruiHf5N3x9Ag637VPS6Lc
BZbHt+te4agfHX0ozNEA/V9ZMHVtEbDVw+fKauWQ/1gX9bAHuQiba6P0gkSo
oZWXI68kUfhfEGA+n0xKj14EXnmhHz55B24QDXf5Fhtgp7z9X9IH4VnICGOL
0AZ4aufOre8a4GLKtYaD4TbgvX28mfafATzE0d8VEwuAG9fCHywZoUpY/aFo
3wJoOIKsndtHQBSSOnZAPQ/Yz5/QEpefACWpgiEKQWapLIcax6F1SqAPOjMH
7O4GXzF3Aqq4ymq71gq8gNt7d0dMw+paT9qZ57OAkWJ0ke9ZwQLip2q/WcA7
g0zR2BK0HqQMWv0swH72Wlups0M0eYPF6piBjGyBhp/tAHGfvfCVfBr9r9fO
gi9XIKOalyjJnAJD9d7TcWXP4dcr7VqvexOgCWOci2l7Cb8YT38eEGqGjEmp
q2zdBYF/UZs82Y/hBPNOjB8Xw7vB3JIdPAoGxiPBZKUnTk3JcG0+OQjvp4nI
jpI3cM3UCcvhk/1AN25iNoq8cfbQ5j+uS5VAb5od2KIg41hnp8B7OZnIO3Xj
kqx4A94+iJk9fVTE8sf+raM2Mv4/GQTGvQ==
      "]]}, 
    {RGBColor[0.5041975290068142, 0.6, 0.24], PointBox[CompressedData["
1:eJwVz31Q03UcB/Afm4AgiXSGcJsBgqCL2EqOsmv7/ELlwUkNyAzPup0niZvI
wg5FvfEj5rY7pDmnzdKawiLYwLBBMB72mzDiIZGGFMZi7HgY48lFkXj8LPr2
x+fe97r33fvuE3W0ICuXhmHYbnT/J6v6zOfds14gAn1a+e0PyANvUtu5M8iX
HJ2KJBt5akja1DjlBcyjq2im15O3d9mCPC5kJmMmJEpPDl8NOMYYQ/6X+nnp
lVpy0iHMCHyE/LrBsU17nQzlVuu5w8hpfkwRR06KEwvKPQPImkPcuwEN8J2w
yDDSi4zTRQmGOrB8O6D5sQv5S+KvPJYeYkTvJ7/cjuyKbrOV6+Bg6q42TSNy
njXlhOEaJPS8tIlbixw00ZV+RU0eTTdTTB1y51RuSeEPQIwcf7B6FTnyU7Fm
7g7kPqMubVAgF26NKctoBH7UZT6zGDmn+R4Vb4LUN+jRbDH6v/fIZIukE1rJ
c783H0b9Bwt9/I8skHd+WU6lIT//2bEb1SYwl3P2mRORJRf3F20yA9upcrAj
kMMT2jfjXSBrMxU5fNHewVsZgaQNNg/+RkuefwxYcU4z450OKMu3acbuI6+e
rf+poBKq7jSt1BqQWebzyfp7UHlOLDTKkFNtIYqTZhCN+TWNH0b2b8i2a9uA
73NijR6PjAfFV9v7gPPn97GhTxeBMLFXilQ9IBrtTnzYgVz6ojUT+qFGZY2Q
ShcBK4safiG2G5yXU3zfTkLuk+94a38/fENqO8vcC4DZlSFCxSBMx/3C26pa
AOJdqorx4RBcS6vUZsajXtA9sPfsQ/DRJ31cSM4DkR4zfpM9AnKVcqd67zxg
KwppBDkK6rj0kQOWObDOaZQBF50QvK+Up46bg0ie9kKJ2AV1ExX3o0tmQbhu
S+TflimQnzErvTYP3PIu7tymdsPy046MkiczIKw3She90+AG/bhl4wxgV2K0
+WGzUJcZbPdsdEMkf7tsevdjSPJf7/YsTYHLZ7BcZloCfY83f9U0CdirOtYO
32UQKIk9NVkTYF07xWsNfwJffN1go/e7wJq9kr0hZxWuP7pwhMFyguC54zW3
X/sHmHdDdTThKBAnOSE8ag3awWl8L/ZX4IQ3Bk9/QsND0wTPwk7bQcLuEuBf
rcOtExL3odO9QFBb9gRy/XDhUFh9lcEMrl5WcZbRH8daWir8/kghJaUyY5Vz
Pd5gx5y0gFaS0JhUZJ0//h/cob4P
      "]]}, 
    {RGBColor[0.24, 0.6, 0.48570930239273163`], PointBox[CompressedData["
1:eJwV0G1Mk2cUBuCXEopCA5rUxkwIIlCEMSgpYXGxnMZJoQE2QIeEYFLN2BgE
FSTg2AYvobISQawIOJbIxK4TClr6YSlfTx1FAcsEYbZYWhtwbRVGYcNKLHF7
/HFy58qd3D9O6Omz2QUUgiAO4Xuf0dLKtvGXLiDFyXdJxgJKP+yJ4DhcoHvH
csey59GZJ9Vq1Qvcz/gbAiKm0E22nua0uYDIU3Dn4vVo/trOL/dZsMMtZlvR
JFo2CzL8TNhrbdGqXzSIwZFKOPPYnAMZvRQ1Kk44e8k5jZ178ei9Q1p0V1DR
Y5zA+2OycV7VGBr9bbrlwRjuA/cLNQdVKLwo98hHw9g56xTZbjX6IoU91KLC
7qr8KprZh2IffriL040dmWZlHVag03ytJ6gTO6P8QEMrQqTx6z/eXsOu3UGn
LylRwban0f9HbL/jWZrWOygt9Epa0LfY+tYKIbcPpXziHRZXjK1EEHLxHhpE
VYuaPOyZhst8Sh0q/G6z3pOKPbnOnHPLkfYSK1mbgJ1P7XBGdKM4a7M5LuT9
f9AqPVSFhEPKCrMPNivxfpakF9EfL1COrKwB4ZAL/XKUqK5E32IxYA+1h5dt
KdGtO+o33T3Y5ZobwTevoq6qYoFMiE1q9kg/SEFFFqr6eR526YKAPTSM0ry+
+c87BnvzzfH0M53A+kfBZGz9DYTC90J/kxSKno0nzI1gm7It/IMyuN2sC6mu
xr6a5OxK6AfrFZ7PZ4nYU+XysQkF/Iraf6+zrwKh7nBPXVbBX5F/JgU3Y7Mu
NOR7PYLW1K72rBjsyXZJY/AAeEkSS8vQChA0dpM83gD1zaIo8VHsx8fiKSID
iCP5xvTRV0B032c6iqchMLk2SRz5CsjPY0+6RE+hd6nJEFbzEohW04Y6ygr1
lVqRS+8EsnT368UOK2xujWTUuB1gE66V/fDxMthB8nw0wAGElsYoDHJAb1bg
rDPADmTgSbNR7IBE3x1258YL0LVtL56KcIHkoavkrXIZZmokq8vSDcgUkZ/e
zl6C/XusmaZH/8JPN+R67ykbkOrawih/N1w3fZ+/L9oK3EHewtoDDwT1Mzop
gmdA9ofRKPx3MAxWWQ7zKdj0kwVEpheXkZq5vff8LOwalzTG/OzN1S2ds584
PwHrihUXO9mHK3iyt+9WjxbOnSphHTtB5RIDA03UdR5i0WltxhFfrnyWsFJ2
DiKB9DVPl0vl/g9SC8pr
      "]]}, 
    {RGBColor[0.2756161337922776, 0.24, 0.6], PointBox[CompressedData["
1:eJwVzX1U01UYwPEfW4w3D3Y8yrGAYwSJkjgKAouX55dsCG0m0iHFyBZJEdOg
LDwhsRWIOxgNnOYL1QAnsQmKwIAx2B1svBWUIDgENtYG2wxi48Ukp9btj3vu
+Zzvc+8TkJGTkkkhCOJVfP6/Q2pPfN97zw58FcPDyzqG2DHOF2KtdiA8OrtO
VoyiT0YL5S2zuD9QvkupG0bV4dp1NqMdyMwyr+r4W2jsnMcRXz3uXEaUOleD
zFOcvZ4T2Omla5e2DSKf2FpJ7Bj+T9/05FlRN+JG5JyxDWM7qqYbNO3oBidP
phvADrUMZEz3INXPw6I+DTaF1rozoQ0FZR/cHdqJLZ09tcu1E6XuCVeKWrBZ
kuLLAR1oZ/+LT8dK8T50pH6TqA9lJCmcfmLcR0NTnAX9iK/76LeH57CjBej5
/F6U+cj5rddpPL/BHOrwVSNWQDnL70vcC2pM6fsa0J7XqIF0Lu7vu+uCGGrU
gfKn2w5hs1etIctqlHVytcSZiE27I35vQzdSnAljKiLw+8E0jXOlEdENwin6
FuwPxlvcDtxExcrmvClXPP+dSnDVoEUbf79L2T2/CISsymxqbUNFx7Qi/RD2
S662qAYlunJd/kAqWwR+FOFY5qpRTT6Xc60Y97MrpGdWM8rW0+Qzh7AX3tkU
I21HLJeP/6XuwN4YU1/LrENhy01bfdb+AoKf5ML22wfZk70Rt7uwCWNlhLwS
1QnVWwoLsfu2zad6y5ChPMH1zUjsljfER9Ouw1V0oafIsgBETu/BnEwFzAWP
x/kLF4D/Qysz1b0HzifWXNi/A3dWktB7UQkukshPP0PzwLd2D54v/RVKhILt
FQzsdTPf0D7sh4rgJB1b9SfwdZFRvIwhWM/8Oq4iGFs6w5u7PwH1prKhQN49
IO5W0nX+Oig5oRDYtTbgL+3Km2rWw+pa117e31Ywbn/MiAsyggUkMypvKxC3
stPmvjJD/f71IzZvC5CHT08mLtkg0s3dYluaBbV88mzu5wsg6bcfe9hship6
1sC45xIkC/jxdSkmqAp/pYQ6uwKXfmrUUn8xwnPRb4016e/DxYmCdN8QA3Ce
sCUvm/8Bv5s+YgpnEshTbmG8Zx5DJxiuvb31DqhNt+PzXidIn8TkR5uPj0BY
x9Hxwy5UUm3KtRw4PgC5BdE/Vpc+RXJGNzdckSkg+cYXNX+waSTR3l5GcySg
cv+ieCbVjWwcIQwUjw7kEBcEemlo5H8iTdT9
      "]]}, 
    {RGBColor[0.6, 0.24, 0.4144770348081764], PointBox[CompressedData["
1:eJwVz2tMk1cYwPGXQpl4AT8YhrNM0AqCSo10bNx8GpVLA25owtgYMw1TJmWC
jgyccnmJtEOBlA7UsbCBtJNScOAEpBR6ymhLkYsUkYulBQuUIpei66azBnf2
4eTJL/+T5+R4J2ecPEMhCCIYn/+n/+3sG+pFKxDe9Nk2FwOKDbPvCV+wAll6
RzupmELpI3mtLXO4pxwqK0ieRLcCVZstM1ZgycV71FljaLTC5fQOA+5bVhSs
Qh2a1XOOb5zAbvMQfT4+gNzDb4vDR/G+krjQzLyHKI2ZUWwZxG7zauJ9NIya
OFnScS12VXnSWfsQUtQNlmt6sJNWubbsfkTnfnbkQCd2yoG7z+v7UXxUoLy8
BTtf+COTrUUBvfu2htfj93IYn+R+qEPJbJmdVo171Aa0KbUfkeNfD72uwP0x
75rnYh8688ZesukH7EdPmSFsFYrxLouhfY/vB1clHArsQ1EhjrsZabiHMTYX
+mpRB7o0dT8R2/RVQUCfBp29bOPbo7FVWmVkpwrJig9GyJjY7FTRiq4HMYwC
PWMn9ncjmhy+ChXK72XpqdjLKRe7Wb1o28NJypGlVSDmhjTvNyrRlXOqcsMA
9ilznXW5Dol+b31ZL8Xe7lrS2q1EtZfSOA2Fq0BuY1mvxXcjrsG5dToRd+nS
fV52C4pxSH3ruB/bkrCXe0OCDr74w8f91QoQF9NNNnUt4j5RMx91YbdXkXsV
EpAIlDvz8rA3xvP8PVrAWBZJ/TgIe/3F4JbYZvgN3fzzinkZCOFT2mm2HOZ9
Hx/2FGA7RHYl5/bA9ejamyf2LwP5dldKxvADcBAHXfgWLQFJbcxxmh8EvqDI
T3hsCQi7JFR0YQSEvuzxWMUzIDOpnmtRY+AWUXBY6Iv9xQdBGfoJaDSVDuzO
XwQiYkqa+6Ue+NmyIqvKAuQ6za2HPgO2V13H8/9ZAGJXNH00eBbMIJ5WuGL/
NUWPbZuHxhNuOourGciFkFsTvGcQ9M4Gs+X5HNQcbfq7P3QNxL3Wc6/vzQKh
dlVlXbVCXBF5VHLSBJzLfL/rHTao/LVZ5fhgBmq2H5uWvvcSfprISdrhb4QZ
zalievW/QLvrXk3hPAHy3cSGq5Pr0AnGhk99xqDGS0uYDQTLPTrujUemDs5L
fOrrvqGwlKbz5oRMLf7v1lW/fU4szojHHZFUBsOCn31+8XJmEe3tpc5rkShO
nh5WYaWymnWEkeLSgcoCYior55xY/wE5rNZI
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  Method->{},
  PlotRange->{{-0.1016999999999999, 0.9972866}, {-0.4537179201293071, 
   3.224981142477535}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.021979732, 0.021979732}, {0.07357398125213685, 
   0.07357398125213685}}]], "Output",
 CellChangeTimes->{3.5756278994910183`*^9, 3.5866610818827205`*^9, 
  3.5884149175434456`*^9, 3.5884165214091907`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wakes", "//", "Dimensions"}]], "Input",
 CellChangeTimes->{{3.4842007511656*^9, 3.4842007539126*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"19", ",", "57", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.5756278995060205`*^9, 3.5866610819567432`*^9, 
  3.588414917560432*^9, 3.5884165214261703`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Choose first profile", "Subsection",
 CellChangeTimes->{{3.4842023240226*^9, 3.4842023497816*^9}, {
  3.4842030329456*^9, 3.4842030378326*^9}, {3.4842188983026524`*^9, 
  3.4842189057380776`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.4842168542017365`*^9, 3.484216872362775*^9}, {
  3.4842169200805044`*^9, 3.4842169214815845`*^9}, {3.484217010376669*^9, 
  3.484217010519677*^9}, {3.484217050220948*^9, 3.484217058173403*^9}, {
  3.4842171504286795`*^9, 3.48421717053183*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Karman", "=", 
  RowBox[{"Karmans", "[", 
   RowBox[{"[", "n", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4842023582436*^9, 3.4842023638396*^9}}],

Cell[BoxData["1824.7`"], "Output",
 CellChangeTimes->{3.575627899538023*^9, 3.586661082057804*^9, 
  3.5884149175844536`*^9, 3.588416521454157*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rey", "=", 
  RowBox[{"Reys", "[", 
   RowBox[{"[", "n", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4842023751226*^9, 3.4842023820856*^9}}],

Cell[BoxData["74345.`"], "Output",
 CellChangeTimes->{3.5756278995620265`*^9, 3.58666108246375*^9, 
  3.5884149176034365`*^9, 3.588416521482172*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"wake", "=", 
   RowBox[{"wakes", "[", 
    RowBox[{"[", "n", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4842023882096*^9, 3.4842024018406*^9}, 
   3.4842027403476*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"w", "[", "\[Xi]_", "]"}], "=", 
   RowBox[{"CC", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["\[Xi]", "2"]}], ")"}], "2"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4841978527326*^9, 3.4841978599936*^9}, {
  3.4841980655956*^9, 3.4841980660906*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fit", "=", 
  RowBox[{"FindFit", "[", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"wake", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "0.88"}], "&"}]}], "]"}], ",", 
    " ", 
    RowBox[{"w", "[", "\[Xi]", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"CC", ",", "2"}], "}"}], "}"}], ",", "\[Xi]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4842026854286003`*^9, 3.4842027189035997`*^9}, {
  3.4842027945396*^9, 3.4842028104435997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"CC", "\[Rule]", "3.1973788137495145`"}], "}"}]], "Output",
 CellChangeTimes->{3.5756278995950313`*^9, 3.5866610826167927`*^9, 
  3.588414917632461*^9, 3.5884165215132046`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 31.7L", "Subsection",
 CellChangeTimes->{{3.5030316168816*^9, 3.5030316228476*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figa", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"wake", ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\[SmallCircle]\>\"", ",", "Tiny"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4842027840956*^9, 3.4842027853366003`*^9}, {
  3.4842028153375998`*^9, 3.4842028236896*^9}, {3.4842028814346*^9, 
  3.4842029068276*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzt0/tPk2cUB/CXErBuQTeDBTIMdoIEcFzUEYdZz4uMW6qmgMIiG+kcjQ4U
sa5MLpEyENmmFoIOcYxbKyJULGNcWi5vV1sLrNKLQRi1LatQ2qJ0uioM0O3x
v9gP/PDkySfnnCd5TvKlHj2VzCJhGMZG580dwE3ac9rqgOko8lRaqIKIp4wr
rbMOwBJML/JPDBJZwk/TmI8dgNvoX8ru9hA/e9R3VJuQUwaGimN+Ja5/t0tz
T+8A7v77E1iygDB2Rzm6H6L5jPYHJgmf2OTFjbPpkB/RFOe1PRARVLtYrUL9
hXQoSREB53AjpVSJ6l5+3491CUFScvNDtgz5GjXUZdNdsGd82zEpQc5uLvA/
PgxJVI/PoQvN/+3hvVegg1BlyDsf30J+n/yWumgEjiaKV3wbUP9sELN/bgy4
E8fGlq8gy1q+iDukA9bqysW3LyBHpx9i9f8OdGol3TcfzfdtMVCWNBAf5bot
LPvNPuIvemRoQEIUPOo94gDpKMeuVKnheKGzfCUB9ZvqNscuj4D4h/BY8W7k
q60+iYQCwow8fZgfep9z53K5fyeU9Xfl6d2QGdFunnl88FT/Qdo3vwCYnFH4
4s8mKD0przaokDPD/2n46DLwO7oXb7Uh193M9Od0QHNBNrO9DDm1qs7eVANZ
Bvdu0xFk/1xnqvlHoLt89a/rDuTwmT29rCIi/Pkv2ylLT9F/J4wtOXzImlLs
fjCI3JwfHXKqBVp5Ur9z55CDz39QWS8kjJVxbgcjkQf2thRM/gQ3iBpZqeUJ
cFVfbw5R/AazgeO0LbwngL2rPpueJ4erCc01STtQ3abtLAxQgYsg8jSbmAdp
juRg24IWynkVQVWfzAMuovUOabRQFZg4sX/IDviB4Ux2qh42xpbQqgLtgFGf
197nTIHQfEm1rdgGjfc4FyIIM5R/I65wyK3QuOrQN1FnwLk0eKD45RxgO6tp
O1PmwAIC09CGOZA+lRye97KBMGmj1rrBAlx2zNayaQdEriNbrM9mgLtvl2GW
9wwESsfJ5a7HUDl87AT1rBMYFdyY1mQz4JaBCKbfItTWi+Suo9No/7ELo7pl
uDZZ9Nl7wUYQ+dypy6l/Db6dlAYScwqkyrxXLCeGD4CxPXX7Q2AE91x/+ZqE
UxIYq95ntIBp0tPdG91wqTnXknZmGHITY8Y91etwps77Nr9NDGQfUYT2FRnH
+vouuf8VR5BjRmwy1XpcpMWMpPUSYquWaghYIeNreVzL41oe/z95/A8Q9Zg9

    "], {
     {GrayLevel[0], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 58], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 59], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 60], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 61], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 62], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 63], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 64], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 65], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 66], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 67], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 68], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 69], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 70], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 71], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 72], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 73], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 74], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 75], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 76], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 77], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 78], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 79], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 80], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 81], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 82], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 83], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 84], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 85], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 86], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 87], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 88], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 89], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 90], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 91], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 92], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 93], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 94], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 95], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 96], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 97], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 98], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 99], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 100], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 101], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 102], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 103], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 104], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 105], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 106], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 107], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 108], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 109], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 110], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 111], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 112], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 113], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 114]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  Method->{},
  PlotRange->{{-0.1016999999999999, 0.9971243}, {-0.1654767813310718, 
   3.224981142477535}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.021976486, 0.021976486}, {0.06780915847617214, 
   0.06780915847617214}}]], "Output",
 CellChangeTimes->{3.5756278996470375`*^9, 3.5866610830108213`*^9, 
  3.588414917683428*^9, 3.5884165215662127`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figb", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "[", "\[Xi]", "]"}], "/.", "fit"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Xi]", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4842028389686003`*^9, 3.4842028614276*^9}, {
  3.4842029132586*^9, 3.4842029194186*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1mk4lVsbB3BjPCoiDZQksyTh0MT/icqYk6FQQkjShJSSsSJCiBBOZCok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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1}, {0., 3.197378813749512}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5756278996740403`*^9, 3.586661083053835*^9, 
  3.5884149177134275`*^9, 3.5884165215942125`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"figa", ",", "figb", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3.3"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*FractionBox[\(r\), \(a\)]\)\>\"", ",", "w"}], 
      "}"}]}]}], "]"}], "//", "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<turbulence-pipewake\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4842028643115997`*^9, 3.4842028680726*^9}, {
   3.4842029443956003`*^9, 3.4842029778666*^9}, {3.484218669938591*^9, 
   3.4842186733557863`*^9}, {3.4842187117709837`*^9, 3.484218711923992*^9}, 
   3.4842189161686745`*^9, {3.501506372538184*^9, 3.501506373968266*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5756278998111277`*^9, 3.586661083196841*^9, 
  3.58841491785146*^9, 3.5884165217292333`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, GraphicsComplexBox[CompressedData["
1:eJzt0/tPk2cUB/CXErBuQTeDBTIMdoIEcFzUEYdZz4uMW6qmgMIiG+kcjQ4U
sa5MLpEyENmmFoIOcYxbKyJULGNcWi5vV1sLrNKLQRi1LatQ2qJ0uioM0O3x
v9gP/PDkySfnnCd5TvKlHj2VzCJhGMZG580dwE3ac9rqgOko8lRaqIKIp4wr
rbMOwBJML/JPDBJZwk/TmI8dgNvoX8ru9hA/e9R3VJuQUwaGimN+Ja5/t0tz
T+8A7v77E1iygDB2Rzm6H6L5jPYHJgmf2OTFjbPpkB/RFOe1PRARVLtYrUL9
hXQoSREB53AjpVSJ6l5+3491CUFScvNDtgz5GjXUZdNdsGd82zEpQc5uLvA/
PgxJVI/PoQvN/+3hvVegg1BlyDsf30J+n/yWumgEjiaKV3wbUP9sELN/bgy4
E8fGlq8gy1q+iDukA9bqysW3LyBHpx9i9f8OdGol3TcfzfdtMVCWNBAf5bot
LPvNPuIvemRoQEIUPOo94gDpKMeuVKnheKGzfCUB9ZvqNscuj4D4h/BY8W7k
q60+iYQCwow8fZgfep9z53K5fyeU9Xfl6d2QGdFunnl88FT/Qdo3vwCYnFH4
4s8mKD0przaokDPD/2n46DLwO7oXb7Uh193M9Od0QHNBNrO9DDm1qs7eVANZ
Bvdu0xFk/1xnqvlHoLt89a/rDuTwmT29rCIi/Pkv2ylLT9F/J4wtOXzImlLs
fjCI3JwfHXKqBVp5Ur9z55CDz39QWS8kjJVxbgcjkQf2thRM/gQ3iBpZqeUJ
cFVfbw5R/AazgeO0LbwngL2rPpueJ4erCc01STtQ3abtLAxQgYsg8jSbmAdp
juRg24IWynkVQVWfzAMuovUOabRQFZg4sX/IDviB4Ux2qh42xpbQqgLtgFGf
197nTIHQfEm1rdgGjfc4FyIIM5R/I65wyK3QuOrQN1FnwLk0eKD45RxgO6tp
O1PmwAIC09CGOZA+lRye97KBMGmj1rrBAlx2zNayaQdEriNbrM9mgLtvl2GW
9wwESsfJ5a7HUDl87AT1rBMYFdyY1mQz4JaBCKbfItTWi+Suo9No/7ELo7pl
uDZZ9Nl7wUYQ+dypy6l/Db6dlAYScwqkyrxXLCeGD4CxPXX7Q2AE91x/+ZqE
UxIYq95ntIBp0tPdG91wqTnXknZmGHITY8Y91etwps77Nr9NDGQfUYT2FRnH
+vouuf8VR5BjRmwy1XpcpMWMpPUSYquWaghYIeNreVzL41oe/z95/A8Q9Zg9

     "], {
      {GrayLevel[0], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 58], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 59], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 60], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 61], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 62], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 63], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 64], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 65], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 66], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 67], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 68], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 69], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 70], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 71], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 72], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 73], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 74], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 75], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 76], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 77], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 78], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 79], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 80], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 81], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 82], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 83], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 84], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 85], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 86], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 87], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 88], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 89], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 90], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 91], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 92], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 93], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 94], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 95], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 96], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 97], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 98], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 99], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 100], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 101], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 102], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 103], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 104], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 105], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 106], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 107], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 108], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 109], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 110], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 111], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 112], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 113], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 114]}, {}}], {}}, {{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV1mk4lVsbB3BjPCoiDZQksyTh0MT/icqYk6FQQkjShJSSsSJCiBBOZCok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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\\!\\(\\*FractionBox[\\(r\\), \\(a\\)]\\)\"", TraditionalForm], 
    FormBox["w", TraditionalForm]},
  AxesOrigin->{0., 0.},
  Method->{},
  PlotRange->{{0, 1}, {0, 3.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.021976486, 0.021976486}, {0.06780915847617214, 
   0.06780915847617214}}]], "Output",
 CellChangeTimes->{3.5756278998360615`*^9, 3.5866610832359056`*^9, 
  3.5884149178714895`*^9, 3.588416521754237*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 31.7R", "Subsection",
 CellChangeTimes->{{3.4842179489643536`*^9, 3.4842179557517414`*^9}, {
  3.5030316468026*^9, 3.5030316496476*^9}, {3.5030316806566*^9, 
  3.5030316832956*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sub", "=", 
   RowBox[{"sub", "\[Union]", "fit", "\[Union]", 
    RowBox[{"{", 
     RowBox[{"Ka", "\[Rule]", "Karman"}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4842036547665997`*^9, 3.4842036770656*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "\[Rule]", 
   RowBox[{
    RowBox[{"Ka", ">", "0"}], "&&", 
    RowBox[{"A", ">", "0"}], "&&", 
    RowBox[{"B", ">", "0"}], "&&", 
    RowBox[{"CC", ">", "0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4842031706026*^9, 3.4842031803146*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalLambda]", "=", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "1"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A", " ", 
       RowBox[{"Log", "[", 
        RowBox[{
         FractionBox["1", "2"], "Ka", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["s", "2"]}], ")"}]}], "]"}]}], "+", "B", "+", 
      RowBox[{"w", "[", "s", "]"}]}], ")"}], "2", "s", 
    RowBox[{"\[DifferentialD]", "s"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4842031114276*^9, 3.4842031289786*^9}, {
  3.4842035541646*^9, 3.4842035656656*^9}, {3.4842172340834646`*^9, 
  3.4842172353845387`*^9}}],

Cell[BoxData[
 RowBox[{"B", "+", 
  FractionBox["CC", "3"], "+", 
  RowBox[{"A", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Log", "[", 
      FractionBox["Ka", "2"], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5756279035765314`*^9, 3.586661086848343*^9, 
  3.5884149201277757`*^9, 3.5884165264818583`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalLambda]n", "=", 
  RowBox[{"\[CapitalLambda]", "/.", "sub"}]}]], "Input",
 CellChangeTimes->{{3.4842034439426003`*^9, 3.4842034925376*^9}, {
   3.4842035475776*^9, 3.4842035730776*^9}, 3.4842036834175997`*^9, {
   3.4842060382186003`*^9, 3.4842060389536*^9}, {3.4842177653988543`*^9, 
   3.484217773699329*^9}, {3.4842183628580265`*^9, 3.484218365043152*^9}}],

Cell[BoxData["20.399769079383134`"], "Output",
 CellChangeTimes->{3.575627903661582*^9, 3.586661087125374*^9, 
  3.588414920196786*^9, 3.588416529841296*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DD", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "A"}], 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", 
        RowBox[{"Log", "[", "2", "]"}]}]}], ")"}]}], "+", "B", "+", 
    RowBox[{
     FractionBox["1", "3"], "CC"}]}], "/.", "sub"}]}]], "Input",
 CellChangeTimes->{{3.4842178154457164`*^9, 3.4842178843126554`*^9}}],

Cell[BoxData["0.9602753020623629`"], "Output",
 CellChangeTimes->{3.575627903683544*^9, 3.5866610871523914`*^9, 
  3.588414920216755*^9, 3.5884165300753107`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"up", "=", 
   RowBox[{"ups", "[", 
    RowBox[{"[", "n", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Xi]", "=", 
   RowBox[{"\[Xi]s", "[", 
    RowBox[{"[", "n", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4842180528512955`*^9, 3.484218078050737*^9}, {
  3.4842182350307155`*^9, 3.484218236493799*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figc", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{"List", "[", 
      RowBox[{"\[Xi]", ",", 
       FractionBox["up", "\[CapitalLambda]n"]}], "]"}], "]"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\[SmallCircle]\>\"", ",", "Tiny"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4842180823889847`*^9, 3.4842181328688717`*^9}, {
  3.4842183391496706`*^9, 3.4842183733946295`*^9}, {3.4842184574624376`*^9, 
  3.4842184682460546`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzt0/8z23cAx/GIQ7fVl5plbvTMWaXU0bVoT29et1l8mRraYdN2Davrymwt
o6dzaClZTcNwqqp62Or7FdUljNBDul6ubRTViKRLyPd83ohiYbd1/8V+8MPr
nj+8fn64J393JIVOo9EyXu2/7iqIPXhOQ2Bh0z230f0IYYwpoWaBoJTzx1eD
dDFSOz5PYCsJblsK5UklE6i3vdlVKSegxhm5u6smcf3H/U/GZwk8Rd9sj7o6
DVlfEOmbJuDxO19COAPHtwtCtRMEB4+W0p+2SfC+V+1apYggLiZ++smYFFlx
txiFQoJB85TOFCJD/8XbARn3Cdy+jzhxSiWH7stLXTP9BMrAyTNE8QKx7rYn
0EuQGGAzfujBn/AV7nH4oJXgWEPUlbuZCiRH8DdcGwjesi7bbu+vRMGz04/M
VQRJdlO+9yRKpGxu/PRGCUH1eDM3J3Ueke7lka45BE5KI0tnu4CwIEsPvzSC
kZ6x3OrLC+gXXJD+lkhwN9LVOEdT4esfVoo3wgluPDfTsk6pwC/dy+L7Ewzp
E7TZIhX8ZNxZPzcChvvIz585qFE00Js9a0Ww8F6DtDhLDafHz+kf6Sk45W56
DUjVKEwfrZwTUai7dywoJliDpq6+tdY2CtzonrZrfA0aL6Sx24sovHOySj7k
qEXqnHWfPJGCJjnDa+m8FpEWZ/6x9KFgiJ7ckyfWYu9yjydj3Yje1g6fq2E6
pErG/J8OGkGxXpevdOrQwh12y8sz4qzb2qxZpYOsPNTq00AjJMOfvHRO0+MX
Qc39QpUBnpYu7374lx4LzKngnVwDHh9YD5KyDagOb6yJ9TFgdT4a1IwBFs2B
5zIEegS4ttimRBtRzOV4VXysR1YZZ/54pxEVzIhnh4d08K6MO7qbRcGedTG4
gqlDUhVPm1dHoUNRJvLI1+LNMbo//xBB8Xk+h4xqYLftpNHjV4KV9cGo/FU1
FB6J+3iOi1ChWT5kp8YOIiynwhfREWsv1tipoL7R7hFSv4hAm20qzdI8vHfW
MKMki2gWknRzrxJWt/6W7fNcQgynIKTliAI+IykroelLqL15Z9Ty4Qs0ujws
rBUs4dpM7nEXbxlOi77doXdYhms3o4HOlsB8OZ67/4tl/A5Ze7znNJpWBnqi
W5bBCI/ZdM4Uw11QfymEbsKw4qwqIfMB6qiiQOZhE9gTzp1NbXzQmrKjeNkm
0Hi8MuvFUMGBAN8cMdeEO2KajP5av6BkbDU/9tW/5XHL45bH/4/HfwGkAMGF

    "], {
     {GrayLevel[0], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 58], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 59], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 60], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 61], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 62], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 63], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 64], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 65], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 66], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 67], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 68], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 69], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 70], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 71], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 72], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 73], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 74], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 75], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 76], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 77], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 78], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 79], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 80], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 81], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 82], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 83], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 84], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 85], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 86], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 87], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 88], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 89], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 90], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 91], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 92], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 93], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 94], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 95], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 96], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 97], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 98], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 99], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 100], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 101], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 102], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 103], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 104], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 105], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 106], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 107], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 108], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 109], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 110], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 111], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 112], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 113], InsetBox[
       StyleBox["\<\"\[SmallCircle]\"\>",
        StripOnInput->False,
        FontSize->Tiny], 114]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  Method->{},
  PlotRange->{{-0.1016999999999999, 0.9971243}, {0, 2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.021976486, 0.021976486}, {0., 0.}}]], "Output",
 CellChangeTimes->{3.575627903738551*^9, 3.5866610872103696`*^9, 
  3.588414920270756*^9, 3.5884165328906198`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"vx", "[", "s_", "]"}], "=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"F", "[", "s", "]"}], "+", 
     RowBox[{"w", "[", "s", "]"}]}], "\[CapitalLambda]"], "/.", 
   "sub"}]}]], "Input",
 CellChangeTimes->{{3.4842181842288094`*^9, 3.484218271077777*^9}}],

Cell[BoxData[
 RowBox[{"0.04902016273363811`", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3.1973788137495145`", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["s", "2"]}], ")"}], "2"]}], "+", 
    RowBox[{"0.5231219920485457`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", "\[Pi]"}], "+", 
       RowBox[{"6", " ", 
        SqrtBox["3"], " ", 
        RowBox[{"ArcTan", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"193.78314`", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SuperscriptBox["s", "2"]}], ")"}]}]}], 
          SqrtBox["3"]], "]"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "+", 
          RowBox[{"96.89157`", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["s", "2"]}], ")"}]}]}], "]"}]}], "-", 
       RowBox[{"3", " ", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "-", 
          RowBox[{"96.89157`", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SuperscriptBox["s", "2"]}], ")"}]}], "+", 
          RowBox[{"9387.976337064902`", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SuperscriptBox["s", "2"]}], ")"}], "2"]}]}], "]"}]}]}], ")"}]}],
     "+", 
    RowBox[{"0.5925`", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", 
       RowBox[{"3.733261888717056`*^7", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["s", "2"]}], ")"}], "4"]}]}], "]"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.5756279037615542`*^9, 3.5866610872504053`*^9, 
  3.5884149202957993`*^9, 3.588416533045685*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figd", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vx", "[", "s", "]"}], ",", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["s", "2"]}], ")"}]}], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "Black", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Dotted"}], "}"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4842181410753417`*^9, 3.484218181490653*^9}, {
  3.484218254220813*^9, 3.484218286493659*^9}, {3.484218424434549*^9, 
  3.484218441577529*^9}, {3.484218622770893*^9, 3.4842186311423717`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k01VsbB3BJUcoUiZJrTJKkCA1fRcauMiXVNWVqMpRcQylC5lzXpaQy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     "]]}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwd1Ak41VkfB3BLoppXGFMvWZKtpNuq0lTfJpWyVLi2loshosZSSpE1VLI1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     "]]}, 
   {GrayLevel[0], Dashing[{0, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7ZX64uKBl6F2DGDwwX6BqH9bl2SLPYzfyLFZvVNy
CpwfEblw/YePS+B87v+NMe5y6+F81cB3Lw53b4Hzy89Z2s/4shPOF98ieI+R
cT+cv+2R85nzNofg/ENZc6Uj3xyB87+q2fKvzT0O5zP9XC0grXoKzjf7n7At
eN0ZOP9Mi8m5Y1rn4Xz5Ca9/rnx3Ac5//f3+vasGl+D8Ja92n+Lruwzn88ku
f//kyRU4vydza9oClWtw/jeH1U8y6q/D+SVGR7aIHb4B599fd6T7ouItOP93
1pXZmlW34XxtR/Z/abvvwPnuixTTN4rfQ4SXbLzSw5j7cL7Om1Du674P4Hxh
/g8cR34h+Cz7Z69XnvMQzs822X2T0/sRnL/aM2nBvm8I/tfXUgLPpj2G87cG
uzNPcXkC59d7tM7f8gzBV7zrdWNx61M438q8ZYqk0TM4P0bu/E/Gywj+11O9
jwoan8P5M1jiSoJUXiDcf2/rIqYjCD5rbWOIZeFLOJ9hZdz6R0Kv4PyiWet7
hQ4h+Hu1OzgE817D+YJeRTpNfG/g/Du6Fy5X7kHwN8yzV3kS9xbOj11vJij7
D8FvaF3YeGfVOzh/7QvZ2Xw+7+F8pRYRD/ZlCP50ee6v//8j+ACgshGH
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{0, 1}, {0., 1.9999999999999991`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5756279038065605`*^9, 3.5866610873014135`*^9, 
  3.588414920338761*^9, 3.588416533136682*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"figc", ",", "figd", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.05"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*FractionBox[\(r\), \(a\)]\)\>\"", ",", 
       RowBox[{"HoldForm", "[", 
        RowBox[{
         SubscriptBox["v", "x"], "\"\</\>\"", "U"}], "]"}]}], "}"}]}]}], 
   "]"}], "//", "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", 
   RowBox[{"\"\<turbulence-pipeprofile\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4842182904668865`*^9, 3.484218309710987*^9}, {
  3.4842183940718117`*^9, 3.484218396059926*^9}, {3.4842185207460575`*^9, 
  3.484218603361783*^9}, {3.4842187376974664`*^9, 3.48421874475387*^9}, {
  3.484218926148245*^9, 3.484218926326255*^9}, {3.501506390178193*^9, 
  3.5015064072971725`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5756279039385767`*^9, 3.586661087450423*^9, 
  3.5884149204738245`*^9, 3.588416534640888*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, GraphicsComplexBox[CompressedData["
1:eJzt0/8z23cAx/GIQ7fVl5plbvTMWaXU0bVoT29et1l8mRraYdN2Davrymwt
o6dzaClZTcNwqqp62Or7FdUljNBDul6ubRTViKRLyPd83ohiYbd1/8V+8MPr
nj+8fn64J393JIVOo9EyXu2/7iqIPXhOQ2Bh0z230f0IYYwpoWaBoJTzx1eD
dDFSOz5PYCsJblsK5UklE6i3vdlVKSegxhm5u6smcf3H/U/GZwk8Rd9sj7o6
DVlfEOmbJuDxO19COAPHtwtCtRMEB4+W0p+2SfC+V+1apYggLiZ++smYFFlx
txiFQoJB85TOFCJD/8XbARn3Cdy+jzhxSiWH7stLXTP9BMrAyTNE8QKx7rYn
0EuQGGAzfujBn/AV7nH4oJXgWEPUlbuZCiRH8DdcGwjesi7bbu+vRMGz04/M
VQRJdlO+9yRKpGxu/PRGCUH1eDM3J3Ueke7lka45BE5KI0tnu4CwIEsPvzSC
kZ6x3OrLC+gXXJD+lkhwN9LVOEdT4esfVoo3wgluPDfTsk6pwC/dy+L7Ewzp
E7TZIhX8ZNxZPzcChvvIz585qFE00Js9a0Ww8F6DtDhLDafHz+kf6Sk45W56
DUjVKEwfrZwTUai7dywoJliDpq6+tdY2CtzonrZrfA0aL6Sx24sovHOySj7k
qEXqnHWfPJGCJjnDa+m8FpEWZ/6x9KFgiJ7ckyfWYu9yjydj3Yje1g6fq2E6
pErG/J8OGkGxXpevdOrQwh12y8sz4qzb2qxZpYOsPNTq00AjJMOfvHRO0+MX
Qc39QpUBnpYu7374lx4LzKngnVwDHh9YD5KyDagOb6yJ9TFgdT4a1IwBFs2B
5zIEegS4ttimRBtRzOV4VXysR1YZZ/54pxEVzIhnh4d08K6MO7qbRcGedTG4
gqlDUhVPm1dHoUNRJvLI1+LNMbo//xBB8Xk+h4xqYLftpNHjV4KV9cGo/FU1
FB6J+3iOi1ChWT5kp8YOIiynwhfREWsv1tipoL7R7hFSv4hAm20qzdI8vHfW
MKMki2gWknRzrxJWt/6W7fNcQgynIKTliAI+IykroelLqL15Z9Ty4Qs0ujws
rBUs4dpM7nEXbxlOi77doXdYhms3o4HOlsB8OZ67/4tl/A5Ze7znNJpWBnqi
W5bBCI/ZdM4Uw11QfymEbsKw4qwqIfMB6qiiQOZhE9gTzp1NbXzQmrKjeNkm
0Hi8MuvFUMGBAN8cMdeEO2KajP5av6BkbDU/9tW/5XHL45bH/4/HfwGkAMGF

     "], {
      {GrayLevel[0], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 58], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 59], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 60], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 61], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 62], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 63], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 64], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 65], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 66], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 67], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 68], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 69], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 70], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 71], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 72], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 73], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 74], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 75], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 76], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 77], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 78], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 79], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 80], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 81], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 82], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 83], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 84], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 85], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 86], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 87], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 88], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 89], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 90], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 91], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 92], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 93], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 94], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 95], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 96], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 97], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 98], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 99], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 100], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 101], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 102], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 103], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 104], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 105], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 106], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 107], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 108], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 109], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 110], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 111], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 112], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 113], InsetBox[
        StyleBox["\<\"\[SmallCircle]\"\>",
         StripOnInput->False,
         FontSize->Tiny], 114]}, {}}], {}}, {{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k01VsbB3BJUcoUiZJrTJKkCA1fRcauMiXVNWVqMpRcQylC5lzXpaQy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      "]]}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwd1Ak41VkfB3BLoppXGFMvWZKtpNuq0lTfJpWyVLi2loshosZSSpE1VLI1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      "]]}, 
    {GrayLevel[0], Dashing[{0, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ7ZX64uKBl6F2DGDwwX6BqH9bl2SLPYzfyLFZvVNy
CpwfEblw/YePS+B87v+NMe5y6+F81cB3Lw53b4Hzy89Z2s/4shPOF98ieI+R
cT+cv+2R85nzNofg/ENZc6Uj3xyB87+q2fKvzT0O5zP9XC0grXoKzjf7n7At
eN0ZOP9Mi8m5Y1rn4Xz5Ca9/rnx3Ac5//f3+vasGl+D8Ja92n+Lruwzn88ku
f//kyRU4vydza9oClWtw/jeH1U8y6q/D+SVGR7aIHb4B599fd6T7ouItOP93
1pXZmlW34XxtR/Z/abvvwPnuixTTN4rfQ4SXbLzSw5j7cL7Om1Du674P4Hxh
/g8cR34h+Cz7Z69XnvMQzs822X2T0/sRnL/aM2nBvm8I/tfXUgLPpj2G87cG
uzNPcXkC59d7tM7f8gzBV7zrdWNx61M438q8ZYqk0TM4P0bu/E/Gywj+11O9
jwoan8P5M1jiSoJUXiDcf2/rIqYjCD5rbWOIZeFLOJ9hZdz6R0Kv4PyiWet7
hQ4h+Hu1OzgE817D+YJeRTpNfG/g/Du6Fy5X7kHwN8yzV3kS9xbOj11vJij7
D8FvaF3YeGfVOzh/7QvZ2Xw+7+F8pRYRD/ZlCP50ee6v//8j+ACgshGH
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\\!\\(\\*FractionBox[\\(r\\), \\(a\\)]\\)\"", TraditionalForm], 
    FormBox[
     TagBox[
      RowBox[{
        SubscriptBox["v", "x"], " ", "\"/\"", " ", "U"}], HoldForm], 
     TraditionalForm]},
  AxesOrigin->{0., 0},
  Method->{},
  PlotRange->{{0, 1}, {0, 2.05}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.021976486, 0.021976486}, {0., 0.}}]], "Output",
 CellChangeTimes->{3.5756279039665794`*^9, 3.5866610874913807`*^9, 
  3.5884149204937983`*^9, 3.5884165346458387`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Figure 31.8 Friction coefficient for smooth pipe flow \
\>", "Section",
 CellChangeTimes->{
  3.482831746038*^9, {3.4828950317967997`*^9, 3.4828950336198*^9}, 
   3.4829006097858*^9, {3.58841664087354*^9, 3.58841665188877*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CleanGlobal", "[", "]"}]], "Input",
 CellChangeTimes->{{3.3902253066607857`*^9, 3.3902253098437862`*^9}, 
   3.482831746039*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"CleanGlobal", "::", "removed"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(50\\)\[NoBreak] symbols\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.5756279041536036`*^9, 3.5866610876594105`*^9, 
  3.5884149206748075`*^9, 3.5884166310481014`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get Oregon and Princeton data on Darcy's friction factor", "Subsection",
 CellChangeTimes->{{3.4827555116116*^9, 3.4827555182346*^9}, {
   3.4827584005076*^9, 3.4827584104116*^9}, 3.482831746039*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"oregon", "=", 
   RowBox[{"Get", "[", "\"\<data/turbulence.oregon.m\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"princeton", "=", 
   RowBox[{"Get", "[", "\"\<data/turbulence.princeton.m\>\"", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4827540621576*^9, 3.4827541600956*^9}, {
   3.4827542167846003`*^9, 3.4827542372346*^9}, {3.4827544039856*^9, 
   3.4827544047036*^9}, {3.4827545130566*^9, 3.4827545329576*^9}, 
   3.48283174605*^9, {3.4830778064250836`*^9, 3.483077824929142*^9}, {
   3.505369601761031*^9, 3.5053696112815757`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xticks", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox["10", "n"], ",", 
       SuperscriptBox["\"\<10\>\"", "n"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "8"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.482831648712*^9, {3.482831690637*^9, 3.482831691771*^9}, 
   3.4828317460550003`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figa", "=", 
  RowBox[{"ListLogLogPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"oregon", ",", "princeton"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
    RowBox[{"Prolog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Dotted", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"8", ",", 
            RowBox[{"-", "7"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[EmptyCircle]", ",", "Tiny"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[EmptyUpTriangle]", ",", "Tiny"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Re\>\"", ",", "\"\<\!\(\*SubscriptBox[\(C\), \(f\)]\)\>\""}], 
      "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"5", ",", 
         RowBox[{"1", " ", 
          SuperscriptBox["10", "8"]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001", ",", "2"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"5", ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]]}], "}"}]}], ",", 
    RowBox[{"Ticks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"xticks", ",", "Automatic"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4827569237226*^9, 3.4827569396626*^9}, {
   3.4827569832816*^9, 3.4827570777976*^9}, {3.4827571079906*^9, 
   3.4827571217986*^9}, {3.4827572015266*^9, 3.4827572290336*^9}, {
   3.4827572810615997`*^9, 3.4827573390126*^9}, {3.4827573922785997`*^9, 
   3.4827573929816*^9}, {3.4827585901516*^9, 3.4827586089026003`*^9}, {
   3.4827586429835997`*^9, 3.4827586478406*^9}, {3.4827588796076*^9, 
   3.4827588999105997`*^9}, {3.4827589307276*^9, 3.4827589445495996`*^9}, {
   3.4827595765036*^9, 3.4827595882776003`*^9}, {3.4827602412995996`*^9, 
   3.4827602462876*^9}, {3.482829808446*^9, 3.482829815151*^9}, {
   3.482830830863*^9, 3.482831015809*^9}, {3.4828317378269997`*^9, 
   3.482831746059*^9}, {3.482831966278*^9, 3.48283197559*^9}, {
   3.482832022917*^9, 3.482832114165*^9}, {3.4828321454*^9, 
   3.482832164149*^9}, {3.4828322555810003`*^9, 3.4828322558190002`*^9}, 
   3.4842193060709753`*^9}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJzt1Ns71AkYB3CZhmHE+M3ZaUYxDTNiQqNW5m1LepaliLRRDrETmkyHFeXZ
TQ+rI6PpqEaSEorKoVQ7b2eqSVLMqkQ5FJWlNqUetr3af2AvXbzP9+a9+H5v
PvYxa4LjDA0MDEq/3b/5fpkwQxNKgmrBi1/jGh/JJi9f6lQ6iQIr5mUlbI+5
qo19bZrfQ6ICoWjvrwjs1Gaobhwa5pnDpgTfK/4977Q3BZSDtjNpkHf/Q0LF
0ffa11csZg2U0cAnLvPe9fiP2rqQZfX6JkvITpOLF1uNaI3JPrE5/QQ8z+q1
mC0Y05Kzl8jmF9JhiOP24tWAATp7jBm1eTMg07NqlYpmiPvSJZ6iawxwkgUc
SnQgoZdTuP+lRUxYf2hiv6PtRHwsTIo+UcuEkDET3VETMh58SbAkchYo780s
7I4zwmn7BHcWkNhwcIpybtcpYwwgC495Z7Oh08HzZU0JBeW/p4tKRtnQYX6g
RpdqgovPVzNCkjkgVLVktMWbor9l+9dHFC6IomRWJteo+CG8nuyeyoUZBVxx
Q44Z1vfW2bubWkHtoOeXrj2TcL5WZ9xbYQUNyX5+SY3mWKlJCosQWUPdgLpx
jtoC766+kXHjjDVYBJHKFD/R8Kyyu798qQ3M9j6xxbWThj7WgU3uZ2ygpYPo
tJ9viUeqBw9qh2xgYu1QoO60JZYkqKUWZ2xh64git4JPYG64LEK20g5WSn/1
uFNJII/Cz1/12A5SXNY8z6fR8X3NwytV0TxYZK+OOrOOjvoBO4VSz4M7Q5qq
lFY6xuVVip918cDs2tfpn0LpSGt26Rt8w4OndgVnu/cQ2HTb2Zc6zIMoXk7q
Ils6mp7K1F2YwIfe7ckVigACN7h3b9Qa8mGm+par4gOB4dI2gReVD5opDb94
7CSwsHotcZnGh40XvSKkjgR+Zq5doZzGh2d/ps7zFBF48nlJ2dc9fNDd/l7z
OYlAEu2jW8EwHzrdKQbGhQQ+Vippx2PsIS3TQfLHIwJf+Wt2VZMmw/6wlG2k
b33MQ5dJm/ZPBn1K5Nvy9XQsD22OnECdArqFIa8GztOR3CjXTaqaAu+SGn87
bMLANx2Kmgi1AyTbF825uZmBlxSDHj7ejiCx27wt0oiJvKvTeVEjjhByWG2d
JmFiaF9ox99nBXDhHkmVdYiJ1d59CcOxU2HYo2F2ZMe3/4j4EXOhEB6c5l55
yGXhZ/L95LdXhdDIOfdUvZCFs4o/lRvNcIJpPTYNYWtZqGHvDlLZOMPKF1Jp
0QUWln+pFXipnEEfE6SXd7DQbNLu9p0+IohsDbOoZLNRPnS/ILNOBK+zgsDX
h40e6QUMyyoHmP4Xc/ecLAZ+6TDAvXMdYfUs5dYN9QzsAlNrSqcj9HHqvGoI
Jm4MXZ7nkySAokRlYnoYE3ceF30oGxVAi3E7tKuZGN8rGv10aypQXc3T975h
Ym9gsYHpnP/23NrRzHCpFEKqt0v6+nksfPj8yI5Vfk4wRukTmK5jYXPwtu9K
W5xgMK9w86ZSFkbnu1z/GOsMM3wDHzxrZeG53JeNF81FoOq+s01NZ6PRSgdx
xWkR+KOvj9ifjQtO8jsEXmKQPtOPuKeyMWyq7FP/XTFke1HWxp9i49ybcuPk
JS5QfOPj4i9tbKSqL9X+2OMCkj006j5DDmb/sOFA1uFpIMuikrM9OegY608U
yVwh0LA1WhXPwXkPou2T6lwhoWBhe3AOB0efBvmZCdzAFY5pZJc5iGF6z3UK
NyAn9v0c3M7BaMThgQtukPu+iNxtxMUtAefnXh5zg+27xFH7RVykCj9TrnpJ
QN7p0Vbsx8W8epuxJzESSOt7ePlJOBfHPR33dNzTcU/HPf1/PP0HS+/BWg==

    "], {
     {GrayLevel[0], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 86], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 87], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 88], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 89], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 90], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 91], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 92], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 93], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 94], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 95], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 96], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 97], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 98], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 99], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 100], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 101], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 102], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 103], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 104], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 105], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 106], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 107], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 108], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 109], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 110], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 111], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 112], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 113], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 114], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 115], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 116], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 117], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 118], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 119], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 120], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 121], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 122], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 123], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 124], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 125], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 126], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 127], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 128], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 129], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 130], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 131], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 132], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 133], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 134], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 135], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 136], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 137], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 138], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 139], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 140], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 141], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 142], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 143], InsetBox[
       StyleBox["\[EmptyCircle]",
        StripOnInput->False,
        FontSize->Tiny], 144]}, 
     {GrayLevel[0], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 145], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 146], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 147], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 148], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 149], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 150], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 151], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 152], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 153], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 154], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 155], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 156], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 157], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 158], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 159], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 160], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 161], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 162], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 163], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 164], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 165], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 166], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 167], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 168], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 169], InsetBox[
       StyleBox["\[EmptyUpTriangle]",
        StripOnInput->False,
        FontSize->Tiny], 170]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Re\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(C\\), \\(f\\)]\\)\"", TraditionalForm]},
  AxesOrigin->NCache[{
     Log[5], -Log[1000]}, {1.6094379124341003`, -6.907755278982137}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-6.907755278982137, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-5.298317366548036, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.605170185988092, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0., 
       FormBox[
        TagBox[
         InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {-2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{1.6094379124341003`, 18.420680743952367`}, {-6.907755278982137,
    0.6931471805599453}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Prolog->{
    Dashing[{0, Small}], 
    LineBox[{{8, -7}, {8, 0}}]},
  Ticks->{{{2.302585092994046, 
      FormBox["\"10\"", TraditionalForm]}, {4.605170185988092, 
      FormBox[
       SuperscriptBox["\"10\"", "2"], TraditionalForm]}, {6.907755278982137, 
      FormBox[
       SuperscriptBox["\"10\"", "3"], TraditionalForm]}, {9.210340371976184, 
      FormBox[
       SuperscriptBox["\"10\"", "4"], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       SuperscriptBox["\"10\"", "5"], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       SuperscriptBox["\"10\"", "6"], TraditionalForm]}, {16.11809565095832, 
      FormBox[
       SuperscriptBox["\"10\"", "7"], TraditionalForm]}, {18.420680743952367`, 
      FormBox[
       SuperscriptBox["\"10\"", "8"], 
       TraditionalForm]}}, {{-6.907755278982137, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-5.298317366548036, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.605170185988092, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0., 
      FormBox[
       TagBox[
        InterpretationBox["\"1.000\"", 1., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"5.000\"", 5., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.6592600369327783`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659907, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782628`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.5756279043096232`*^9, 3.5866610878054433`*^9, 
  3.5884149208488855`*^9, 3.5884166312251434`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make fit", "Subsection",
 CellChangeTimes->{{3.4828976221498003`*^9, 3.4828976249158*^9}, {
  3.4829006492848*^9, 3.4829006519868*^9}, {3.5030318032326*^9, 
  3.5030318061766*^9}, {3.5884166972184863`*^9, 3.5884166985446897`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sub", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "\[Rule]", "2.37"}], ",", 
     RowBox[{"B", "\[Rule]", "5.55"}], ",", 
     RowBox[{"\[Gamma]", "\[Rule]", "0.1062"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", 
      RowBox[{"1.277", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}], ",", 
     RowBox[{"CC", "\[Rule]", "3.197"}], ",", 
     RowBox[{"DD", "->", "0.9151"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4842194698453426`*^9, 3.484219470951406*^9}, {
  3.484219513257826*^9, 3.484219572130193*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalLambda]", "[", 
   RowBox[{"R_", "?", "NumericQ"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "\[CapitalLambda]", "}"}], ",", 
    RowBox[{"\[CapitalLambda]", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A", " ", 
             RowBox[{"Log", "[", 
              FractionBox["R", "\[CapitalLambda]"], "]"}]}], "+", "DD"}], 
           ")"}], "/.", "sub"}], ")"}], "\[Equal]", "\[CapitalLambda]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[CapitalLambda]", ",", "1"}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4842195814737277`*^9, 3.484219674672058*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalLambda]", "[", "3000", "]"}]], "Input",
 CellChangeTimes->{{3.484219678337268*^9, 3.4842196927560925`*^9}}],

Cell[BoxData["13.688886368819764`"], "Output",
 CellChangeTimes->{3.575627904351631*^9, 3.586661087857465*^9, 
  3.5884149208948507`*^9, 3.5884166312791495`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figb", "=", 
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    FractionBox["2", 
     SuperscriptBox[
      RowBox[{"\[CapitalLambda]", "[", "R", "]"}], "2"]], ",", 
    RowBox[{"{", 
     RowBox[{"R", ",", "100", ",", 
      SuperscriptBox["10", "9"]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4828980817167997`*^9, 3.4828981656057997`*^9}, {
  3.4828982141538*^9, 3.4828982150137997`*^9}, {3.4828988784258003`*^9, 
  3.4828988853528*^9}, {3.4842197028896723`*^9, 3.484219730417247*^9}, {
  3.484219774909792*^9, 3.484219776652891*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwVz2s01AkYBnCpxGjSzBgz8w+DchnM5PLXUktvyO7aFQkpW26RTKjEpghd
OK3UzKxLp6iWtREzk5RWBi+dDmVbJ0Ka3ZImDdpltNpoaWc/vOc5v/N8eM5r
GZMSHKero6MToL3/83ZW1+N6IR0S9X2W2s8Y4PpjsTfbD9DBtyKF4zJngHhk
QfI4jQ61jSnz7p8M8GEqGaLJpkNU/oN1PgYUHN53dcCpiA6qbM2xr8woSAk7
opQr6JAV137HbDMFowR2r6VUBsjGl9mqf9D2L/I/1MgZEH5Uv8lMYIjB327w
GVnBBJzIcxpLWo6d5YT7kzATiOt28XybT8VFJozQ7RdY4DdJi/c+twIF1z8V
EzNsiJg1DY0tM8Izuuzc0vUEJJ1IMDT0W4mD6WtEIZdWgZKeqNfavhLHLf07
K2ZMIUal7jzoRkMH8aXq6+7mcK4nzPtaGQ13m76UTpdwwZRfd7R3GR1fuNUI
5pIt4LeT8XMte+k4fST5oo+RJUhrlZOCDjouPOCz+S2WEKu6rBJbMNByXleY
GmkF8fKCsF1pDPT06u3ZYbQaKGtPP59+xEAFIevSV6yGqjT+1XuWxhg8dKXE
eNca8IsVlXyTZIwvqwrS0dAapE893ucrjDE/pNDhgcwa3D82vCGWMNGGdmb6
YKQNDKRwn7kHMtFunzjg1XJbsFcfKqwqYeKmSnlWvcwWJMO0h1sHmbhtorON
u9sOuKPD1sJVJpjJfD8wvogHzq+t9MkdJqivdDpxvIIHNE3G5/wiEyyUxW28
GWQPdYHx0Yd7TZC358Zj73f2ML2neYFqyMJW25m01EoHMHI5m9jnx8LGPD/Z
/iBHkG+vqZ3PZuH9Tmlzh8YRdqapvl56i4WPTIyUv1zlg/mo52ZigoVvv8jr
MfQVgO4hV52tZmxMNqaE26oEoLHRo6cHsHHsr/zpEfFaoOqWJxTksLGln1o/
z3GCWdPAUZ6cjYubn2iGDjoBvc7qbtkwG0PFNuWqe04Q9Sx36BGVg+G3j0u2
GTtDZxT2e3hoPdwnkgidoT08ozVyLwdj/22Y/aRwhtDguaZiMQeFXLHQk+kC
XZX1vKRWDq4RHbZ9IXQBZWlbl2SMg2rNSIBc4QJNiWQQjUZgzc4tWYHGrjAk
Wb6Ss4HA9Fu+LPN4V+gYnPO6HE3g3xGbPgY1usKFDz9N3c0jMJmyQb2NSoKE
5x7tL9P2NW0bT+8m4cJE27iol0CrL797OBlJgnWuU55zH4FbRwWhO6NJUNgp
mL1ay6wuJ67dQ0L4KQcao5/AhEuZxUP7SPB3u5hRNEig8qzHBD+NhGIRSS/+
ncCOlIaSgQISlui5JheOEjhFFVpuKiRBZ2yLyPENgdw6q7racyQkjDT/3K11
plrcniMmYVf7+RsGYwSuiz7w1r6UhPt3A9xPT2j/DeZ7Z1eQIOgp5hydIvDp
lOrXsUoSWI7f57I1BOqdL9seUkVCPzH+R6PWMd2GSbxqEq7Au9R30wSa+o6X
9klJ6CgPZ+6fIdB/5EcrLzkJ5pmDFpT3BGbk7JBW3yBhsUGPRbXWA4qujqwG
ErwaBQuv/iFwSUROgPoWCbWci8rcDwS6zn72NLiRhO76U1LurHavdDKm5Q4J
Qdyp1BatRW7X/rRtIqFI97kgYo7A/wDFKzgt
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->NCache[{
     Log[100], -6.744488460827274}, {4.605170185988092, -6.744488460827274}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-6.907755278982137, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-6.214608098422191, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.002\"", 0.002, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-5.298317366548036, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.605170185988092, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-3.912023005428146, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.020\"", 0.02, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.200\"", 0.2, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.2039728043259361`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {-2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.2039728043259361`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{4.605170185988092, 
       FormBox["100", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {7.090076835776092, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.7406644019172415`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.131530710604252, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.411832675758411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.630521876723241, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.809862805379057, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.961879012677683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.093806555720231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.695247021764184`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.345834587905333`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.736700896592344`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.017002861746503`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.235692062711331`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.415032991367148`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.567049198665774`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.698976741708323`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.300417207752275`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.951004773893423`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.341871082580436`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.622173047734595`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.840862248699423`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.02020317735524, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.172219384653864`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.304146927696415`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {18.420680743952367`, 
       FormBox["\"\"", TraditionalForm]}, {7.090076835776092, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.7406644019172415`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.131530710604252, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.411832675758411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.630521876723241, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.809862805379057, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.961879012677683, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.093806555720231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.695247021764184`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.345834587905333`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.736700896592344`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.017002861746503`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.235692062711331`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.415032991367148`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.567049198665774`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.698976741708323`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.300417207752275`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.951004773893423`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.341871082580436`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.622173047734595`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {17.840862248699423`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.02020317735524, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.172219384653864`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {18.304146927696415`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->NCache[{{
      Log[100], 
      Log[1000000000]}, {-6.744488460827274, -3.2447090540963943`}}, {{
    4.605170185988092, 
    20.72326583694641}, {-6.744488460827274, -3.2447090540963943`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {18.420680743952367`, 
      FormBox[
       TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {7.090076835776092, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.7406644019172415`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.131530710604252, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.411832675758411, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.630521876723241, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.809862805379057, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.961879012677683, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.093806555720231, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.695247021764184`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.345834587905333`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.736700896592344`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.017002861746503`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.235692062711331`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.415032991367148`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.567049198665774`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.698976741708323`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.300417207752275`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.951004773893423`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {17.341871082580436`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {17.622173047734595`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {17.840862248699423`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {18.02020317735524, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {18.172219384653864`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {18.304146927696415`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-6.907755278982137, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.214608098422191, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.002\"", 0.002, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-5.298317366548036, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.605170185988092, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-3.912023005428146, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.020\"", 0.02, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.200\"", 0.2, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.6592600369327783`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.2039728043259361`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.575627904470643*^9, 3.5866610880324883`*^9, 
  3.588414921016887*^9, 3.5884166314021626`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figc", "=", 
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    RowBox[{"0.079", " ", 
     SuperscriptBox["R", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "4"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"R", ",", 
      SuperscriptBox["10", "2"], ",", 
      SuperscriptBox["10", "7"]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4828304585810003`*^9, 3.4828305187469997`*^9}, 
   3.482831746105*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVxXs0VAkcAGAcRM2Yced153rFMIMxcy/r2VZ+NBSnSVF5pK1Iz5VHqaXI
FutZrLRaqSYtG509m5TC0u+UtjKFyJ7DnKStjUpbjRIns+3uH9/5HBNSIpNM
jIyM1P/5/77HmdqmnQQsKc02U+ex8Xnl+M6IFALuP788aPMdG2fDolmv0wmI
CZqoe1nARtfL3mrXLAJ2TcWFFpawMbfwTc/pQgKqN/oX3Kxgo6dnUn9JHQGT
3pMWC86yseLQyqGkxwT89GgbS9bJxjUusjFxFA/M6NU842k29ue8/Tit5kOX
7trJ1AwrvDpVxvf3F0BLlYV7+UsrfDJiOzpiJwTtvN6yxPUcNNbd0swKRaAr
kqTqhzhY8kGVnPVZBOUlnhdIGRdZzqPKlE8kMNEndIItXOy9se2MVi+GJzlt
HyfOcdFw8LZN4RAFHsp+Yc0jLjqtCj7SPmADe/9kJl1trfEiHJsb0WELsfb5
/UfWWuO3mge+4bV2oG6pPHWvzBrD+R4xv1XbA0S9cnlx3xoP1MfnHz3kAPf2
+TU9mkNgZP3DgVeL58Pas90zv4YSWNiUtlDVNh/eScXK+DwCJ7UzjcsVjiDz
Xp802kFg7FtOJbfREeJCx2ODZwl8L7E+nGfvBLLRbasO+PKweJNmornGCfQ5
jHllBg+Do+sVVaQEejKb6/ObeUjHV+1xL5VAyKw8POI1D0U7hb6Zls7QevhV
45Scj95FuYZ9Oc5wu0JjtXcLH3dv2FTj/s4Zxgzcr3rP8PGXwL4rJ5JdwHTX
nR3mI3y0pd0HW564QHtSRpaAFGCBK5FSvkEKaQnbl5pEC5A3nDpqp5OCXztp
dLdSgA+r26LXrZBB1cmO9q09Avw+qSJstVYGU7kN3s9YQjwcuCbIEOgKb14X
X/RfKsQfHhzlxl1yhekWGbk1V4h1yWvj0pVuYJQ/b9HuTiG+IC0bF9S6Qe3w
s83R00J07Qnb0+ngDkE+ZuFiPxHWVGSo9JXusF9k49WcJkIvDjkxNEcOv6+Z
MJNdEOHN48ussvPkwPnRtOqbFyIskm/27ZuWgz6RkNdKSAzXsodG9npA/xdb
DzQkkKiQKKPO6j2ga8O+1mINiSHFAQO8LQpYycueWTJMYsyn/vtBTxUwpL07
NUyKUbM/uschRgmGeayPYVFinHs5sr6pWwle5y2fVpSKMWVKN/1PKA1JYStK
W7vFaLls5arZNhq80gv9r5lSKN3NXmjSQQPOGVO0m1GoOt0ttbhOQ8SpEEmn
OYW571WzvJs0JN8xseqyoHBaE/CzXEtDg332014WheMzToY4HQ2O2rSjY3wK
71z4cL71Ew3WzuueCV0ofP7HpWPXDTRoWluHxFIKTU1Sc259poGOIHttZRTO
9/jQMG7MgDprsNXJjcL4QykH35sxUNQXUaZUUPhQudmdZcWAcbZqQagPhYld
Nxw4HAbKiXN0mC+F+lhHAcFlwOG8sctyPwq5+SOfRQQDiwY6OZEBFC7XxQxK
hAxkugX8tX4RhbrUq91SEQMW16uGNy6mcIe5EN1IBqpWT/UmBlJY6DnQSFMM
XDnY3LY9iELRbU+Nlw0DKgFx8etgCuvjy4/72DIw0Jhal7KEQh/938X+dgwk
QG91uorCrgJ17pf2DLwbVJRnhFD4Lz90G+4=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->NCache[{
     Log[100], -6.567831280515279}, {4.605170185988092, -6.567831280515279}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-6.907755278982137, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0010\"", 0.001, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0100\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-5.298317366548036, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0050\"", 0.005, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0500\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-6.214608098422191, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0020\"", 0.002, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-3.912023005428146, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0200\"", 0.02, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-5.809142990314028, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0030\"", 0.003, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-3.506557897319982, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0300\"", 0.03, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-6.502290170873972, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0015\"", 0.0015, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.199705077879927, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0150\"", 0.015, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.961845129926823, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0070\"", 0.007, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.659260036932778, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.0700\"", 0.07, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-6.812445099177812, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188182, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.6453910145146455`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.571283042360924, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.437751649736401, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.3771270279199666`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.319968614080018, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.2659013928097425`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.487387150331708, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.382026634673882, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.286716454869556, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.135166556742356, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.074541934925921, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.017383521085972, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.9633162998156966`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm]}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm]}, {-6.502290170873972, 
       FormBox["\"\"", TraditionalForm]}, {-4.199705077879927, 
       FormBox["\"\"", TraditionalForm]}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm]}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm]}, {-6.812445099177812, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.725433722188182, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.6453910145146455`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.571283042360924, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.437751649736401, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.3771270279199666`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.319968614080018, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.2659013928097425`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.487387150331708, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.382026634673882, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.286716454869556, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.135166556742356, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.074541934925921, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.017383521085972, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.9633162998156966`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.914122846632385`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.201804919084164`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.60727002719233, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.761420707019587`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.89495209964411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.012735135300492`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {13.815510557964274`, 
       FormBox["\"\"", TraditionalForm]}, {16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.002099841204238`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.156250521031495`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.289781913656018`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.407564949312402`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.611537753638338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {12.89921982609012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.304684934198283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.458835614025542`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.592367006650065`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.710150042306449`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.914122846632385`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.201804919084164`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.60727002719233, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.761420707019587`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.89495209964411, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.012735135300492`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->NCache[{{
      Log[100], 
      Log[10000000]}, {-6.567831280515279, -3.6896000317515543`}}, {{
    4.605170185988092, 
    16.11809565095832}, {-6.567831280515279, -3.6896000317515543`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {16.11809565095832, 
      FormBox[
       TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.002099841204238`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.156250521031495`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.289781913656018`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {11.407564949312402`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.611537753638338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {12.89921982609012, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.304684934198283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.458835614025542`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.592367006650065`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {13.710150042306449`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.508657738524219`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {14.914122846632385`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.201804919084164`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.424948470398375`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.60727002719233, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.761420707019587`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {15.89495209964411, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {16.012735135300492`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-6.907755278982137, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0010\"", 0.001, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.605170185988091, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0100\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-5.298317366548036, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0050\"", 0.005, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0500\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.214608098422191, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0020\"", 0.002, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-3.912023005428146, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0200\"", 0.02, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-5.809142990314028, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0030\"", 0.003, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-3.506557897319982, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0300\"", 0.03, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.502290170873972, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0015\"", 0.0015, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.199705077879927, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0150\"", 0.015, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.961845129926823, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0070\"", 0.007, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.659260036932778, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.0700\"", 0.07, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 4}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.812445099177812, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.725433722188182, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.6453910145146455`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.571283042360924, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.437751649736401, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.3771270279199666`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.319968614080018, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.2659013928097425`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.487387150331708, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.382026634673882, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.286716454869556, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.135166556742356, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.074541934925921, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.017383521085972, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.9633162998156966`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.575627904589658*^9, 3.586661088152465*^9, 
  3.588414921146905*^9, 3.588416631522168*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fige", "=", 
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    FractionBox["16", "R"], ",", 
    RowBox[{"{", 
     RowBox[{"R", ",", "5", ",", 
      SuperscriptBox["10", "4"]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4828305273929996`*^9, 3.4828305556949997`*^9}, {
   3.482831328304*^9, 3.482831335776*^9}, 3.4828317461219997`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwVxXk4lHkcAPDBsBOTGMz4jWPMK2lShEdtLd5vKpFos4hOyRG5ylVZu3iK
x6aelFLUJEWS5K6o3t9sSe42WznKg9oxWM1Rcgz2+OPzfPhBMd4hqjQazfM/
/y8IyOG74Bmyjnvw/carCvKVzd7szpYZUntT3pEH5xXkMQ3B1K7uGTI0qk3D
KktBvqjB7XHiGRJhe1tWooIM1pYlFTNnyRMh9IzB7QpS+MyrkxEwS26oLLZJ
UVOQLGtmcpd8lmzfLEmvj5CTc6qZf+4xnyOHY6MEgnUykvv0wq2BRwtk1mFR
tdfmcTJXJ+ua43kaRBU/P4VixaSHd/P9YyIVOCdscxTUDJF3jHN+PKSpBrZj
bnFvTHvJhYYLPsFOdNCThpWMLe4ip4f4I3q/qcP4gqZy+FQtaY7uQ/UrDYgX
F6yReNZSW5YmzO9RYUByccXIddsOSufhC7dGj0VAlx/0+n28h3rF2zFlkaoJ
J/N2D53eMkSJ8voif63QArektAdympgKuCyNzf7GhNvH3zRb8McpSaRTT/Fy
bRhuY4acHpVSRq3szqPxS8DfbJ1wf7aCwgVJmzl7dYCvHOW840xS0Y6pvsqv
OtCXwvQPS5qiYm50rnx0RRcGdF3r9mnOUpGxjxxS7Fnw2lPeE31kjmpUG1M3
6mOBdkENEmv9Q5nz8tdVpujBTvr6eJMOGs68JRZ6sPWBt6Tb2WdBBTt/PtaG
G/XhTNFUnrO7GpbduC1w9DMA+SJfH4df6Ljxg+94xYQBZKZVvePeU8e9H9zj
lTlseJZ2ZbRmUgN/2dJn7WXFgSnfhn0Byxl4f2Jl5Yk/ONBVHRpUHb8If1qp
cUkYbwi9PNaq2QZNHOI5Xf6SiaA/8Nsur3Et/L3d6tPtVQjSVoRy/BwW4+/S
6AVvPbjAe6m9NiJcG0t3+mv3DHNBmlBvEpW3BK/4IneryTACu7fxLTkxOjhw
2rIul2cMh/rLHOIYunhUdFOyvckY5LeWhVtX6OLoyUZP3UATSOxx7pS6sTCz
6id265QJ6Oe+vVQ6yMJzq21L9lw1Bbp+7bIfTulhCfdu2KQDD2TzqyTdpvrY
siVCFvaeBzblE7GuTfqY+sfns4Q0g4zhlXsrDxng0S6XebNsM+hLZySbqbCx
U3q3tGnADNJHBIERJWx8NtxOOWHFh6X1I4kNwMF/6+94mJPEh0GmhVylh4Pj
ilgBRS18+GxZamf+syGeDi5irWETMF3eXLzVAOHXA7Yq2RwCygvF6d84CN/z
F0mHDAkIylUPLOIiHLRtsP2MEQHtyRu5szyE2+1NM/8yI6BwK3X2zgqEC1Xz
lblWBLhJ6pMYgLBbYc6nL0DAZfMS9xcRCBNcfre7CwHbOE3LjkYhPH+hUnR9
IwGqWp/UTGMRrs7sEnq4EhCp4D9NSEDYOGZxwE0PAkB0zc4iFWGZU1aHtx8B
kn0XjU5eRLj1geHj0p0EXPWunba5jHCxbWnZgj8B3q7db/rzEd5l0ZxZtpuA
J6t0z9kXIvycqe6ieoCAc3PZ9I9lCAszclf7BxGwSXZ36Ow9hI/TlvIqDhKg
/Nj6dH0lwtZfXeYCQgkIbmMcP1+HMCP69dj9MAIMKUs/54cID48c6FUPJ6Cj
2tV+rAHhxwfkzbsjCEgrCdG59AThvP7U+qrDBKzNPzmxASP8L+i8Q34=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->NCache[{
     Log[5], -6.437751494615944}, {1.6094379124341003`, -6.437751494615944}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {8.517193191416238, 
       FormBox["5000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
          
          TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
      10.819778284410283`, 
       FormBox[
        TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
          
          TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
           SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
      2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {10.819778284410283`, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.308952660644293`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.596634733096073`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->NCache[{{
      Log[5], 
      Log[10000]}, {-6.437751494615944, 1.1631506546852226`}}, {{
    1.6094379124341003`, 9.210340371976184}, {-6.437751494615944, 
    1.1631506546852226`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{2.302585092994046, 
      FormBox["10", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {8.517193191416238, 
      FormBox["5000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"\[Times]", "\"\[Times]\"", "1", 
         TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
          SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
     10.819778284410283`, 
      FormBox[
       TemplateBox[{"\[Times]", "\"\[Times]\"", "5", 
         TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
          SuperscriptBox]}, "RowWithSeparators"], TraditionalForm]}, {
     2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.308952660644293`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {10.596634733096073`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.5756279047606792`*^9, 3.5866610882714877`*^9, 
  3.5884149213159304`*^9, 3.5884166316421933`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Reyc", "=", "3000"}], ";"}]], "Input",
 CellChangeTimes->{{3.484220035403691*^9, 3.4842200402059655`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"figa", ",", "figb", ",", "figc", ",", "fige", ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Dotted", ",", "Black", ",", 
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{"{", 
            RowBox[{"Reyc", ",", 
             SuperscriptBox["10", 
              RowBox[{"-", "7"}]]}], "}"}], "]"}], ",", 
          RowBox[{"Log", "[", 
           RowBox[{"{", 
            RowBox[{"Reyc", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}]}], "}"}],
      "]"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", 
     RowBox[{"1", "/", "GoldenRatio"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Re", ",", 
       SubscriptBox["C", "f"]}], "}"}]}]}], "]"}], "//", 
  "\[IndentingNewLine]", 
  RowBox[{"Figure", "[", "\"\<turbulence-pipefriction\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.390225359564786*^9, 3.390225386867786*^9}, {
   3.390225482523786*^9, 3.3902255526867857`*^9}, {3.390225726946786*^9, 
   3.390225747257786*^9}, {3.482659321843997*^9, 3.4826593449063168`*^9}, 
   3.4827591162076*^9, 3.4827591696205997`*^9, {3.4827592900236*^9, 
   3.4827593001156*^9}, {3.4827593474966*^9, 3.4827593785186*^9}, {
   3.4827601262616*^9, 3.4827601520006*^9}, {3.4827604495116*^9, 
   3.4827604634936*^9}, {3.4827606173936*^9, 3.4827606210456*^9}, {
   3.4827606639105997`*^9, 3.4827607249496*^9}, {3.482830635521*^9, 
   3.48283063608*^9}, {3.482830666415*^9, 3.482830713583*^9}, {
   3.482830777457*^9, 3.482830791826*^9}, {3.482831216847*^9, 
   3.482831218014*^9}, {3.4828314993459997`*^9, 3.48283158592*^9}, {
   3.482831652705*^9, 3.4828316596949997`*^9}, {3.482831731092*^9, 
   3.482831746141*^9}, 3.482834630481*^9, {3.4828986937418003`*^9, 
   3.4828986976558*^9}, 3.483077841554093*^9, {3.484219269659893*^9, 
   3.484219297164466*^9}, {3.484220046136305*^9, 3.4842201321702256`*^9}, {
   3.4842201975219636`*^9, 3.484220234143058*^9}, {3.5015064421781673`*^9, 
   3.5015064453603497`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Figure", "::", "noexport"}], "MessageName"], 
  RowBox[{":", " "}], "\<\"Image not exported\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5756279049157023`*^9, 3.5866610884244986`*^9, 
  3.5884149214839463`*^9, 3.5884166317952137`*^9}],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJzt1Ns71AkYB3CZhmHE+M3ZaUYxDTNiQqNW5m1LepaliLRRDrETmkyHFeXZ
TQ+rI6PpqEaSEorKoVQ7b2eqSVLMqkQ5FJWlNqUetr3af2AvXbzP9+a9+H5v
PvYxa4LjDA0MDEq/3b/5fpkwQxNKgmrBi1/jGh/JJi9f6lQ6iQIr5mUlbI+5
qo19bZrfQ6ICoWjvrwjs1Gaobhwa5pnDpgTfK/4977Q3BZSDtjNpkHf/Q0LF
0ffa11csZg2U0cAnLvPe9fiP2rqQZfX6JkvITpOLF1uNaI3JPrE5/QQ8z+q1
mC0Y05Kzl8jmF9JhiOP24tWAATp7jBm1eTMg07NqlYpmiPvSJZ6iawxwkgUc
SnQgoZdTuP+lRUxYf2hiv6PtRHwsTIo+UcuEkDET3VETMh58SbAkchYo780s
7I4zwmn7BHcWkNhwcIpybtcpYwwgC495Z7Oh08HzZU0JBeW/p4tKRtnQYX6g
RpdqgovPVzNCkjkgVLVktMWbor9l+9dHFC6IomRWJteo+CG8nuyeyoUZBVxx
Q44Z1vfW2bubWkHtoOeXrj2TcL5WZ9xbYQUNyX5+SY3mWKlJCosQWUPdgLpx
jtoC766+kXHjjDVYBJHKFD/R8Kyyu798qQ3M9j6xxbWThj7WgU3uZ2ygpYPo
tJ9viUeqBw9qh2xgYu1QoO60JZYkqKUWZ2xh64git4JPYG64LEK20g5WSn/1
uFNJII/Cz1/12A5SXNY8z6fR8X3NwytV0TxYZK+OOrOOjvoBO4VSz4M7Q5qq
lFY6xuVVip918cDs2tfpn0LpSGt26Rt8w4OndgVnu/cQ2HTb2Zc6zIMoXk7q
Ils6mp7K1F2YwIfe7ckVigACN7h3b9Qa8mGm+par4gOB4dI2gReVD5opDb94
7CSwsHotcZnGh40XvSKkjgR+Zq5doZzGh2d/ps7zFBF48nlJ2dc9fNDd/l7z
OYlAEu2jW8EwHzrdKQbGhQQ+Vippx2PsIS3TQfLHIwJf+Wt2VZMmw/6wlG2k
b33MQ5dJm/ZPBn1K5Nvy9XQsD22OnECdArqFIa8GztOR3CjXTaqaAu+SGn87
bMLANx2Kmgi1AyTbF825uZmBlxSDHj7ejiCx27wt0oiJvKvTeVEjjhByWG2d
JmFiaF9ox99nBXDhHkmVdYiJ1d59CcOxU2HYo2F2ZMe3/4j4EXOhEB6c5l55
yGXhZ/L95LdXhdDIOfdUvZCFs4o/lRvNcIJpPTYNYWtZqGHvDlLZOMPKF1Jp
0QUWln+pFXipnEEfE6SXd7DQbNLu9p0+IohsDbOoZLNRPnS/ILNOBK+zgsDX
h40e6QUMyyoHmP4Xc/ecLAZ+6TDAvXMdYfUs5dYN9QzsAlNrSqcj9HHqvGoI
Jm4MXZ7nkySAokRlYnoYE3ceF30oGxVAi3E7tKuZGN8rGv10aypQXc3T975h
Ym9gsYHpnP/23NrRzHCpFEKqt0v6+nksfPj8yI5Vfk4wRukTmK5jYXPwtu9K
W5xgMK9w86ZSFkbnu1z/GOsMM3wDHzxrZeG53JeNF81FoOq+s01NZ6PRSgdx
xWkR+KOvj9ifjQtO8jsEXmKQPtOPuKeyMWyq7FP/XTFke1HWxp9i49ybcuPk
JS5QfOPj4i9tbKSqL9X+2OMCkj006j5DDmb/sOFA1uFpIMuikrM9OegY608U
yVwh0LA1WhXPwXkPou2T6lwhoWBhe3AOB0efBvmZCdzAFY5pZJc5iGF6z3UK
NyAn9v0c3M7BaMThgQtukPu+iNxtxMUtAefnXh5zg+27xFH7RVykCj9TrnpJ
QN7p0Vbsx8W8epuxJzESSOt7ePlJOBfHPR33dNzTcU/HPf1/PP0HS+/BWg==

     "], {
      {GrayLevel[0], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 86], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 87], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 88], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 89], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 90], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 91], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 92], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 93], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 94], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 95], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 96], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 97], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 98], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 99], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 100], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 101], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 102], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 103], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 104], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 105], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 106], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 107], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 108], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 109], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 110], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 111], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 112], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 113], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 114], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 115], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 116], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 117], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 118], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 119], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 120], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 121], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 122], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 123], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 124], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 125], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 126], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 127], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 128], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 129], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 130], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 131], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 132], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 133], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 134], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 135], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 136], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 137], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 138], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 139], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 140], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 141], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 142], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 143], InsetBox[
        StyleBox["\[EmptyCircle]",
         StripOnInput->False,
         FontSize->Tiny], 144]}, 
      {GrayLevel[0], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 145], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 146], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 147], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 148], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 149], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 150], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 151], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 152], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 153], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 154], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 155], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 156], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 157], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 158], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 159], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 160], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 161], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 162], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 163], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 164], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 165], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 166], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 167], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 168], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 169], InsetBox[
        StyleBox["\[EmptyUpTriangle]",
         StripOnInput->False,
         FontSize->Tiny], 170]}, {}}], {}}, {{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwVz2s01AkYBnCpxGjSzBgz8w+DchnM5PLXUktvyO7aFQkpW26RTKjEpghd
OK3UzKxLp6iWtREzk5RWBi+dDmVbJ0Ka3ZImDdpltNpoaWc/vOc5v/N8eM5r
GZMSHKero6MToL3/83ZW1+N6IR0S9X2W2s8Y4PpjsTfbD9DBtyKF4zJngHhk
QfI4jQ61jSnz7p8M8GEqGaLJpkNU/oN1PgYUHN53dcCpiA6qbM2xr8woSAk7
opQr6JAV137HbDMFowR2r6VUBsjGl9mqf9D2L/I/1MgZEH5Uv8lMYIjB327w
GVnBBJzIcxpLWo6d5YT7kzATiOt28XybT8VFJozQ7RdY4DdJi/c+twIF1z8V
EzNsiJg1DY0tM8Izuuzc0vUEJJ1IMDT0W4mD6WtEIZdWgZKeqNfavhLHLf07
K2ZMIUal7jzoRkMH8aXq6+7mcK4nzPtaGQ13m76UTpdwwZRfd7R3GR1fuNUI
5pIt4LeT8XMte+k4fST5oo+RJUhrlZOCDjouPOCz+S2WEKu6rBJbMNByXleY
GmkF8fKCsF1pDPT06u3ZYbQaKGtPP59+xEAFIevSV6yGqjT+1XuWxhg8dKXE
eNca8IsVlXyTZIwvqwrS0dAapE893ucrjDE/pNDhgcwa3D82vCGWMNGGdmb6
YKQNDKRwn7kHMtFunzjg1XJbsFcfKqwqYeKmSnlWvcwWJMO0h1sHmbhtorON
u9sOuKPD1sJVJpjJfD8wvogHzq+t9MkdJqivdDpxvIIHNE3G5/wiEyyUxW28
GWQPdYHx0Yd7TZC358Zj73f2ML2neYFqyMJW25m01EoHMHI5m9jnx8LGPD/Z
/iBHkG+vqZ3PZuH9Tmlzh8YRdqapvl56i4WPTIyUv1zlg/mo52ZigoVvv8jr
MfQVgO4hV52tZmxMNqaE26oEoLHRo6cHsHHsr/zpEfFaoOqWJxTksLGln1o/
z3GCWdPAUZ6cjYubn2iGDjoBvc7qbtkwG0PFNuWqe04Q9Sx36BGVg+G3j0u2
GTtDZxT2e3hoPdwnkgidoT08ozVyLwdj/22Y/aRwhtDguaZiMQeFXLHQk+kC
XZX1vKRWDq4RHbZ9IXQBZWlbl2SMg2rNSIBc4QJNiWQQjUZgzc4tWYHGrjAk
Wb6Ss4HA9Fu+LPN4V+gYnPO6HE3g3xGbPgY1usKFDz9N3c0jMJmyQb2NSoKE
5x7tL9P2NW0bT+8m4cJE27iol0CrL797OBlJgnWuU55zH4FbRwWhO6NJUNgp
mL1ay6wuJ67dQ0L4KQcao5/AhEuZxUP7SPB3u5hRNEig8qzHBD+NhGIRSS/+
ncCOlIaSgQISlui5JheOEjhFFVpuKiRBZ2yLyPENgdw6q7racyQkjDT/3K11
plrcniMmYVf7+RsGYwSuiz7w1r6UhPt3A9xPT2j/DeZ7Z1eQIOgp5hydIvDp
lOrXsUoSWI7f57I1BOqdL9seUkVCPzH+R6PWMd2GSbxqEq7Au9R30wSa+o6X
9klJ6CgPZ+6fIdB/5EcrLzkJ5pmDFpT3BGbk7JBW3yBhsUGPRbXWA4qujqwG
ErwaBQuv/iFwSUROgPoWCbWci8rcDwS6zn72NLiRhO76U1LurHavdDKm5Q4J
Qdyp1BatRW7X/rRtIqFI97kgYo7A/wDFKzgt
      "]]}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVxXs0VAkcAGAcRM2Yced153rFMIMxcy/r2VZ+NBSnSVF5pK1Iz5VHqaXI
FutZrLRaqSYtG509m5TC0u+UtjKFyJ7DnKStjUpbjRIns+3uH9/5HBNSIpNM
jIyM1P/5/77HmdqmnQQsKc02U+ex8Xnl+M6IFALuP788aPMdG2fDolmv0wmI
CZqoe1nARtfL3mrXLAJ2TcWFFpawMbfwTc/pQgKqN/oX3Kxgo6dnUn9JHQGT
3pMWC86yseLQyqGkxwT89GgbS9bJxjUusjFxFA/M6NU842k29ue8/Tit5kOX
7trJ1AwrvDpVxvf3F0BLlYV7+UsrfDJiOzpiJwTtvN6yxPUcNNbd0swKRaAr
kqTqhzhY8kGVnPVZBOUlnhdIGRdZzqPKlE8kMNEndIItXOy9se2MVi+GJzlt
HyfOcdFw8LZN4RAFHsp+Yc0jLjqtCj7SPmADe/9kJl1trfEiHJsb0WELsfb5
/UfWWuO3mge+4bV2oG6pPHWvzBrD+R4xv1XbA0S9cnlx3xoP1MfnHz3kAPf2
+TU9mkNgZP3DgVeL58Pas90zv4YSWNiUtlDVNh/eScXK+DwCJ7UzjcsVjiDz
Xp802kFg7FtOJbfREeJCx2ODZwl8L7E+nGfvBLLRbasO+PKweJNmornGCfQ5
jHllBg+Do+sVVaQEejKb6/ObeUjHV+1xL5VAyKw8POI1D0U7hb6Zls7QevhV
45Scj95FuYZ9Oc5wu0JjtXcLH3dv2FTj/s4Zxgzcr3rP8PGXwL4rJ5JdwHTX
nR3mI3y0pd0HW564QHtSRpaAFGCBK5FSvkEKaQnbl5pEC5A3nDpqp5OCXztp
dLdSgA+r26LXrZBB1cmO9q09Avw+qSJstVYGU7kN3s9YQjwcuCbIEOgKb14X
X/RfKsQfHhzlxl1yhekWGbk1V4h1yWvj0pVuYJQ/b9HuTiG+IC0bF9S6Qe3w
s83R00J07Qnb0+ngDkE+ZuFiPxHWVGSo9JXusF9k49WcJkIvDjkxNEcOv6+Z
MJNdEOHN48ussvPkwPnRtOqbFyIskm/27ZuWgz6RkNdKSAzXsodG9npA/xdb
DzQkkKiQKKPO6j2ga8O+1mINiSHFAQO8LQpYycueWTJMYsyn/vtBTxUwpL07
NUyKUbM/uschRgmGeayPYVFinHs5sr6pWwle5y2fVpSKMWVKN/1PKA1JYStK
W7vFaLls5arZNhq80gv9r5lSKN3NXmjSQQPOGVO0m1GoOt0ttbhOQ8SpEEmn
OYW571WzvJs0JN8xseqyoHBaE/CzXEtDg332014WheMzToY4HQ2O2rSjY3wK
71z4cL71Ew3WzuueCV0ofP7HpWPXDTRoWluHxFIKTU1Sc259poGOIHttZRTO
9/jQMG7MgDprsNXJjcL4QykH35sxUNQXUaZUUPhQudmdZcWAcbZqQagPhYld
Nxw4HAbKiXN0mC+F+lhHAcFlwOG8sctyPwq5+SOfRQQDiwY6OZEBFC7XxQxK
hAxkugX8tX4RhbrUq91SEQMW16uGNy6mcIe5EN1IBqpWT/UmBlJY6DnQSFMM
XDnY3LY9iELRbU+Nlw0DKgFx8etgCuvjy4/72DIw0Jhal7KEQh/938X+dgwk
QG91uorCrgJ17pf2DLwbVJRnhFD4Lz90G+4=
      "]]}}, {{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwVxXk4lHkcAPDBsBOTGMz4jWPMK2lShEdtLd5vKpFos4hOyRG5ylVZu3iK
x6aelFLUJEWS5K6o3t9sSe42WznKg9oxWM1Rcgz2+OPzfPhBMd4hqjQazfM/
/y8IyOG74Bmyjnvw/carCvKVzd7szpYZUntT3pEH5xXkMQ3B1K7uGTI0qk3D
KktBvqjB7XHiGRJhe1tWooIM1pYlFTNnyRMh9IzB7QpS+MyrkxEwS26oLLZJ
UVOQLGtmcpd8lmzfLEmvj5CTc6qZf+4xnyOHY6MEgnUykvv0wq2BRwtk1mFR
tdfmcTJXJ+ua43kaRBU/P4VixaSHd/P9YyIVOCdscxTUDJF3jHN+PKSpBrZj
bnFvTHvJhYYLPsFOdNCThpWMLe4ip4f4I3q/qcP4gqZy+FQtaY7uQ/UrDYgX
F6yReNZSW5YmzO9RYUByccXIddsOSufhC7dGj0VAlx/0+n28h3rF2zFlkaoJ
J/N2D53eMkSJ8voif63QArektAdympgKuCyNzf7GhNvH3zRb8McpSaRTT/Fy
bRhuY4acHpVSRq3szqPxS8DfbJ1wf7aCwgVJmzl7dYCvHOW840xS0Y6pvsqv
OtCXwvQPS5qiYm50rnx0RRcGdF3r9mnOUpGxjxxS7Fnw2lPeE31kjmpUG1M3
6mOBdkENEmv9Q5nz8tdVpujBTvr6eJMOGs68JRZ6sPWBt6Tb2WdBBTt/PtaG
G/XhTNFUnrO7GpbduC1w9DMA+SJfH4df6Ljxg+94xYQBZKZVvePeU8e9H9zj
lTlseJZ2ZbRmUgN/2dJn7WXFgSnfhn0Byxl4f2Jl5Yk/ONBVHRpUHb8If1qp
cUkYbwi9PNaq2QZNHOI5Xf6SiaA/8Nsur3Et/L3d6tPtVQjSVoRy/BwW4+/S
6AVvPbjAe6m9NiJcG0t3+mv3DHNBmlBvEpW3BK/4IneryTACu7fxLTkxOjhw
2rIul2cMh/rLHOIYunhUdFOyvckY5LeWhVtX6OLoyUZP3UATSOxx7pS6sTCz
6id265QJ6Oe+vVQ6yMJzq21L9lw1Bbp+7bIfTulhCfdu2KQDD2TzqyTdpvrY
siVCFvaeBzblE7GuTfqY+sfns4Q0g4zhlXsrDxng0S6XebNsM+hLZySbqbCx
U3q3tGnADNJHBIERJWx8NtxOOWHFh6X1I4kNwMF/6+94mJPEh0GmhVylh4Pj
ilgBRS18+GxZamf+syGeDi5irWETMF3eXLzVAOHXA7Yq2RwCygvF6d84CN/z
F0mHDAkIylUPLOIiHLRtsP2MEQHtyRu5szyE2+1NM/8yI6BwK3X2zgqEC1Xz
lblWBLhJ6pMYgLBbYc6nL0DAZfMS9xcRCBNcfre7CwHbOE3LjkYhPH+hUnR9
IwGqWp/UTGMRrs7sEnq4EhCp4D9NSEDYOGZxwE0PAkB0zc4iFWGZU1aHtx8B
kn0XjU5eRLj1geHj0p0EXPWunba5jHCxbWnZgj8B3q7db/rzEd5l0ZxZtpuA
J6t0z9kXIvycqe6ieoCAc3PZ9I9lCAszclf7BxGwSXZ36Ow9hI/TlvIqDhKg
/Nj6dH0lwtZfXeYCQgkIbmMcP1+HMCP69dj9MAIMKUs/54cID48c6FUPJ6Cj
2tV+rAHhxwfkzbsjCEgrCdG59AThvP7U+qrDBKzNPzmxASP8L+i8Q34=
      "]]}}, 
   {GrayLevel[0], Dashing[{0, Small}], 
    LineBox[NCache[{{Log[3000], -Log[10000000]}, {Log[3000], 0}}, {{
       8.006367567650246, -16.11809565095832}, {8.006367567650246, 0}}]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["Re", TraditionalForm], 
    FormBox[
     SubscriptBox["C", "f"], TraditionalForm]},
  AxesOrigin->NCache[{
     Log[5], -Log[1000]}, {1.6094379124341003`, -6.907755278982137}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-6.907755278982137, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-5.298317366548036, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-4.605170185988092, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-2.302585092994046, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {0., 
       FormBox[
        TagBox[
         InterpretationBox["\"1.000\"", 1., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {1.6094379124341003`, 
       FormBox[
        TagBox[
         InterpretationBox["\"5.000\"", 5., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
        TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {-2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.6592600369327783`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659907, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {4.787491742782046, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.438079308923196, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.8289456176102075`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.1092475827643655`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.327936783729195, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.507277712385012, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.659293919683638, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.7912214627261855`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.392661928770137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.043249494911286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.4341158035983, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.714417768752456`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {10.933106969717286`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.112447898373103`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.26446410567173, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {11.396391648714276`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {13.997832114758229`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {14.648419680899378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.03928598958639, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.319587954740548`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.538277155705378`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.717618084361195`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {15.86963429165982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {16.00156183470237, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{1.6094379124341003`, 18.420680743952367`}, {-6.907755278982137,
    0.6931471805599453}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Prolog->{
    Dashing[{0, Small}], 
    LineBox[{{8, -7}, {8, 0}}]},
  Ticks->{{{2.302585092994046, 
      FormBox["\"10\"", TraditionalForm]}, {4.605170185988092, 
      FormBox[
       SuperscriptBox["\"10\"", "2"], TraditionalForm]}, {6.907755278982137, 
      FormBox[
       SuperscriptBox["\"10\"", "3"], TraditionalForm]}, {9.210340371976184, 
      FormBox[
       SuperscriptBox["\"10\"", "4"], TraditionalForm]}, {11.512925464970229`, 
      FormBox[
       SuperscriptBox["\"10\"", "5"], TraditionalForm]}, {13.815510557964274`, 
      FormBox[
       SuperscriptBox["\"10\"", "6"], TraditionalForm]}, {16.11809565095832, 
      FormBox[
       SuperscriptBox["\"10\"", "7"], TraditionalForm]}, {18.420680743952367`, 
      FormBox[
       SuperscriptBox["\"10\"", "8"], 
       TraditionalForm]}}, {{-6.907755278982137, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.001\"", 0.001, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-5.298317366548036, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-4.605170185988092, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.995732273553991, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-2.302585092994046, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-0.6931471805599453, 
      FormBox[
       TagBox[
        InterpretationBox["\"0.500\"", 0.5, AutoDelete -> True], 
        NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {0., 
      FormBox[
       TagBox[
        InterpretationBox["\"1.000\"", 1., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {1.6094379124341003`, 
      FormBox[
       TagBox[
        InterpretationBox["\"5.000\"", 5., AutoDelete -> True], NumberForm[#, {
          DirectedInfinity[1], 3}, NumberPadding -> {"", "0"}]& ], 
       TraditionalForm]}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.6592600369327783`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659907, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782628`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.575627905008711*^9, 3.58666108851551*^9, 
  3.588414921565959*^9, 3.588416631887227*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{968, 959},
WindowMargins->{{124, Automatic}, {Automatic, 15}},
ShowSelection->True,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1485, 35, 190, 3, 65, "Title"],
Cell[1678, 40, 240, 5, 41, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[1955, 50, 195, 4, 65, "Title"],
Cell[CellGroupData[{
Cell[2175, 58, 179, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[2379, 66, 99, 2, 41, "Input"],
Cell[2481, 70, 339, 9, 21, "Message"]
}, Open  ]],
Cell[2835, 82, 66, 1, 30, "Text"],
Cell[2904, 85, 1299, 41, 129, "Input"],
Cell[4206, 128, 73, 1, 30, "Text"],
Cell[4282, 131, 131, 4, 41, "Input"],
Cell[4416, 137, 76, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[4517, 142, 198, 6, 58, "Input"],
Cell[4718, 150, 706, 17, 41, "Output"]
}, Open  ]],
Cell[5439, 170, 75, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[5539, 175, 184, 5, 56, "Input"],
Cell[5726, 182, 194, 3, 41, "Output"]
}, Open  ]],
Cell[5935, 188, 84, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[6044, 193, 289, 9, 59, "Input"],
Cell[6336, 204, 706, 17, 41, "Output"]
}, Open  ]],
Cell[7057, 224, 91, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[7173, 229, 280, 7, 41, "Input"],
Cell[7456, 238, 681, 16, 41, "Output"]
}, Open  ]],
Cell[8152, 257, 152, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[8329, 263, 150, 4, 56, "Input"],
Cell[8482, 269, 188, 3, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8719, 278, 203, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[8947, 286, 59, 1, 41, "Input"],
Cell[9009, 289, 284, 8, 21, "Message"]
}, Open  ]],
Cell[9308, 300, 470, 9, 41, "Input"],
Cell[9781, 311, 160, 4, 41, "Input"],
Cell[CellGroupData[{
Cell[9966, 319, 798, 20, 43, "Input"],
Cell[10767, 341, 42502, 897, 251, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53306, 1243, 517, 14, 43, "Input"],
Cell[53826, 1259, 22747, 433, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76610, 1697, 760, 17, 62, "Input"],
Cell[77373, 1716, 255, 6, 21, "Message"],
Cell[77631, 1724, 44693, 931, 261, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[122373, 2661, 348, 6, 75, "Section"],
Cell[CellGroupData[{
Cell[122746, 2671, 121, 2, 41, "Input"],
Cell[122870, 2675, 290, 8, 21, "Message"]
}, Open  ]],
Cell[123175, 2686, 496, 16, 84, "Input"],
Cell[123674, 2704, 72, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[123771, 2709, 344, 11, 41, "Input"],
Cell[124118, 2722, 518, 12, 41, "Output"]
}, Open  ]],
Cell[124651, 2737, 66, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[124742, 2742, 342, 11, 41, "Input"],
Cell[125087, 2755, 520, 12, 41, "Output"]
}, Open  ]],
Cell[125622, 2770, 70, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[125717, 2775, 446, 14, 62, "Input"],
Cell[126166, 2791, 716, 17, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126919, 2813, 98, 1, 36, "Subsection"],
Cell[127020, 2816, 98, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[127143, 2821, 171, 4, 58, "Input"],
Cell[127317, 2827, 137, 2, 41, "Output"]
}, Open  ]],
Cell[127469, 2832, 92, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[127586, 2837, 327, 10, 41, "Input"],
Cell[127916, 2849, 728, 19, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[128693, 2874, 237, 4, 36, "Subsection"],
Cell[128933, 2880, 380, 10, 62, "Input"],
Cell[129316, 2892, 68, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[129409, 2897, 252, 8, 41, "Input"],
Cell[129664, 2907, 650, 16, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130351, 2928, 131, 3, 54, "Input"],
Cell[130485, 2933, 142, 2, 41, "Output"]
}, Open  ]],
Cell[130642, 2938, 90, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[130757, 2943, 135, 4, 41, "Input"],
Cell[130895, 2949, 140, 2, 41, "Output"]
}, Open  ]],
Cell[131050, 2954, 71, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[131146, 2959, 181, 6, 56, "Input"],
Cell[131330, 2967, 142, 2, 41, "Output"]
}, Open  ]],
Cell[131487, 2972, 67, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[131579, 2977, 167, 5, 41, "Input"],
Cell[131749, 2984, 140, 2, 41, "Output"]
}, Open  ]],
Cell[131904, 2989, 66, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[131995, 2994, 232, 8, 44, "Input"],
Cell[132230, 3004, 502, 12, 41, "Output"]
}, Open  ]],
Cell[132747, 3019, 76, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[132848, 3024, 106, 3, 44, "Input"],
Cell[132957, 3029, 140, 2, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[133170, 3039, 407, 7, 65, "Title"],
Cell[CellGroupData[{
Cell[133602, 3050, 138, 3, 75, "Section"],
Cell[CellGroupData[{
Cell[133765, 3057, 121, 2, 41, "Input"],
Cell[133889, 3061, 287, 8, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134213, 3074, 119, 1, 36, "Subsection"],
Cell[134335, 3077, 463, 7, 41, "Input"],
Cell[134801, 3086, 204, 5, 41, "Input"],
Cell[135008, 3093, 1228, 25, 41, "Input"],
Cell[CellGroupData[{
Cell[136261, 3122, 1048, 23, 41, "Input"],
Cell[137312, 3147, 84506, 2188, 250, "Output"]
}, Open  ]],
Cell[221833, 5338, 318, 9, 41, "Input"],
Cell[222154, 5349, 1734, 50, 129, "Input"],
Cell[CellGroupData[{
Cell[223913, 5403, 622, 18, 61, "Input"],
Cell[224538, 5423, 341, 7, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[224916, 5435, 1644, 31, 43, "Input"],
Cell[226563, 5468, 143, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[226743, 5475, 468, 11, 41, "Input"],
Cell[227214, 5488, 2867, 55, 255, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230118, 5548, 434, 12, 41, "Input"],
Cell[230555, 5562, 3024, 57, 258, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233616, 5624, 372, 10, 41, "Input"],
Cell[233991, 5636, 1398, 30, 255, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[235438, 5672, 125, 1, 36, "Subsection"],
Cell[235566, 5675, 624, 10, 41, "Input"],
Cell[CellGroupData[{
Cell[236215, 5689, 127, 2, 41, "Input"],
Cell[236345, 5693, 196, 4, 41, "Output"]
}, Open  ]],
Cell[236556, 5700, 250, 6, 41, "Input"],
Cell[CellGroupData[{
Cell[236831, 5710, 226, 6, 41, "Input"],
Cell[237060, 5718, 129, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237226, 5725, 248, 4, 41, "Input"],
Cell[237477, 5731, 14486, 274, 255, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[252012, 6011, 103, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[252140, 6016, 1188, 25, 41, "Input"],
Cell[253331, 6043, 16272, 432, 250, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[269640, 6480, 1149, 25, 82, "Input"],
Cell[270792, 6507, 259, 6, 21, "Message"],
Cell[271054, 6515, 109197, 2722, 395, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[380312, 9244, 188, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[380525, 9252, 184, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[380734, 9258, 59, 1, 41, "Input"],
Cell[380796, 9261, 285, 8, 21, "Message"]
}, Open  ]],
Cell[381096, 9272, 466, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[381587, 9283, 101, 1, 41, "Input"],
Cell[381691, 9286, 470, 9, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[382198, 9300, 134, 2, 41, "Input"],
Cell[382335, 9304, 180, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[382552, 9313, 71, 1, 41, "Input"],
Cell[382626, 9316, 126, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[382789, 9323, 175, 4, 54, "Input"],
Cell[382967, 9329, 781, 14, 86, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[383797, 9349, 182, 2, 36, "Subsection"],
Cell[383982, 9353, 204, 5, 41, "Input"],
Cell[384189, 9360, 594, 19, 41, "Input"],
Cell[CellGroupData[{
Cell[384808, 9383, 1686, 35, 65, "Input"],
Cell[386497, 9420, 50321, 1235, 263, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[436855, 10660, 1532, 35, 41, "Input"],
Cell[438390, 10697, 201, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[438628, 10706, 241, 4, 56, "Input"],
Cell[438872, 10712, 136, 2, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[439057, 10720, 150, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[439232, 10726, 948, 20, 43, "Input"],
Cell[440183, 10748, 13282, 263, 257, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[453502, 11016, 568, 10, 62, "Input"],
Cell[454073, 11028, 257, 6, 21, "Message"],
Cell[454333, 11036, 52934, 1265, 263, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[507328, 12308, 281, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[507634, 12317, 129, 2, 41, "Input"],
Cell[507766, 12321, 287, 8, 21, "Message"]
}, Open  ]],
Cell[508068, 12332, 959, 33, 128, "Input"],
Cell[CellGroupData[{
Cell[509052, 12369, 350, 10, 41, "Input"],
Cell[509405, 12381, 123, 2, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[509577, 12389, 200, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[509802, 12397, 59, 1, 41, "Input"],
Cell[509864, 12400, 283, 8, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510184, 12413, 49, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[510258, 12417, 154, 2, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[510437, 12423, 491, 13, 59, "Input"],
Cell[510931, 12438, 726, 23, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[511694, 12466, 267, 7, 41, "Input"],
Cell[511964, 12475, 811, 26, 76, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[512812, 12506, 172, 4, 41, "Input"],
Cell[512987, 12512, 245, 7, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[513269, 12524, 239, 6, 41, "Input"],
Cell[513511, 12532, 545, 16, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[514093, 12553, 426, 11, 41, "Input"],
Cell[514522, 12566, 794, 24, 61, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[515365, 12596, 104, 1, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[515494, 12601, 486, 13, 62, "Input"],
Cell[515983, 12616, 288, 8, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516308, 12629, 372, 10, 56, "Input"],
Cell[516683, 12641, 400, 13, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[517120, 12659, 140, 3, 41, "Input"],
Cell[517263, 12664, 284, 8, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[517584, 12677, 479, 12, 41, "Input"],
Cell[518066, 12691, 932, 28, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[519035, 12724, 251, 7, 41, "Input"],
Cell[519289, 12733, 1136, 37, 76, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[520498, 12778, 355, 6, 75, "Section"],
Cell[CellGroupData[{
Cell[520878, 12788, 121, 2, 41, "Input"],
Cell[521002, 12792, 309, 8, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[521348, 12805, 108, 1, 36, "Subsection"],
Cell[521459, 12808, 464, 7, 41, "Input"],
Cell[521926, 12817, 204, 5, 41, "Input"],
Cell[522133, 12824, 1228, 25, 41, "Input"],
Cell[523364, 12851, 318, 9, 41, "Input"],
Cell[CellGroupData[{
Cell[523707, 12864, 101, 2, 41, "Input"],
Cell[523811, 12868, 149, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[523997, 12875, 298, 7, 41, "Input"],
Cell[524298, 12884, 23483, 424, 257, "Output"]
}, Open  ]],
Cell[547796, 13311, 162, 3, 41, "Input"],
Cell[547961, 13316, 1734, 50, 129, "Input"],
Cell[CellGroupData[{
Cell[549720, 13370, 622, 18, 61, "Input"],
Cell[550345, 13390, 364, 7, 68, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[550746, 13402, 1644, 31, 43, "Input"],
Cell[552393, 13435, 169, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[552599, 13442, 179, 2, 41, "Input"],
Cell[552781, 13446, 162, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[552980, 13453, 486, 8, 41, "Input"],
Cell[553469, 13463, 163, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[553669, 13470, 239, 4, 56, "Input"],
Cell[553911, 13476, 159, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[554107, 13483, 503, 11, 43, "Input"],
Cell[554613, 13496, 20794, 393, 256, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[575456, 13895, 148, 2, 36, "Subsection"],
Cell[575607, 13899, 576, 12, 41, "Input"],
Cell[CellGroupData[{
Cell[576208, 13915, 1379, 23, 41, "Input"],
Cell[577590, 13940, 32551, 579, 257, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[610178, 14524, 766, 17, 43, "Input"],
Cell[610947, 14543, 27957, 502, 258, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[638941, 15050, 998, 21, 43, "Input"],
Cell[639942, 15073, 16948, 324, 262, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[656927, 15402, 377, 11, 41, "Input"],
Cell[657307, 15415, 163, 2, 41, "Output"]
}, Open  ]],
Cell[657485, 15420, 417, 12, 43, "Input"],
Cell[CellGroupData[{
Cell[657927, 15436, 1924, 40, 106, "Input"],
Cell[659854, 15478, 283, 6, 21, "Message"],
Cell[660140, 15486, 46307, 814, 397, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[706520, 16308, 179, 4, 65, "Title"],
Cell[CellGroupData[{
Cell[706724, 16316, 201, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[706950, 16324, 112, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[707087, 16329, 129, 2, 41, "Input"],
Cell[707219, 16333, 289, 8, 21, "Message"]
}, Open  ]],
Cell[707523, 16344, 185, 4, 41, "Input"],
Cell[707711, 16350, 871, 23, 56, "Input"],
Cell[CellGroupData[{
Cell[708607, 16377, 261, 5, 41, "Input"],
Cell[708871, 16384, 137, 2, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[709057, 16392, 99, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[709181, 16397, 1456, 30, 43, "Input"],
Cell[710640, 16429, 17427, 329, 257, "Output"]
}, Open  ]],
Cell[728082, 16761, 832, 19, 41, "Input"],
Cell[CellGroupData[{
Cell[728939, 16784, 1215, 24, 43, "Input"],
Cell[730157, 16810, 36533, 677, 256, "Output"]
}, Open  ]],
Cell[766705, 17490, 924, 23, 43, "Input"],
Cell[CellGroupData[{
Cell[767654, 17517, 879, 19, 62, "Input"],
Cell[768536, 17538, 261, 6, 21, "Message"],
Cell[768800, 17546, 27217, 512, 259, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[796090, 18066, 250, 5, 65, "Title"],
Cell[CellGroupData[{
Cell[796365, 18075, 190, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[796580, 18083, 59, 1, 41, "Input"],
Cell[796642, 18086, 288, 8, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[796967, 18099, 55, 0, 36, "Subsection"],
Cell[797025, 18101, 381, 6, 41, "Input"],
Cell[CellGroupData[{
Cell[797431, 18111, 135, 2, 41, "Input"],
Cell[797569, 18115, 191, 4, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[797809, 18125, 33, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[797867, 18129, 97, 1, 41, "Input"],
Cell[797967, 18132, 194, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[798198, 18141, 171, 4, 41, "Input"],
Cell[798372, 18147, 125, 2, 41, "Output"]
}, Open  ]],
Cell[798512, 18152, 465, 12, 102, "Input"],
Cell[CellGroupData[{
Cell[799002, 18168, 204, 5, 56, "Input"],
Cell[799209, 18175, 142, 2, 41, "Output"]
}, Open  ]],
Cell[799366, 18180, 153, 2, 30, "Text"],
Cell[799522, 18184, 443, 12, 43, "Input"],
Cell[799968, 18198, 1782, 50, 129, "Input"],
Cell[801753, 18250, 589, 19, 57, "Input"],
Cell[802345, 18271, 554, 15, 60, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[802936, 18291, 34, 0, 36, "Subsection"],
Cell[802973, 18293, 820, 23, 82, "Input"],
Cell[CellGroupData[{
Cell[803818, 18320, 472, 10, 41, "Input"],
Cell[804293, 18332, 2951, 54, 255, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[807281, 18391, 775, 16, 41, "Input"],
Cell[808059, 18409, 5453, 95, 252, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[813549, 18509, 152, 3, 41, "Input"],
Cell[813704, 18514, 8041, 138, 255, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[821794, 18658, 200, 3, 36, "Subsection"],
Cell[821997, 18663, 644, 19, 41, "Input"],
Cell[CellGroupData[{
Cell[822666, 18686, 682, 15, 41, "Input"],
Cell[823351, 18703, 17633, 443, 253, "Output"]
}, Open  ]],
Cell[840999, 19149, 766, 16, 55, "Input"],
Cell[841768, 19167, 638, 16, 56, "Input"],
Cell[CellGroupData[{
Cell[842431, 19187, 2189, 39, 41, "Input"],
Cell[844623, 19228, 398, 9, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[845058, 19242, 752, 15, 41, "Input"],
Cell[845813, 19259, 5126, 92, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[850976, 19356, 804, 16, 76, "Input"],
Cell[851783, 19374, 261, 6, 21, "Message"],
Cell[852047, 19382, 22852, 524, 260, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[874948, 19912, 147, 2, 36, "Subsection"],
Cell[875098, 19916, 410, 10, 41, "Input"],
Cell[CellGroupData[{
Cell[875533, 19930, 797, 20, 58, "Input"],
Cell[876333, 19952, 366, 11, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[876736, 19968, 429, 9, 56, "Input"],
Cell[877168, 19979, 139, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[877344, 19986, 251, 6, 57, "Input"],
Cell[877598, 19994, 140, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[877775, 20001, 263, 8, 56, "Input"],
Cell[878041, 20011, 138, 2, 41, "Output"]
}, Open  ]],
Cell[878194, 20016, 83, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[878302, 20021, 311, 8, 56, "Input"],
Cell[878616, 20031, 137, 2, 41, "Output"]
}, Open  ]],
Cell[878768, 20036, 142, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[878935, 20043, 223, 6, 41, "Input"],
Cell[879161, 20051, 127, 2, 41, "Output"]
}, Open  ]],
Cell[879303, 20056, 530, 14, 56, "Input"],
Cell[CellGroupData[{
Cell[879858, 20074, 1030, 20, 41, "Input"],
Cell[880891, 20096, 17711, 446, 253, "Output"]
}, Open  ]],
Cell[898617, 20545, 518, 13, 56, "Input"],
Cell[CellGroupData[{
Cell[899160, 20562, 447, 10, 41, "Input"],
Cell[899610, 20574, 5272, 93, 251, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[904919, 20672, 773, 23, 56, "Input"],
Cell[905695, 20697, 4436, 81, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[910168, 20783, 1109, 21, 76, "Input"],
Cell[911280, 20806, 259, 6, 21, "Message"],
Cell[911542, 20814, 27189, 601, 260, "Output"]
}, Open  ]],
Cell[938746, 21418, 102, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[938873, 21423, 518, 17, 79, "Input"],
Cell[939394, 21442, 141, 2, 41, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[939608, 21452, 241, 5, 65, "Title"],
Cell[CellGroupData[{
Cell[939874, 21461, 186, 4, 75, "Section"],
Cell[CellGroupData[{
Cell[940085, 21469, 121, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[940231, 21474, 59, 1, 41, "Input"],
Cell[940293, 21477, 308, 8, 21, "Message"]
}, Open  ]],
Cell[940616, 21488, 461, 7, 41, "Input"],
Cell[CellGroupData[{
Cell[941102, 21499, 133, 2, 41, "Input"],
Cell[941238, 21503, 523, 9, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[941798, 21517, 101, 1, 41, "Input"],
Cell[941902, 21520, 497, 9, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[942436, 21534, 134, 2, 41, "Input"],
Cell[942573, 21538, 197, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[942807, 21547, 384, 9, 41, "Input"],
Cell[943194, 21558, 50120, 902, 257, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[993363, 22466, 159, 2, 36, "Subsection"],
Cell[993525, 22470, 443, 12, 43, "Input"],
Cell[993971, 22484, 1782, 50, 129, "Input"],
Cell[995756, 22536, 141, 3, 43, "Text"],
Cell[995900, 22541, 757, 17, 56, "Input"],
Cell[CellGroupData[{
Cell[996682, 22562, 555, 12, 41, "Input"],
Cell[997240, 22576, 94253, 1568, 259, "Output"]
}, Open  ]],
Cell[1091508, 24147, 626, 16, 62, "Input"],
Cell[CellGroupData[{
Cell[1092159, 24167, 186, 3, 41, "Input"],
Cell[1092348, 24172, 17805, 316, 245, "Output"]
}, Open  ]],
Cell[1110168, 24491, 790, 19, 41, "Input"],
Cell[CellGroupData[{
Cell[1110983, 24514, 185, 3, 41, "Input"],
Cell[1111171, 24519, 18288, 321, 242, "Output"]
}, Open  ]],
Cell[1129474, 24843, 384, 11, 41, "Input"],
Cell[CellGroupData[{
Cell[1129883, 24858, 213, 3, 41, "Input"],
Cell[1130099, 24863, 26001, 450, 252, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1156137, 25318, 125, 2, 41, "Input"],
Cell[1156265, 25322, 202, 4, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1156516, 25332, 202, 3, 36, "Subsection"],
Cell[1156721, 25337, 333, 6, 41, "Input"],
Cell[CellGroupData[{
Cell[1157079, 25347, 174, 4, 41, "Input"],
Cell[1157256, 25353, 147, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1157440, 25360, 168, 4, 41, "Input"],
Cell[1157611, 25366, 148, 2, 41, "Output"]
}, Open  ]],
Cell[1157774, 25371, 214, 6, 41, "Input"],
Cell[1157991, 25379, 345, 10, 45, "Input"],
Cell[CellGroupData[{
Cell[1158361, 25393, 560, 17, 41, "Input"],
Cell[1158924, 25412, 215, 4, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1159188, 25422, 96, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[1159309, 25427, 449, 11, 41, "Input"],
Cell[1159761, 25440, 8224, 208, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1168022, 25653, 399, 10, 41, "Input"],
Cell[1168424, 25665, 5168, 92, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1173629, 25762, 917, 21, 76, "Input"],
Cell[1174549, 25785, 280, 6, 21, "Message"],
Cell[1174832, 25793, 13183, 288, 261, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1188064, 26087, 194, 3, 36, "Subsection"],
Cell[1188261, 26092, 250, 6, 41, "Input"],
Cell[1188514, 26100, 295, 8, 41, "Input"],
Cell[CellGroupData[{
Cell[1188834, 26112, 656, 18, 58, "Input"],
Cell[1189493, 26132, 351, 10, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1189881, 26147, 392, 6, 41, "Input"],
Cell[1190276, 26155, 157, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1190470, 26162, 378, 12, 56, "Input"],
Cell[1190851, 26176, 161, 2, 41, "Output"]
}, Open  ]],
Cell[1191027, 26181, 376, 10, 62, "Input"],
Cell[CellGroupData[{
Cell[1191428, 26195, 703, 17, 54, "Input"],
Cell[1192134, 26214, 8145, 206, 268, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1200316, 26425, 301, 9, 56, "Input"],
Cell[1200620, 26436, 1841, 55, 141, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1202498, 26496, 866, 24, 43, "Input"],
Cell[1203367, 26522, 9473, 165, 255, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1212877, 26692, 1051, 25, 76, "Input"],
Cell[1213931, 26719, 281, 6, 21, "Message"],
Cell[1214215, 26727, 17555, 364, 267, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1231831, 27098, 237, 5, 75, "Section"],
Cell[CellGroupData[{
Cell[1232093, 27107, 152, 3, 41, "Input"],
Cell[1232248, 27112, 315, 8, 21, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1232600, 27125, 205, 2, 36, "Subsection"],
Cell[1232808, 27129, 605, 13, 62, "Input"],
Cell[1233416, 27144, 424, 13, 43, "Input"],
Cell[CellGroupData[{
Cell[1233865, 27161, 2472, 60, 87, "Input"],
Cell[1236340, 27223, 30610, 691, 259, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1266999, 27920, 236, 3, 36, "Subsection"],
Cell[1267238, 27925, 582, 15, 43, "Input"],
Cell[1267823, 27942, 781, 22, 56, "Input"],
Cell[CellGroupData[{
Cell[1268629, 27968, 140, 2, 41, "Input"],
Cell[1268772, 27972, 161, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1268970, 27979, 620, 14, 59, "Input"],
Cell[1269593, 27995, 21147, 429, 252, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1290777, 28429, 542, 16, 43, "Input"],
Cell[1291322, 28447, 30744, 616, 245, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1322103, 29068, 418, 10, 56, "Input"],
Cell[1322524, 29080, 23864, 453, 247, "Output"]
}, Open  ]],
Cell[1346403, 29536, 141, 3, 41, "Input"],
Cell[CellGroupData[{
Cell[1346569, 29543, 2080, 43, 86, "Input"],
Cell[1348652, 29588, 285, 6, 21, "Message"],
Cell[1348940, 29596, 36321, 784, 259, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 0wpmM9T3NoWhTAKEKzIjjul8 *)
